/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(xb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function vb(wb){var r=wb.a;var s=r.buffer;r.grow=tb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=wb.abort;var M=NaN;var N=Infinity;var O=wb.b;var P=wb.c;var Q=wb.d;var R=wb.e;var S=wb.f;var T=wb.g;var U=wb.h;var V=wb.i;var W=wb.j;var X=wb.k;var Y=wb.l;var Z=wb.m;var _=wb.n;var $=wb.o;var aa=wb.p;var ba=wb.q;var ca=wb.r;var da=wb.s;var ea=wb.t;var fa=wb.u;var ga=wb.v;var ha=wb.w;var ia=wb.x;var ja=wb.y;var ka=wb.z;var la=wb.A;var ma=wb.B;var na=wb.C;var oa=wb.D;var pa=wb.E;var qa=wb.F;var ra=wb.G;var sa=wb.H;var ta=wb.I;var ua=wb.J;var va=wb.K;var wa=wb.L;var xa=wb.M;var ya=wb.N;var za=wb.O;var Aa=wb.P;var Ba=wb.Q;var Ca=wb.R;var Da=wb.S;var Ea=wb.T;var Fa=wb.U;var Ga=wb.V;var Ha=wb.W;var Ia=wb.X;var Ja=wb.Y;var Ka=wb.Z;var La=wb._;var Ma=wb.$;var Na=wb.aa;var Oa=wb.ba;var Pa=wb.ca;var Qa=wb.da;var Ra=wb.ea;var Sa=wb.fa;var Ta=wb.ga;var Ua=wb.ha;var Va=wb.ia;var Wa=wb.ja;var Xa=wb.ka;var Ya=wb.la;var Za=wb.ma;var _a=wb.na;var $a=wb.oa;var ab=wb.pa;var bb=wb.qa;var cb=wb.ra;var db=wb.sa;var eb=wb.ta;var fb=wb.ua;var gb=wb.va;var hb=wb.wa;var ib=wb.xa;var jb=5706928;var kb=0;var lb=0;var mb=0;
// EMSCRIPTEN_START_FUNCS
function Saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=C(0),da=0,ea=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=C(0),Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=C(0),Ma=0;ha=jb-32|0;jb=ha;a:{b:{ya=a+24604|0;g=ya;if(!v[g+16>>2]){break b}e=v[g+20>>2];if(e>>>0>4|!(1<<e&22)){break b}e=v[g+28>>2];if(e>>>0>4){break b}e=23>>>e&1;break a}e=0}if(!e){GL(ha+16|0,20656,20676,207);g=ha+16|0;f=jb-160|0;jb=f;m=Ub(f+120|0,38211);v[114578]=0;U(6,f+104|0,1,20681);e=v[114578];v[114578]=0;c:{d:{e:{f:{g:{if((e|0)!=1){v[114578]=0;U(3,f+136|0,m|0,f+104|0);e=v[114578];v[114578]=0;if((e|0)==1){break g}v[114578]=0;fa(2117,f+88|0,g|0,1,38204,f+136|0);e=v[114578];v[114578]=0;if((e|0)==1){break f}yb(f+136|0);yb(f+104|0);break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(f+136|0)}yb(f+104|0)}yb(m);S(a|0);L()}yb(m);jb=f+160|0}e=a+946300|0;n=a+906300|0;while(1){za=v[n>>2];if(!za){n=n+160|0;if((e|0)!=(n|0)){continue}}break}h:{if(!b){break h}n=v[a+480208>>2];if(n&512){break h}Ga=a+8204|0;Ha=a+1074328|0;Ia=a+393352|0;ra=a+12|0;Aa=a+1304392|0;m=v[a+1074380>>2];while(1){i:{if(m){break i}_=a;e=n|512;j:{if(n&256){break j}m=0;r=jb-32|0;jb=r;da=jb-16|0;jb=da;A=a;f=A;e=f+1074392|0;g=v[e>>2]+1|0;v[e>>2]=g;k:{l:{m:{if(wl(f)>>>0>g>>>0){break m}h=f+1074984|0;k=f+1074308|0;n=f+1304360|0;s=f+484344|0;I=f+484360|0;E=f+1074438|0;o=f+1074424|0;q=f+480210|0;while(1){i=0;n:{if(!v[f+1074396>>2]){break n}i=0;if(!(w[q|0]&8)){break n}i=v[f+480180>>2]==1}o:{if(v[f+480180>>2]!=2|(w[q|0]&8?0:v[f+1074428>>2])){break o}g=0;if(!x[f+480188>>1]){break o}while(1){v[(f+B(g,896)|0)+1075788>>2]=0;g=g+1|0;if(g>>>0<x[f+480188>>1]){continue}break}}v[f+1074400>>2]=0;v[f+1074392>>2]=0;v[f+1074396>>2]=0;v[f+1074424>>2]=v[f+1074428>>2];g=x[f+1074440>>1];u[f+1074438>>1]=g;if(!(w[f+480208|0]&32)){e=f;p:{if(oc(Vb(I))>>>0>g>>>0){g=x[rc(Vb(I),x[E>>1])>>1];break p}g=65535}u[e+1074436>>1]=g;q:{if(Ce(s)>>>0<=(g&65535)>>>0){break q}if(mh(_b(s,x[f+1074436>>1]))){break q}u[f+1074436>>1]=65534}if(x[f+1074436>>1]>=Ce(s)>>>0){while(1){r:{s:{t:{u:{if(x[f+1074436>>1]!=65535){e=x[E>>1];if(oc(Vb(I))>>>0>e>>>0){break u}}e=x[Vb(I)+28>>1];if(e){break s}e=x[E>>1];if(oc(Vb(I))>>>0<e>>>0){break t}g=x[E>>1];if(!g){break t}while(1){e=g;g=e-1|0;if(!g){break t}if(x[rc(Vb(I),g)>>1]!=65535){continue}break}break s}g=x[E>>1]+1|0;u[E>>1]=g;break r}e=0}u[f+1074438>>1]=e;v[f+480208>>2]=v[f+480208>>2]&-524289;v:{if(oc(Vb(I))>>>0<=(e&65535)>>>0){break v}while(1){if(x[rc(Vb(I),x[E>>1])>>1]!=65534){break v}e=x[E>>1]+1|0;u[E>>1]=e;if(oc(Vb(I))>>>0>(e&65535)>>>0){continue}break}}e=x[E>>1];w:{if(oc(Vb(I))>>>0<=e>>>0){break w}if(!np(Vb(I),x[E>>1])){break w}g=x[E>>1];break r}pj(n,1);break l}e=f;x:{if(oc(Vb(I))>>>0>(g&65535)>>>0){g=x[rc(Vb(I),x[E>>1])>>1];break x}g=65535}u[e+1074436>>1]=g;y:{if(Ce(s)>>>0<=(g&65535)>>>0){break y}if(mh(_b(s,x[f+1074436>>1]))){break y}u[f+1074436>>1]=65534}if(x[f+1074436>>1]>=Ce(s)>>>0){continue}break}}u[f+1074440>>1]=x[f+1074438>>1]}if(!dg(s,x[f+1074436>>1])){break l}if(y[f+1074424>>2]>=y[_b(s,x[f+1074436>>1])+12>>2]){v[o>>2]=0}if(v[f+480272>>2]==-1){e=0}else{e=(w[f+480208|0]&32)>>>5|0}if(i){g=n+12|0;if(nd(g)){g=-1}else{g=v[oj(g)>>2]}g=(g|0)!=v[o>>2]}else{g=0}z:{if(e|g){break z}if(!cN(n,x[E>>1],v[o>>2],1)){break z}e=v[f+480272>>2];if(e){if((e|0)>=1){v[f+480272>>2]=e-1}pj(n,1);dL(n,x[E>>1],v[o>>2]);break z}A:{if(w[q|0]&64){if(bN(n,E,o,1)){break A}u[f+1074438>>1]=0;u[f+1074440>>1]=0;v[f+1074424>>2]=0;v[f+1074428>>2]=0;e=w[I+16|0];if((e|0)>=(Nh(I)-1|0)){mp(I,0);pj(n,1);e=0;break k}mp(I,w[I+16|0]+1&255);pj(n,1);break A}pj(n,1);break l}g=0;while(1){pn((f+B(g,896)|0)+1074984|0,f,g&65535);g=g+1|0;if((g|0)!=256){continue}break}zL(f);v[f+1074416>>2]=v[f+480196>>2];v[f+1074420>>2]=v[f+480204>>2];v[f+1074444>>2]=v[f+480200>>2];u[f+1074440>>1]=x[f+1074438>>1];v[f+1074428>>2]=v[f+1074424>>2];g=n;j=oc(Vb(I));e=x[f+1074438>>1];if(j>>>0>e>>>0){Ja=f,Ka=x[rc(Vb(I),x[f+1074438>>1])>>1],u[Ja+1074436>>1]=Ka;e=x[f+1074438>>1]}dL(g,e&65535,v[f+1074424>>2]);if(!dg(s,x[f+1074436>>1])){break l}}e=v[f+1074424>>2]+1|0;v[f+1074428>>2]=e;B:{if(e>>>0<y[_b(s,x[f+1074436>>1])+12>>2]){break B}if(!(w[f+480208|0]&32)){u[f+1074440>>1]=x[f+1074438>>1]+1}v[f+1074428>>2]=0;Eb(da+8|0,k,63);if(!Cb(da+8|0)){break B}e=v[f+1074432>>2];v[f+1074432>>2]=0;v[f+1074428>>2]=e}e=Xe(_b(s,x[f+1074436>>1]),v[f+1074424>>2],0);g=x[f+480188>>1];if(g){l=(f+B(g,896)|0)+1074984|0;g=h;while(1){Eb(da+8|0,k,82);C:{if(!Cb(da+8|0)|w[g+827|0]!=1){break C}j=w[e+3|0];if((j|0)!=3?(j|0)!=2:0){break C}Ja=g,Ka=$f(f,w[g+822|0],v[g+768>>2],v[g+704>>2]),v[Ja+700>>2]=Ka}Eb(da+8|0,k,91);D:{if(!Cb(da+8|0)){break D}if(cg(e)){break D}if(!cg(g+810|0)|w[g+813|0]!=19){break D}j=w[g+815|0];if((j&240)!=208|y[f+1074416>>2]>(j&15)>>>0){break D}Ja=g,Ka=$f(f,w[g+810|0],v[g+768>>2],0),v[Ja+700>>2]=Ka}Eb(da+8|0,k,92);E:{if(!Cb(da+8|0)){break E}Eb(da,k,5);if(Cb(da)|v[f+1074416>>2]!=1|w[g+813|0]!=17){break E}v[f+1074420>>2]=B(w[g+815|0],1e4)}j=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[g+810|0]=j;t[g+811|0]=j>>>8;t[g+812|0]=j>>>16;t[g+813|0]=j>>>24;j=w[e+4|0]|w[e+5|0]<<8;t[g+814|0]=j;t[g+815|0]=j>>>8;j=v[g+676>>2];v[g+20>>2]=v[g+672>>2];v[g+24>>2]=j;v[g+88>>2]=v[g+88>>2]&-393217;Eb(da+8|0,k,21);if(!Cb(da+8|0)){t[g+851|0]=0}v[g+884>>2]=0;t[g+827|0]=0;e=e+6|0;g=g+896|0;if((l|0)!=(g|0)){continue}break}}e=f;g=f+1074412|0;F:{G:{j=f+484344|0;if(Kn(j,x[f+1074436>>1])){if(HM(_b(j,x[e+1074436>>1]))){break G}}v[e+1074408>>2]=v[e+480216>>2];e=v[e+480220>>2];break F}Ja=e+1074408|0,Ka=v[_b(j,x[e+1074436>>1])+16>>2],v[Ja>>2]=Ka;e=v[_b(j,x[e+1074436>>1])+20>>2]}v[g>>2]=e;if(!i){break m}e=v[f+1074416>>2]+1|0;v[f+1074392>>2]=e;if(wl(f)>>>0<=e>>>0){continue}break}}if(!v[f+1074416>>2]){v[f+1074416>>2]=1}e=v[f+480208>>2];H:{if(v[f+1074392>>2]){v[f+480208>>2]=e&-4097;if(v[f+480180>>2]&1048580|(w[f+480210|0]&32?0:v[f+480180>>2]==1)){break H}if(y[f+1074392>>2]>=wl(f)>>>0|y[f+1074392>>2]%(v[f+1074400>>2]+v[f+1074416>>2]>>>0)){break H}v[f+480208>>2]=v[f+480208>>2]|4096;break H}v[f+480208>>2]=e&-528385|4096}k=0;p=jb-32|0;jb=p;K=f+1074308|0;ba=f+480208|0;I=-1;H=65535;I:{if(!x[f+480188>>1]){q=-1;break I}T=f+1075821|0;R=f+1304392|0;V=f+1074376|0;q=-1;while(1){F=f+B(k,896)|0;N=F+1075799|0;i=w[N|0];s=F+1075797|0;M=w[s|0];l=F+1075798|0;Z=w[l|0];G=F+1075796|0;E=w[G|0];X=F+1075795|0;j=w[X|0];h=v[f+1074392>>2];g=v[f+1074400>>2];e=v[f+1074416>>2];Y=F+1075794|0;n=Fs(Y);$=F+1075856|0;t[$|0]=v[f+480208>>2]>>>12&1|w[$|0]&254;J=(h>>>0)%(e+g>>>0)|0;e=w[Y|0];if((e|0)==252){h=w[X|0];g=hy(Y);e=Ds(Y);J:{if(!h|h-251>>>0<5){break J}h=v[(f+B(h,160)|0)+906140>>2];if(!h){break J}nb[v[v[h>>2]+44>>2]](h,g,C(C(e>>>0)*C(.0010010009864345193)))}e=w[Y|0]}K:{if(M&255|z[F+1075868>>2]==C(0)?(e&255)!=251:0){break K}e=v[ba>>2]&4096;L:{if(!e){o=w[F+1075878|0];break L}o=w[X|0];t[F+1075878|0]=o}g=o&255;if(g-251>>>0<5|!g){break K}o=(f+B(g,160)|0)+906140|0;if(!v[o>>2]){break K}M:{if(!e){e=x[F+1075876>>1];break M}e=Bs(w[G|0],w[l|0]);u[F+1075876>>1]=e;ca=C(C(Bs(w[s|0],w[N|0])>>>0)*C(.0010010009864345193));z[F+1075872>>2]=ca;g=v[o>>2];Ja=F+1075868|0,La=C(C(ca-C(nb[v[v[g>>2]+48>>2]](g,e)))/C(wl(f)>>>0)),z[Ja>>2]=La}h=v[f+1074392>>2];g=wl(f);l=v[o>>2];if((g|0)==(h+1|0)){nb[v[v[l>>2]+44>>2]](l,e,z[F+1075872>>2]);break K}nb[v[v[l>>2]+100>>2]](l,e,z[F+1075868>>2])}l=F+1074984|0;N:{O:{P:{Q:{R:{if(!CM(w[Y|0])){if(w[ba+1|0]&16){break R}break Q}g=jb-16|0;jb=g;u[g+12>>1]=0;v[g+8>>2]=0;Rh(g+8|0);e=x[g+12>>1];t[l+814|0]=e;t[l+815|0]=e>>>8;e=v[g+8>>2];t[l+810|0]=e;t[l+811|0]=e>>>8;t[l+812|0]=e>>>16;t[l+813|0]=e>>>24;jb=g+16|0;j=0;E=0;Z=0;M=0;i=0;n=0;if(!(w[ba+1|0]&16)){break Q}o=0;break O}if(!j){j=0;break P}v[F+1075768>>2]=0;break P}tM(f,l)}g=M&255;if((g|0)==33){Eb(p+24|0,K,30);o=i>>>4|0;cy(f,k&65535,o+(i&15)|0,Cb(p+24|0));M=33;break O}o=0;if((M-19&255)>>>0>1){break O}S:{if(!(!(v[f+480180>>2]&16777250)|i)){i=w[F+1075837|0];break S}t[F+1075837|0]=i}h=i&240;if((h|0)==208){e=i&15;if(!e){if(v[f+480180>>2]&16777248){o=1;break O}if(v[f+480180>>2]!=2){break O}break N}T:{if(e>>>0<v[f+1074400>>2]+v[f+1074416>>2]>>>0){break T}Eb(p+24|0,K,14);if(!Cb(p+24|0)){break T}if(!j){break N}t[F+1075809|0]=j;break N}o=e;break O}if(!(w[ba+1|0]&16)){break O}e=19;U:{V:{W:{if(!((h|0)==96?(g|0)==19:0)){if((h|0)!=176){break V}e=20;if((g|0)!=20){break W}}Eb(p+24|0,K,77);if(!(!Cb(p+24|0)|!(v[(f+(k<<5)|0)+480280>>2]&1024))){M=e;break O}s=f;g=l;Q=0;N=jb-16|0;jb=N;M=i&15;X:{Y:{if(M){h=w[g+861|0];Z:{if(h){h=h-1|0;t[g+861|0]=h;if(h&255){break Z}Eb(N+8|0,s+1074308|0,16);if(!Cb(N+8|0)){h=-1;if(v[s+480180>>2]!=2){break X}}v[g+804>>2]=v[s+1074424>>2]+1;break Y}Eb(N+8|0,s+1074308|0,17);if(!(Cb(N+8|0)|v[s+480180>>2]&3|!x[s+480188>>1])){h=s+1074984|0;while(1){if(w[h+861|0]?(h|0)!=(g|0):0){break Y}h=h+896|0;Q=Q+1|0;if(x[s+480188>>1]>(Q&65535)>>>0){continue}break}}t[g+861|0]=M}h=v[g+804>>2];v[s+1074432>>2]=h;break X}v[g+804>>2]=v[s+1074424>>2]}h=-1}jb=N+16|0;g=h;_:{if((h|0)==-1){g=q;break _}$:{if((I|0)!=-1){Eb(p+24|0,K,68);I=Cb(p+24|0)?g:I;break $}I=-1}Eb(p+24|0,K,103);H=Cb(p+24|0)?-1:H}if(!x[f+480188>>1]|v[f+480180>>2]!=2){break U}s=F+1075845|0;q=F+1075788|0;M=0;while(1){h=f+B(M,896)|0;v[h+1075788>>2]=v[q>>2];t[h+1075845|0]=w[s|0];M=M+1|0;if(M>>>0<x[f+480188>>1]){continue}break}break U}M=19;break O}if((h|0)!=224|(v[f+1074396>>2]?v[f+480180>>2]&16777250:0)){break O}e=i&15;if(v[f+480180>>2]&2?!e:0){break O}v[f+1074396>>2]=e+1;break O}M=e;q=g}Q=M&255;g=(Q|0)==19&v[f+480180>>2]==16&(i&240)==208;ea=g?0:o;aa:{if(!ea|w[Y|0]!=255|w[G|0]!=2){break aa}Eb(p+24|0,K,74);if(!Cb(p+24|0)){break aa}t[G|0]=0}h=v[f+1074392>>2];Eb(p+24|0,K,72);ba:{if(Cb(p+24|0)){N=0;if(ea>>>0>=y[f+1074416>>2]){break ba}}Eb(p+24|0,K,88);N=(J|0)==(ea|0)|(h|0)==(ea|0);if(!(!ea|!Cb(p+24|0))){break ba}N=(h|0)==(ea|0)}Eb(p+24|0,K,44);if(Cb(p+24|0)){t[$|0]=w[$|0]&254|(J|0)==(ea|0)}$=i&15;h=g?$|144:i;Eb(p+24|0,K,66);n=(!ea|Cb(p+24|0)^1)&n;ca:{da:{if(!(v[f+1074392>>2]|(!j|!(v[ba>>2]&2097152)))){v[F+1075644>>2]=0;if(N){break da}if(!Kh(l)){break ca}t[F+1075809|0]=j;if(x[f+480190>>1]<j>>>0){break ca}e=f+B(j,104)|0;v[F+1075672>>2]=x[e+484410>>1];v[F+1075752>>2]=t[e+484417|0];break ca}if(!N){break ca}}i=w[Y|0];if(j){t[F+1075809|0]=j}ea:{fa:{if(!be(i)){break fa}Eb(p+24|0,K,67);if(!Cb(p+24|0)){break fa}e=v[F+1075756>>2];ga:{if(!j|n){break ga}ha:{if(x[f+480192>>1]){g=65535;if(x[f+480192>>1]<j>>>0){break ha}o=v[(f+(j<<2)|0)+900380>>2];if(!o){break ha}g=x[ed(o+236|0,i-1|0)>>1];break ha}g=j}g=g&65535;if(g>>>0>x[f+480190>>1]){break ga}e=t[vp(f,g)+36|0]}i=(e+i|0)-12>>>0>119?0:i;break ea}if(!(v[f+480180>>2]&25165856)|!x[f+480192>>1]){break ea}e=i;g=1;ia:{if(!e){break ia}g=be(e)}if(!g){break ea}e=j;if(!e){e=w[F+1075810|0]}if(!e|(v[(f+(e<<2)|0)+900380>>2]?x[f+480192>>1]>=e>>>0:0)){break ea}i=0;j=0}if(!((Q|0)!=25|h)){Eb(p+24|0,K,55);e=Cb(p+24|0);j=e?0:j;i=e?0:i}Eb(p+24|0,K,65);J=(j|0)!=0;o=!i;g=Cb(p+24|0);aa=1;ja:{if(v[f+480180>>2]&16777248){break ja}Eb(p+24|0,K,107);if(Cb(p+24|0)){break ja}Eb(p+16|0,K,85);aa=0;if(!Cb(p+16|0)){break ja}if(Kh(l)){break ja}aa=1;e=v[F+1075088>>2];if(!e){break ja}aa=De(e)^1}s=o&J;J=g&J;ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{if(!(v[f+480180>>2]&1048580)){break ra}sa:{if((i|0)!=255){break sa}if(!(j?0:!((Q|0)==13|(E&255)==1))){Eb(p+24|0,K,55);if(Cb(p+24|0)){break sa}}e=v[F+1075640>>2];if(t[e+60|0]&1?e:0){break sa}v[F+1075672>>2]=0;e=F+1075072|0;v[e>>2]=v[e>>2]|2097152;ta:{if(!(v[f+480208>>2]&4096)){break ta}Eb(p+24|0,K,86);if(!Cb(p+24|0)){break ta}v[e>>2]=v[e>>2]|4096}j=0;i=0;g=0;e=0;o=0;s=1;if(J){break la}break ka}Eb(p+24|0,K,59);if(!Cb(p+24|0)|v[ba>>2]&4096){break ra}g=w[F+1075803|0]-w[F+1075756|0]|0;if(!i){break pa}if(i>>>0>250){aa=0;J=1;g=0;break pa}if(!j){Eb(p+24|0,K,98);J=0;if(Cb(p+24|0)){break qa}}aa=1;J=1;break qa}g=0;o=0;if(!s){break na}break oa}g=i}n=0}Eb(p+24|0,K,65);if(!Cb(p+24|0)){break ma}i=g;o=1}e=i;g=o;s=1;if(J){break la}break ka}i=g;g=1;s=J}ua:{va:{if(!x[f+480192>>1]){if(x[f+480190>>1]<j>>>0){break ua}e=(f+B(j,104)|0)+484380|0;break va}e=v[F+1075088>>2];if(!e){break ua}}wa:{if(u[e+34>>1]<0){break wa}if(v[f+480180>>2]==2){if(!De(e)){break wa}}v[F+1075672>>2]=x[e+30>>1]}if(!s){break ua}$s(l,x[e+28>>1],f)}e=i;o=g}Eb(p+24|0,K,71);if(!(!j|!Cb(p+24|0))){t[F+1075843|0]=32}xa:{if(!x[f+480192>>1]){break xa}Eb(p+24|0,K,100);if(!j|!Cb(p+24|0)){break xa}if(be(e&255)){break xa}g=v[ba>>2];ya:{if(n){if(g&8){break ya}break xa}if(!(g&4)){break xa}}yl(l);v[F+1075680>>2]=65536;g=F+1075072|0;v[g>>2]=v[g>>2]|2097152}if(o){Eb(p+24|0,K,11);za:{if(Ja=!Cb(p+24|0),Ka=0,Ma=v[f+480180>>2]!=268435456,Ma?Ja:Ka){break za}Eb(p+24|0,K,87);i=0;if(Cb(p+24|0)){i=Kh(l)^1}if(x[f+480192>>1]){if((i^-1)&v[F+1075640>>2]==v[(f+(j<<2)|0)+900380>>2]|x[f+480192>>1]<j>>>0){break za}e=w[F+1075803|0];break za}if((i^-1)&v[F+1075088>>2]==((f+B(j,104)|0)+484380|0)|j>>>0>3999){break za}e=w[F+1075803|0]}Aa:{if(!x[f+480192>>1]|!(v[f+480180>>2]&1048588)){break Aa}yl(l);t[F+1075822|0]=0;v[F+1075764>>2]=0;v[F+1075680>>2]=65536;g=F+1075072|0;v[g>>2]=v[g>>2]&-2101249|2097152;Eb(p+24|0,K,86);if(!Cb(p+24|0)){break Aa}v[g>>2]=v[g>>2]&-2049}j=aa?j:0}W=e&255;Ba:{if(W>>>0<251){break Ba}Eb(p+24|0,K,50);Ca:{if(!j|!Cb(p+24|0)){break Ca}if(x[f+480192>>1]){if(x[f+480192>>1]<j>>>0){break Ca}i=(f+(j<<2)|0)+900380|0;if(!v[i>>2]){break Ca}g=F+1075805|0;if(!be(w[g|0])){break Ca}g=x[ed(v[i>>2]+236|0,w[g|0]-1|0)>>1]}else{g=j}g=g&65535;if(!g|g>>>0>x[f+480190>>1]){break Ca}g=f+B(g,104)|0;if(u[g+484414>>1]<0){break Ca}v[F+1075672>>2]=x[g+484410>>1]}Eb(p+24|0,K,100);if(Ja=Cb(p+24|0),Ka=0,Ma=v[ba>>2]&4,Ma?Ja:Ka){break Ba}j=0}Da:{if(!be(W)){break Da}t[F+1075808|0]=e;t[F+1075805|0]=e;if(!n){wM(f,k&65535,j,W,0)}g=F+1075780|0;e=u[g>>1];if(e){v[F+1075676>>2]=(e&32767)-1;if((e|0)<=-1){e=F+1075072|0;v[e>>2]=v[e>>2]|256}u[g>>1]=0}g=F+1075801|0;e=w[g|0];if(e){t[F+1075842|0]=e-1;t[g|0]=0}g=F+1075802|0;e=w[g|0];if(!e){break Da}t[F+1075841|0]=e-1;t[g|0]=0}Ea:{Fa:{Ga:{Ha:{Ia:{if(j){i=F+1075088|0;g=v[i>>2];dp(f,l,j,n,1,1);e=v[i>>2];Ja:{if(!e|!(w[e+35|0]&2)){break Ja}if(!rd(R)){break Ja}Os(v[R>>2],k&65535,v[i>>2]+68|0)}Ka:{if(v[f+480180>>2]==1){if(n){Eb(p+24|0,K,85);if(Cb(p+24|0)){break Ka}}t[F+1075809|0]=0;break Ka}Eb(p+24|0,K,50);if(Cb(p+24|0)){if(!be(W)){break Ka}}t[F+1075809|0]=0}Eb(p+24|0,K,42);if(Cb(p+24|0)){if(!be(W)|(g|0)==v[i>>2]){break Ha}break Ia}if(!(!(v[f+480180>>2]&16777248)|(g|0)==v[i>>2])){e=0;if(be(W)){break Ga}}Eb(p+24|0,K,107);La:{if(!Cb(p+24|0)|(g|0)==v[i>>2]){break La}if(!n){if(be(W)){break La}}e=F+1075060|0;if(y[e>>2]>=y[l+4>>2]){break La}v[e>>2]=0;break Ha}Eb(p+24|0,K,85);if(!Cb(p+24|0)){break Ha}if(!Kh(l)){break Ia}break Ha}if(!W){e=n;break Ea}g=0;J=F+1075809|0;Ma:{if(!w[J|0]){break Ma}if(!be(W)){break Ma}dp(f,l,w[J|0],n,v[F+1075088>>2]?0:!v[F+1075640>>2],!(v[f+480180>>2]&1048580));t[J|0]=0;g=1}e=n;break Fa}v[l>>2]=0;v[l+4>>2]=0}e=n}g=0;if(!W){break Ea}}n=F+1075088|0;i=v[n>>2];Na:{if(!i|!(w[i+35|0]&2)){break Na}if(!rd(R)){break Na}if(!g){if(xM(v[R>>2],k&65535)){break Na}}Os(v[R>>2],k&65535,v[n>>2]+68|0)}i=k&65535;Cs(f,l,W,e,!(v[f+480180>>2]&1048580),0,i);if(!(!e|(!j|!(v[f+480180>>2]&1048580)))){g=F+1075072|0;v[g>>2]=v[g>>2]|2097152;yl(l);t[F+1075822|0]=0;v[F+1075764>>2]=0}if(!(v[F+1075072>>2]&512)){break Ea}if(!rd(R)){break Ea}Oa:{switch(W-253|0){case 0:Eb(p+24|0,K,99);if(Cb(p+24|0)){break Ea}break;case 1:case 2:break Oa;default:break Ea}}uk(v[R>>2],i)}Pa:{Qa:{switch((E&255)-1|0){case 0:Z=Z>>>0<64?Z:64;v[F+1075672>>2]=Z<<2;g=F+1075072|0;v[g>>2]=v[g>>2]|2097152;break Pa;case 1:break Qa;default:break Pa}}zl(f,l,Z,6)}if(x[f+480192>>1]){aL(f,k&65535)}n=e}Eb(p+24|0,K,77);if(Ja=Cb(p+24|0),Ka=0,Ma=v[(f+(k<<5)|0)+480280>>2]&1024,Ma?Ja:Ka){break N}e=v[f+1074392>>2];Eb(p+24|0,K,75);Ra:{Sa:{Ta:{g=e>>>0>=ea>>>0;Ua:{if(!ea|!Cb(p+24|0)){break Ua}e=v[f+1074392>>2];if(!e){break Ta}g=1;if((e|0)!=(ea|0)){break Ua}g=!w[X|0]&(E&255)!=11}e=E&255;if(!g|e>>>0<3){break Ta}if((e|0)==11){gy(p+24|0,f,Y,ea);e=w[hc(p+24|0)|0];an(f,l,v[p+24>>2]);if(e){break Ra}j=11;break Sa}Eb(p+24|0,K,62);Va:{if(!(!Cb(p+24|0)|Z)){Z=0;j=0;Wa:{switch(e-8|0){case 0:break Va;case 1:break Wa;default:break Sa}}if(w[ba+1|0]&16){break Sa}v[F+1075676>>2]=0;break Sa}Eb(p+24|0,K,41);if(Cb(p+24|0)){break Va}if(Z){t[F+1075838|0]=Z;break Va}Z=w[F+1075838|0]}j=E;Xa:{switch(e-3|0){case 0:case 1:Ya:{Za:{if(Z){break Za}Eb(p+24|0,K,41);if(!Cb(p+24|0)){break Za}Z=w[F+1075838|0];if(Z){break Ya}Z=0;break Ta}t[F+1075838|0]=Z}dn(f,l,((e|0)==3?Z<<4:Z)&255);break Ta;case 2:if((ea|0)!=v[f+1074392>>2]){Eb(p+24|0,K,41);j=5;if(Cb(p+24|0)){break Sa}}Eb(p+24|0,K,41);bp(f,l,Z,Cb(p+24|0));j=5;break Sa;case 3:if((ea|0)!=v[f+1074392>>2]){Eb(p+24|0,K,41);j=6;if(Cb(p+24|0)){break Sa}}Eb(p+24|0,K,41);ap(f,l,Z,Cb(p+24|0));j=6;break Sa;case 4:Eb(p+24|0,K,53);if(Cb(p+24|0)){t[F+1075827|0]=Z&15;j=7;break Sa}rk(l,Z<<4);j=7;break Sa;case 5:rk(l,Z);j=8;break Sa;case 6:Eb(p+24|0,K,62);by(f,l,Z,Cb(p+24|0)^1);j=9;break Sa;case 7:Eb(p+24|0,K,62);by(f,l,Z<<4&240,Cb(p+24|0)^1);j=10;break Sa;case 9:j=12;Eb(p+24|0,K,12);sM(f,k&65535,Z<<2&252,Cb(p+24|0));break Sa;case 10:Eb(p+24|0,K,12);rM(f,k&65535,Z<<2&252,Cb(p+24|0));j=13;break Sa;case 12:break Xa;default:break Sa}}j=15;if(!N|Z>>>0>9){break Sa}e=v[F+1075088>>2];if(!e){break Sa}_a:{if(!Z){o=v[F+1075648>>2];break _a}o=v[(e+(Z<<2)|0)- -64>>2];v[F+1075648>>2]=o}cp(f,l,o);break Sa}j=E}$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{switch(Q-1|0){case 12:if(!(w[ba+1|0]&16)){break Ra}e=f+B(k,896)|0;v[e+1075672>>2]=h>>>0<64?h<<2:256;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Ra;case 1:if(v[f+480180>>2]&1?!h:0){break xb}sM(f,k&65535,h,0);break Ra;case 2:if(v[f+480180>>2]&1?!h:0){break xb}rM(f,k&65535,h,0);break Ra;case 10:if(v[f+480180>>2]==1?!h:0){break xb}dn(f,l,h);break Ra;case 3:an(f,l,h);break Ra;case 5:if(!(v[f+480180>>2]==1?!h:0)){dn(f,l,h)}an(f,l,0);break Ra;case 4:rk(l,h);break Ra;case 6:if(!(v[f+480180>>2]==1?!h:0)){dn(f,l,h)}rk(l,0);break Ra;case 15:if(!(w[ba+1|0]&16)){break Ra}break $a;case 16:Eb(p+24|0,K,5);if(Cb(p+24|0)){if(!h){break Ra}if(v[ba>>2]&4096){break $a}break Ra}h=ep(f,x[f+1074436>>1],v[f+1074424>>2],k&65535,0);zb:{if(!(v[f+480180>>2]&16777250)){break zb}if(h){t[(f+B(k,896)|0)+1075839|0]=h;break zb}h=w[(f+B(k,896)|0)+1075839|0]}v[p+24>>2]=B(h,1e4);Cc(p+24|0,B(v[v[f+8>>2]+24>>2],1e4));o=jb-16|0;jb=o;g=v[p+24>>2];v[o+8>>2]=g;e=f;j=v[f+8>>2];Ab:{if(g>>>0>=(v[f+480180>>2]&16392?1e4:32e4)>>>0){g=v[e+480208>>2];Eb(o,e+1074308|0,92);if((Cb(o)|0)==((g&4096)>>>12|0)){break Ab}v[o>>2]=B(v[j+24>>2],1e4);Ja=e+1074420|0,Ka=v[Lb(o+8|0,o)>>2],v[Ja>>2]=Ka;break Ab}if(w[e+480209|0]&16){break Ab}n=e+1074420|0;i=(g>>>0)/1e4|0;g=B(i&15,1e4);v[n>>2]=v[n>>2]+((i&240)==16?g:0-g|0);i=v[j+20>>2];g=v[j+24>>2];Eb(o,e+1074308|0,8);Yn(n,B(i,1e4),Cb(o)?255e4:B(g,1e4))}jb=o+16|0;break Ra;case 9:if(!N|(v[f+480180>>2]==4?n:0)){break Ra}t[p+24|0]=0;i=ep(f,x[f+1074436>>1],v[f+1074424>>2],k&65535,p+24|0);g=f;e=l;if(!w[p+24|0]){n=(f+B(k,896)|0)+1075648|0;j=i<<8;Bb:{if(j){v[n>>2]=j;break Bb}j=v[n>>2]}i=(w[(f+B(k,896)|0)+1075840|0]<<16)+j|0}cp(g,e,i);break Ra;case 40:if(!N){break Ra}e=Fma(v[(f+B(k,896)|0)+1075060>>2],0,h,0);g=mb;i=g>>>8|0;cp(f,l,id((g&255)<<24|e>>>8,i));break Ra;case 0:if(v[f+1074392>>2]){break Ra}e=f+B(k,896)|0;Cb:{if(w[e+1075803|0]?v[e+1075684>>2]:0){break Cb}e=v[e+1075640>>2];if(e){if(zi(e)){break Cb}}Eb(p+24|0,K,13);if(Cb(p+24|0)){break Cb}if(v[f+480180>>2]&16777248){break Ra}}if(!h){h=0;if(v[f+480180>>2]&5){break Ra}t[(f+B(k,896)|0)+1075811|0]=1;break Ra}e=f+B(k,896)|0;t[e+1075812|0]=h;t[e+1075811|0]=1;break Ra;case 14:if(v[f+480180>>2]&1048580){h=h&240?h:x[(f+B(k,896)|0)+1075784>>1]&240|h;if(!(h&15)){h=x[(f+B(k,896)|0)+1075784>>1]&15|h}h=h|256}Eb(p+24|0,K,23);if(Cb(p+24|0)){Db:{if(!h){o=x[(f+B(k,896)|0)+1075784>>1];break Db}o=h&255;u[(f+B(k,896)|0)+1075784>>1]=o}ay(f,k&65535,o<<16>>16,(j&255)==15?Z+1|0:0);break Ra}Eb:{if(h){u[(f+B(k,896)|0)+1075784>>1]=h&255;break Eb}h=u[(f+B(k,896)|0)+1075784>>1]}ay(f,k&65535,h,(j&255)==15?Z+1|0:0);break Ra;case 39:break db;case 38:break eb;case 34:case 35:case 36:case 37:break fb;case 13:break gb;case 11:break hb;case 29:break ib;case 26:break jb;case 21:break kb;case 20:break lb;case 27:break mb;case 24:break nb;case 19:break ob;case 18:break pb;case 25:break qb;case 7:break rb;case 28:break sb;case 8:break tb;case 23:break ub;case 22:break vb;case 17:break yb;default:break Ra}}if(!(w[ba+1|0]&16)){break Ra}Eb(p+24|0,K,22);Fb:{Gb:{if(Cb(p+24|0)){if(!h){h=0;break Gb}if(w[ba|0]&4){break Gb}e=h&240?h-16|0:h;h=e-((e&15)!=0)|0;break Gb}Eb(p+24|0,K,71);if(!Cb(p+24|0)){break Fb}}e=(f+B(k,896)|0)+1075843|0;t[e|0]=w[e|0]|128}e=f+B(k,896)|0;t[e+1075811|0]=18;if(h){break wb}}h=0;break Ra}t[e+1075844|0]=h;break Ra}if(!(w[ba+1|0]&16)){break Ra}h=h<<!(v[f+480180>>2]&59593760);if(h>>>0<=128){v[f+1074444>>2]=h<<1;break Ra}if(v[f+480180>>2]&16777250){break Ra}v[f+1074444>>2]=256;break Ra}Eb(p+24|0,K,9);if(Cb(p+24|0)){qM(f,h,(f+B(k,896)|0)+1075821|0);break Ra}qM(f,h,T);break Ra}if(!(w[ba+1|0]&16)){break Ra}zl(f,l,h,8);break Ra}by(f,l,h,1);break Ra}JM(l,h);break Ra}KM(f,l,h);break Ra}e=h;o=e&15;i=f;j=k&65535;g=f+B(j,896)|0;n=g+1074984|0;Hb:{Ib:{switch(e>>>4|0){case 0:if(!x[i+480188>>1]){break Hb}n=(e&1)<<14;g=0;while(1){e=(i+B(g,896)|0)+1075072|0;v[e>>2]=(n|v[e>>2]&-16385)^16384;g=g+1|0;if(g>>>0<x[i+480188>>1]){continue}break};break Hb;case 1:if(v[i+480180>>2]&1048580?0:!o){break Hb}hM(i,n,o);break Hb;case 2:if(v[i+480180>>2]&1048580?0:!o){break Hb}fM(i,n,o);break Hb;case 3:e=g+1075072|0;v[e>>2]=v[e>>2]&-1048577|((o|0)!=0)<<20;break Hb;case 4:t[g+1075826|0]=e&7;break Hb;case 5:if(!(w[i+480209|0]&16)){break Hb}if(v[i+480180>>2]&69206025){n=i+B(j,896)|0;g=n+1075752|0;v[g>>2]=o<<28>>24;e=n+1075684|0;if(!v[e>>2]){break Hb}if(!cg(n+1075794|0)){break Hb}n=e;e=i+B(j,896)|0;Ja=n,Ka=$f(i,w[e+1075803|0],v[g>>2],v[e+1075688>>2]),v[Ja>>2]=Ka;break Hb}g=v[i+480180>>2];n=cg((i+B(j,896)|0)+1075794|0);if((g|0)==16){if(!n){break Hb}g=i+B(j,896)|0;e=v[g+1075088>>2];if(!e){break Hb}t[e+37|0]=o;v[g+1075752>>2]=o;e=g+1075684|0;if(!v[e>>2]){break Hb}g=e;e=i+B(j,896)|0;Ja=g,Ka=$f(i,w[e+1075803|0],o,v[e+1075688>>2]),v[Ja>>2]=Ka;break Hb}if(!n){break Hb}n=i+B(j,896)|0;g=e<<28>>24^-128;v[n+1075752>>2]=g;e=n+1075684|0;if(!v[e>>2]){break Hb}Ja=e,Ka=$f(i,w[n+1075803|0],g,v[n+1075688>>2]),v[Ja>>2]=Ka;break Hb;case 7:t[g+1075829|0]=e&7;break Hb;case 8:if(!(w[i+480209|0]&16)){break Hb}zl(i,n,o,4);break Hb;case 9:ay(i,j,o,0);break Hb;case 10:if(v[i+480180>>2]&1048580?0:!o){break Hb}bp(i,n,o,0);break Hb;case 11:if(v[i+480180>>2]&1048580?0:!o){break Hb}ap(i,n,o,0);break Hb;case 12:cy(i,j,o,0);break Hb;case 15:break Ib;default:break Hb}}if(v[i+480180>>2]==1){t[(i+B(j,896)|0)+1075850|0]=o;if(!(w[i+480209|0]&16)){break Hb}tM(i,n);break Hb}t[(i+B(j,896)|0)+1075848|0]=o}break Ra}Eb(p+24|0,K,78);e=f;g=k&65535;if(!(!Cb(p+24|0)|h)){h=w[(f+B(k,896)|0)+1075812|0]}pM(e,g,h);break Ra}Eb(p+24|0,K,55);if(Cb(p+24|0)){if(v[f+1074392>>2]!=(h|0)){break Ra}e=v[(f+B(k,896)|0)+1075640>>2];if(t[e+60|0]&1?e:0){break ab}if(!((w[G|0]?0:!w[X|0])|h)){e=(f+B(k,896)|0)+1075072|0;v[e>>2]=v[e>>2]|4096;break ab}e=f+B(k,896)|0;v[e+1075672>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break ab}if(w[ba+1|0]&16){break ab}break Ra}e=(h&240)-16>>>4|0;if(e>>>0>9){break Ra}if(!(1<<e&880)){if(!e){break cb}if((e|0)!=1){break Ra}oM(f,l,h&15);break Ra}Eb(p+24|0,K,58);if(Cb(p+24|0)){break Ra}pM(f,k&65535,h);break Ra}if(!(v[ba>>2]&4096)|h>>>0>64){break Ra}e=f+B(k,896)|0;v[e+1075744>>2]=h;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Ra}g=f;i=l;e=h;Jb:{if(e){t[i+836|0]=e;break Jb}e=w[i+836|0]}j=e&255;n=e&240;o=e&15;Kb:{Lb:{if(!(!n|(o|0)!=15)){if(!(w[g+480209|0]&16)){break Kb}e=j>>>4|0;if(e){break Lb}break Kb}e=v[g+480208>>2]&4096;if(!(!o|(n|0)!=240)){if(!e){break Kb}e=0-o|0;break Lb}if(e){break Kb}if(o){e=0-o|0;if(!n|!(v[g+480180>>2]&25690144)){break Lb}break Kb}e=j>>>4|0;if(!e){break Kb}}Ja=i,Ka=Yb(v[i+760>>2]+e|0,0,64),v[Ja+760>>2]=Ka}break Ra}IM(l,h);break Ra}if(!(w[ba+1|0]&16)){break Ra}e=f+B(k,896)|0;v[e+1075712>>2]=h;Eb(p+24|0,K,60);if(Ja=0,Ka=Cb(p+24|0),Ma=w[e+1075708|0]&4,Ma?Ja:Ka){break Ra}e=f+B(k,896)|0;v[e+1075736>>2]=h;v[e+1075724>>2]=h;break Ra}v[f+1074432>>2]=0;H=ep(f,x[f+1074436>>1],v[f+1074424>>2],k&65535,0);I=(I|0)!=-1?v[f+480180>>2]&5?0:I:I;break Ra}e=LM(f,V,k&65535,h);if((e|0)==-1){break Ra}if(!(w[ba|0]&32)){break bb}H=x[f+1074438>>1];break bb}i=l;g=h;e=M&255;j=(e|0)==35|(e|0)==37;n=(M-37&255)>>>0<2;e=f;Mb:{if(w[f+480209|0]&16){if((g&255)>>>0>=16){t[i+869|0]=(g&240)>>>4}e=g&15;if(e){t[i+870|0]=e}t[i+868|0]=w[i+869|0];break Mb}g=w[i+868|0]-1|0;t[i+868|0]=g;Nb:{if(g&255){break Nb}t[i+868|0]=w[i+869|0];g=w[i+870|0];g=j?g:0-g|0;Ob:{if(tj(i)){v[i+876>>2]=v[i+876>>2]+B(g,v[v[v[i+656>>2]+44>>2]+36>>2]);break Ob}Ja=i,Ka=$f(e,ws(e,v[i+700>>2],0,0)+g|0,8363,0),v[Ja+700>>2]=Ka}if(!n){break Nb}v[i>>2]=0;v[i+4>>2]=0}}break Ra}GM(p,l,h);break Ra}if(v[f+1074392>>2]|$>>>0>2|h>>>0>31){break Ra}j=k;E=k;if((h&240)==16){E=x[f+480188>>1]-1|0;j=0}while(1){i=j&65535;e=(f+(i<<5)|0)+480280|0;g=v[e>>2];Pb:{if(($|0)==1){M=v[(f+B(i,896)|0)+1075072>>2]|67108864;g=g|67108864;break Pb}M=v[(f+B(i,896)|0)+1075072>>2]&-67108865;g=g&-67108865}v[e>>2]=g;v[(f+B(i,896)|0)+1075072>>2]=M;j=j+1|0;if((j&65535)>>>0<=(E&65535)>>>0){continue}break}break Ra}nM(f,l,h&15);break Ra}I=e;break Ra}cn(f,l);break Ra}MM(f,V,h)}Eb(p+24|0,K,78);if(!(!h|!Cb(p+24|0))){e=h&255;t[l+860|0]=e;t[l+832|0]=e;t[l+831|0]=e;t[l+829|0]=e;t[l+828|0]=e;u[l+800>>1]=e;t[l+846|0]=e>>>4;t[l+847|0]=e<<2&60}e=w[X|0];if(!e){break N}t[F+1075810|0]=e}k=k+1|0;if(k>>>0<x[f+480188>>1]){continue}break}}Qb:{if(!(w[ba+1|0]&16)){break Qb}Rb:{if(!((H&65535)!=65535|(I|0)!=-1)){if((q|0)==-1){break Qb}break Rb}Sb:{if((q|0)==-1){break Sb}Eb(p+24|0,K,68);if(Cb(p+24|0)){break Sb}Eb(p+16|0,K,103);e=(H&65535)==65535;if(Cb(p+16|0)?!e:0){break Sb}Eb(p+8|0,K,49);if(e|!Cb(p+8|0)){break Rb}}H=(H&65535)==65535?x[f+1074438>>1]+1|0:H;v[f+480208>>2]=v[f+480208>>2]|524288;e=f+484360|0;if(oc(Vb(e))>>>0<=(H&65535)>>>0){H=x[Vb(e)+28>>1]}g=(I|0)==-1?0:I;Tb:{if(x[f+1074438>>1]==(H&65535)){break Tb}Eb(p+24|0,K,26);if(Cb(p+24|0)){break Tb}Eb(p+16|0,K,68);if(Cb(p+16|0)|v[f+480180>>2]==1|!x[f+480188>>1]){break Tb}e=0;while(1){t[(f+B(e,896)|0)+1075845|0]=0;e=e+1|0;if(e>>>0<x[f+480188>>1]){continue}break}}v[f+1074428>>2]=g;if(w[f+480208|0]&32){break Qb}u[f+1074440>>1]=H;break Qb}u[f+1074440>>1]=x[f+1074438>>1];v[f+1074428>>2]=q;Ub:{if(!v[f+1074396>>2]){break Ub}if(v[f+480180>>2]==32){Eb(p+24|0,K,103);if(Cb(p+24|0)){break Ub}}if(v[f+480180>>2]==2){break Ub}v[f+1074428>>2]=v[f+1074428>>2]+1}if(y[_b(f+484344|0,x[f+1074436>>1])+12>>2]<=q>>>0){v[f+1074428>>2]=0;u[f+1074440>>1]=x[f+1074440>>1]+1}h=x[f+1074438>>1];j=jb-16|0;jb=j;f=f+1304360|0;n=f+12|0;ZN(j+8|0,n);$M(j,n);Vb:{if(!Xs(j+8|0,j)|(q|0)==-1){break Vb}while(1){g=jb-16|0;jb=g;v[g+8>>2]=v[j+12>>2];e=v[_M(g+8|0)>>2];jb=g+16|0;g=v[e>>2];qy(f,h,g,0);i=j+8|0;e=v[i+4>>2];v[j>>2]=v[i>>2];v[j+4>>2]=e;_M(i+4|0);$M(j,n);e=Xs(j+8|0,j);if((g|0)==(q|0)){break Vb}if(e){continue}break}}jb=j+16|0}jb=p+32|0;e=1;break k}e=0}jb=da+16|0;Wb:{if(!e|!v[A+1074420>>2]){break Wb}e=vL(A,A+1074376|0);v[A+1074380>>2]=e;v[A+1074404>>2]=e;g=Cd(x[A+480188>>1],1,31);$=A+1074328|0;Xb:{if(w[$+37|0]){e=v[A+24628>>2];if((e|0)>=129){e=((B(e-128|0,g+4|0)|0)/16|0)+128|0}s=B(v[A+480228>>2],e)>>>6|0;break Xb}s=v[A+480228>>2]}s=w[$+37|0]?(s<<7>>>0)/w[(g>>>1|0)+20752|0]|0:s;u[A+480212>>1]=0;X=A+1304392|0;R=A+1074308|0;N=A+480210|0;M=A+480209|0;p=0;while(1){H=A+B(p,896)|0;W=H+1075072|0;Yb:{if(!(v[W>>2]&4096)|(v[H+1075008>>2]|(v[H+1075004>>2]|v[H+1075680>>2]))){break Yb}Eb(r+24|0,R,64);if(Cb(r+24|0)){break Yb}v[H+1075060>>2]=0;e=H+1075076|0;v[e>>2]=0;v[e+4>>2]=0}e=x[A+480188>>1];Zb:{_b:{f=v[W>>2];if(!(f&1024)){h=e>>>0>p>>>0;if(h|v[H+1075060>>2]){break _b}}if(e>>>0>p>>>0){jL(A,p&65535)}u[H+1075846>>1]=0;break Zb}m=0;E=H+1075704|0;v[E>>2]=0;Q=H+1075664|0;v[Q>>2]=0;n=H+1074992|0;e=n;v[e>>2]=0;v[e+4>>2]=0;v[H+1075084>>2]=0;v[r+20>>2]=1065353216;u[r+18>>1]=0;V=H+1075684|0;m=v[V>>2]?v[H+1075060>>2]!=0:m;g=H+1074984|0;I=H+1075640|0;T=v[I>>2];$b:{ac:{bc:{cc:{if(!h){break cc}if(w[(A+(p<<5)|0)+480288|0]){break ac}if(!T){break cc}e=w[T+34|0]!=0|m;break bc}e=m}if(!e){break $b}}v[r+8>>2]=v[H+1075672>>2];v[r+4>>2]=v[H+1075748>>2];Eb(r+24|0,R,28);i=g;j=Cb(r+24|0)?r+4|0:r+8|0;h=jb-16|0;jb=h;e=A+1074308|0;Eb(h+8|0,e,28);dc:{if(Cb(h+8|0)){v[j>>2]=v[j>>2]+u[i+788>>1];ce(j,0,64);break dc}Eb(h+8|0,e,1);e=Cb(h+8|0);f=u[i+788>>1];if(e){v[j>>2]=f+v[j>>2];ce(j,0,256);break dc}v[i+688>>2]=f+v[i+688>>2];ce(i+688|0,0,256);v[j>>2]=v[i+688>>2];u[i+788>>1]=0}jb=h+16|0;f=jb-16|0;jb=f;e=A+1074308|0;Eb(f+8|0,e,28);ec:{fc:{if(!Cb(f+8|0)){Eb(f,e,1);if(!Cb(f)){break fc}}v[i+684>>2]=v[i+692>>2]+u[i+790>>1];ce(i+684|0,0,256);break ec}v[i+692>>2]=v[i+692>>2]+u[i+790>>1];ce(i+692|0,0,256);u[i+790>>1]=0;v[i+684>>2]=v[i+692>>2]}jb=f+16|0;l=jb-16|0;jb=l;h=A;gc:{if(!(w[g+90|0]&4)|(v[h+480208>>2]&2101248)==2101248){break gc}hc:{if(v[r+8>>2]<=0){Eb(l+8|0,h+1074308|0,21);if(!Cb(l+8|0)){break hc}}o=5;if(!(v[h+480180>>2]&5)){Eb(l+8|0,h+1074308|0,21);o=Cb(l+8|0)?5:6}f=Hx(h,w[i+845|0],w[i+840|0]);ic:{if((w[i+845|0]&3)!=1){break ic}Eb(l+8|0,h+1074308|0,89);if(!Cb(l+8|0)){break ic}f=w[i+839|0];j=w[i+840|0];e=j<<2&124;e=(!(w[i+90|0]&2)|w[h+480209|0]&16?f:w[i+843|0]+f|0)&32?e^127:e;f=j&32?0-e|0:e}e=r;if(v[h+480180>>2]!=131072){f=v[r+8>>2]+((B(w[i+847|0],f)|0)/(1<<o)|0)|0}else{j=64-f|0;f=v[r+8>>2];f=((B(w[i+847|0],B(j,f))|0)/-8192|0)+f|0}v[e+8>>2]=f}if(!(v[h+480180>>2]&16777248)|w[h+480208|0]&4?w[h+480209|0]&16:0){break gc}Eb(l+8|0,h+1074308|0,21);e=Cb(l+8|0);f=w[i+846|0];if(e){t[i+840|0]=w[i+840|0]+(f<<2);break gc}t[i+840|0]=f+w[i+840|0]}jb=l+16|0;J=p&65535;k=J;l=jb-16|0;jb=l;e=A+1074308|0;Eb(l+8|0,e,71);jc:{if(Cb(l+8|0)){e=(h+B(k,896)|0)+1075843|0;f=t[e|0];if((f|0)>-1){break jc}if(!(w[h+480209|0]&16|w[(h+B(k,896)|0)+1075811|0]!=18)){i=f&-33;t[e|0]=i;kc:{lc:{if((i|0)!=-64){f=f&223;if((f|0)!=128){break lc}f=w[(h+B(k,896)|0)+1075844|0]>>>4|-64;break kc}f=w[(h+B(k,896)|0)+1075844|0]&15|-128;break kc}f=f-1|0}t[e|0]=f;e=(h+B(k,896)|0)+1075072|0;v[e>>2]=v[e>>2]|2097152}if((f&224)!=128){break jc}v[r+8>>2]=0;break jc}if(w[(h+B(k,896)|0)+1075811|0]!=18){break jc}Eb(l+8|0,e,22);mc:{if(Cb(l+8|0)){i=h+B(k,896)|0;e=i+1075843|0;j=w[e|0];f=j<<24>>24;if(!((f|0)>-1|!v[i+1075060>>2])){nc:{oc:{if((j|0)!=192){if((j|0)!=128){break oc}f=w[(h+B(k,896)|0)+1075844|0]>>>4|-64;break nc}f=w[(h+B(k,896)|0)+1075844|0]&15|-128;break nc}f=f-1|0}t[e|0]=f}if((f&192)!=128){break mc}v[r+8>>2]=0;break mc}e=w[(h+B(k,896)|0)+1075844|0];o=e>>>4|0;i=o+(e&15)|0;if(!(w[h+480208|0]&4?0:v[h+480180>>2]&16777248)){o=o+1|0;i=i+2|0}j=(h+B(k,896)|0)+1075843|0;f=w[j|0];if(!(v[h+480180>>2]&4)){e=(f&255)>>>0<i>>>0?f:0;if((e&255)>>>0>=o>>>0){v[r+8>>2]=0}t[j|0]=e+1;break mc}pc:{if(w[h+480209|0]&16){f=f&255?f-1|0:0;break pc}t[j|0]=f+1}if(((f&255)>>>0)%(i>>>0)>>>0<o>>>0){break mc}v[r+8>>2]=0}e=(h+B(k,896)|0)+1075072|0;v[e>>2]=v[e>>2]|2097152}e=h+B(k,896)|0;qc:{if(w[e+1075811|0]!=18){break qc}f=e+1075640|0;e=v[f>>2];if(!e|!w[e+34|0]|w[e+15|0]&2){break qc}e=h+B(k,896)|0;if(v[e+1075072>>2]&134218752){break qc}j=e+1075805|0;if(!be(w[j|0])){break qc}i=v[f>>2];q=v[(h+B(w[i+34|0],160)|0)+906140>>2];if(!q){break qc}f=nb[v[v[q>>2]+96>>2]](q,w[j|0],k)|0;e=v[r+8>>2];if(!(!f|e)){nb[v[v[q>>2]+88>>2]](q,i,w[j|0]+255|0,0,k);break qc}if(f|!e){break qc}nb[v[v[q>>2]+88>>2]](q,i,w[j|0],x[(h+B(k,896)|0)+1075672>>1],k)}jb=l+16|0;ce(r+8|0,0,256);f=v[r+8>>2]<<6;v[r+8>>2]=f;rc:{sc:{if(T){Eb(r+24|0,R,31);if(Cb(r+24|0)){os(A,g)}k=jb-16|0;jb=k;e=g;tc:{if(!Gx(A,e,0)){break tc}o=v[e+656>>2];q=h+1074308|0;Eb(k+8|0,q,31);uc:{if(Cb(k+8|0)){G=v[e+728>>2];if(G){break uc}break tc}G=v[e+728>>2]}Eb(k+8|0,q,31);l=o+48|0;h=G-Cb(k+8|0)|0;G=qp(l,h,256,64);f=w[o+65|0];vc:{if((f|0)==255){break vc}j=v[e+732>>2];if((j|0)==-1){break vc}i=w[Pb(l,f)+2|0];e=x[Pb(l,w[o+65|0])>>1];Eb(k+8|0,q,94);f=i<<2;e=(e|0)==(h|0)?f:G;if(Cb(k+8|0)){G=j+(e-f<<1)|0;break vc}if(!i){G=0;break vc}G=(B(e,j)|0)/(f|0)|0}Ja=r,Ka=(B(v[r+8>>2],Yb(G,0,512))|0)/256|0,v[Ja+8>>2]=Ka}jb=k+16|0;iL(g,r+8|0);i=jb-16|0;jb=i;e=A;f=g;wc:{if(!Gx(e,f,1)){break wc}h=v[f+656>>2];e=e+1074308|0;Eb(i+8|0,e,31);xc:{if(Cb(i+8|0)){o=v[f+740>>2];if(o){break xc}break wc}o=v[f+740>>2]}Eb(i+8|0,e,31);j=qp(h+68|0,o-Cb(i+8|0)|0,64,64)-32|0;e=v[f+684>>2];Ja=f,Ka=Yb(((B(j,(e|0)>127?256-e|0:e)|0)/32|0)+e|0,0,256),v[Ja+684>>2]=Ka}jb=i+16|0;e=g;i=v[e+656>>2];h=t[i+26|0];yc:{if(!h){break yc}f=w[e+819|0];if(!f){break yc}Ja=e,Ka=Yb(v[e+684>>2]+((B(h,f+(w[i+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Ja+684>>2]=Ka}f=v[r+8>>2];break sc}if(!(w[W+1|0]&16)){break sc}v[H+1075680>>2]=0;v[r+8>>2]=0;break rc}if(!f){break rc}if(w[W+3|0]&8){v[Q>>2]=0;break rc}f=v[r+8>>2];if(w[$+36|0]){e=B(v[r+4>>2],v[H+1075744>>2]);i=e;j=e>>31;e=f<<8;Ja=Q,Ka=yc(Gma(Fma(i,j,e,e>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;break rc}e=B(v[r+4>>2],v[H+1075744>>2]);i=e;j=e>>31;e=B(f,v[A+1074444>>2]);Ja=Q,Ka=yc(Gma(Fma(i,j,e,e>>31),mb,1048576,0),mb),v[Ja>>2]=Ka}v[E>>2]=v[r+8>>2];zc:{if(v[A+480180>>2]==2|v[V>>2]>=v[A+480260>>2]){break zc}if(Zo(A)){break zc}v[V>>2]=v[A+480260>>2]}Eb(r+24|0,R,73);if(Cb(r+24|0)){Yb(v[V>>2],1,31999)}f=v[V>>2];v[r+12>>2]=f;Ac:{if((v[W>>2]&1572864)!=1572864){break Ac}if(w[N|0]&32){if(!Fs(H+1075794|0)|w[M|0]&16){break Ac}f=v[r+12>>2]}e=H+1075696|0;Bc:{if(v[e>>2]==(f|0)){f=v[H+1075700>>2];break Bc}v[e>>2]=f;i=f;f=H+1075752|0;e=H+1075688|0;f=$f(A,ws(A,i,v[f>>2],v[e>>2]),v[f>>2],v[e>>2]);v[H+1075700>>2]=f}v[r+12>>2]=f}k=jb-16|0;jb=k;f=A;q=f+B(J,896)|0;o=v[q+1075640>>2];Cc:{if(!o){break Cc}e=w[o+34|0];if(!e|w[o+15|0]&2|(!v[(f+B(e,160)|0)+906140>>2]|v[(f+B(J,896)|0)+1075072>>2]&134218752)){break Cc}h=f+B(J,896)|0;i=h+1075797|0;j=w[i|0];l=0;e=h+1075805|0;if(be(w[e|0])){l=w[fc(o+108|0,w[e|0]-1|0)|0]}o=h+1075794|0;Dc:{Ec:{if((j|0)==1){G=0;Fc:{Gc:{switch((y[f+1074392>>2]%3|0)-1|0){case 0:G=w[(f+B(J,896)|0)+1075812|0]>>>4|0;break Fc;case 1:break Gc;default:break Fc}}G=w[(f+B(J,896)|0)+1075812|0]&15}e=f+B(J,896)|0;t[e+1075807|0]=l;if(w[e+1075806|0]==(l+G|0)){break Dc}if(!(w[f+480209|0]&16)){break Ec}if(!cg(o)){break Ec}break Dc}G=0;if(w[o|0]|!w[(f+B(J,896)|0)+1075806|0]){break Dc}}e=f+B(J,896)|0;qk(f,J,w[e+1075807|0]+G|0,x[e+1075672>>1])}e=(f+B(J,896)|0)+1075806|0;h=w[e|0];Hc:{if(h){qk(f,J,h+255|0,0);break Hc}if(!(w[f+480209|0]&16)|(j|0)!=1){break Hc}if(cg(o)){break Hc}if(!be(l)){break Hc}qk(f,J,l+255|0,0)}t[e|0]=w[i|0]==1?w[(f+B(J,896)|0)+1075807|0]+G|0:0}Ic:{if(w[q+1075811|0]!=1){break Ic}if(tj(q+1074984|0)){l=0;Jc:{Kc:{Lc:{switch(y[f+1074392>>2]%3|0){case 1:l=w[(f+B(J,896)|0)+1075812|0]>>>4|0;break Kc;case 0:break Kc;case 2:break Lc;default:break Jc}}l=w[(f+B(J,896)|0)+1075812|0]&15}u[r+18>>1]=l}e=(f+B(J,896)|0)+1075856|0;t[e|0]=w[e|0]|12;break Ic}if(!(!(w[f+480209|0]&16)|v[f+480180>>2]!=1048576)){h=f+B(J,896)|0;e=$f(f,w[h+1075803|0],v[h+1075752>>2],v[h+1075688>>2]);v[r+12>>2]=e;v[h+1075684>>2]=e}j=f+1074308|0;Eb(k+8|0,j,13);if(Cb(k+8|0)){l=w[(f+B(J,896)|0)+1075812|0];if(!l){break Ic}e=65536;Mc:{switch(((y[f+1074392>>2]%(v[f+1074400>>2]+v[f+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:l=l<<4;case 0:e=v[((l&240)<<2)+25312>>2];break;default:break Mc}}i=Zo(f);f=v[r+12>>2];l=f;f=f>>31;h=r;if(i){e=Fma(l,f,e,e>>31)+32768|0;o=mb;f=Gma(e,e>>>0<32768?o+1|0:o,65536,0)}else{j=l;l=f<<16|j>>>16;i=(e|0)/2|0;f=j<<16;q=i+f|0;j=l+(i>>31)|0;f=Gma(q,f>>>0>q>>>0?j+1|0:j,e,e>>31)}e=mb;Ja=h,Ka=yc(f,e),v[Ja+12>>2]=Ka;break Ic}Eb(k+8|0,j,51);if(Cb(k+8|0)){if(w[f+480209|0]&16){break Ic}Nc:{Oc:{e=v[f+1074416>>2];e=e-(y[f+1074392>>2]%(e>>>0)|0)|0;if((e|0)>16){break Oc}if((e|0)==16){break Ic}G=0;Pc:{switch((e|0)%3|0){case 0:break Ic;case 2:break Oc;case 1:break Pc;default:break Nc}}G=w[(f+B(J,896)|0)+1075812|0]>>>4|0;break Nc}G=w[(f+B(J,896)|0)+1075812|0]&15}h=f+B(J,896)|0;e=h+1075752|0;i=h+1075688|0;h=ws(f,v[r+12>>2],v[e>>2],v[i>>2])+G|0;e=$f(f,h,v[e>>2],v[i>>2]);v[r+12>>2]=e;if(h>>>0<109){break Ic}v[k+8>>2]=e;Ja=k,Ka=$f(f,109,0,v[i>>2]),v[Ja+4>>2]=Ka;Ja=r,Ka=v[bd(k+8|0,k+4|0)>>2],v[Ja+12>>2]=Ka;break Ic}h=v[f+1074392>>2];if(v[f+480180>>2]!=1){G=w[(f+B(J,896)|0)+1075803|0]}else{e=f+B(J,896)|0;G=ws(f,v[r+12>>2],v[e+1075752>>2],v[e+1075688>>2])}Qc:{Rc:{switch((((v[f+480180>>2]&67633152?h+2|0:h)>>>0)%3|0)-1|0){case 0:G=(w[(f+B(J,896)|0)+1075812|0]>>>4|0)+G|0;break Qc;case 1:break Rc;default:break Qc}}G=(w[(f+B(J,896)|0)+1075812|0]&15)+G|0}if(!(v[f+480180>>2]&67633408|w[(f+B(J,896)|0)+1075803|0]!=(G&255))){Eb(k+8|0,j,82);if(!Cb(k+8|0)){break Ic}}h=r;l=f;if(w[f+480210|0]&32){i=G&255;if((i|0)==85){v[r+12>>2]=2147483647;break Ic}G=i>>>0>85?G-37|0:G}e=f+B(J,896)|0;Ja=h,Ka=$f(l,G&255,v[e+1075752>>2],v[e+1075688>>2]),v[Ja+12>>2]=Ka;if(v[f+480180>>2]&71827712){v[e+1075684>>2]=v[r+12>>2];break Ic}Eb(k+8|0,j,82);if(!Cb(k+8|0)){break Ic}t[(f+B(J,896)|0)+1075806|0]=G}jb=k+16|0;if(!(!(w[N|0]&33)|v[r+12>>2]==2147483647)){Sc:{if(v[A+480180>>2]==2){f=452;e=3424;break Sc}h=B(v[H+1075752>>2]>>>4&15,24)+21024|0;e=x[h+22>>1];f=e>>>0<904?452:e>>>1|0;e=x[h>>1]<<1}ce(r+12|0,f,e);ce(V,f,e)}hL(A,g);f=v[W>>2]}Tc:{if(!(f&256)|w[M|0]&64){break Tc}Eb(r+24|0,R,37);if(!Cb(r+24|0)){break Tc}v[H+1075668>>2]=128}q=p&65535;jL(A,q);Uc:{if(!m){break Uc}e=gL(A,g,r+12|0);if((e|0)<0|!(w[W+1|0]&2)){break Uc}if(!rd(X)){break Uc}lp(v[X>>2],q,e>>>2&255,1)}Vc:{if(w[H+1075796|0]!=8){break Vc}Wc:{Xc:{e=w[H+1075797|0];switch(e-5|0){case 1:break Vc;case 0:case 2:break Wc;default:break Xc}}if((e|0)!=26){break Vc}}if(v[A+480180>>2]==4){if(w[M|0]&16){break Vc}e=H+1075823|0;t[e|0]=w[e|0]+w[H+1075827|0];break Vc}if(!(v[A+480180>>2]&16777248)){break Vc}rk(g,w[H+1075798|0]);fL(A,q,r+12|0,r+20|0)}fL(A,q,r+12|0,r+20|0);if(m){v[r+8>>2]=0;m=A;j=r+12|0;G=jb-16|0;jb=G;Y=v[g+104>>2];Yc:{if(!Y|!w[Y+40|0]){break Yc}l=g;k=tj(g);J=Zo(m);Eb(G+8|0,m+1074308|0,21);f=J?26336:25312;i=J?25312:26336;if(!(k|!Cb(G+8|0)|v[m+480180>>2]==1048576)){if(!w[Y+41|0]){break Yc}h=w[l+838|0];v[G+4>>2]=v[l+780>>2]+w[Y+39|0];Ak(G+4|0,w[Y+40|0]<<8);e=v[G+4>>2];v[l+780>>2]=e;o=(e|0)/256|0;v[G+4>>2]=o;t[l+838|0]=w[l+838|0]+w[Y+41|0];Zc:{_c:{switch(w[Y+38|0]-1|0){case 3:e=cL(bn(m))+-64|0;o=v[G+4>>2];break Zc;case 2:e=64-(h+1>>>1|0)|0;break Zc;case 1:e=(h+1>>>1|0)+-64|0;break Zc;case 0:e=(h>>>1^-1)&64;break Zc;default:break _c}}e=t[h+21616|0]}Ak(j,8388607);k=v[j>>2]<<8;v[j>>2]=k;h=B(e,o);e=(h|0)/64|0;m=e>>31;l=m^e+m;e=l>>>2|0;m=j;$c:{if((h|0)<=-64){e=v[(e<<2)+f>>2];f=yc(Gma(Fma(e,e>>31,k,k>>31),mb,65536,0),mb);e=v[j>>2];h=f-e|0;i=h;f=l&3;if(!f){break $c}f=v[(f<<2)+(J?25248:25184)>>2];f=yc(Gma(Fma(f,f>>31,e,e>>31),mb,65536,0),mb)+h|0;e=v[j>>2];i=f-e|0;break $c}e=v[i+(e<<2)>>2];f=yc(Gma(Fma(e,e>>31,k,k>>31),mb,65536,0),mb);e=v[j>>2];h=f-e|0;i=h;f=l&3;if(!f){break $c}f=v[(f<<2)+(J?25184:25248)>>2];f=yc(Gma(Fma(f,f>>31,e,e>>31),mb,65536,0),mb)+h|0;e=v[j>>2];i=f-e|0}v[m>>2]=(e+i|0)/256;v[r+8>>2]=i&255;break Yc}ad:{if(!(w[Y+39|0]|v[m+480180>>2]&16777248)){v[l+780>>2]=w[Y+40|0]<<8;break ad}bd:{cd:{if(v[m+480180>>2]&16777248){o=w[Y+39|0]<<1;h=v[l+780>>2];e=l+780|0;break cd}if(w[l+89|0]&8){break bd}h=((w[Y+40|0]<<8&65280)>>>0)/w[Y+39|0]|0;o=v[l+780>>2];e=l+780|0}v[e>>2]=h+o}Ak(l+780|0,w[Y+40|0]<<8)}e=w[l+838|0]+w[Y+41|0]|0;t[l+838|0]=e;e=e<<24>>24;dd:{ed:{switch(w[Y+38|0]-1|0){case 3:t[l+838|0]=e+1;h=t[(e&63)+21552|0];break dd;case 2:h=(64-(e>>>1|0)&127)+-64|0;break dd;case 1:h=((e>>>1|0)- -64&127)+-64|0;break dd;case 0:h=(e|0)>-1?-64:64;break dd;default:break ed}}e=w[l+838|0];h=0-t[e+21616|0]|0;if(v[m+480180>>2]!=1048576){break dd}h=(64-t[(e+-64&255)+21616|0]|0)/2<<16>>16}e=h;o=B(e,v[l+780>>2]);h=(o|0)/256|0;if(k){z[r+20>>2]=C(C(C(e|0)*C(1220703143189894e-20))*C(w[Y+40|0]))+z[r+20>>2];t[l+872|0]=w[l+872|0]|8;break Yc}if(v[m+480180>>2]!=4){fd:{if((o|0)<=-256){h=0-h|0;e=0-o>>>16|0;i=(e<<2)+f|0;break fd}f=i;e=(o|0)/65536|0;i=f+(e<<2)|0}m=v[j>>2];f=v[((e<<2)+f|0)+4>>2];e=v[i>>2];e=((B(f-e|0,(h|0)/4&63)|0)/64|0)+e|0;e=yc(Gma(Fma(m,m>>31,e,e>>31),mb,256,0),mb);v[j>>2]=e;v[r+8>>2]=e&255;v[j>>2]=v[j>>2]/256;break Yc}v[j>>2]=v[j>>2]+((o|0)/16384|0)}jb=G+16|0;if(v[r+12>>2]<=v[A+480260>>2]){Eb(r+24|0,R,81);if(Cb(r+24|0)){v[H+1075060>>2]=0}v[r+12>>2]=v[A+480260>>2]}m=tj(g);gd:{if(!m){break gd}f=H+1075856|0;e=w[f|0];if(v[A+1074392>>2]|!(e&4)?!(e&8):0){break gd}qO(g,z[r+20>>2],u[r+18>>1],A);e=w[f|0];if(!(e&8)){t[f|0]=e&251;break gd}t[f|0]=e&247}hd:{if((v[W>>2]&134219264)!=512){break hd}if(!rd(X)){break hd}Eb(r+24|0,R,99);if(!(Ja=!(Cb(r+24|0)|!(w[W+1|0]&16)),Ka=0,Ma=v[A+480180>>2]!=2,Ma?Ja:Ka)){if(!(w[W+1|0]&8?v[A+480180>>2]==2:0)){if(m){e=v[V>>2]}else{e=aM(A,v[r+12>>2],v[H+1075688>>2],v[r+8>>2])}e=Fma(e,0,261625,0)+66904|0;l=mb;e=id(Ima(e,e>>>0<66904?l+1|0:l,133808,0),mb);e=Fma(v[A+480240>>2],0,e,0)+32768|0;i=mb;i=e>>>0<32768?i+1|0:i;h=id((i&65535)<<16|e>>>16,i>>>16|0);e=v[W>>2];m=1;id:{if(e&2048){break id}m=0;if(!(e&4096)){break id}m=!v[H+1075680>>2]}k=v[X>>2];Eb(r+24|0,R,95);i=Cb(r+24|0);o=jb-16|0;jb=o;e=q;l=vk(k,e);jd:{if((l|0)==255){break jd}if(qj(k)){break jd}kd:{if(h>>>0>6208431){f=7;h=1023;break kd}f=7;ld:{if(h>>>0>3104215){break ld}f=6;if(h>>>0>1552107){break ld}f=5;if(h>>>0>776053){break ld}f=4;if(h>>>0>388026){break ld}f=3;if(h>>>0>194013){break ld}f=2;if(h>>>0>97006){break ld}f=h>>>0>48503}h=Fma(1<<20-f,0,h,0)+24858e3|0;j=mb;h=id(Ima(h,h>>>0<24858e3?j+1|0:j,49716e3,0),mb)}if(i){u[o+14>>1]=(e&3)+h;u[o+12>>1]=1023;h=x[lf(o+14|0,o+12|0)>>1]}i=Ps(l);e=k+4|0;Ja=fc(e,l),Ka=(f<<10|h)>>>8|(m?0:32),t[Ja|0]=Ka;hh(v[k>>2],i|160,h&255);hh(v[k>>2],i|176,w[fc(e,l)|0]);t[k+530|0]=1}jb=o+16|0}f=v[X>>2];e=Fma(B(v[H+1075748>>2],B(v[H+1075744>>2],v[E>>2])),0,63,0)+33554432|0;l=mb;l=e>>>0<33554432?l+1|0:l;lp(f,q,id((l&67108863)<<6|e>>>26,l>>>26|0)&255,0);e=H+1075668|0;f=e;i=v[f>>2];m=0;j=v[X>>2];h=vk(j,q);md:{if((h|0)==255){break md}if(qj(j)){break md}e=w[fc(Ii(j+314|0,h),10)|0];e=e&-49;e=(i|0)<171?e|16:e;e=((i|0)>84?e|32:e)&255;hh(v[j>>2],Ps(h)|192,e);m=(e>>>5&1)+(e<<27>>31)|0}v[f>>2]=(m<<7)+128}nd:{e=v[I>>2];if(!e|(w[e+60|0]&7)!=1){break nd}e=e+48|0;if(nd(e)){break nd}if(y[eL(g,0)+4>>2]<x[oj(e)>>1]){break nd}if(w[oj(e)+2|0]){break nd}Mh(v[X>>2],q,1);Eb(r+24|0,R,109);e=Cb(r+24|0);m=v[W>>2];if(!e){m=m&-513;v[W>>2]=m}v[W>>2]=m|4096;v[H+1075680>>2]=0;break hd}Eb(r+24|0,R,99);if(!Cb(r+24|0)|!(w[W+1|0]&16)|v[H+1075680>>2]){break hd}Mh(v[X>>2],q,1);v[W>>2]=v[W>>2]&-513}h=Fma(Ix(A,g,v[r+12>>2],v[r+8>>2]),mb,v[A+480240>>2],0);l=mb;m=Gma(h,l,65536,0);f=mb;e=n;i=m;m=h+65535|0;l=m>>>0<65535?l+1|0:l;m=!l&m>>>0<131071;v[e>>2]=m?1:i;v[e+4>>2]=m?0:f}od:{if(!T){break od}Eb(r+24|0,R,31);if(Cb(r+24|0)){break od}os(A,g)}q=H+1075004|0;l=H+1075008|0;v[W>>2]=v[W>>2]&-65537|((v[q>>2]|(v[l>>2]|v[Q>>2]))!=0)<<16;h=H+1075656|0;e=h;v[e>>2]=0;v[e+4>>2]=0;k=H+1075846|0;e=w[k|0];m=e-4|0;t[k|0]=e>>>0<m>>>0?0:m;o=H+1075847|0;e=w[o|0];m=e-4|0;t[o|0]=e>>>0<m>>>0?0:m;pd:{qd:{rd:{sd:{td:{m=H+1075088|0;e=v[m>>2];ud:{if(!e){break ud}if(!De(e)|!v[H+1075060>>2]){break ud}if(Kh(g)){break td}}f=H+1075e3|0;v[f>>2]=0;break sd}f=H+1075e3|0;e=v[v[m>>2]+20>>2];v[f>>2]=e;if(e){break rd}}if(!nj(g)|w[W+1|0]&24){break qd}}i=v[Q>>2];j=v[H+1075668>>2];e=(B(i,256-j|0)|0)/16384|0;e=e>>>0<127?e:127;m=t[k|0];if((m|0)<=-1){t[k|0]=e;m=e}e=e>>>1|0;if((m&255)>>>0<e>>>0){t[k|0]=e}e=(B(i,j)|0)/16384|0;e=e>>>0<127?e:127;m=t[o|0];if((m|0)<=-1){t[o|0]=e;m=e}e=e>>>1|0;if((m&255)>>>0>=e>>>0){break pd}t[o|0]=e;break pd}if(w[k|0]>=129){t[k|0]=0}if(w[o|0]<129){break pd}t[o|0]=0}vd:{if(v[f>>2]){f=H+1075660|0;wd:{if(y[A+24624>>2]>=2){v[r+24>>2]=v[H+1075668>>2];ce(r+24|0,0,256);l=B(v[Q>>2],s)>>>(w[$+37|0]?7:8)|0;m=f;xd:{yd:{zd:{switch(v[$+32>>2]){case 0:if(!(w[A+24616|0]&16)){break yd}case 1:e=v[r+24>>2];if((e|0)<=127){v[h>>2]=l>>>1;e=(B(e,l)|0)/256|0;break xd}v[h>>2]=(B(l,256-e|0)|0)/256;e=l>>>1|0;break xd;case 3:break zd;default:break yd}}Ak(r+24|0,255);e=h;i=v[r+24>>2];j=l<<16;Ad:{if((i|0)<=0){break Ad}j=B(l,x[(0-i<<1)+27872>>1])}v[e>>2]=j>>>16;e=B(l,x[(i<<1)+27360>>1])>>>16|0;break xd}e=v[r+24>>2];v[h>>2]=(B(l,256-e|0)|0)/256;e=(B(e,l)|0)/256|0}v[m>>2]=e;break wd}e=B(v[Q>>2],s)>>>8|0;v[h>>2]=e;v[f>>2]=e}i=H+1075800|0;m=i;Bd:{Cd:{e=v[I>>2];if(!e){break Cd}if(!Sn(w[e+14|0])){break Cd}e=w[v[I>>2]+14|0];break Bd}if(Sn(w[A+480268|0])){e=w[A+480268|0];break Bd}if(w[N|0]&128){e=255;if(v[A+24668>>2]){break Bd}}e=w[A+24648|0]}t[m|0]=e;if(!(w[W+2|0]&2|(v[n>>2]!=0|v[n+4>>2]!=1)|(v[H+1075764>>2]|(e&255)==255))){t[i|0]=0}e=1<<v[$+28>>2];v[h>>2]=v[h>>2]/(e|0);m=v[f>>2]/(e|0)|0;v[f>>2]=m;e=v[W>>2];if(!(!(e&256)|v[A+24624>>2]!=2)){v[f>>2]=0-m}if(e&128){m=v[n>>2];e=0-(v[n+4>>2]+((m|0)!=0)|0)|0;v[n>>2]=0-m;v[n+4>>2]=e}n=A;j=jb-16|0;jb=j;e=g;v[e+28>>2]=0;v[e+32>>2]=0;h=e;Dd:{Ed:{f=v[e+88>>2];if(!(f&65536)){m=v[e+676>>2];g=v[e+672>>2];break Ed}g=v[e+20>>2];l=v[e+672>>2];Fd:{if((g|0)!=(l|0)){m=v[e+24>>2];i=v[e+676>>2];break Fd}i=v[e+676>>2];m=v[e+24>>2];if((i|0)==(m|0)){break Ed}}q=n+24604|0;f=j;m=(g|0)<(l|0)|(i|0)>(m|0);Gd:{if(m){g=uO(q);break Gd}g=tO(q)}v[f+12>>2]=g;Eb(j,n+1074308|0,4);if(!(!Cb(j)|!(v[n+480180>>2]&4))){g=v[n+24620>>2];g=Fma(g,g>>31,5,0)+500|0;l=mb;g=yc(Gma(g,g>>>0<500?l+1|0:l,1e3,0),mb);v[j+12>>2]=g}f=v[e+656>>2];Hd:{if(!(!m|!f)){m=g;f=x[f+12>>1];if(f){m=(B(f,v[n+24620>>2])>>>0)/1e5|0}E=(f|0)!=0;break Hd}m=v[j+12>>2];E=0}q=m?m:1;f=v[e+676>>2];k=v[e+24>>2];o=f-k<<12;i=v[e+672>>2];l=v[e+20>>2];m=i-l<<12;if(!(w[e+90|0]&32|(!(k|l)|(E|!(f|i))))){v[j+12>>2]=v[n+1074380>>2];ce(j+12|0,g,2048);i=v[e+672>>2];q=v[j+12>>2];f=v[e+676>>2]}l=(o|0)/(q|0)|0;v[e+32>>2]=l;n=(m|0)/(q|0)|0;v[e+28>>2]=n;m=((B(l,q)|0)/-4096|0)+f|0;v[e+24>>2]=m;g=((B(n,q)|0)/-4096|0)+i|0;v[e+20>>2]=g;if(l|n){v[e+100>>2]=q;f=v[e+88>>2];break Dd}v[e+24>>2]=f;v[e+20>>2]=i;m=f;g=i;f=v[e+88>>2]&-65537;break Dd}v[e+24>>2]=m;v[e+20>>2]=g;f=f&-65537}v[h+88>>2]=f&-2097153;v[e+40>>2]=m<<12;v[e+36>>2]=g<<12;jb=j+16|0;if(w[W+1|0]&2){break vd}e=x[A+480212>>1];u[A+480212>>1]=e+1;u[(A+(e<<1)|0)+1074466>>1]=p;break vd}v[q>>2]=0;v[l>>2]=0;v[H+1075060>>2]=0;if(v[H+1075076>>2]?0:!v[H+1075080>>2]){break vd}e=x[A+480212>>1];u[A+480212>>1]=e+1;u[(A+(e<<1)|0)+1074466>>1]=p}v[H+1075652>>2]=v[W>>2]}p=p+1|0;if((p|0)!=256){continue}break}m=1;if(y[A+24608>>2]>x[A+480212>>1]){break Wb}l=A+1074466|0;q=l;e=l+(v[A+24608>>2]<<1)|0;i=l+(x[A+480212>>1]<<1)|0;j=jb-16|0;jb=j;v[j+8>>2]=A;n=j+8|0;h=n;g=e-l|0;if((g|0)>=3){f=g>>1;o=(f-2|0)/2|0;while(1){Ex(l,h,f,l+(o<<1)|0);g=(o|0)>0;o=o-1|0;if(g){continue}break}}if((e|0)!=(i|0)){g=e-q>>1;f=e;while(1){if(Ro(n,x[f>>1],x[q>>1])){_K(f,q);Ex(q,n,g,q)}f=f+2|0;if((i|0)!=(f|0)){continue}break}}g=e-q|0;if((g|0)>=3){f=g>>>1|0;while(1){_K(q,e-2|0);Ex(q,n,f-1|0,q);e=e-2|0;g=(f|0)>2;f=f-1|0;if(g){continue}break}}jb=j+16|0}jb=r+32|0;if(m){n=v[a+480208>>2];break i}e=v[a+480208>>2]|512;if(w[a+1304512|0]){break j}m=0;e=v[a+24620>>2];n=yc(Gma(Fma(e,e>>31,100,0),mb,1e3,0),mb);Id:{if(!n){break Id}i=n>>>0<1048576?n:1048576;v[A+1074380>>2]=i;f=x[A+480212>>1];if(!f){break Id}h=A+1074376|0;while(1){A=h+B(x[(h+(m<<1)|0)+90>>1],896)|0;e=A+1280|0;v[e>>2]=0;v[e+4>>2]=0;v[A+708>>2]=i;g=v[A+632>>2]<<12;v[A+648>>2]=g;e=v[A+628>>2]<<12;v[A+644>>2]=e;v[A+696>>2]=v[A+696>>2]|65536;v[A+636>>2]=(0-e|0)/(i|0);v[A+640>>2]=(0-g|0)/(i|0);m=m+1|0;if((f|0)!=(m|0)){continue}break}}g=v[a+480208>>2];e=g|256;if(n){break j}e=g|512}n=e;v[_+480208>>2]=n}if(n&512){Ja=a+1074392|0,Ka=wl(a),v[Ja>>2]=Ka;break h}v[ha+16>>2]=512;e=v[a+1074380>>2];v[ha+12>>2]=3;v[ha+24>>2]=b;v[ha+20>>2]=e;v[ha+8>>2]=ha+16;e=v[ha+12>>2];v[ha>>2]=v[ha+8>>2];v[ha+4>>2]=e;A=QS(ha);if(v[a+24632>>2]){f=a;m=d;e=0;n=jb-16|0;jb=n;g=A;i=g<<2;while(1){v[n>>2]=0;h=(f+(e<<11)|0)+16396|0;mK(h,h+i|0,n);e=e+1|0;if((e|0)!=4){continue}break}e=0;while(1){v[n+(e<<2)>>2]=(f+(e<<11)|0)+16396;e=e+1|0;if((e|0)!=4){continue}break}nb[v[v[m>>2]+8>>2]](m,n,v[f+24632>>2],g);jb=n+16|0}Q=a;G=0;m=jb-112|0;jb=m;q=A;if(q){T=Q+12|0;J=Q+24592|0;N=Q+24588|0;rn(T,q,J,N);if(y[Q+24624>>2]>=3){rn(Q+8204|0,q,Q+24600|0,Q+24596|0)}u[m+30>>1]=0;xa=Q+1074308|0;Eb(m+8|0,xa,33);e=Cb(m+8|0);k=x[Q+480212>>1];if(k){F=e?2:1;K=Q+24648|0;_=Q+24596|0;M=Q+24600|0;I=Q+8204|0;E=Q+397460|0;s=Q+397456|0;r=Q+393352|0;Ba=Q+1074376|0;while(1){f=Ba+(G<<1)|0;g=B(x[f+90>>1],896);n=g+Ba|0;ka=n;Jd:{Kd:{if(v[n+624>>2]){break Kd}e=g+Q|0;if(v[e+1075080>>2]){break Kd}if(!v[e+1075076>>2]){break Jd}}R=g+Q|0;e=w[R+1075800|0]+1|0;Ld:{if((e&255)>>>0<=5){o=v[(e<<24>>24<<2)+18440>>2];break Ld}o=0}ga=R+1075072|0;k=v[ga>>2];V=k&1;Md:{if(!(k&8388608)){g=T;h=J;i=k;e=N;if(!(!(i&16777216)&(w[Q+24612|0]&32)>>>5)){break Md}}e=q;g=r;if(!v[g+4116>>2]){rn(g+8|0,e,g+4104|0,g+4108|0)}v[g+4116>>2]=1;g=g+8|0;i=v[ga>>2];h=s;e=E}if(!(!(i&256)|y[Q+24624>>2]<3)){g=I;h=M;e=_}n=n+608|0;la=xl(Q,x[f+90>>1],2,1);Nd:{if((!la|0)==(la>>>0<251|0)){break Nd}i=v[(Q+B(la,160)|0)+906140>>2];if(!i){break Nd}f=v[i+24>>2];if(!f){break Nd}e=i+36|0;h=i+40|0;if(!(t[i+28|0]&1)){rn(f,q,h,e);v[i+28>>2]=v[i+28>>2]|1}g=f}ta=0;ua=m+8|0;f=ua;v[f>>2]=0;v[f+4>>2]=0;v[f+8>>2]=0;v[f+12>>2]=0;f=n;if(v[f+16>>2]){lC(ua,f);j=v[f+12>>2];i=j;j=v[f+8>>2];f=i>>31;X=j+f|0;l=i>>31;j=l+i|0;f=l^(f>>>0>X>>>0?j+1|0:j);v[ua+12>>2]=f>>>0>8191?2:16384/(f+1>>>0)|0}$=k>>>12&8|(k>>>5&2|(o|V));Ca=R+1075809|0;Z=R+1075792|0;ba=R+1075680|0;da=R+1075016|0;ea=R+1075012|0;H=R+1075660|0;W=R+1075656|0;ja=R+1074992|0;ma=R+1075080|0;na=R+1075076|0;Da=R+1075008|0;p=R+1075004|0;va=R+1075088|0;sa=R+1075068|0;ia=R+1075060|0;wa=R+1075064|0;oa=R+1075084|0;i=q;while(1){Od:{f=v[oa>>2];f=f?f>>>0<i>>>0?f:i:i;v[m+68>>2]=f;X=v[wa>>2];R=v[ga>>2];aa=v[ja+4>>2];l=v[ja>>2];v[m+56>>2]=l;v[m+60>>2]=aa;Pd:{Qd:{if(!f|!(l|aa)){break Qd}Y=v[ia>>2];if(!Y){break Qd}v[ka+624>>2]=v[m+8>>2];o=v[n+4>>2];j=o;f=v[n>>2];V=X&R<<30>>31;k=j;Rd:{if((V|0)>(k|0)){if((aa|0)<-1?1:(aa|0)<=-1){f=m;v[f+104>>2]=0;l=V;v[f+108>>2]=l<<1;f=ig(f+104|0,n);o=mb;j=o;v[n>>2]=f;v[n+4>>2]=j;if(!(j>>>0<v[ia>>2]+l>>>1>>>0?(l|0)<=(j|0):0)){f=0;v[n>>2]=f;v[n+4>>2]=l;j=l}R=v[m+60>>2];X=v[m+56>>2];l=X;o=0-(R+((l|0)!=0)|0)|0;l=0-l|0;v[m+56>>2]=l;v[m+60>>2]=o;v[ja>>2]=l;v[ja+4>>2]=o;l=v[ga>>2];Sd:{if(l&4){k=l&-129;v[ga>>2]=k;break Sd}k=l|128;v[ga>>2]=k;o=v[ia>>2]-1|0;j=o;l=n;v[l>>2]=f;v[l+4>>2]=j;v[ja>>2]=X;v[ja+4>>2]=R}Td:{if(!(k&2)){k=v[ia>>2];break Td}k=v[ia>>2];if(j>>>0<k>>>0){break Rd}}f=n;v[f>>2]=0;v[f+4>>2]=k;break Qd}if((k|0)>-1){break Rd}l=0;j=l;v[n>>2]=f;v[n+4>>2]=j;break Rd}if(k>>>0<Y>>>0){break Rd}if(!(R&2)){break Qd}if(R&4){if((aa|0)>0?1:(aa|0)>=0?l>>>0>=1:0){j=0-l|0;v[m+56>>2]=j;o=0-(((l|0)!=0)+aa|0)|0;v[m+60>>2]=o;v[ja>>2]=j;v[ja+4>>2]=o}v[ga>>2]=R|128;j=1-((f|0)!=0)|0;f=0-f|0;k=(Y<<1)-(j+k|0)|0;j=k;v[n>>2]=f;v[n+4>>2]=k;if(k>>>0<Y>>>0?k>>>0>X>>>0:0){break Rd}v[m+104>>2]=F;l=Y-v[Lb(ia,m+104|0)>>2]|0;f=v[n>>2];v[n>>2]=f;j=l;v[n+4>>2]=j;break Rd}if((aa|0)<-1?1:(aa|0)<=-1){f=0-l|0;v[m+56>>2]=f;j=0-(((l|0)!=0)+aa|0)|0;v[m+60>>2]=j;v[ja>>2]=f;v[ja+4>>2]=j}f=m;v[f+104>>2]=0;v[f+108>>2]=V-Y;Sb(n,f+104|0);v[ga>>2]=v[ga>>2]|8192;f=v[n>>2];j=v[n+4>>2]}v[m+48>>2]=f;v[m+52>>2]=j;Ud:{Vd:{f=j;if((f|0)<(V|0)){k=0;if((j|0)<0|v[m+60>>2]<0){break Ud}break Vd}if((j|0)>0?1:(j|0)>=0){break Vd}k=0;break Ud}k=0;if(f>>>0>=y[ia>>2]){break Ud}Y=v[m+68>>2];v[m+44>>2]=Y;j=v[m+56>>2];f=v[m+60>>2];Cc(m+68|0,v[m+20>>2]);Ja=m,Ka=Iu(m+56|0,v[m+68>>2]-1|0),v[Ja+32>>2]=Ka;v[m+36>>2]=mb;l=f;o=f>>31;R=f>>31;f=R;k=f+j|0;j=l+o|0;j=f>>>0>k>>>0?j+1|0:j;X=k;l=v[m+36>>2]+v[m+52>>2]|0;f=v[m+48>>2];k=f+v[m+32>>2]|0;f=f>>>0>k>>>0?l+1|0:l;k=v[m+52>>2];pa=k;qa=v[m+48>>2];l=v[wa>>2];aa=k;k=l>>>0<=k>>>0&k>>>0<l+16>>>0;if(!k){v[ga>>2]=v[ga>>2]&-8193}R=R^X;X=j^o;Wd:{Xd:{Yd:{if(!v[m+12>>2]){k=v[m+60>>2];break Yd}j=v[m+16>>2];if(j>>>0<=aa>>>0){l=m;f=v[m+60>>2];Zd:{if((f|0)<-1?1:(f|0)<=-1){v[m+96>>2]=qa;v[m+100>>2]=pa;f=m;v[f+104>>2]=0;v[f+108>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;f=Zl(f+88|0,R,X);break Zd}j=v[sa>>2];v[m+104>>2]=qa;v[m+108>>2]=pa;f=m;v[f+96>>2]=0;v[f+100>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;f=Zl(f+88|0,R,X)}v[l+44>>2]=f+1;v[ka+624>>2]=v[m+12>>2];break Wd}if(!(!k|!(w[ga+1|0]&32))){v[m+104>>2]=qa;v[m+108>>2]=pa;f=m;v[f+96>>2]=0;v[f+100>>2]=V+16;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=Zl(f+88|0,R,X)+1|0,v[Ja+44>>2]=Ka;Ja=ka,Ka=v[f+12>>2]+B(v[sa>>2]-V|0,Zn(v[va>>2]))|0,v[Ja+624>>2]=Ka;break Wd}o=v[m+60>>2];k=o;if((k|0)<0?1:(k|0)<=0?y[m+56>>2]<1:0){break Yd}if(Y>>>0<2|f>>>0<j>>>0){break Xd}v[m+104>>2]=qa;v[m+108>>2]=pa;f=m;v[f+96>>2]=0;v[f+100>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=Zl(f+88|0,R,X)+1|0,v[Ja+44>>2]=Ka;break Wd}if((k|0)>-1){break Xd}if((f|0)>=(V|0)){break Wd}v[m+96>>2]=qa;v[m+100>>2]=pa;f=m;v[f+104>>2]=0;v[f+108>>2]=l;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=Zl(f+88|0,R,X)+1|0,v[Ja+44>>2]=Ka;break Wd}j=v[ia>>2];if((j|0)>(f|0)){break Wd}v[m+104>>2]=qa;v[m+108>>2]=pa;f=m;v[f+96>>2]=0;v[f+100>>2]=j;Ja=f,Ka=ig(f+96|0,f+104|0),v[Ja+80>>2]=Ka;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ja=f,Ka=ig(f+80|0,f+72|0),v[Ja+88>>2]=Ka;v[f+92>>2]=mb;Ja=f,Ka=Zl(f+88|0,R,X)+1|0,v[Ja+44>>2]=Ka}Yn(m+44|0,1,v[m+68>>2]);k=v[m+44>>2]}if((k|0)>0){break Pd}}v[ka+624>>2]=0;v[ia>>2]=0;v[n>>2]=0;v[n+4>>2]=0;v[oa>>2]=0;V=0;j=n;f=v[j+96>>2];k=v[j+92>>2];if(f|k){if(i){while(1){l=V<<3;n=l+g|0;k=k-(((-2147483648-k>>>31|0)-1&255)+k>>8)|0;v[n>>2]=k+v[n>>2];n=(l|4)+g|0;f=f-(((-2147483648-f>>>31|0)-1&255)+f>>8)|0;v[n>>2]=f+v[n>>2];V=V+1|0;if((V|0)!=(i|0)){continue}break}}v[j+96>>2]=f;v[j+92>>2]=k}v[h>>2]=v[h>>2]+v[na>>2];v[e>>2]=v[e>>2]+v[ma>>2];v[ma>>2]=0;v[na>>2]=0;v[ga>>2]=v[ga>>2]&-129;break Od}_d:{$d:{if(y[Q+24608>>2]<=x[m+30>>1]){break $d}if(v[oa>>2]){j=$|4}else{if(!(v[Da>>2]|v[p>>2])){break $d}j=$}f=(k<<3)+g|0;o=f-8|0;v[na>>2]=0-v[o>>2];l=f-4|0;v[ma>>2]=0-v[l>>2];nb[v[(j<<2)+77360>>2]](n,K,g,k);v[na>>2]=v[na>>2]+v[o>>2];v[ma>>2]=v[ma>>2]+v[l>>2];ta=1;break _d}Ja=m,Ka=Fma(v[ja>>2],v[ja+4>>2],k,k>>31),v[Ja+104>>2]=Ka;v[m+108>>2]=mb;Sb(n,m+104|0);ta=0;v[ma>>2]=0;v[na>>2]=0;f=(k<<3)+g|0}g=f;f=v[oa>>2];ae:{if(!f){break ae}if(f>>>0<=k>>>0){v[oa>>2]=0;v[p>>2]=v[W>>2];v[Da>>2]=v[H>>2];v[ea>>2]=0;v[da>>2]=0;if(v[ba>>2]|!(w[ga+1|0]&16)){break ae}v[ia>>2]=0;v[ka+624>>2]=0;break ae}v[oa>>2]=f-k}aa=0;V=0;f=v[n+4>>2];V=f>>>0>=y[sa>>2]?(w[ga|0]&2)>>>1|0:V;j=f;f=v[ia>>2];aa=j>>>0<f>>>0|(!f|w[ga|0]&2)?aa:!x[Z>>1];i=i-k|0;Eb(m+104|0,xa,85);be:{ce:{de:{ee:{if(!Cb(m+104|0)){break ee}f=w[Ca|0];if(!f|f>>>0>x[Q+480190>>1]){break ee}f=v[va>>2];l=Q+B(w[Ca|0],104)|0;j=l+484380|0;if(!(V|aa)|(f|0)==(j|0)){break de}v[va>>2]=j;v[ka+624>>2]=v[l+484400>>2];f=x[l+484414>>1];v[ga>>2]=f|v[ga>>2]&-768;j=v[l+484388>>2];v[ia>>2]=j&f<<30>>31;f=v[l+484384>>2];v[wa>>2]=f;v[sa>>2]=j;v[n+4>>2]=f;lC(ua,n);if(!v[ka+624>>2]){break Od}if((i|0)>0){continue}break Od}if(V){break ce}break be}if(!V|(f|0)!=(j|0)){break be}}Eb(m+104|0,xa,83);if(!Cb(m+104|0)|v[wa>>2]){break be}v[n>>2]=v[n>>2];v[n+4>>2]=0;f=v[v[va>>2]+8>>2];v[ia>>2]=f;v[sa>>2]=f}if((i|0)>0){continue}}break}v[ka+624>>2]=v[m+8>>2];u[m+30>>1]=x[m+30>>1]+ta;fe:{if(!la|!ta|la>>>0>250){break fe}e=v[(Q+B(la,160)|0)+906140>>2];if(!e){break fe}nb[v[v[e>>2]+144>>2]](e)}k=x[Q+480212>>1]}G=G+1|0;if(G>>>0<(k&65535)>>>0){continue}break}}Ja=Q,Ka=x[Si(Q+480214|0,m+30|0)>>1],u[Ja+480214>>1]=Ka}jb=m+112|0;if(rd(Aa)){m=ra;f=A;e=(B(v[a+480232>>2],v[a+480236>>2])>>>0)/48|0;N=jb-16|0;jb=N;s=v[Aa>>2];ge:{if(!w[s+530|0]){break ge}e=Fma(e,0,6169,0);g=mb;j=g>>>16|0;_=id((g&65535)<<16|e>>>16,j);if(!f){break ge}while(1){o=v[s>>2];h=v[o>>2];e=v[o+4>>2];if((h|0)<=(e|0)){n=o+14|0;i=o+12|0;while(1){v[o+8>>2]=v[o+12>>2];q=o;h=i;g=n;G=0;l=0;V=0;j=jb-16|0;jb=j;while(1){T=q+B(V,44)|0;he:{if(!w[T+56|0]){u[j+12>>1]=0;u[j+14>>1]=0;break he}e=v[T+32>>2];r=x[e+3840>>1];k=0;ie:{if(!(r&3)){break ie}e=(x[T+36>>1]>>>7&7)>>>(w[e+3844|0]^1)>>>(r&1)|0;k=r&4?0-e|0:e}J=k<<x[T+38>>1];e=j;r=v[T+52>>2];je:{if(r){r=x[r+32>>1];k=x[T+48>>1];M=Nf(v[T+16>>2],v[T+40>>2],J<<16>>16,0,u[T+46>>1]);I=v[T+40>>2];E=v[T+20>>2];if(!r){if(!k){k=J<<16>>16;r=Nf(E,I,k,M,0);r=Nf(v[T+24>>2],v[T+40>>2],k,r,0);r=Nf(v[T+28>>2],v[T+40>>2],k,r,0);break je}k=J<<16>>16;r=Nf(E,I,k,0,0);r=Nf(v[T+24>>2],v[T+40>>2],k,r,0);r=Nf(v[T+28>>2],v[T+40>>2],k,r,0)+M|0;break je}if(!k){k=E;E=J<<16>>16;k=Nf(k,I,E,M,0);r=Nf(v[T+24>>2],v[T+40>>2],E,0,0);r=Nf(v[T+28>>2],v[T+40>>2],E,r,0)+k|0;break je}k=J<<16>>16;r=Nf(E,I,k,0,0);r=(Nf(v[T+24>>2],v[T+40>>2],k,r,0)+M|0)+Nf(v[T+28>>2],v[T+40>>2],k,0,0)|0;break je}r=x[T+48>>1];M=J<<16>>16;I=Nf(v[T+16>>2],v[T+40>>2],M,0,u[T+46>>1]);E=v[T+40>>2];k=v[T+20>>2];if(!r){r=Nf(k,E,M,I,0);break je}r=Nf(k,E,M,0,0)+I|0}u[e+14>>1]=w[T+57|0]?r:0;u[j+12>>1]=w[T+58|0]?r:0}G=u[j+12>>1]+G|0;l=u[j+14>>1]+l|0;V=V+1|0;if((V|0)!=18){continue}break}e=(l|0)<32767?l:32767;u[h>>1]=(e|0)>-32768?e:-32768;e=(G|0)<32767?G:32767;u[g>>1]=(e|0)>-32768?e:-32768;u[q+3832>>1]=x[q+3832>>1]+1;e=(x[q+3834>>1]+1>>>0)%13440|0;u[q+3834>>1]=e;e=((e>>>0<6720?e:13440-e|0)|0)/256|0;u[q+3836>>1]=e;if(!w[q+3843|0]){u[q+3836>>1]=(e&65532)>>>2}e=x[q+3838>>1]+1|0;u[q+3838>>1]=e;if((e&65535)>>>0>=1024){u[q+3838>>1]=0;u[q+3840>>1]=x[q+3840>>1]+1&7}jb=j+16|0;h=v[o>>2];e=v[o+4>>2]-h|0;v[o+4>>2]=e;if((e|0)>=(h|0)){continue}break}}g=h-e|0;u[N+14>>1]=(B(u[o+12>>1],e)+B(g,u[o+8>>1])|0)/(h|0);u[N+12>>1]=(B(u[o+14>>1],e)+B(g,u[o+10>>1])|0)/(h|0);v[o+4>>2]=e+49716;v[m>>2]=v[m>>2]+B(_,u[N+14>>1]);v[m+4>>2]=v[m+4>>2]+B(_,u[N+12>>1]);m=m+8|0;f=f-1|0;if(f){continue}break}}jb=N+16|0}m=ra;g=A;j=Ia;ke:{if(!v[j+4116>>2]){if(!v[j+4120>>2]){break ke}rn(j+8|0,g,j+4104|0,j+4108|0)}l=v[j>>2];n=v[j+4184>>2];e=B(l,n)>>>4|0;e=e>>>0<32767?e:32767;u[j+4202>>1]=e;u[j+4200>>1]=e;h=v[j+54052>>2];e=B(h,l)>>>4|0;e=e>>>0<65536?e:65536;f=e+127>>>3|0;u[j+54050>>1]=f;e=e+255>>>4|0;u[j+54048>>1]=e;u[j+54046>>1]=e;u[j+54044>>1]=f;f=m;i=j+8|0;o=i;e=(h|0)<(n|0)?n:h;h=(e|0)<32768?e:32768;e=36-l>>>1|0;e=e>>>0>8?e:8;l=16-(B(h,(e|0)<16?16-e|0:0)>>15)|0;q=0;e=g;if(e){while(1){n=q<<3;h=n+f|0;v[h>>2]=v[h>>2]+B(l,v[o+n>>2]>>4);n=n|4;h=n+f|0;v[h>>2]=v[h>>2]+B(l,v[o+n>>2]>>4);q=q+1|0;if((e|0)!=(q|0)){continue}break}}n=j+4172|0;f=i;h=0;e=j;k=v[e+4144>>2];l=v[e+4140>>2];if(g){E=u[e+4188>>1];while(1){q=h<<3;s=(q|4)+f|0;r=v[s>>2];o=f+q|0;q=v[o>>2]>>12;l=(B(E,q-l|0)>>15)+q|0;v[o>>2]=l;q=r>>12;k=(B(E,q-k|0)>>15)+q|0;v[s>>2]=k;h=h+1|0;if((g|0)!=(h|0)){continue}break}}v[e+4144>>2]=k;v[e+4140>>2]=l;le:{if(!g){f=v[n>>2];break le}h=n;G=x[h+22>>1];l=x[h+20>>1];k=v[h+4>>2];e=g;if(e){T=u[h+26>>1];I=u[h+18>>1];J=u[h+24>>1];E=u[h+16>>1];s=v[h>>2]-1|0;N=h+32928|0;while(1){r=Sc(v[f>>2]);o=Sc(v[f+4>>2]);l=Sc((l<<16>>16)-r|0);q=Sc((G<<16>>16)-o|0);l=Vc(Sc((B(l,E)|0)/65536<<1)+r|0);G=Vc(Sc((B(q,I)|0)/65536<<1)+o|0);q=N+(k<<2)|0;_=u[q+2>>1];r=u[q>>1];M=Vc(((B(r,J)|0)/-65536|0)+l|0);k=k+1&127;q=N+(k<<2)|0;o=Vc(((B(T,_)|0)/-65536|0)+G|0);u[q+2>>1]=o;u[q>>1]=M;s=s+1&8191;q=h+(s<<2)|0;Ja=q,Ka=Vc(r+((B(J,M)|0)/65536|0)|0),u[Ja+160>>1]=Ka;Ja=q,Ka=Vc(_+((B(o,T)|0)/65536|0)|0),u[Ja+162>>1]=Ka;f=f+8|0;e=e-1|0;if(e){continue}break}}o=j+53996|0;u[h+22>>1]=G;u[h+20>>1]=l;v[h+4>>2]=k;h=v[j+4180>>2];ba=j+37612|0;e=i;q=g;while(1){r=h&4095;l=ba+(r<<2)|0;f=e;N=h-v[j+53996>>2]&4095;h=4096-(r>>>0>N>>>0?r:N)|0;h=h>>>0<q>>>0?h:q;r=h>>>0<64?h:64;T=r;k=0;$=jb-32|0;jb=$;h=n;s=v[h>>2];while(1){v[$+(k<<2)>>2]=s+(v[(h+(k<<4)|0)+32>>2]^-1);k=k+1|0;if((k|0)!=7){continue}break}k=u[h+28>>1]/8|0;if(T){_=k<<16>>16;while(1){G=0;s=0;k=0;while(1){E=$+(k<<2)|0;I=v[E>>2]+1&8191;v[E>>2]=I;J=s;s=h+(I<<2)|0;I=u[s+160>>1];M=h+(k<<4)|0;E=u[s+162>>1];s=(J+B(I,u[M+44>>1])|0)+B(E,u[M+46>>1])|0;G=(B(I,u[M+40>>1])+G|0)+B(E,u[M+42>>1])|0;k=k+1|0;if((k|0)!=4){continue}break}V=0;k=4;M=Vc((G|0)/32768|0);I=Vc((s|0)/32768|0);G=0;while(1){s=$+(k<<2)|0;E=v[s>>2]+1&8191;v[s>>2]=E;s=h+(E<<2)|0;E=u[s+160>>1];J=h+(k<<4)|0;s=u[s+162>>1];G=(B(E,u[J+44>>1])+G|0)+B(s,u[J+46>>1])|0;V=(B(E,u[J+40>>1])+V|0)+B(s,u[J+42>>1])|0;k=k+1|0;if((k|0)!=7){continue}break}k=Vc(M+((V|0)/32768|0)|0);u[l>>1]=k;v[f>>2]=B(k,_);k=Vc(I+((G|0)/32768|0)|0);u[l+2>>1]=k;v[f+4>>2]=B(k,_);f=f+8|0;l=l+4|0;T=T-1|0;if(T){continue}break}}jb=$+32|0;l=ba+(N<<2)|0;h=e;k=o;G=v[k+4>>2];p=G&2047;f=r;if(f){aa=k+8256|0;F=k- -64|0;K=k+24640|0;Z=k+16448|0;while(1){da=u[(aa+((G+754&2047)<<2)|0)+2>>1];ea=u[aa+((G+1206&2047)<<2)>>1];H=u[(F+((G+1602&2047)<<2)|0)+2>>1];W=u[F+((G+1750&2047)<<2)>>1];s=K+((G+22&2047)<<2)|0;Y=u[s+2>>1];R=u[s>>1];s=K+((G+502&2047)<<2)|0;X=u[s+2>>1];Q=u[l>>1];V=u[l+2>>1];$=u[s>>1];T=Sc(u[k+32>>1]-$|0);J=u[k+24>>1];N=Sc(u[k+34>>1]-X|0);_=u[k+26>>1];M=Sc(u[k+36>>1]-R|0);I=u[k+28>>1];E=Sc(u[k+38>>1]-Y|0);s=u[k+30>>1];Ja=k,Ka=Vc(Sc((B(J,T)|0)/65536<<1)+$|0),u[Ja+32>>1]=Ka;Ja=k,Ka=Vc(Sc((B(N,_)|0)/65536<<1)+X|0),u[Ja+34>>1]=Ka;Ja=k,Ka=Vc(Sc((B(I,M)|0)/65536<<1)+R|0),u[Ja+36>>1]=Ka;Ja=k,Ka=Vc(Sc((B(s,E)|0)/65536<<1)+Y|0),u[Ja+38>>1]=Ka;E=Sc((B(u[k+32>>1],u[k+16>>1])|0)/32768|0);s=Sc((B(u[k+38>>1],u[k+22>>1])|0)/32768|0);_=Sc(E+((Q|0)/4<<16>>16)|0);M=Sc(s+((V|0)/4<<16>>16)|0);I=Sc(_+((B(W,u[k+8>>1])|0)/-65536|0)|0);X=p<<2;E=X+F|0;s=Sc(M+((B(H,u[k+10>>1])|0)/-65536|0)|0);u[E+2>>1]=s;u[E>>1]=I;I=Sc(W+((B(I,u[k+8>>1])|0)/65536|0)|0);E=X+Z|0;s=Sc(H+((B(s,u[k+10>>1])|0)/65536|0)|0);u[E+2>>1]=s;u[E>>1]=I;N=Sc(I+_|0);_=Sc(s+M|0);s=Z+((G+426&2047)<<2)|0;M=u[s+2>>1];I=u[s>>1];s=Z+((G+682&2047)<<2)|0;E=u[s+2>>1];s=u[s>>1];Q=Sc((B(E,u[k+42>>1])+B(s,u[k+40>>1])|0)/32768|0);V=Sc((B(M,u[k+46>>1])+B(I,u[k+44>>1])|0)/32768|0);$=Sc(Sc(s+N|0)-Q|0);T=Sc(Sc(E+_|0)-V|0);J=Sc(Sc(I+N|0)-Q|0);N=Sc(Sc(M+_|0)-V|0);_=Sc(Q+((B(ea,u[k+8>>1])|0)/-65536|0)|0);M=Sc(V+((B(da,u[k+10>>1])|0)/-65536|0)|0);E=u[k+8>>1];I=u[k+10>>1];s=X+aa|0;u[s+2>>1]=M;u[s>>1]=_;_=(B(E,_)|0)/65536|0;V=Sc(_+ea|0);E=K+X|0;M=(B(I,M)|0)/65536|0;s=Sc(M+da|0);u[E+2>>1]=s;u[E>>1]=V;I=Sc(V+$|0);E=u[k+48>>1];s=Sc(s+T|0);v[h>>2]=(v[h>>2]+B(E,I)|0)+B(s,u[k+50>>1]);I=Sc(Sc(_)+J|0);E=u[k+52>>1];s=Sc(Sc(M)+N|0);v[h+4>>2]=(v[h+4>>2]+B(E,I)|0)+B(s,u[k+54>>1]);h=h+8|0;l=l+4|0;G=p+1|0;p=G&2047;f=f-1|0;if(f){continue}break}}v[k+4>>2]=p;h=r+v[j+4180>>2]&4095;v[j+4180>>2]=h;f=r+v[j+4172>>2]&8191;v[j+4172>>2]=f;e=(r<<3)+e|0;q=q-r|0;if(q){continue}break}}v[j+4172>>2]=f&8191;f=i;h=m;o=0;k=0;i=j;q=v[i+4160>>2];l=v[i+4156>>2];e=g;if(e){m=v[i+4164>>2];n=v[i+4168>>2];while(1){o=v[f>>2];k=v[f+4>>2];n=n-k|0;n=(((n|0)/1024|0)-n|0)+q|0;v[h+4>>2]=n+v[h+4>>2];m=m-o|0;m=(((m|0)/1024|0)-m|0)+l|0;v[h>>2]=m+v[h>>2];q=n+((n|0)/-512|0)|0;l=m+((m|0)/-512|0)|0;h=h+8|0;f=f+8|0;n=k;m=o;e=e-1|0;if(e){continue}break}}v[i+4168>>2]=k;v[i+4164>>2]=o;v[i+4160>>2]=q;v[i+4156>>2]=l;me:{if(v[j+4116>>2]){v[j+4120>>2]=v[j+4124>>2];break me}e=v[j+4120>>2];if(e>>>0>g>>>0){v[j+4120>>2]=e-g;break me}EI(j);v[j+4120>>2]=0}v[j+4116>>2]=0}if(za){k=0;Q=0;j=A;m=j<<2;n=a;p=x[n+480214>>1]!=0;e=n+1074328|0;ca=z[e>>2];Ea=z[e+4>>2];while(1){g=(n+B(k,160)|0)+906300|0;e=v[g>>2];ne:{if(!e|!v[e+24>>2]){break ne}if(!rh(e+44|0)){break ne}i=v[g>>2];if(!(nb[v[v[i>>2]+108>>2]](i)|0)){nb[v[v[i>>2]+104>>2]](i,1);nb[v[v[i>>2]+116>>2]](i)}e=i+44|0;h=Pd(e,0);f=Pd(e,1);oe:{if(t[i+28|0]&1){Gy(v[i+24>>2],h,f,j,ca);break oe}e=i+40|0;if(!(v[i+36>>2]?0:!v[e>>2])){rn(v[i+24>>2],j,e,i+36|0);Gy(v[i+24>>2],h,f,j,ca);break oe}Rb(h,0,m);Rb(f,0,m)}v[i+28>>2]=v[i+28>>2]&-2;if(Hu(g)){break ne}p=!(w[i+28|0]&4)|p}k=k+1|0;if((k|0)!=250){continue}break}l=n+12|0;i=n+12300|0;h=n+14348|0;Gy(l,i,h,j,ca);e=n+1074464|0;r=w[e|0];t[e|0]=0;g=i;m=h;while(1){N=(n+B(Q,160)|0)+906300|0;e=v[N>>2];pe:{if(!e|!v[e+24>>2]){break pe}if(!rh(e+44|0)){break pe}M=v[N>>2];qe:{if(Hu(N)){break qe}e=v[N>>2];if(nb[v[v[e>>2]+140>>2]](e)|w[v[N>>2]+28|0]&2){break qe}k=0;if(!Q){break pe}while(1){if((Ij((n+B(k,160)|0)+906300|0)|0)==(Q|0)){break qe}k=k+1|0;if((Q|0)!=(k|0)){continue}break}break pe}e=M+44|0;I=Pd(e,0);s=Pd(e,1);_=v[N>>2];o=(g|0)==(I|0);g=o?i:g;e=g;m=o?h:m;f=m;re:{if(!(w[N+28|0]|w[N+29|0]<<8|(w[N+30|0]<<16|w[N+31|0]<<24))){break re}e=g;q=Ij(N);f=m;if(q>>>0<=Q>>>0){break re}f=m;if((q|0)==255){break re}q=v[(n+B(q,160)|0)+906300>>2];f=m;if(!q){break re}if(!(w[_+28|0]&4)){nb[v[v[q>>2]+144>>2]](q)}q=q+44|0;f=m;if(!rh(q)){break re}e=Pd(q,0);f=Pd(q,1)}se:{if(!Hu(N)){break se}te:{if(o){break te}k=0;if(!j){break te}while(1){E=k<<2;q=E+I|0;o=g+E|0;z[q>>2]=z[q>>2]+z[o>>2];q=s+E|0;J=q;ca=z[q>>2];q=m+E|0;z[J>>2]=ca+z[q>>2];v[o>>2]=0;v[q>>2]=0;k=k+1|0;if((j|0)!=(k|0)){continue}break}}m=f;g=e;if(!(p&1)){break se}g=v[N>>2];if(g){nb[v[v[g>>2]+144>>2]](g)}g=e;k=Ij(N);if(k>>>0>249|k>>>0<=Q>>>0){break se}while(1){m=k&255;g=(n+B(m,160)|0)+906300|0;k=Ij(g);g=v[g>>2];if(g){nb[v[v[g>>2]+144>>2]](g)}if(k>>>0>m>>>0?k>>>0<=249:0){continue}break}m=f;g=e}ue:{ve:{if(!((w[N+24|0]&2)>>>1|0)){if(!kC(N)|!(w[_+28|0]&4)){break ve}}k=0;if(!j){break ue}while(1){o=k<<2;q=o+e|0;z[q>>2]=z[q>>2]+z[o+I>>2];q=f+o|0;z[q>>2]=z[q>>2]+z[o+s>>2];k=k+1|0;if((j|0)!=(k|0)){continue}break}break ue}if(r){nb[v[v[M>>2]+124>>2]](M)}nb[v[v[M>>2]+60>>2]](M,e,f,j);v[_+32>>2]=j+v[_+32>>2];if(!kC(N)){break ue}if((nb[v[v[M>>2]+152>>2]](M)|0)<1|y[_+32>>2]<v[n+24620>>2]<<2>>>0){break ue}k=0;we:{if(!j){break we}while(1){xe:{q=k<<2;ca=z[q+e>>2];if(ca>=C(1.1920928955078125e-7)|ca<=C(-1.1920928955078125e-7)){break xe}ca=z[f+q>>2];if(ca>=C(1.1920928955078125e-7)|!(ca>C(-1.1920928955078125e-7))){break xe}k=k+1|0;if((j|0)!=(k|0)){continue}break we}break}v[_+32>>2]=0;break ue}v[_+28>>2]=v[_+28>>2]|4}v[_+28>>2]=v[_+28>>2]&-3}Q=Q+1|0;if((Q|0)!=250){continue}break}ye:{if(!j){break ye}e=1;while(1){f=l;ca=C(z[g>>2]*Ea);ze:{if(C(D(ca))<C(2147483648)){i=~~ca;break ze}i=-2147483648}v[f>>2]=i;f=l;ca=C(z[m>>2]*Ea);Ae:{if(C(D(ca))<C(2147483648)){i=~~ca;break Ae}i=-2147483648}v[f+4>>2]=i;if((e|0)==(j|0)){break ye}l=l+8|0;m=m+4|0;g=g+4|0;e=e+1|0;continue}}}if(v[a+24624>>2]==1){m=ra;e=0;g=A;if(g){while(1){f=e<<3;v[m+(e<<2)>>2]=(v[m+(f|4)>>2]+v[f+m>>2]|0)/2;e=e+1|0;if((g|0)!=(e|0)){continue}break}}}if(w[Ha+36|0]){m=A;r=jb-16|0;jb=r;Be:{Ce:{h=a;De:{if(!v[h+1074376>>2]){o=h+1074448|0;e=o;v[e>>2]=0;v[e+4>>2]=0;v[h+1074456>>2]=v[h+1074444>>2];break De}g=v[h+1074456>>2];i=v[h+1074444>>2];Ee:{if((g|0)==(i|0)){f=v[h+1074448>>2];break Ee}v[h+1074456>>2]=i;f=h+24604|0;e=h+1074448|0;Fe:{if((i|0)>(g|0)){f=uO(f);break Fe}f=tO(f)}v[e>>2]=f;v[h+1074452>>2]=f}o=h+1074448|0;if((f|0)>=1){break Ce}}q=0;break Be}i=(v[h+1074456>>2]<<12)-v[h+1074460>>2]|0;q=(i|0)/(f|0)|0;if(v[h+1074368>>2]!=2){break Be}v[r+12>>2]=50;v[r+8>>2]=1e4/(v[h+1074452>>2]+1|0);g=v[zf(r+12|0,r+8|0)>>2];e=q>>31;if((g|0)>=(e+q^e)){break Be}f=v[h+1074448>>2];e=v[h+1074452>>2];while(1){f=f+e|0;q=(i|0)/(f|0)|0;n=q>>31;if((g|0)<(n^n+q)){continue}break}v[o>>2]=f}Ge:{He:{switch(v[h+24624>>2]-1|0){case 0:if((m|0)<1){break Ge}e=v[h+1074444>>2];j=e<<12;g=e;n=e>>31;f=h+12|0;e=0;while(1){Ie:{if(v[o>>2]>=1){l=v[h+1074460>>2]+q|0;v[h+1074460>>2]=l;i=v[f>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,l,l>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;v[h+1074448>>2]=v[h+1074448>>2]-1;break Ie}i=v[f>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,g,n),mb,256,0),mb),v[Ja>>2]=Ka;v[h+1074460>>2]=j}f=f+4|0;e=e+1|0;if((m|0)!=(e|0)){continue}break};break Ge;case 1:if((m|0)<1){break Ge}e=v[h+1074444>>2];n=e<<12;g=e;l=e>>31;f=h+12|0;e=0;while(1){Je:{if(v[o>>2]>=1){j=v[h+1074460>>2]+q|0;v[h+1074460>>2]=j;i=v[f>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,j,j>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;i=v[h+1074460>>2];j=i;k=i>>31;i=v[f+4>>2];Ja=f,Ka=yc(Gma(Fma(j,k,i,i>>31),mb,1048576,0),mb),v[Ja+4>>2]=Ka;v[h+1074448>>2]=v[h+1074448>>2]-1;break Je}i=v[f>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,g,l),mb,256,0),mb),v[Ja>>2]=Ka;i=v[f+4>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,g,l),mb,256,0),mb),v[Ja+4>>2]=Ka;v[h+1074460>>2]=n}f=f+8|0;e=e+1|0;if((m|0)!=(e|0)){continue}break};break Ge;case 3:break He;default:break Ge}}if((m|0)<1){break Ge}e=v[h+1074444>>2];n=e<<12;g=e;l=e>>31;f=h+12|0;e=h+8204|0;p=0;while(1){Ke:{if(v[o>>2]>=1){j=v[h+1074460>>2]+q|0;v[h+1074460>>2]=j;i=v[f>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,j,j>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;i=v[h+1074460>>2];j=i;k=i>>31;i=v[f+4>>2];Ja=f,Ka=yc(Gma(Fma(j,k,i,i>>31),mb,1048576,0),mb),v[Ja+4>>2]=Ka;i=v[h+1074460>>2];j=i;k=i>>31;i=v[e>>2];Ja=e,Ka=yc(Gma(Fma(j,k,i,i>>31),mb,1048576,0),mb),v[Ja>>2]=Ka;i=v[h+1074460>>2];j=i;k=i>>31;i=v[e+4>>2];Ja=e,Ka=yc(Gma(Fma(j,k,i,i>>31),mb,1048576,0),mb),v[Ja+4>>2]=Ka;v[h+1074448>>2]=v[h+1074448>>2]-1;break Ke}i=v[f>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,g,l),mb,256,0),mb),v[Ja>>2]=Ka;i=v[f+4>>2];Ja=f,Ka=yc(Gma(Fma(i,i>>31,g,l),mb,256,0),mb),v[Ja+4>>2]=Ka;i=v[e>>2];Ja=e,Ka=yc(Gma(Fma(i,i>>31,g,l),mb,256,0),mb),v[Ja>>2]=Ka;i=v[e+4>>2];Ja=e,Ka=yc(Gma(Fma(i,i>>31,g,l),mb,256,0),mb),v[Ja+4>>2]=Ka;v[h+1074460>>2]=n}e=e+8|0;f=f+8|0;p=p+1|0;if((m|0)!=(p|0)){continue}break}}jb=r+16|0}if(v[ya>>2]!=128){f=a+12|0;m=a+8204|0;e=A;h=v[a+24604>>2];g=v[a+24624>>2];Le:{if((h|0)==128|g>>>0<2){break Le}$K(f,e,h);if(g>>>0<4){break Le}$K(m,e,h)}}m=c;g=ra;e=v[a+24624>>2];if((e|0)==4){f=ra;e=Ga;k=A-1|0;if((k|0)>-1){while(1){n=k<<4;i=k<<3;h=i|4;v[f+(n|12)>>2]=v[h+e>>2];v[f+(n|8)>>2]=v[e+i>>2];v[f+(n|4)>>2]=v[f+h>>2];v[f+n>>2]=v[f+i>>2];h=(k|0)>0;k=k-1|0;if(h){continue}break}}e=v[a+24624>>2]}nb[v[v[c>>2]+8>>2]](m,g,e,A);m=v[a+1074380>>2]-A|0;v[a+1074380>>2]=m;v[a+1074376>>2]=A+v[a+1074376>>2];Fa=A+Fa|0;b=b-A|0;if(!b){break h}n=v[a+480208>>2];if(!(n&512)){continue}break}}jb=ha+32|0;return Fa|0}function $ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;d=jb-608|0;jb=d;Jc(b);g=jb-16|0;jb=g;k=d+416|0;Zp(g+8|0,k);h=Hb(g+8|0);e=b;j=nc(e,ac(g,g+8|0));if((h|0)==(j|0)){$b(e,Hb(g+8|0))}jb=g+16|0;e=(h|0)==(j|0);if(!e){RR(k)}a:{b:{c:{if(!e){break c}if(!sS(d+416|0)){break c}if(!Qb(b,id(rS(d+416|0),mb))){break c}if(!c){f=1;break c}Hd(a,32);t[d+415|0]=0;k=gd(d+400|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if(v[d+416>>2]==778924148){v[114578]=0;R(621,a|0,16777216);e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;e=T(255,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(256,b|0,e-4|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;r=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break H}break b}I:{J:{K:{L:{if((w[d+456|0]|w[d+457|0]<<8)>>>0<2185|(w[d+456|0]|w[d+457|0]<<8)>>>0>4095){break L}v[114578]=0;e=T(255,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;Q(256,b|0,e-4|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;r=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}if(r>>>0<256){break L}v[114578]=0;e=T(255,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(e>>>0<=r>>>0){break L}v[114578]=0;e=Q(256,b|0,r|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!e){break L}v[114578]=0;e=Q(622,b|0,13434)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!e){break L}v[114578]=0;R(621,a|0,16777216);e=v[114578];v[114578]=0;if((e|0)==1){break b}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=4096){v[114578]=0;b=Q(623,d+224|0,13438)|0;c=v[114578];v[114578]=0;if((c|0)==1){break G}v[114578]=0;R(624,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);f=0;break d}f=P()|0;O()|0;yb(b);break a}if((w[d+456|0]|w[d+457|0]<<8)>>>0<2194){break L}v[114578]=0;e=Q(623,d+224|0,13534)|0;f=v[114578];v[114578]=0;if((f|0)==1){break K}v[114578]=0;R(624,a|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break J}yb(e)}if(v[a+480180>>2]!=32){break H}if(((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break I}v[a+1074304>>2]=((w[d+456|0]|w[d+457|0]<<8)&4095)<<16;if(v[d+476>>2]!=1414548815){break H}t[d+415|0]=1;break H}f=P()|0;O()|0;break a}f=P()|0;O()|0;yb(e);break a}if(!((w[d+456|0]|w[d+457|0]<<8)!=2184?(w[d+458|0]|w[d+459|0]<<8)!=2184:0)){t[d+415|0]=1;v[a+1074304>>2]=18284544;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=535|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[114578]=0;e=W(625,d+480|0,255,64)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}M:{if(e){v[a+1074304>>2]=18219008;v[114578]=0;e=Q(2,d+224|0,13680)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break M}f=P()|0;O()|0;break a}v[a+1074304>>2]=18284544;v[114578]=0;e=Q(2,d+224|0,13708)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}}Gb(k,e);yb(e);t[d+415|0]=1;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=514|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[a+1074304>>2]=17367040;v[114578]=0;e=Q(2,d+224|0,13744)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);t[d+415|0]=1;break H}f=P()|0;O()|0;break a}if((w[d+456|0]|w[d+457|0]<<8)!=768|(w[d+458|0]|w[d+459|0]<<8)!=768|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|(w[d+448|0]|w[d+449|0]<<8)!=256)){break H}if(w[d+469|0]|w[d+468|0]!=128){break H}v[a+1074304>>2]=18285088;t[d+415|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+460|0]|w[d+461|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+460|0]|w[d+461|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+460|0]|w[d+461|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+460|0]|w[d+461|0]<<8)<<3&32768;v[114578]=0;U(626,d+328|0,3,d+416|4);e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;R(417,d+224|0,d+328|0);e=v[114578];v[114578]=0;if((e|0)==1){break E}Gb(a+1304400|0,d+224|0);yb(d+224|0);if(!(!(w[d+462|0]&4)|(y[a+1074304>>2]<18285314?v[a+1074304>>2]:0))){v[a+480216>>2]=w[d+446|0];v[a+480220>>2]=w[d+447|0]}e=w[d+464|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+466|0]){v[a+480196>>2]=w[d+466|0]}t[d+224|0]=31;e=w[d+467|0];v[114578]=0;t[d+328|0]=e;e=Q(455,d+224|0,d+328|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);e=w[d+465|0];v[114578]=0;t[d+224|0]=e;t[d+328|0]=128;e=Q(393,d+224|0,d+328|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];f=0;while(1){j=(d+416|0)+f|0;g=j- -64|0;N:{if(w[g|0]==255){break N}v[114578]=0;h=(f<<5)+a|0;e=h+480280|0;Z(434,e|0);i=v[114578];v[114578]=0;if((i|0)==1){break D}C=h+480286|0,D=Cd(w[j+128|0],0,64),u[C>>1]=D;if(t[g|0]<=-1){v[e>>2]=v[e>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[h+480284>>1]=g<<2;break N}if((g|0)!=100){break N}v[e>>2]=v[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}v[114578]=0;Q(256,b|0,192)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}O:{if(!(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2187|(w[d+456|0]|w[d+457|0]<<8)>>>0>2189)){f=0;v[114578]=0;e=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}if(e){break d}v[114578]=0;e=T(392,b|0)|0;g=v[114578];v[114578]=0;P:{if((g|0)==1){break P}if(e>>>0>x[v[19811]+12>>1]){break d}g=Vb(a+484360|0);v[114578]=0;e=ea(627,g|0,b|0,e|0,65535,65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break P}if(!e){break d}break O}f=P()|0;O()|0;break a}e=Vb(a+484360|0);f=w[d+448|0]|w[d+449|0]<<8;v[114578]=0;ea(581,e|0,b|0,f|0,255,254)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}}q=Jp(d+384|0);p=Jp(d+368|0);m=Jp(d+352|0);e=w[d+450|0]|w[d+451|0]<<8;f=0;v[114578]=0;e=W(628,b|0,q|0,e|0)|0;g=v[114578];v[114578]=0;Q:{if((g|0)==1){break Q}if(!e){break A}e=w[d+452|0]|w[d+453|0]<<8;v[114578]=0;e=W(628,b|0,p|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Q}if(!e){break A}e=w[d+454|0]|w[d+455|0]<<8;v[114578]=0;e=W(628,b|0,m|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Q}if(!e){break A}v[d+348>>2]=-1;C=d,D=bc(q),v[C+224>>2]=D;C=d,D=cc(q),v[C+328>>2]=D;if(!Jb(d+224|0,d+328|0)){break B}while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}_d(d+224|0);if(Jb(d+224|0,d+328|0)){continue}break}break B}f=P()|0;O()|0;break g}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}C=d,D=bc(p),v[C+224>>2]=D;C=d,D=cc(p),v[C+328>>2]=D;if(Jb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}_d(d+224|0);if(Jb(d+224|0,d+328|0)){continue}break}}C=d,D=bc(m),v[C+224>>2]=D;C=d,D=cc(m),v[C+328>>2]=D;if(Jb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}_d(d+224|0);if(Jb(d+224|0,d+328|0)){continue}break}}R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if(t[d+462|0]&1){e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114578]=0;v[d+224>>2]=e;e=Q(333,d+348|0,d+224|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}v[d+348>>2]=v[e>>2]}f=0;da:{if((w[d+458|0]|w[d+459|0]<<8)!=532|(w[d+456|0]|w[d+457|0]<<8?(w[d+456|0]|w[d+457|0]<<8)!=532:0)|(w[d+447|0]|w[d+446|0])){break da}if(w[d+460|0]&192|(w[d+469|0]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break da}ea:{if(!(w[d+452|0]|w[d+453|0]<<8)|(w[d+450|0]|w[d+451|0]<<8)){break ea}if((v[b+8>>2]+(Kb(p)<<2)|0)+2>>>0>y[d+348>>2]){break ea}if(w[d+452|0]|w[d+453|0]<<8){e=0;while(1){v[114578]=0;f=T(392,b|0)|0;g=v[114578];v[114578]=0;fa:{if((g|0)!=1){if(!f){break fa}fg(b,((e&65535)<<2)+4|0);break ea}f=P()|0;O()|0;break g}e=e+1|0;if((e&65535)>>>0<(w[d+452|0]|w[d+453|0]<<8)>>>0){continue}break}}v[114578]=0;e=Q(2,d+224|0,13772)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}Gb(k,e);yb(e)}f=1;if(w[d+456|0]|w[d+457|0]<<8){break da}v[114578]=0;e=Q(2,d+224|0,13785)|0;g=v[114578];v[114578]=0;if((g|0)==1){break $}Gb(k,e);yb(e)}ga:{if(w[d+462|0]&2){v[114578]=0;e=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break _}v[114578]=0;g=e<<3;h=Q(258,b|0,g|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break _}if(!(!h|y[d+348>>2]<g+v[b+8>>2]>>>0)){v[114578]=0;g=a+1304500|0;R(629,g|0,e|0);h=v[114578];v[114578]=0;if((h|0)==1){break _}C=d,D=bc(g),v[C+328>>2]=D;C=d,D=cc(g),v[C+312>>2]=D;if(Jb(d+328|0,d+312|0)){while(1){g=v[d+328>>2];v[114578]=0;Q(630,b|0,d+224|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Z}v[114578]=0;R(631,d+224|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break Z}v[d+328>>2]=v[d+328>>2]+48;if(Jb(d+328|0,d+312|0)){continue}break}}if(!(!e&f)){break ga}if(w[d+462|0]&4){v[114578]=0;e=Q(2,d+224|0,13796)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);break ga}f=P()|0;O()|0;break g}v[114578]=0;e=Q(2,d+224|0,13813)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);break ga}f=P()|0;O()|0;break g}fg(b,2);break ga}if(!f|(w[d+462|0]|w[d+463|0]<<8)>>>0>1){break ga}v[114578]=0;e=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ba}if(!e){v[114578]=0;e=Q(2,d+224|0,13772)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(k,e);yb(e);break ga}f=P()|0;O()|0;break g}fg(b,2)}ha:{if(w[d+462|0]&8?0:!(w[d+460|0]&128)){break ha}v[114578]=0;e=a+901404|0;f=Q(632,b|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}if(!f){break ha}v[114578]=0;Z(633,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}}if((w[d+456|0]|w[d+457|0]<<8)>>>0<=531){v[114578]=0;Z(634,a+901404|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}}v[114578]=0;s=T(277,d+328|0)|0;e=v[114578];v[114578]=0;ia:{ja:{ka:{la:{ma:{na:{if((e|0)!=1){v[114578]=0;e=Q(618,b|0,13819)|0;f=v[114578];v[114578]=0;if((f|0)==1){break na}if(e){v[114578]=0;e=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ma}v[114578]=0;U(343,d+224|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break ma}Wd(s,d+224|0);Bb(d+224|0)}u[a+480188>>1]=1;v[114578]=0;e=Q(618,b|0,13824)|0;f=v[114578];v[114578]=0;if((f|0)==1){break na}if(e){v[114578]=0;e=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break la}v[114578]=0;U(343,d+224|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break la}v[114578]=0;e=T(255,d+224|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ka}v[114578]=0;u[d+312>>1]=(e>>>0)/20;e=Q(478,13830,d+312|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ka}e=x[e>>1];u[a+480188>>1]=e;if(e){f=0;while(1){v[114578]=0;W(635,d+224|0,((f<<5)+a|0)+480289|0,20)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ka}f=f+1|0;if((e|0)!=(f|0)){continue}break}}Bb(d+224|0)}if(y[b+8>>2]>y[d+348>>2]){break ja}e=v[d+348>>2]-v[b+8>>2]|0;break ia}f=P()|0;O()|0;break g}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;Bb(d+224|0);break i}v[114578]=0;e=T(332,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Y}}v[114578]=0;U(343,d+312|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break Y}v[114578]=0;z=Q(636,a|0,d+312|0)|0;e=v[114578];v[114578]=0;oa:{pa:{if((e|0)==1){break pa}if(!(t[d+462|0]&1)|!(w[d+470|0]|w[d+471|0]<<8)){break oa}e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break pa}if(!e){break oa}e=w[d+470|0]|w[d+471|0]<<8;v[114578]=0;aa(584,a+1304424|0,b|0,e|0,4)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break oa}}f=P()|0;O()|0;break j}f=0;u[a+480192>>1]=0;if(w[d+460|0]&4){e=w[d+450|0]|w[d+451|0]<<8;v[114578]=0;u[d+224>>1]=e;u[d+208>>1]=255;e=Q(478,d+224|0,d+208|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break X}u[a+480192>>1]=x[e>>1]}if(x[a+480192>>1]){while(1){e=Pb(q,f);qa:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break qa}e=Pb(q,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break W}if(!e){break qa}v[114578]=0;e=Q(258,b|0,554)|0;g=v[114578];v[114578]=0;if((g|0)==1){break W}if(!e){break qa}v[114578]=0;e=W(456,a|0,f+1&65535,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break V}if(!e){break qa}g=w[d+458|0]|w[d+459|0]<<8;v[114578]=0;aa(637,a|0,b|0,e|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break V}t[e+33|0]=w[d+469|0]}f=f+1|0;if(f>>>0<x[a+480192>>1]){continue}break}}v[d+308>>2]=0;if(w[d+452|0]|w[d+453|0]<<8){e=Pb(p,(w[d+452|0]|w[d+453|0]<<8)-1|0);v[d+308>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}e=w[d+452|0]|w[d+453|0]<<8;v[114578]=0;u[d+224>>1]=e;u[d+208>>1]=3999;e=Q(478,d+224|0,d+208|0)|0;f=v[114578];v[114578]=0;ra:{if((f|0)!=1){u[a+480190>>1]=x[e>>1];f=0;if(x[a+480190>>1]){break ra}g=0;break R}f=P()|0;O()|0;break j}j=c&2;n=d+244|0;g=0;while(1){e=Pb(p,f);sa:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break sa}e=Pb(p,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;h=v[114578];v[114578]=0;ta:{ua:{va:{wa:{xa:{ya:{za:{if((h|0)==1){break za}if(!e){break sa}v[114578]=0;e=Q(638,b|0,d+224|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break za}if(!e){break sa}v[114578]=0;i=f+1|0;e=B(i,104)+a|0;h=e+484380|0;o=Q(639,d+224|0,h|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ya}v[114578]=0;U(626,d+192|0,3,n|0);l=v[114578];v[114578]=0;if((l|0)==1){break xa}v[114578]=0;R(417,d+208|0,d+192|0);l=v[114578];v[114578]=0;if((l|0)==1){break xa}v[114578]=0;Q(371,((i<<5)+a|0)+946300|0,d+208|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break wa}yb(d+208|0);v[114578]=0;o=Q(256,b|0,o|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break ya}if(!o){break sa}e=x[e+484414>>1];if(!(e&512)){break va}v[114578]=0;e=Q(640,b|0,d+208|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){if(!e){break ua}v[114578]=0;v[d+16>>2]=v[d+216>>2];e=v[d+212>>2];v[d+8>>2]=v[d+208>>2];v[d+12>>2]=e;U(641,h|0,1,d+8|0);e=v[114578];v[114578]=0;if((e|0)!=1){break ua}}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(d+208|0);break j}if(!(e&16384)){e=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;U(642,d+208|0,d+224|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break S}Aa:{if(j){e=0;v[114578]=0;W(402,d+208|0,h|0,b|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){break Aa}break S}e=1;i=w[d+211|0];if(i>>>0>18){break Aa}i=1<<i;Ba:{if(!(i&126991)){if(i&396800){break Ba}break Aa}if(!w[d+208|0]){break Aa}}e=v[h>>2];v[114578]=0;i=Q(643,d+208|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break S}e=0;v[114578]=0;Q(340,b|0,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break S}}if(w[d+211|0]!=1){break ta}g=v[h>>2]!=0|g;break ta}v[114578]=0;Q(644,b|0,d+188|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break T}e=v[d+188>>2];if(!(!j|!e)){e=Wb(d+208|0);v[114578]=0;W(482,b|0,e|0,v[d+188>>2])|0;h=v[114578];v[114578]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((h|0)!=1){v[114578]=0;h=Q(2,d+160|0,13832)|0;o=v[114578];v[114578]=0;if((o|0)==1){break Ka}v[114578]=0;R(219,d+176|0,h|0);o=v[114578];v[114578]=0;if((o|0)==1){break Ja}v[114578]=0;v[d+156>>2]=i;U(13,d+144|0,0,e|0);i=v[114578];v[114578]=0;if((i|0)==1){break Ia}v[114578]=0;X(645,d+192|0,d+176|0,d+156|0,d+144|0);i=v[114578];v[114578]=0;if((i|0)==1){break Ha}v[114578]=0;U(646,a|0,2,d+192|0);i=v[114578];v[114578]=0;if((i|0)==1){break Ga}yb(d+192|0);yb(d+144|0);Ib(d+176|0);yb(h);yb(e);break ua}f=P()|0;O()|0;break Ca}f=P()|0;O()|0;break Ca}f=P()|0;O()|0;break Da}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;break Fa}f=P()|0;O()|0;yb(d+192|0)}yb(d+144|0)}Ib(d+176|0)}yb(h)}yb(e);break j}v[114578]=0;Q(340,b|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break T}}e=0}h=v[b+8>>2];v[114578]=0;v[d+208>>2]=h;h=Q(647,d+308|0,d+208|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break U}v[d+308>>2]=v[h>>2];A=(e|0)!=0}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}break R}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break i}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}u[d+224>>1]=1;e=x[a+480190>>1];v[114578]=0;u[d+208>>1]=e;e=Q(454,d+224|0,d+208|0)|0;f=v[114578];v[114578]=0;La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{if((f|0)!=1){u[a+480190>>1]=x[e>>1];Xa:{if(!(g&1)|(w[d+456|0]|w[d+457|0]<<8)!=516|(w[d+462|0]|w[d+463|0]<<8|(w[d+458|0]|w[d+459|0]<<8)!=512)){break Xa}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&65527)!=21|(w[d+464|0]!=128|w[d+465|0]!=48)){break Xa}if(w[d+469|0]|w[d+468|0]!=128|(w[d+470|0]|w[d+471|0]<<8)){break Xa}g=d+544|0;e=d+480|0;f=1;while(1){f=(w[e|0]|128)!=160?0:f;e=e+1|0;if((g|0)!=(e|0)){continue}break}g=d+608|0;e=d+544|0;while(1){f=w[e|0]==64&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=20;while(1){f=!w[(d+e|0)+420|0]&f;e=e+1|0;if(e>>>0<26){continue}break}if(!f){break Xa}v[114578]=0;e=Q(2,d+224|0,13910)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ma}Gb(k,e);yb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;C=d,D=Kb(m),u[C+224>>1]=D;e=v[a+8>>2];v[114578]=0;e=Q(478,d+224|0,e+10|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Wa}e=x[e>>1];u[d+188>>1]=e;if((Kb(m)|0)!=(e|0)){v[114578]=0;R(509,d+208|0,13924);e=v[114578];v[114578]=0;if((e|0)==1){break Va}e=Kb(m);v[114578]=0;v[d+192>>2]=e;X(648,d+128|0,d+208|0,d+192|0,d+188|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ua}v[114578]=0;e=Q(649,d+224|0,d+128|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ta}v[114578]=0;R(624,a|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break Sa}yb(e);yb(d+128|0);Ib(d+208|0)}if(c&1){break Pa}u[d+188>>1]=0;break Oa}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Qa}f=P()|0;O()|0;break Ra}f=P()|0;O()|0;yb(e)}yb(d+128|0)}Ib(d+208|0);break j}if(!x[d+188>>1]){break Oa}e=0;while(1){c=Pb(m,e);Ya:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break Ya}c=Pb(m,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Na}if(!c){break Ya}v[114578]=0;c=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}v[114578]=0;h=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}if((h-1&65535)>>>0>1023){break Ya}v[114578]=0;f=Q(340,b|0,4)|0;g=v[114578];v[114578]=0;if((g|0)==1){break l}if(!f){break Ya}v[114578]=0;U(343,d+224|0,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break m}c=0;f=x[a+480188>>1];v[114578]=0;g=Q(650,d+208|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}while(1){Za:{v[114578]=0;f=Q(258,d+224|0,1)|0;j=v[114578];v[114578]=0;_a:{$a:{if((j|0)!=1){if(!f){break Za}v[114578]=0;f=T(389,d+224|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}j=f<<24>>24;if(j){break $a}c=c+1|0;break _a}break p}ab:{f=j&127;i=f?f-1|0:0;f=i&65535;if(Ac(g)>>>0>f>>>0){break ab}v[114578]=0;t[d+192|0]=0;U(651,g|0,f+1|0,d+192|0);n=v[114578];v[114578]=0;if((n|0)!=1){break ab}break p}if((j|0)<=-1){v[114578]=0;j=T(389,d+224|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break p}C=xc(g,f),D=j,t[C|0]=D}if(!(!(w[xc(g,f)|0]&15)|f>>>0<x[a+480188>>1])){u[a+480188>>1]=i+1}if(t[xc(g,f)|0]&1){v[114578]=0;Q(340,d+224|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}}if(w[xc(g,f)|0]&2){v[114578]=0;Q(340,d+224|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}}if(w[xc(g,f)|0]&4){v[114578]=0;Q(340,d+224|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}}if(!(w[xc(g,f)|0]&8)){break _a}v[114578]=0;Q(340,d+224|0,2)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}}if(c>>>0<h>>>0){continue}}break}c=v[b+8>>2];v[114578]=0;v[d+192>>2]=c;c=Q(647,d+308|0,d+192|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}v[d+308>>2]=v[c>>2];fe(g);Bb(d+224|0)}e=e+1|0;if(e>>>0<x[d+188>>1]){continue}break}}bb:{cb:{c=v[d+308>>2];if(!c){break cb}v[114578]=0;Q(256,b|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}if(!A){break cb}while(1){db:{v[114578]=0;c=Q(258,b|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break db}if(!c){break cb}v[114578]=0;c=Q(618,b|0,14016)|0;e=v[114578];v[114578]=0;if((e|0)==1){break db}eb:{if(!c){v[114578]=0;c=Q(618,b|0,14021)|0;e=v[114578];v[114578]=0;if((e|0)==1){break db}if(!c){break eb}}v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break bb}fg(b,8);if(c&-2139062144){break eb}if(c&1616928864){break cb}}v[114578]=0;c=T(359,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break db}v[114578]=0;Q(340,b|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}f=P()|0;O()|0;break j}v[114578]=0;c=Q(652,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}c=c|w[d+415|0];t[d+415|0]=c;if(!(!c|z)){Ft(a+1074308|0);v[a+1074368>>2]=0}v[114578]=0;X(653,a|0,b|0,0,d+415|0);c=v[114578];v[114578]=0;if((c|0)==1){break q}v[114578]=0;n=a+484344|0;R(403,n|0,x[d+188>>1]);c=v[114578];v[114578]=0;if((c|0)==1){break q}u[d+156>>1]=0;if(!x[d+188>>1]){break La}f=0;while(1){fb:{gb:{c=Pb(m,f);hb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Pb(m,x[d+156>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break hb}if(c){break gb}}v[114578]=0;c=W(404,n|0,x[d+156>>1],64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break hb}if(!c){v[114578]=0;R(509,d+208|0,14026);c=v[114578];v[114578]=0;ib:{jb:{kb:{lb:{mb:{if((c|0)!=1){v[114578]=0;U(654,d+112|0,d+208|0,d+156|0);c=v[114578];v[114578]=0;if((c|0)==1){break mb}v[114578]=0;c=Q(649,d+224|0,d+112|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break lb}v[114578]=0;R(624,a|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break kb}yb(c);yb(d+112|0);Ib(d+208|0);break La}f=P()|0;O()|0;break j}f=P()|0;O()|0;break ib}f=P()|0;O()|0;break jb}f=P()|0;O()|0;yb(c)}yb(d+112|0)}Ib(d+208|0);break j}c=_b(n,x[d+156>>1]);v[114578]=0;R(655,c|0,s|0);c=v[114578];v[114578]=0;if((c|0)!=1){break fb}}f=P()|0;O()|0;break j}v[114578]=0;c=T(359,b|0)|0;e=v[114578];v[114578]=0;nb:{ob:{if((e|0)!=1){v[114578]=0;o=T(359,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ob}v[114578]=0;e=Q(340,b|0,4)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ob}if(!e){break fb}v[114578]=0;e=W(404,n|0,x[d+156>>1],o|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ob}if(e){break nb}break fb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}v[114578]=0;U(343,d+224|0,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){c=_b(n,x[d+156>>1]);v[114578]=0;R(655,c|0,s|0);c=v[114578];v[114578]=0;pb:{if((c|0)!=1){c=x[a+480188>>1];v[114578]=0;i=Q(650,d+208|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){c=x[a+480188>>1];Qh(d+176|0);v[114578]=0;j=W(656,d+192|0,c|0,d+176|0)|0;c=v[114578];v[114578]=0;qb:{if((c|0)!=1){C=d,D=bc(_b(n,x[d+156>>1])),v[C+144>>2]=D;l=0;rb:{if(!o){break rb}while(1){v[114578]=0;c=Q(258,d+224|0,1)|0;e=v[114578];v[114578]=0;sb:{if((e|0)!=1){tb:{if(!c){break rb}v[114578]=0;c=T(389,d+224|0)|0;e=v[114578];v[114578]=0;ub:{if((e|0)!=1){c=c<<24>>24;if(c){break ub}nS(d+144|0,x[a+480188>>1]);l=l+1|0;break sb}break tb}vb:{e=c&127;h=e?e-1&65535:0;if(Ac(i)>>>0>h>>>0){break vb}v[114578]=0;t[d+176|0]=0;e=h+1|0;U(651,i|0,e|0,d+176|0);f=v[114578];v[114578]=0;if((f|0)==1){break tb}Qh(d+176|0);v[114578]=0;U(657,j|0,e|0,d+176|0);e=v[114578];v[114578]=0;if((e|0)!=1){break vb}break tb}if((c|0)<=-1){v[114578]=0;c=T(389,d+224|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break tb}C=xc(i,h),D=c,t[C|0]=D}Qh(d+176|0);e=d+176|0;if(h>>>0<x[a+480188>>1]){e=Nc(d+144|0,h)}if(w[xc(i,h)|0]&16){C=e,D=w[Nc(j,h)|0],t[C|0]=D}if(w[xc(i,h)|0]&32){C=e,D=w[Nc(j,h)+1|0],t[C+1|0]=D}if(w[xc(i,h)|0]&64){C=e,D=w[Nc(j,h)+2|0],t[C+2|0]=D;C=e,D=w[Nc(j,h)+4|0],t[C+4|0]=D}if(t[xc(i,h)|0]<=-1){C=e,D=w[Nc(j,h)+3|0],t[C+3|0]=D;C=e,D=w[Nc(j,h)+5|0],t[C+5|0]=D}if(t[xc(i,h)|0]&1){v[114578]=0;c=T(389,d+224|0)|0;f=v[114578];v[114578]=0;g=e;wb:{xb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break xb}f=c;break wb}break tb}f=253;if((c-121&255)>>>0<132){break wb}f=(c&255)==253?0:c}t[g|0]=f;C=Nc(j,h),D=f,t[C|0]=D}if(w[xc(i,h)|0]&2){v[114578]=0;c=T(389,d+224|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break tb}t[e+1|0]=c;C=Nc(j,h),D=c,t[C+1|0]=D}if(w[xc(i,h)|0]&4){v[114578]=0;c=T(389,d+224|0)|0;f=v[114578];v[114578]=0;yb:{zb:{if((f|0)!=1){if(c>>>0>64){break zb}t[e+4|0]=c;t[e+2|0]=1;break yb}break tb}if(!(c<<24>>24>-1|c>>>0>192)){t[e+2|0]=2;t[e+4|0]=c^128;break yb}if(c>>>0<=74){t[e+2|0]=5;t[e+4|0]=c-65;break yb}if(c>>>0<=84){t[e+2|0]=6;t[e+4|0]=c-75;break yb}if(c>>>0<=94){t[e+2|0]=3;t[e+4|0]=c-85;break yb}if(c>>>0<=104){t[e+2|0]=4;t[e+4|0]=c-95;break yb}if(c>>>0<=114){t[e+2|0]=13;t[e+4|0]=c-105;break yb}if(c>>>0<=124){t[e+2|0]=12;t[e+4|0]=c-115;break yb}f=c+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;t[e+2|0]=11;break yb}f=c+53|0;g=f&255;if(g>>>0<=9){t[e+4|0]=f;t[e+2|0]=8;if(!g|!v[a+1074304>>2]|y[a+1074304>>2]>18285140){break yb}t[e+2|0]=7;break yb}c=c+33|0;if((c&255)>>>0>9){break yb}t[e+4|0]=c;t[e+2|0]=15}c=w[e+2|0];C=Nc(j,h),D=c,t[C+2|0]=D;c=w[e+4|0];C=Nc(j,h),D=c,t[C+4|0]=D}if(!(w[xc(i,h)|0]&8)){break sb}v[114578]=0;R(473,d+104|0,d+224|0);c=v[114578];v[114578]=0;if((c|0)!=1){Ab:{c=dd(d+104|0);t[e+3|0]=w[d+104|0];t[e+5|0]=w[c|0];v[114578]=0;R(658,e|0,1);c=v[114578];v[114578]=0;if((c|0)==1){break Ab}c=w[e+3|0];C=Nc(j,h),D=c,t[C+3|0]=D;c=w[e+5|0];C=Nc(j,h),D=c,t[C+5|0]=D;break sb}}}}f=P()|0;O()|0;Ll(j);break qb}if(l>>>0<o>>>0){continue}break}}Ll(j);fe(i);Bb(d+224|0);break fb}f=P()|0;O()|0}fe(i);break pb}f=P()|0;O()|0;break pb}f=P()|0;O()|0}Bb(d+224|0);break j}f=P()|0;O()|0;break j}c=x[d+156>>1]+1|0;u[d+156>>1]=c;f=c&65535;if(f>>>0<x[d+188>>1]){continue}break}break La}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}c=a+1074304|0;Bb:{Cb:{if(!v[a+1074304>>2]){Db:{if((w[d+456|0]|w[d+457|0]<<8)==2184){v[c>>2]=18284544;e=18284544;break Db}e=v[c>>2]}if(!e){break Cb}}if(!Wc(k)){break Cb}v[114578]=0;e=Q(2,d+208|0,14078)|0;f=v[114578];v[114578]=0;Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{if((f|0)!=1){v[114578]=0;R(242,d+192|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break Jb}v[114578]=0;U(3,d+224|0,e|0,d+192|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ib}Gb(k,d+224|0);yb(d+224|0);yb(d+192|0);yb(e);if(v[d+476>>2]==1414548815|((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break Eb}v[114578]=0;c=Q(2,d+224|0,14087)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Gb}v[114578]=0;Q(192,k|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Fb}yb(c);break Bb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Hb}f=P()|0;O()|0;yb(d+192|0)}yb(e);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}if(!fD(c)){break Bb}v[114578]=0;c=Q(2,d+224|0,14111)|0;e=v[114578];v[114578]=0;Kb:{if((e|0)!=1){v[114578]=0;Q(192,k|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Kb}yb(c);break Bb}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}Lb:{switch((w[d+456|0]|w[d+457|0]<<8)>>>12|0){case 0:if(z){v[114578]=0;c=Q(2,d+224|0,14125)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Bb}f=P()|0;O()|0;break j}Mb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+462|0]|w[d+463|0]<<8|(w[d+460|0]|w[d+461|0]<<8)!=9)){break Mb}if(w[d+447|0]|w[d+446|0]|(w[d+450|0]|w[d+451|0]<<8|((w[d+454|0]|w[d+455|0]<<8)+1|0)!=(w[d+448|0]|w[d+449|0]<<8))){break Mb}if(w[d+464|0]!=128|w[d+465|0]!=100|(w[d+466|0]!=1|w[d+468|0]!=128)){break Mb}if(w[d+469|0]|(w[d+470|0]|w[d+471|0]<<8)|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24)|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break Mb}v[114578]=0;c=Q(2,d+224|0,14137)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Bb}f=P()|0;O()|0;break j}Nb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+447|0]|w[d+446|0])){break Nb}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)){break Nb}v[c>>2]=16777381;v[114578]=0;c=Q(2,d+224|0,14156)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);t[d+415|0]=1;break Bb}f=P()|0;O()|0;break j}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|v[d+476>>2]!=1229080643)){v[114578]=0;c=Q(2,d+224|0,14179)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);v[114578]=0;Q(480,a+1074308|0,38)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}break Bb}f=P()|0;O()|0;break j}Ob:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|(w[d+469|0]|(w[d+462|0]|w[d+463|0]<<8)>>>0>1)){break Ob}if(!x[a+480190>>1]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&4294)!=4)){break Ob}v[114578]=0;c=Q(85,d+224|0,14192)|0;e=v[114578];v[114578]=0;Pb:{Qb:{if((e|0)!=1){v[114578]=0;e=Q(659,a+484527|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Qb}yb(c);if(!e){break Ob}v[114578]=0;c=Q(2,d+224|0,14205)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Pb}Gb(k,c);yb(c);break Bb}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}f=P()|0;O()|0;break j}Rb:{if(w[d+456|0]|w[d+457|0]<<8){break Rb}if(!Wc(k)){break Rb}v[114578]=0;c=Q(2,d+224|0,14219)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Bb}f=P()|0;O()|0;break j}if((w[d+458|0]|w[d+459|0]<<8)>>>0>767){break Bb}if(!Wc(k)){break Bb}Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{if((w[d+458|0]|w[d+459|0]<<8)>>>0>=533){v[114578]=0;c=Q(2,d+224|0,14227)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);break Yb}f=P()|0;O()|0;break j}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=533){v[114578]=0;c=Q(2,d+88|0,14248)|0;e=v[114578];v[114578]=0;Zb:{_b:{$b:{if((e|0)!=1){v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break $b}e=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;v[d+192>>2]=e-532;U(245,d+224|0,d+208|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break _b}Gb(k,d+224|0);yb(d+224|0);Ib(d+208|0);break Yb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Zb}f=P()|0;O()|0;Ib(d+208|0)}yb(c);break j}v[114578]=0;c=Q(2,d+72|0,14272)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Xb}v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break Wb}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114578]=0;v[d+144>>2]=e;R(660,d+192|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break Vb}v[114578]=0;X(645,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ub}Gb(k,d+224|0);yb(d+224|0);yb(d+192|0);Ib(d+208|0)}yb(c);c=a+1304500|0;if(!nd(c)|!(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24))){break Bb}e=w[d+456|0]|w[d+457|0]<<8;f=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114578]=0;e=Q(661,e|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break t}f=Sp(d+224|0);v[f+44>>2]=e;v[114578]=0;R(662,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)!=1){break Bb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Sb}f=P()|0;O()|0;break Tb}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(c);break j;case 1:c=w[d+456|0]|w[d+457|0]<<8;e=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114578]=0;U(663,d+224|0,c|0,e|0);c=v[114578];v[114578]=0;ac:{if((c|0)!=1){Gb(k,d+224|0);yb(d+224|0);if((w[d+456|0]|w[d+457|0]<<8)>>>0>=6092){break ac}v[114578]=0;Q(480,a+1074308|0,7)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break ac}break q}f=P()|0;O()|0;break j}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=6562){break Bb}v[114578]=0;Q(480,a+1074308|0,38)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}break Bb;case 4:v[114578]=0;c=Q(2,d+56|0,14294)|0;e=v[114578];v[114578]=0;bc:{cc:{dc:{ec:{fc:{if((e|0)!=1){v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break fc}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114578]=0;v[d+144>>2]=e;R(660,d+192|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break ec}v[114578]=0;X(645,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break dc}Gb(k,d+224|0);yb(d+224|0);yb(d+192|0);Ib(d+208|0);yb(c);break Bb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break bc}f=P()|0;O()|0;break cc}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(c);break j;case 6:v[114578]=0;c=Q(2,d+224|0,14125)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Bb}f=P()|0;O()|0;break j;case 7:if(!((w[d+456|0]|w[d+457|0]<<8)!=32767|(w[d+458|0]|w[d+459|0]<<8)!=533)){v[114578]=0;c=Q(2,d+224|0,14305)|0;e=v[114578];v[114578]=0;if((e|0)!=1){Gb(k,c);yb(c);break Bb}f=P()|0;O()|0;break j}v[114578]=0;c=Q(2,d+40|0,14314)|0;e=v[114578];v[114578]=0;gc:{hc:{ic:{if((e|0)!=1){v[114578]=0;R(219,d+208|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break ic}v[d+192>>2]=w[d+457|0]&15;v[d+176>>2]=(w[d+456|0]|w[d+457|0]<<8)>>>4&15;e=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;v[d+144>>2]=e&15;fa(239,d+224|0,d+208|0,d+192|0,d+176|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break hc}Gb(k,d+224|0);yb(d+224|0);Ib(d+208|0);yb(c);break Bb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break gc}f=P()|0;O()|0;Ib(d+208|0)}yb(c);break j;case 13:break Lb;default:break Bb}}v[114578]=0;c=Q(2,d+224|0,14329)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}Gb(k,c);yb(c)}jc:{if(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2186){break jc}v[114578]=0;c=Q(256,b|0,r|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}if(!c){break jc}c=w[d+456|0]|w[d+457|0]<<8;v[114578]=0;U(664,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break q}}c=v[a+480180>>2];kc:{if((c|0)==16777216){v[114578]=0;Q(2,d+224|0,14336)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break kc}f=P()|0;O()|0;break j}v[114578]=0;b=Q(2,d+24|0,14272)|0;e=v[114578];v[114578]=0;if((e|0)==1){break z}v[114578]=0;R(219,d+208|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break y}v[d+176>>2]=w[d+459|0];e=w[d+458|0];v[114578]=0;v[d+144>>2]=e;R(660,d+192|0,d+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break x}v[114578]=0;X(645,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114578];v[114578]=0;if((e|0)==1){break w}}Gb(a+1304436|0,d+224|0);yb(d+224|0);if((c|0)!=16777216){yb(d+192|0);Ib(d+208|0);yb(d+24|0)}lc:{if(v[a+480180>>2]==16777216){v[114578]=0;Q(2,d+224|0,14349)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break lc}break r}v[114578]=0;Q(2,d+224|0,14354)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}}Gb(a+1304448|0,d+224|0);yb(d+224|0);Gb(a+1304460|0,k);v[a+1304496>>2]=v[a+1074304>>2]?7:4;Bb(d+312|0);Bb(s);f=1}Ji(m);Ji(p);Ji(q);break d}f=P()|0;O()|0;break j}f=P()|0;O()|0;break u}f=P()|0;O()|0;break v}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(b);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;fe(g);break n}f=P()|0;O()|0}Bb(d+224|0);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0}Bb(d+312|0)}Bb(s);break g}f=P()|0;O()|0}Ji(m);Ji(p);Ji(q);break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}yb(k)}jb=d+608|0;return f|0}f=P()|0;O()|0}yb(k);S(f|0);L()}function kja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;e=jb-1584|0;jb=e;Jc(b);a:{b:{if(!Ff(b,e+1576|0)){break b}if(!QQ(e+1576|0)){break b}if(!c){f=1;break b}d=w[e+1576|3];t[e+1575|0]=d;v[e+1568>>2]=-1;v[e+1564>>2]=1048576;if(d>>>0>=5){d=Cf(b);v[e+1568>>2]=d;if(!Qb(b,d)){break b}v[e+208>>2]=134217727;J=e,K=v[Lb(e+208|0,e+1568|0)>>2]<<5,v[J+1564>>2]=K}D=rq(e+1552|0);d=e+1576|4;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;v[e+208>>2]=g;g=Q(333,e+1564|0,e+208|0)|0;f=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)==1){break y}g=v[g>>2];v[114578]=0;R(831,D|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break y}d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=0;v[114578]=0;d=W(832,b|0,D|0,d|0)|0;g=v[114578];v[114578]=0;z:{if((g|0)==1){break z}if(!d){break u}if(w[e+1575|0]>=5){v[114578]=0;Q(256,b|0,v[e+1568>>2]+12|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break z}}v[114578]=0;R(449,a|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break z}v[114578]=0;Z(477,a|0);d=v[114578];v[114578]=0;if((d|0)==1){break z}v[114578]=0;R(833,e+1528|0,D|0);g=v[114578];v[114578]=0;d=a;A:{B:{C:{D:{if((g|0)==1){break D}v[114578]=0;l=W(834,e+1536|0,e+1528|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break D}v[114578]=0;W(597,l|0,a+1304400|0,-1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;W(597,l|0,a+1304424|0,-1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;g=Q(835,l|0,e+1104|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break e}if(!g|!w[e+1104|0]|t[e+1104|0]<0){break v}g=e+1113|0;if((w[g|0]|w[g+1|0]<<8)>>>0>255){break v}h=e+1115|0;if((w[h|0]|w[h+1|0]<<8)>>>0>3999){break v}u[a+480188>>1]=w[e+1104|0];j=a+484360|0;o=e+1104|3;Oe(Vb(j),w[o|0]|w[o+1|0]<<8);u[a+480192>>1]=w[g|0]|w[g+1|0]<<8;u[a+480190>>1]=w[h|0]|w[h+1|0]<<8;g=e+1117|0;if(w[g|0]){break B}g=6;break A}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}g=w[g|0]}v[d+480196>>2]=g;d=a;h=e+1118|0;g=125e4;E:{if(!w[h|0]){break E}g=B(w[h|0],1e4)}v[d+480204>>2]=g;o=e+1119|0;F:{if(t[o+1|0]&1){v[114578]=0;R(621,a|0,32);d=v[114578];v[114578]=0;if((d|0)!=1){break F}break e}if(w[o|0]&2){v[114578]=0;R(621,a|0,2);d=v[114578];v[114578]=0;if((d|0)==1){break e}break F}if(w[o|0]&128){v[114578]=0;R(621,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break e}break F}if(w[o|0]&8){v[114578]=0;R(621,a|0,16);d=v[114578];v[114578]=0;if((d|0)==1){break e}break F}v[114578]=0;R(621,a|0,4);d=v[114578];v[114578]=0;if((d|0)==1){break e}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[o|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[o|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[o|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[o+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[o+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[o+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[o+2|0]&8){v[114578]=0;W(479,a+1074308|0,5,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}}G:{d=v[a+480180>>2];H:{if((d|0)!=2){if((d|0)!=32){break H}d=w[e+1123|0];v[114578]=0;t[e+208|0]=d;t[e+136|0]=128;d=Q(393,e+208|0,e+136|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break x}v[a+480200>>2]=w[d|0]<<1;break H}d=w[e+1123|0];v[114578]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(393,e+208|0,e+136|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break G}v[a+480200>>2]=w[d|0]<<2}G=a+480188|0;h=e+1125|0;g=t[h|0];d=a;if(t[h|0]<=-1){g=g+52|0}else{F=qw(+(g|0)*.15500000000000003);I:{if(F<4294967296&F>=0){g=~~F>>>0;break I}g=0}g=g+51|0}v[d+480228>>2]=g;v[114578]=0;u[e+208>>1]=64;d=Q(478,G|0,e+208|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){J:{g=x[d>>1];if(g){while(1){d=v[a+480180>>2];if((d|0)==32){d=w[(e+f|0)+1126|0];v[114578]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(393,e+208|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break J}u[((f<<5)+a|0)+480286>>1]=w[d|0];d=v[a+480180>>2]}K:{if((d|0)==4){break K}d=(e+f|0)+1190|0;if(w[d|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break K}if(w[d|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break K}u[((f<<5)+a|0)+480284>>1]=w[d|0]}f=f+1|0;if((g|0)!=(f|0)){continue}break}}f=0;h=0;while(1){f=w[(e+h|0)+1254|0]!=0|f;h=h+1|0;if((h|0)!=16){continue}break}while(1){f=w[((i<<1)+e|0)+1271|0]!=0|f;i=i+1|0;if((i|0)!=128){continue}break}if(f&1){f=0;while(1){L:{d=(e+f|0)+1254|0;if(w[d|0]){v[114578]=0;R(509,e+136|0,15167);g=v[114578];v[114578]=0;M:{N:{O:{P:{Q:{if((g|0)!=1){d=w[d|0];v[114578]=0;v[e+160>>2]=d-1;R(836,e+1088|0,e+160|0);d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;U(511,e+208|0,e+136|0,e+1088|0);d=v[114578];v[114578]=0;if((d|0)==1){break P}v[114578]=0;R(512,e+1072|0,((f<<5)+a|0)+901692|0);d=v[114578];v[114578]=0;if((d|0)==1){break O}v[114578]=0;Q(471,e+1072|0,e+208|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break O}yb(e+208|0);yb(e+1088|0);Ib(e+136|0);break L}d=P()|0;O()|0;break d}d=P()|0;O()|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;yb(e+208|0)}yb(e+1088|0)}Ib(e+136|0);break d}v[114578]=0;g=Q(85,e+208|0,15175)|0;d=v[114578];v[114578]=0;R:{if((d|0)!=1){v[114578]=0;R(512,e+136|0,((f<<5)+a|0)+901692|0);d=v[114578];v[114578]=0;if((d|0)==1){break R}v[114578]=0;Q(471,e+136|0,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break R}yb(g);break L}d=P()|0;O()|0;break d}d=P()|0;O()|0;yb(g);break d}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){d=(e+1104|0)+(f<<1)|0;g=d;S:{if(w[d+167|0]){v[114578]=0;R(509,e+136|0,15176);h=v[114578];v[114578]=0;T:{U:{V:{W:{X:{Y:{Z:{if((h|0)!=1){g=w[g+167|0];v[114578]=0;v[e+112>>2]=g-1;R(836,e+1088|0,e+112|0);g=v[114578];v[114578]=0;if((g|0)==1){break Z}d=w[d+166|0];v[114578]=0;t[e+1056|0]=d;R(837,e+1072|0,e+1056|0);d=v[114578];v[114578]=0;if((d|0)==1){break Y}v[114578]=0;X(838,e+208|0,e+136|0,e+1088|0,e+1072|0);d=v[114578];v[114578]=0;if((d|0)==1){break X}v[114578]=0;R(512,e+160|0,((f<<5)+a|0)+902204|0);d=v[114578];v[114578]=0;if((d|0)==1){break W}v[114578]=0;Q(471,e+160|0,e+208|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break W}yb(e+208|0);yb(e+1072|0);yb(e+1088|0);Ib(e+136|0);break S}d=P()|0;O()|0;break d}d=P()|0;O()|0;break T}d=P()|0;O()|0;break U}d=P()|0;O()|0;break V}d=P()|0;O()|0;yb(e+208|0)}yb(e+1072|0)}yb(e+1088|0)}Ib(e+136|0);break d}v[114578]=0;g=Q(85,e+208|0,15175)|0;d=v[114578];v[114578]=0;_:{if((d|0)!=1){v[114578]=0;R(512,e+136|0,((f<<5)+a|0)+902204|0);d=v[114578];v[114578]=0;if((d|0)==1){break _}v[114578]=0;Q(471,e+136|0,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break _}yb(g);break S}d=P()|0;O()|0;break d}d=P()|0;O()|0;yb(g);break d}f=f+1|0;if((f|0)!=128){continue}break}}d=Vb(j);g=e+1104|1;g=w[g|0]|w[g+1|0]<<8;v[114578]=0;ea(581,d|0,l|0,g|0,255,254)|0;d=v[114578];v[114578]=0;$:{aa:{ba:{ca:{da:{ea:{if((d|0)!=1){q=e+1104|5;d=w[q|0]|w[q+1|0]<<8;g=w[e+1104|0];v[114578]=0;U(343,e+1088|0,l|0,B(d,g)<<1);d=v[114578];v[114578]=0;if((d|0)==1){break ea}d=w[q|0]|w[q+1|0]<<8;v[114578]=0;U(343,e+1072|0,l|0,d<<1);d=v[114578];v[114578]=0;if((d|0)==1){break da}d=e+1104|7;d=w[d|0]|w[d+1|0]<<8;v[114578]=0;A=Q(397,e+1056|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ca}J=e,K=bc(A),v[J+136>>2]=K;J=e,K=cc(A),v[J+160>>2]=K;if(Jb(e+136|0,e+160|0)){while(1){d=v[e+136>>2];v[114578]=0;g=T(392,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ba}v[114578]=0;U(343,e+208|0,l|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break aa}Wd(d,e+208|0);Bb(e+208|0);Tf(e+136|0);if(Jb(e+136|0,e+160|0)){continue}break}}d=v[a+480180>>2];k=1;p=c&1;if(!p){break $}g=w[q|0]|w[q+1|0]<<8;v[114578]=0;R(403,a+484344|0,g|0);g=v[114578];v[114578]=0;if((g|0)!=1){break $}d=P()|0;O()|0;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}E=a+484344|0;fa:{ga:{ha:{ia:{ja:{ka:{if(w[q|0]|w[q+1|0]<<8){n=(d|0)==16?14:(d|0)==32?1:13;while(1){v[114578]=0;d=T(359,e+1072|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break fa}v[e+136>>2]=d;la:{if(!p){break la}v[114578]=0;d=W(404,E|0,r&65535,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break fa}if(!d){break la}j=0;if(!w[e+1104|0]){break la}while(1){v[114578]=0;d=T(359,e+1088|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break ga}ma:{if(od(A)>>>0<=d>>>0){break ma}m=tc(A,d);Jc(m);d=_b(E,r);v[114578]=0;f=W(472,d|0,0,j&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}g=0;if(!v[e+136>>2]){break ma}while(1){v[114578]=0;z=T(389,m|0)|0;d=v[114578];v[114578]=0;na:{oa:{if((d|0)!=1){if(!z){break ma}Qh(e+208|0);h=0;s=z&15;if(s){break oa}break na}d=P()|0;O()|0;break h}while(1){pa:{v[114578]=0;Q(839,m|0,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break pa}qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{d=w[e+160|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break sa;case 33:break wa;case 30:case 31:break xa;case 29:break ya;case 28:break za;case 26:break Aa;case 19:case 20:break Ba;case 17:break Ca;case 15:break Da;case 14:break Ea;case 10:break Fa;case 6:break Ga;case 5:break Ha;case 1:break Ia;case 0:break Ja;default:break Ka}}switch(d-48|0){case 4:break ta;case 1:case 2:break ua;case 0:break va;default:break sa}}d=w[e+161|0];La:{if(d>>>0<=119){t[e+208|0]=d+n;break La}Ma:{switch(d-254|0){case 1:t[e+208|0]=255;break La;case 0:t[e+208|0]=254;break La;default:break Ma}}t[e+208|0]=253}v[114578]=0;d=T(611,e+208|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break pa}k=d&k;break qa}t[e+209|0]=w[e+161|0]+1;break qa}Na:{if(w[e+210|0]){break Na}d=v[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break Na}d=w[e+161|0];if(d&15){break Na}t[e+210|0]=11;t[e+212|0]=d>>>4;break qa}i=0;d=w[e+161|0];while(1){if((d|0)==w[i+20832|0]){t[e+212|0]=i;t[e+210|0]=11;break qa}i=i+1|0;if((i|0)!=10){continue}break}}t[e+211|0]=4;t[e+213|0]=w[e+161|0];break qa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>9|v[a+480180>>2]!=32)){t[e+212|0]=d;t[e+210|0]=8;break qa}t[e+213|0]=d;t[e+211|0]=5;break qa}Oa:{if(w[e+210|0]){break Oa}Pa:{d=v[a+480180>>2];if((d|0)!=4){if((d|0)!=32){break Oa}i=w[e+161|0];if((i|0)!=255){break Pa}t[e+212|0]=64;t[e+210|0]=2;break qa}i=w[e+161|0];if(i&15){break Oa}break ra}if(!(i&3)){break ra}}t[e+211|0]=9;t[e+213|0]=w[e+161|0];break qa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>64|v[a+480180>>2]==1)){t[e+212|0]=d;t[e+210|0]=1;break qa}t[e+213|0]=d;t[e+211|0]=13;break qa}t[e+211|0]=14;d=w[e+161|0];t[e+213|0]=d;if(v[a+480180>>2]==32){break qa}t[e+213|0]=B((d&240)>>>4|0,10)+(d&15);break qa}d=w[e+161|0];t[e+213|0]=d;if(d>>>0<=31){t[e+211|0]=16;break qa}t[e+211|0]=17;break qa}i=w[e+161|0];if(i>>>0>=16){t[e+212|0]=i>>>4;t[e+210|0]=(d|0)==20?3:5;break qa}t[e+212|0]=i;t[e+210|0]=(d|0)==20?4:6;break qa}d=w[e+161|0];if(d>>>0>=16){t[e+210|0]=10;t[e+212|0]=d>>>4;break qa}t[e+212|0]=d;t[e+210|0]=9;break qa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|16;break qa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|32;break qa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+15200|0];break qa}t[e+213|0]=w[e+161|0];d=w[e+211|0];t[e+211|0]=(d|0)==4?6:(d|0)==5?7:11;break qa}d=w[e+161|0];t[e+212|0]=(d>>>0)%10;if(d>>>0<=9){t[e+210|0]=5;break qa}if(d>>>0<=19){t[e+210|0]=6;break qa}if(d>>>0<=29){t[e+210|0]=3;break qa}if(d>>>0>39){break qa}t[e+210|0]=4;break qa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+15200|0];break qa}d=w[e+161|0]+33|0;if((d&255)>>>0>9){break qa}t[e+212|0]=d;t[e+210|0]=15;break qa}if(d>>>0>55){break qa}t[e+213|0]=w[e+161|0];t[e+211|0]=w[d+15200|0];break qa}t[e+210|0]=2;t[e+212|0]=i>>>2}h=h+1|0;if(s>>>0>(h&255)>>>0){continue}break na}break}d=P()|0;O()|0;break h}v[114578]=0;v[e+160>>2]=(z>>>4|0)+g;d=Q(333,e+160|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ka}d=v[d>>2];if(d>>>0>g>>>0){while(1){h=v[e+208>>2];t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24;h=x[e+212>>1];t[f+4|0]=h;t[f+5|0]=h>>>8;f=B(w[e+1104|0],6)+f|0;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(y[e+136>>2]>g>>>0){continue}break}}j=j+1|0;if(w[e+1104|0]>(j&65535)>>>0){continue}break}}r=r+1|0;if(r>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}}if(!((k^-1|x[a+480188>>1]!=4)&1|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ja}h=0;break ia}d=P()|0;O()|0;break h}h=!((w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))&512);d=0;if(v[a+480180>>2]!=4){break ha}}d=x[a+480192>>1]}v[114578]=0;q=Q(840,e+1040|0,d|0)|0;d=v[114578];v[114578]=0;g=1;if((d|0)!=1){Qa:{Ra:{Sa:{if(x[a+480192>>1]){d=1;while(1){Ta:{Ua:{Va:{if(!h){v[114578]=0;i=W(456,a|0,d&65535,0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Va}if(i){break Ua}}while(1){v[114578]=0;g=T(389,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}if(g){continue}break}if(w[e+1575|0]>=5){while(1){v[114578]=0;g=T(389,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){d=P()|0;O()|0;break j}if(g){continue}break}}v[114578]=0;Q(340,l|0,826)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break Ta}}d=P()|0;O()|0;break j}f=Wb(e+136|0);v[114578]=0;W(597,l|0,f|0,-1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break Sa}v[114578]=0;Q(371,i+492|0,f|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break Sa}Wa:{if(w[e+1575|0]<5){break Wa}v[114578]=0;W(597,l|0,f|0,-1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break Sa}v[114578]=0;Q(371,i+524|0,f|0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break Wa}break Sa}v[114578]=0;j=Q(841,l|0,e+208|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break Sa}if(!j){break Ra}j=v[a+480180>>2];v[114578]=0;U(842,e+208|0,i|0,j|0);i=v[114578];v[114578]=0;if((i|0)==1){break Sa}if(v[a+480180>>2]==4){g=Pb(q,g-1|0);i=x[e+1010>>1]|x[e+1012>>1]<<16;t[g|0]=i;t[g+1|0]=i>>>8;t[g+2|0]=i>>>16;t[g+3|0]=i>>>24}yb(f)}d=d+1|0;g=d&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}if(!h){break Qa}u[a+480192>>1]=0;break Qa}d=P()|0;O()|0;yb(f);break j}yb(f)}d=x[a+480190>>1];v[114578]=0;z=Q(843,e+192|0,d|0)|0;d=v[114578];v[114578]=0;j=1;if((d|0)!=1){j=w[e+1575|0]<=4?!(t[o|0]&1):j;s=c&2;c=0;Xa:{if(!x[a+480190>>1]){break Xa}h=1;g=1;while(1){d=c;r=Wb(e+176|0);v[114578]=0;W(597,l|0,r|0,-1)|0;c=v[114578];v[114578]=0;Ya:{Za:{_a:{$a:{ab:{if((c|0)==1){break ab}v[114578]=0;Q(371,((h<<5)+a|0)+946300|0,r|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ab}p=B(h,104);k=p+a|0;if(w[e+1575|0]<5){break $a}v[114578]=0;W(597,l|0,r|0,-1)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ab}v[114578]=0;Q(372,k+484423|0,r|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break $a}}d=P()|0;O()|0;break _a}v[114578]=0;c=Q(844,l|0,e+208|0)|0;f=v[114578];v[114578]=0;bb:{cb:{db:{eb:{fb:{gb:{hb:{if((f|0)==1){break hb}if(!c){break gb}c=v[a+480180>>2];v[114578]=0;f=k+484380|0;X(845,e+208|0,f|0,c|0,j|0);c=v[114578];v[114578]=0;if((c|0)==1){break hb}i=0;ib:{if(((w[e+228|0]|w[e+229|0]<<8)&61440)!=28672|w[e+1575|0]<5){break ib}v[114578]=0;i=T(846,l|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break ib}d=P()|0;O()|0;break _a}if(!s){break Za}C=w[e+228|0]|w[e+229|0]<<8;m=C&61440;if(!(m|(w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24)))){c=ad(e+136|0,(w[e+228|0]|w[e+229|0]<<8)&1?16:8,(w[e+228|0]|w[e+229|0]<<8)&1024?3:1,0,0);v[114578]=0;W(402,c|0,f|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break Za}d=P()|0;O()|0;break _a}if(!(((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))+h|0)<1|(w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))>-1)){i=a+484380|0;m=B((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))+h|0,104);c=i+m|0;Cc(f,v[c>>2]);h=i+p|0;i=x[h+34>>1]&-2|u[c+34>>1]&1;u[h+34>>1]=i;u[h+34>>1]=x[c+34>>1]&64|i&65471;if(!De(c)){break Za}v[114578]=0;c=T(466,f|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(!c){break Za}c=v[k+484400>>2];v[114578]=0;c=T(467,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[(a+m|0)+484400>>2];v[114578]=0;h=T(847,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}lc(c,h,Aj(f));break Za}d=P()|0;O()|0;break _a}if((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))<1){break Za}if(t[e+228|0]&1){c=k+484414|0;u[c>>1]=x[c>>1]|1}if(w[e+229|0]&4){c=k+484414|0;u[c>>1]=x[c>>1]|64}c=w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24);v[114578]=0;U(343,e+160|0,b|0,c|0);p=v[114578];v[114578]=0;jb:{kb:{I=e;lb:{mb:{if((p|0)!=1){p=ue(f);H=(m|0)==16384;if((m|0)!=8192?!H:0){break kb}v[114578]=0;n=T(255,e+160|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break jb}v[e+136>>2]=n;c=v[e+136>>2];n=4/(p>>>0)|0;if(c>>>0>4294967295/(n>>>0)>>>0){break mb}n=B(c,n);break lb}d=P()|0;O()|0;break _a}n=-1}v[I+136>>2]=n;Cc(f,n);if(!H){if((m|0)!=8192){break kb}v[114578]=0;c=T(466,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break cb}if(!c){break eb}if(t[e+228|0]&1){c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(848,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)!=1){break db}break cb}c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(849,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)==1){break cb}break db}v[114578]=0;c=T(466,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break cb}if(!c){break eb}if(t[e+228|0]&1){c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(850,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)==1){break cb}break db}c=v[k+484400>>2];f=v[f>>2];v[114578]=0;X(851,e+160|0,c|0,f|0,p|0);f=v[114578];v[114578]=0;c=d;if((f|0)==1){break cb}break db}if((C&45056)==12288){c=OQ(e+136|0,e+160|0,w[e+247|0]|w[e+248|0]<<8,i);f=rz(z,h-1|0);Wd(f,c);v[f+16>>2]=v[c+16>>2];Bb(c);break eb}if((m|0)!=32768){c=1;if((m|0)!=4096){break db}h=Ze(e+136|0,e+160|0);v[114578]=0;Q(852,e+128|0,e+160|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){nb:{if(!w[e+133|0]){break nb}c=x[e+130>>1]<<1;if((c&65535)>>>0>(w[e+247|0]|w[e+248|0]<<8)>>>0){break nb}c=(w[e+247|0]|w[e+248|0]<<8)-c|0;t[e+247|0]=c;t[e+248|0]=c>>>8;v[114578]=0;Q(256,e+160|0,x[e+128>>1])|0;c=v[114578];v[114578]=0;if((c|0)==1){break fb}v[114578]=0;c=T(332,e+160|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break fb}v[114578]=0;U(343,e+112|0,e+160|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break fb}Wd(h,e+112|0);Bb(e+112|0)}v[114578]=0;c=g&65535;i=ea(853,a|0,c|0,h|0,1,1)|0;m=v[114578];v[114578]=0;if((m|0)==1){break fb}ob:{if(!i){v[114578]=0;i=aa(854,a|0,c|0,h|0,1)|0;c=v[114578];v[114578]=0;if((c|0)==1){break fb}c=1;if(!i){break ob}}pb:{if(!(w[e+247|0]|w[e+248|0]<<8)){break pb}c=w[e+247|0]|w[e+248|0]<<8;if(Aj(f)>>>0<=c>>>0){break pb}c=w[e+247|0]|w[e+248|0]<<8;i=Zn(f);k=k+484400|0;m=v[k>>2];v[114578]=0;m=T(467,m|0)|0;p=v[114578];v[114578]=0;if((p|0)==1){break a}k=v[k>>2];v[114578]=0;k=T(467,k|0)|0;p=v[114578];v[114578]=0;if((p|0)==1){break a}$i(m,k+(w[e+247|0]|w[e+248|0]<<8)|0,Aj(f)-(w[e+247|0]|w[e+248|0]<<8)|0);v[f>>2]=v[f>>2]-((c>>>0)/(i>>>0)|0)}c=v[e+216>>2];v[e+108>>2]=c;v[e+12>>2]=c;if(y[f>>2]>(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){v[f>>2]=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24)}c=d}Bb(h);break db}break fb}v[114578]=0;c=Q(640,e+160|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(!c){break eb}v[114578]=0;v[e+24>>2]=v[e+144>>2];c=v[e+140>>2];v[e+16>>2]=v[e+136>>2];v[e+20>>2]=c;U(641,f|0,1,e+16|0);c=v[114578];v[114578]=0;if((c|0)!=1){break eb}}d=P()|0;O()|0;break bb}d=P()|0;O()|0;break bb}d=P()|0;O()|0;break _a}yb(r);c=d;break Xa}d=P()|0;O()|0;Bb(h);break bb}c=d}Bb(e+160|0);break Ya}d=P()|0;O()|0}Bb(e+160|0)}yb(r);break l}c=d}yb(r);g=g+1|0;h=g&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}if(!(!s|!x[a+480190>>1])){i=1;r=1;while(1){g=rz(z,i-1|0);v[114578]=0;b=T(339,g|0)|0;d=v[114578];v[114578]=0;qb:{rb:{sb:{if((d|0)!=1){if(!b){break qb}tb:{ub:{vb:{b=x[g+18>>1];wb:{if(!b){break wb}b=b+r&65535;if(!b){break wb}if(b>>>0<=x[a+480190>>1]){break vb}}v[114578]=0;T(255,g|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ub}break m}b=rz(z,b-1|0);d=x[g+16>>1];Jc(b);f=x[g+16>>1];v[114578]=0;f=Q(258,b|0,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break m}if(!f){break qb}v[114578]=0;v[e+136>>2]=0;v[e+160>>2]=0;U(855,e+208|0,b|0,d|0);d=v[114578];v[114578]=0;xb:{if((d|0)!=1){v[114578]=0;d=T(414,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break xb}v[114578]=0;d=T(856,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break xb}f=v[e+208>>2];v[114578]=0;f=T(857,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break xb}v[114578]=0;j=ea(858,d|0,f|0,e+136|0,e+160|0,0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break xb}v[114578]=0;Q(340,b|0,v[e+136>>2])|0;b=v[114578];v[114578]=0;if((b|0)==1){break xb}Ec(e+208|0);b=1;break tb}d=P()|0;O()|0;break l}d=P()|0;O()|0;Ec(e+208|0);break l}Jc(g);v[e+136>>2]=0;v[e+160>>2]=0;j=0;b=0}v[114578]=0;R(859,e+208|0,g|0);d=v[114578];v[114578]=0;yb:{zb:{if((d|0)!=1){v[114578]=0;d=T(414,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break yb}k=v[e+208>>2];if(!b){v[114578]=0;b=T(856,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break sb}v[114578]=0;f=T(857,k|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break sb}v[114578]=0;j=ea(858,b|0,f|0,e+136|0,e+160|0,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break sb}v[114578]=0;Q(340,g|0,v[e+136>>2])|0;b=v[114578];v[114578]=0;if((b|0)==1){break sb}b=v[e+136>>2];k=k-b|0;d=b+d|0}if(j){break zb}c=1;break rb}d=P()|0;O()|0;break l}v[114578]=0;f=B(i,104)+a|0;b=f+484380|0;T(466,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break sb}i=f+484400|0;p=f+484414|0;h=0;f=v[e+160>>2];while(1){Ab:{if(y[b>>2]<=h>>>0|(!k|(f|0)!=1?f:0)){break Ab}if(!De(b)){break Ab}v[114578]=0;v[e+112>>2]=0;v[e+176>>2]=0;f=T(856,d|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break sb}v[114578]=0;m=T(857,k|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break sb}v[114578]=0;f=ka(860,j|0,f|0,m|0,e+112|0,e+128|0,e+176|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break sb}v[114578]=0;v[e+136>>2]=f;Q(340,g|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break sb}f=v[b>>2];v[114578]=0;m=v[e+136>>2];f=T(861,f-h|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break sb}Ak(e+176|0,f);Bb:{if(v[e+176>>2]<1){break Bb}if(v[e+112>>2]!=(ue(b)|0)){break Bb}f=0;if(v[e+112>>2]<=0){break Bb}while(1){Cb:{if(t[p|0]&1){n=v[i>>2];s=ue(b);C=v[v[e+128>>2]+(f<<2)>>2];v[114578]=0;fa(862,n+(B(h,s)<<1)|0,C|0,v[e+112>>2],v[e+176>>2],f|0);n=v[114578];v[114578]=0;if((n|0)!=1){break Cb}break sb}n=v[i>>2];s=ue(b);C=v[v[e+128>>2]+(f<<2)>>2];v[114578]=0;fa(863,n+B(h,s)|0,C|0,v[e+112>>2],v[e+176>>2],f|0);n=v[114578];v[114578]=0;if((n|0)==1){break sb}}f=f+1|0;if((f|0)<v[e+112>>2]){continue}break}}v[114578]=0;n=v[e+176>>2];f=T(864,j|0)|0;s=v[114578];v[114578]=0;if((s|0)==1){break sb}k=k-m|0;d=d+m|0;v[e+160>>2]=f;h=h+n|0;continue}break}v[114578]=0;Z(865,j|0);b=v[114578];v[114578]=0;if((b|0)!=1){break rb}break sb}break sb}d=P()|0;O()|0;break l}d=P()|0;O()|0;Ec(e+208|0);break l}Ec(e+208|0)}r=r+1|0;i=r&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}Db:{if(v[a+480180>>2]!=4){break Db}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break Db}b=w[Pb(q,f)|0];d=w[Pb(q,f)+1|0];g=w[Pb(q,f)+2|0];h=w[Pb(q,f)+3|0];v[114578]=0;f=f+1|0;ma(866,a|0,f&65535,b|0,d|0,g|0,h|0);b=v[114578];v[114578]=0;if((b|0)!=1){continue}break}d=P()|0;O()|0;break l}Eb:{Fb:{Gb:{Hb:{if(!(w[o+2|0]&16)){break Hb}v[114578]=0;b=Q(258,l|0,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}if(!b){break Hb}v[114578]=0;b=T(389,l|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}if(!(!(b&1)|!x[G>>1])){f=0;while(1){v[114578]=0;b=T(392,l|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Gb}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[114578]=0;b=Q(258,l|0,1)|0;d=v[114578];v[114578]=0;Ib:{if((d|0)!=1){if(!b){break Hb}v[114578]=0;b=T(389,l|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Fb}if(!b){break Hb}v[114578]=0;d=T(392,l|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Eb}v[114578]=0;U(343,e+208|0,l|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break Eb}if(b>>>0>250){break Ib}v[114578]=0;R(666,e+208|0,(B(b,160)+a|0)+906140|0);b=v[114578];v[114578]=0;if((b|0)!=1){break Ib}d=P()|0;O()|0;Bb(e+208|0);break l}d=P()|0;O()|0;break l}Bb(e+208|0);continue}}j=a+901404|0;k=a+1074304|0;h=gd(e+112|0);g=0;b=0;Jb:{Kb:{while(1){v[114578]=0;d=Q(258,l|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Jb}if(!d){break Kb}v[114578]=0;d=T(392,l|0)|0;f=v[114578];v[114578]=0;Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{$b:{if((f|0)!=1){v[114578]=0;f=T(392,l|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break $b}v[114578]=0;U(343,e+136|0,l|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break _b}if((d|0)<=1397900629){if((d|0)==1229211981){break Yb}if((d|0)!=1229476432){break Mb}v[114578]=0;d=T(389,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[a+480216>>2]=d;v[114578]=0;d=T(389,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[a+480220>>2]=d;break Mb}if((d|0)==1397900630){break Zb}if((d|0)!=1414548815){break Mb}v[114578]=0;d=Q(618,e+136|0,15275)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}if(!d){break Wb}v[114578]=0;d=T(392,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;U(343,e+160|0,e+136|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break Xb}}d=P()|0;O()|0;break q}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}ac:{bc:{cc:{d=v[a+480180>>2];switch(d-2|0){case 1:break Mb;case 0:break Nb;case 2:break bc;default:break cc}}if((d|0)==16){break ac}if((d|0)!=32){break Mb}v[114578]=0;g=T(359,e+136|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;b=T(359,e+136|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break Mb}break r}v[114578]=0;v[e+208>>2]=32;d=T(255,e+136|0)|0;f=v[114578];v[114578]=0;dc:{if((f|0)==1){break dc}v[114578]=0;v[e+160>>2]=d;d=Q(33,e+208|0,e+160|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break dc}d=v[d>>2];v[114578]=0;aa(867,e+136|0,h|0,4,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break Mb}}d=P()|0;O()|0;break q}v[114578]=0;d=T(389,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Lb}v[114578]=0;f=Q(2,e+96|0,15256)|0;i=v[114578];v[114578]=0;ec:{fc:{gc:{if((i|0)!=1){v[114578]=0;R(219,e+160|0,f|0);i=v[114578];v[114578]=0;if((i|0)==1){break gc}v[114578]=0;v[e+176>>2]=d>>>4;v[e+128>>2]=d&15;X(534,e+208|0,e+160|0,e+176|0,e+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break fc}Gb(h,e+208|0);yb(e+208|0);Ib(e+160|0);yb(f);break Mb}d=P()|0;O()|0;break q}d=P()|0;O()|0;break ec}d=P()|0;O()|0;Ib(e+160|0)}yb(f);break q}v[114578]=0;Q(632,e+136|0,j|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}v[114578]=0;Z(633,j|0);d=v[114578];v[114578]=0;if((d|0)==1){break r}break Mb}v[114578]=0;d=T(255,e+160|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Vb}u[e+208>>1]=d>>>5;d=Ce(E);v[114578]=0;u[e+176>>1]=d;d=Q(478,e+208|0,e+176|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Vb}d=x[d>>1];if(d){i=0;while(1){v[114578]=0;W(868,e+160|0,e+208|0,32)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Vb}f=_b(E,i);v[114578]=0;Q(869,f|0,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Vb}i=i+1|0;if((d|0)!=(i|0)){continue}break}}Bb(e+160|0)}v[114578]=0;d=Q(618,e+136|0,15280)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}if(!d){break Tb}v[114578]=0;d=T(392,e+136|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;U(343,e+208|0,e+136|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break Ub}}d=P()|0;O()|0;break q}d=P()|0;O()|0;Bb(e+160|0);break q}v[114578]=0;d=T(255,e+208|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Sb}u[e+160>>1]=(d>>>0)/20;d=x[a+480188>>1];v[114578]=0;u[e+176>>1]=d;d=Q(478,e+160|0,e+176|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Sb}d=x[d>>1];if(d){f=0;while(1){v[114578]=0;W(635,e+208|0,((f<<5)+a|0)+480289|0,20)|0;i=v[114578];v[114578]=0;if((i|0)==1){break Sb}f=f+1|0;if((d|0)!=(f|0)){continue}break}}Bb(e+208|0)}v[114578]=0;Q(652,a|0,e+136|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}v[114578]=0;X(653,a|0,e+136|0,1,0);d=v[114578];v[114578]=0;if((d|0)==1){break r}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[114578]=0;U(664,a|0,e+136|0,g&65535);d=v[114578];v[114578]=0;if((d|0)==1){break r}}if(!v[k>>2]){break Mb}v[114578]=0;f=Q(2,e+160|0,15285)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Rb}v[114578]=0;R(242,e+176|0,k|0);d=v[114578];v[114578]=0;if((d|0)==1){break Qb}v[114578]=0;U(3,e+208|0,f|0,e+176|0);d=v[114578];v[114578]=0;if((d|0)==1){break Pb}Gb(h,e+208|0);yb(e+208|0);yb(e+176|0);yb(f);break Mb}d=P()|0;O()|0;Bb(e+208|0);break q}d=P()|0;O()|0;break q}d=P()|0;O()|0;break Ob}d=P()|0;O()|0;yb(e+176|0)}yb(f);break q}v[114578]=0;g=T(359,e+136|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}}Bb(e+136|0);continue}break}d=P()|0;O()|0;break q}hc:{ic:{jc:{kc:{if(!((g&65504)!=4864|v[a+480180>>2]!=2?!((v[a+480180>>2]==32?(g-256&65535)>>>0<=275:0)|(v[a+480180>>2]==2?(g-12544&65535)>>>0<=275:0)):0)){v[114578]=0;Z(634,j|0);d=v[114578];v[114578]=0;if((d|0)==1){break kc}}if(!(t[o+2|0]&1)){break hc}if(!(v[a+1074304>>2]|!x[a+480192>>1])){f=1;while(1){d=v[(((f&65535)<<2)+a|0)+900380>>2];if(d){v[114578]=0;g=Q(376,d|0,2)|0;i=v[114578];v[114578]=0;if((i|0)==1){break jc}i=v[a+480180>>2];v[114578]=0;U(870,g|0,4,i|0);g=v[114578];v[114578]=0;if((g|0)==1){break ic}t[d+19|0]=w[d+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}if(y[a+1074304>>2]<18350080){v[114578]=0;d=a+1074308|0;Q(480,d|0,27)|0;g=v[114578];v[114578]=0;if((g|0)==1){break kc}v[114578]=0;Q(480,d|0,57)|0;d=v[114578];v[114578]=0;if((d|0)==1){break kc}}if(y[a+1074304>>2]<19070976){v[114578]=0;Q(480,a+1074308|0,73)|0;d=v[114578];v[114578]=0;if((d|0)==1){break kc}}if(y[a+1074304>>2]>=19267584){break hc}v[114578]=0;Q(480,a+1074308|0,50)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break hc}}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(Wc(h)){v[114578]=0;g=Q(2,e+80|0,15294)|0;d=v[114578];v[114578]=0;Dc:{Ec:{Fc:{if((d|0)!=1){v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break Fc}v[114578]=0;U(537,e+208|0,e+136|0,e+1575|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ec}break Cc}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Dc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}v[114578]=0;g=Q(2,e- -64|0,15302)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Bc}v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ac}v[114578]=0;X(453,e+208|0,e+136|0,e+1575|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break zc}}Gb(h,e+208|0);yb(e+208|0);Ib(e+136|0);yb(g);v[114578]=0;g=Q(2,e+48|0,15315)|0;d=v[114578];v[114578]=0;if((d|0)==1){break wc}v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break vc}v[114578]=0;U(537,e+208|0,e+136|0,e+1575|0);d=v[114578];v[114578]=0;if((d|0)==1){break uc}Gb(a+1304436|0,e+208|0);yb(e+208|0);Ib(e+136|0);yb(g);v[114578]=0;d=Q(2,e+208|0,15331)|0;g=v[114578];v[114578]=0;if((g|0)==1){break sc}Gb(a+1304448|0,d);yb(d);d=v[a+480180>>2];if((d|0)>15){break xc}switch(d-1|0){case 1:break oc;case 3:break pc;case 0:break qc;default:break w}}d=P()|0;O()|0;break p}d=P()|0;O()|0;break yc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}if((d|0)==16){break rc}if((d|0)==32){break nc}if((d|0)!=16777216){break w}v[114578]=0;b=Q(2,e+208|0,15446)|0;d=v[114578];v[114578]=0;if((d|0)==1){break mc}Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15451)|0;d=v[114578];v[114578]=0;if((d|0)==1){break lc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break tc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15335)|0;d=v[114578];v[114578]=0;Gc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15339)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Gc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15352)|0;d=v[114578];v[114578]=0;Hc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15356)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Hc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15368)|0;d=v[114578];v[114578]=0;Ic:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15371)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ic}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;b=Q(2,e+208|0,15385)|0;d=v[114578];v[114578]=0;Jc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114578]=0;b=Q(2,e+208|0,15389)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Jc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114578]=0;d=Q(2,e+208|0,15405)|0;g=v[114578];v[114578]=0;Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{if((g|0)!=1){Gb(a+1304484|0,d);yb(d);if(!(b&65535)){break Kc}v[114578]=0;g=Q(2,e+32|0,15408)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Qc}v[114578]=0;R(219,e+136|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break Pc}v[114578]=0;v[e+176>>2]=(b&65280)>>>8;v[e+128>>2]=b&255;R(660,e+160|0,e+128|0);b=v[114578];v[114578]=0;if((b|0)==1){break Oc}v[114578]=0;X(645,e+208|0,e+136|0,e+176|0,e+160|0);b=v[114578];v[114578]=0;if((b|0)==1){break Nc}Gb(a+1304472|0,e+208|0);yb(e+208|0);yb(e+160|0);Ib(e+136|0);yb(g);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Lc}d=P()|0;O()|0;break Mc}d=P()|0;O()|0;yb(e+160|0)}Ib(e+136|0)}yb(g);break p}v[114578]=0;b=Q(2,e+208|0,15430)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break j}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}Gb(a+1304460|0,h);Rc:{if(v[a+1074304>>2]){v[a+1304496>>2]=7;break Rc}if(v[a+480180>>2]==1){v[a+1304496>>2]=2;break Rc}v[a+1304496>>2]=4}f=1;if(c&1){v[114578]=0;b=Q(2,e+208|0,15464)|0;c=v[114578];v[114578]=0;if((c|0)==1){break t}v[114578]=0;U(646,a|0,2,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break s}yb(b)}yb(h);MQ(z);LQ(q);hd(A);Bb(e+1072|0);Bb(e+1088|0)}Bb(l)}fe(D);break b}d=P()|0;O()|0;break p}d=P()|0;O()|0;yb(b);break p}d=P()|0;O()|0}Bb(e+136|0)}yb(h);break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0}MQ(z);break j}d=P()|0;O()|0}LQ(q);break h}d=P()|0;O()|0}hd(A)}Bb(e+1072|0)}Bb(e+1088|0);break d}d=P()|0;O()|0}Bb(l)}fe(D);S(d|0);L()}jb=e+1584|0;return f|0}V(0)|0;O()|0;Ab();L()}function Dja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0;e=jb-912|0;jb=e;Jc(b);a:{b:{if(!mR(b,e+856|0)){break b}if(!oR(e+856|0)){break b}if(!Qb(b,id(nR(e+856|0),mb))){break b}if(!c){g=1;break b}Hd(a,8);wi(a);t[e+855|0]=w[e+856|3]-48;d=w[e+864|0]|w[e+865|0]<<8|(w[e+866|0]<<16|w[e+867|0]<<24);Pc(b,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24));ud(e+832|0,b,504);v[114578]=0;Q(772,b|0,e+544|0)|0;d=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((d|0)!=1){if(w[e+544|0]&128|w[e+827|0]>63){break c}Rb(e+464|0,0,80);o:{if(!(w[e+888|0]|w[e+889|0]<<8|(w[e+890|0]<<16|w[e+891|0]<<24))){break o}d=w[e+888|0]|w[e+889|0]<<8|(w[e+890|0]<<16|w[e+891|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){if(!f){break o}v[114578]=0;Q(773,b|0,e+464|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break o}}g=P()|0;O()|0;break f}v[114578]=0;U(774,e+456|0,b|0,w[e+855|0]);d=v[114578];v[114578]=0;if((d|0)!=1){ia=Bf(e+456|0);d=x[e+456>>1];if((d-1&65535)>>>0>126){break c}u[a+480188>>1]=d;f=jb-16|0;jb=f;J=e+440|0;d=J;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(814,d+8|0,f+12|0,f+8|0)|0;d=v[114578];v[114578]=0;p:{if((d|0)!=1){jb=f+16|0;break p}break a}q:{if(w[e+880|0]|w[e+881|0]<<8|(w[e+882|0]<<16|w[e+883|0]<<24)){d=w[e+880|0]|w[e+881|0]<<8|(w[e+882|0]<<16|w[e+883|0]<<24);v[114578]=0;Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=w[e+827|0];v[114578]=0;W(775,b|0,J|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break q}}g=P()|0;O()|0;break g}if(w[e+827|0]){break d}}d=w[e+827|0];u[a+480192>>1]=d;u[a+480190>>1]=d;g=1;ja=1;if(w[e+855|0]>=2){ja=t[e+808|0]>-1;d=x[a+480192>>1]}if(d&65535){ka=c&2;z=!ja;F=e+80|2;A=e+80|7;I=e+80|6;K=e+80|5;Y=e+80|4;C=e+56|4;s=1;D=1;while(1){v[114578]=0;d=D&65535;i=W(456,a|0,s&65535,d|0)|0;f=v[114578];v[114578]=0;r:{s:{t:{u:{if((f|0)!=1){if(!i){break e}k=v[((g<<2)+a|0)+900380>>2];v[114578]=0;u[e+60>>1]=0;v[e+56>>2]=0;G=T(277,e+152|0)|0;f=v[114578];v[114578]=0;v:{w:{x:{y:{if((f|0)!=1){f=g-1|0;i=Pb(J,f);z:{if(!(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))){break z}f=Pb(J,f);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114578]=0;i=Q(256,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}if(!i){break z}v[114578]=0;Q(776,b|0,e+56|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}f=w[e+56|0]|w[e+57|0]<<8|(w[e+58|0]<<16|w[e+59|0]<<24);v[114578]=0;U(343,e+80|0,b|0,f<<8&16711680|f<<24|(f>>>8&65280|f>>>24));f=v[114578];v[114578]=0;if((f|0)==1){break s}Wd(G,e+80|0);Bb(e+80|0)}i=w[C+1|0]&15;_=(w[C|0]|w[C+1|0]<<8)&128;if(!_){break y}v[114578]=0;R(777,k|0,0);f=v[114578];v[114578]=0;na=1;if((f|0)!=1){break x}break s}g=P()|0;O()|0;break g}if(i>>>0>=7){break x}f=w[i+14806|0];if(!i){i=f;break u}u[a+480190>>1]=(x[a+480190>>1]+f|0)-1;M=k+108|0;p=k+236|0;m=f-2|0;n=4;while(1){i=n-4|0;h=m<<3;l=w[i+(h+14816|0)|0]+D|0;j=w[i+(h+14864|0)|0];h=B(n,12);g=0;while(1){i=g+h|0;oa=ed(p,i),pa=l,u[oa>>1]=pa;i=fc(M,i);t[i|0]=j+w[i|0];g=g+1|0;if((g|0)!=12){continue}break}o=1;n=n+1|0;if((n|0)!=10){continue}break}i=f;break w}f=1;if((i|0)!=7){i=1;break u}o=0;v[114578]=0;R(778,k|0,-24);f=v[114578];v[114578]=0;i=1;if((f|0)==1){break v}f=1}$=1;break t}break s}g=P()|0;O()|0;break g}o=0;if(z|_){break t}m=k+108|0;n=7;while(1){l=B(n,12);j=B(n,-12)+72|0;g=0;while(1){h=fc(m,g+l|0);t[h|0]=j+w[h|0];g=g+1|0;if((g|0)!=12){continue}break}n=n+1|0;if((n|0)!=10){continue}break}}v[114578]=0;Q(779,e+832|0,e+80|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){A:{if(!(!w[Y|0]|w[Y|0]>16)){t[k+31|0]=w[Y|0];$=1}if(!(!w[K|0]|w[K|0]>128)){t[k+30|0]=w[K|0]}B:{if(!i){break B}k=0;h=d;while(1){v[114578]=0;l=B(h,104)+a|0;R(388,l+484380|0,8);h=v[114578];v[114578]=0;if((h|0)==1){break s}h=w[I|0];v[114578]=0;t[e+408|0]=h;t[e+136|0]=64;j=Q(393,e+408|0,e+136|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break s}u[l+484410>>1]=w[j|0]<<2;t[l+484416|0]=w[A|0];k=k+1|0;h=k&65535;if(h>>>0>=i>>>0){break B}h=d+h|0;continue}}if(_|!ka){break r}p=ad(e+408|0,8,1,1,0);m=w[F|0]|w[F+1|0]<<8;l=w[e+80|0]|w[e+81|0]<<8;j=w[F|0]|w[F+1|0]<<8;v[114578]=0;g=T(255,G|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(w[C+1|0]&16){bA(p);g=g>>>1|0}if(w[C+1|0]&32){UB(p);g=g>>>1|0}if(w[C+1|0]&64){Gj(p,2)}g=o?(g>>>0)/((-1<<i^-1)>>>0)|0:g;if(!i){break r}k=(l<<8|l>>>8)&65535;o=k+((j<<8|j>>>8)&65535)|0;j=m<<8|m>>>8;n=0;h=d;while(1){l=B(h,104)+a|0;h=l+484380|0;v[h>>2]=g;v[114578]=0;W(402,p|0,h|0,G|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break A}k=k<<1;o=o<<1;if((j&65535)>>>0>=2){v[l+484388>>2]=o;v[l+484384>>2]=k;h=l+484414|0;u[h>>1]=x[h>>1]|2}n=n+1|0;h=n&65535;if(h>>>0>=i>>>0){break r}g=g<<1;h=d+h|0;continue}}}}}g=P()|0;O()|0;Bb(G);break g}Bb(G);D=f+D|0;s=s+1|0;g=s&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}d=e+464|4;C:{if(!(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))|!(w[e+472|0]|w[e+473|0]<<8)){break C}d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}if(!f){break C}d=w[e+472|0]|w[e+473|0]<<8;u[e+152>>1]=d<<8|d>>>8;d=w[e+827|0];v[114578]=0;u[e+80>>1]=d;f=Q(478,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}M=x[f>>1];if(!M){break C}I=e+152|5;p=e+152|3;z=e+152|1;f=e+88|0;m=e+80|4;d=w[e+474|0]|w[e+475|0]<<8;A=(d<<8|d>>>8)&65535;l=A>>>0<19;k=0;while(1){v[114578]=0;W(780,b|0,e+152|0,A|0)|0;d=v[114578];v[114578]=0;D:{E:{F:{if((d|0)!=1){k=k+1|0;h=v[((k<<2)+a|0)+900380>>2];if(!w[e+152|0]){break D}j=Cp(e+80|0,0,64);Cp(m,w[e+152|0]-1&65535,64);i=w[e+152|0];d=f;if(w[z|0]){i=i+(64/w[z|0]|0)|0}Cp(d,i,0);v[114578]=0;v[e+436>>2]=3;v[e+432>>2]=j;d=v[e+436>>2];v[e+8>>2]=v[e+432>>2];v[e+12>>2]=d;i=h+48|0;R(781,i|0,e+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break F}if(w[e+152|0]!=1){break E}oa=e,pa=bc(i),v[oa+80>>2]=pa;Md(e+424|0,e+80|0);v[114578]=0;Q(782,i|0,v[e+424>>2])|0;d=v[114578];v[114578]=0;if((d|0)!=1){break E}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}d=h;if(w[z|0]){i=w[z|0]<<9}else{i=32767}v[d>>2]=i;$=1;t[h+60|0]=w[h+60|0]|1}G:{if(l){break G}v[h+4>>2]=w[e+170|0]+1>>>1;if(A>>>0<21){break G}u[h+28>>1]=w[e+172|0]|w[e+173|0]<<8}i=B(x[ed(h+236|0,61)>>1],104)+a|0;t[i+484417|0]=w[p|0]<<4;H:{I:{if(A>>>0>=15){d=w[e+162|0]|w[e+163|0]<<8|(w[e+164|0]<<16|w[e+165|0]<<24);v[i+484384>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=w[e+166|0]|w[e+167|0]<<8|(w[e+168|0]<<16|w[e+169|0]<<24);h=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=w[e+162|0]|w[e+163|0]<<8|(w[e+164|0]<<16|w[e+165|0]<<24);v[i+484388>>2]=h+(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));break I}if(A>>>0<6){break H}}if(t[I|0]&1){d=i+484414|0;u[d>>1]=x[d>>1]|2}if(w[I|0]&8){d=i+484414|0;u[d>>1]=x[d>>1]|6}if(!(w[I|0]&4)){break H}u[i+484412>>1]=0}if((k|0)!=(M|0)){continue}break}}if(!(w[e+484|0]|w[e+485|0]<<8|(w[e+486|0]<<16|w[e+487|0]<<24))|!(w[e+488|0]|w[e+489|0]<<8)){break j}d=w[e+484|0]|w[e+485|0]<<8|(w[e+486|0]<<16|w[e+487|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}if(!f){break j}d=w[e+488|0]|w[e+489|0]<<8;u[e+152>>1]=d<<8|d>>>8;d=w[e+827|0];v[114578]=0;u[e+80>>1]=d;f=Q(478,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){j=x[f>>1];if(!j){break j}d=w[e+490|0]|w[e+491|0]<<8;i=(d<<8|d>>>8)&65535;h=0;J:while(1){K:{v[114578]=0;W(783,b|0,e+152|0,i|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break k}v[114578]=0;U(784,e+56|0,2,e+152|0);d=v[114578];v[114578]=0;if((d|0)==1){break l}v[114578]=0;R(417,e+80|0,e+56|0);d=v[114578];v[114578]=0;if((d|0)==1){break l}h=h+1|0;l=((h<<2)+a|0)+900380|0;d=v[l>>2];v[114578]=0;Q(371,d+492|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}yb(e+80|0);d=v[l>>2];v[114578]=0;R(785,e+80|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break n}oa=e,pa=vn(e+80|0),v[oa+56>>2]=pa;oa=e,pa=Hi(e+80|0),v[oa+408>>2]=pa;while(1){v[114578]=0;f=Q(786,e+56|0,e+408|0)|0;d=v[114578];v[114578]=0;L:{if((d|0)!=1){if(f){break L}Ap(e+80|0);if((h|0)!=(j|0)){continue J}break j}break K}v[114578]=0;f=T(787,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){p=v[l>>2];d=v[p+520>>2];m=(x[f>>1]<<5)+a|0;f=m+946324|0;v[f>>2]=v[p+516>>2];v[f+4>>2]=d;d=v[p+512>>2];f=m+946316|0;v[f>>2]=v[p+508>>2];v[f+4>>2]=d;d=v[p+504>>2];f=m+946308|0;v[f>>2]=v[p+500>>2];v[f+4>>2]=d;d=v[p+496>>2];f=m+946300|0;v[f>>2]=v[p+492>>2];v[f+4>>2]=d;vt(e+56|0);continue}break}}break}g=P()|0;O()|0;Ap(e+80|0);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break f}g=P()|0;O()|0;break f}g=P()|0;O()|0;break g}g=P()|0;O()|0;yb(e+80|0);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}v[114578]=0;Z(634,a+901404|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}f=a+901692|0;d=w[14912]|w[14913]<<8|(w[14914]<<16|w[14915]<<24);t[f|0]=d;t[f+1|0]=d>>>8;t[f+2|0]=d>>>16;t[f+3|0]=d>>>24;t[a+901696|0]=w[14916];Jc(b);la=a+484360|0;M:{N:{O:{P:{Q:{R:{S:{if(!w[ia|0]){break S}Y=c&1;N=a+484344|0;ba=a+1304424|0;k=a+1304400|0;_=e+152|1;q=e+152|4;c=e+32|4;C=e+32|2;G=e+72|2;ka=e+72|3;H=e+544|2;while(1){v[114578]=0;X(788,b|0,e+856|0,e+464|0,e+544|0);d=v[114578];v[114578]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{if((d|0)==1){break $}i=ma&255;if(i){v[114578]=0;f=T(486,la|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break $}if((f|0)==255){break e}}r=Di(la,i);i=jb-16|0;jb=i;f=i+8|0;j=jb-16|0;jb=j;v[114578]=0;E=e+408|0;h=E;T(815,h+4|0)|0;d=v[114578];v[114578]=0;aa:{if((d|0)!=1){v[114578]=0;v[j+12>>2]=0;W(816,h+8|0,j+12|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break aa}break a}break a}oa=h,pa=hc(h),v[oa>>2]=pa;jb=j+16|0;jb=i+16|0;Xp(r);if(w[e+855|0]>1){break Z}d=w[H|0]|w[H+1|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>256|x[a+480188>>1]>16){break X}jR(e+152|0,e+544|0);d=w[H|0]|w[H+1|0]<<8;v[114578]=0;ea(789,r|0,e+152|0,(d<<8|d>>>8)&65535,65535,65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Y}oa=e,pa=bc(r),v[oa+152>>2]=pa;oa=e,pa=cc(r),v[oa+80>>2]=pa;if(Jb(e+152|0,e+80|0)){break _}break V}g=P()|0;O()|0;break g}while(1){d=v[e+152>>2];u[d>>1]=x[d>>1]+ca;te(e+152|0);if(Jb(e+152|0,e+80|0)){continue}break}break V}jR(e+152|0,e+544|0);if(!(w[e+164|0]|w[e+165|0]<<8)){break X}d=w[e+164|0]|w[e+165|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>64|x[a+480188>>1]>64){break X}j=w[e+172|0]|w[e+173|0]<<8|(w[e+174|0]<<16|w[e+175|0]<<24);if(!(w[e+176|0]|w[e+177|0]<<8)){o=32;break W}d=w[e+176|0]|w[e+177|0]<<8;v[114578]=0;u[e+80>>1]=d<<8|d>>>8;u[e+56>>1]=800;f=Q(478,e+80|0,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=x[f>>1];v[114578]=0;o=Gg(790,((d<<5)+50>>>0)/100|0,0);d=v[114578];v[114578]=0;if((d|0)!=1){break W}}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}zp(E);break e}d=w[e+160|0]|w[e+161|0]<<8|(w[e+162|0]<<16|w[e+163|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;ba:{if((d|0)==1){break ba}ca:{if(!f){break ca}g=0;if(!x[a+480188>>1]){break ca}da:{while(1){ea:{v[114578]=0;f=T(389,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ea}v[114578]=0;t[e+80|0]=f;t[e+56|0]=64;f=Q(393,e+80|0,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break da}u[((g<<5)+a|0)+480286>>1]=w[f|0];g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break ca}break}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}fa:{ga:{if(!(w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24))){break ga}d=w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break ba}if(!f){break ga}g=0;if(!x[a+480188>>1]){break fa}while(1){ha:{v[114578]=0;f=T(791,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ha}oa=((g<<5)+a|0)+480284|0,pa=(Yb(f,-16,16)<<3)+128|0,u[oa>>1]=pa;g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break fa}break}g=P()|0;O()|0;break M}v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break ba}}f=jb-16|0;jb=f;m=e+136|0;d=m;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(817,d+8|0,f+12|0,f+8|0)|0;d=v[114578];v[114578]=0;ia:{if((d|0)!=1){jb=f+16|0;break ia}break a}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;ja:{ka:{la:{ma:{na:{if((d|0)==1){break na}h=1;g=0;if(!f){break ja}d=w[H|0]|w[H+1|0]<<8;v[114578]=0;f=Q(258,b|0,((d<<8|d>>>8)&65535)<<1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break na}if(!f){break ja}d=w[H|0]|w[H+1|0]<<8;v[114578]=0;f=W(792,b|0,m|0,(d<<8|d>>>8)&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break na}if(!f){break ja}oa=e,pa=bc(m),v[oa+32>>2]=pa;oa=e,pa=cc(m),v[oa+128>>2]=pa;if(!Jb(e+32|0,e+128|0)){break ka}while(1){d=w[e+166|0]|w[e+167|0]<<8;h=(d<<8|d>>>8)&65535;d=v[e+32>>2];d=w[d|0]|w[d+1|0]<<8;d=(d<<8|d>>>8)&65535;oa:{if(h>>>0<d>>>0){break oa}f=w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24);v[114578]=0;Q(256,b|0,(f<<8&16711680|f<<24|(f>>>8&65280|f>>>24))+(d<<2)|0)|0;d=v[114578];v[114578]=0;pa:{qa:{ra:{sa:{ta:{if((d|0)==1){break ta}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ta}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ta}if(!f){break oa}v[114578]=0;f=Q(258,b|0,42)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ta}if(!f){break oa}v[114578]=0;Q(793,b|0,e+80|0)|0;d=v[114578];v[114578]=0;ua:{if((d|0)!=1){if(nd(r)){break ua}v[114578]=0;R(794,r|0,65534);d=v[114578];v[114578]=0;if((d|0)!=1){break ua}}g=P()|0;O()|0;break la}d=w[e+120|0]|w[e+121|0]<<8;v[114578]=0;d=(d<<8|d>>>8)&65535;v[e+76>>2]=d;f=Q(258,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break sa}if(!f){v[114578]=0;f=T(332,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break sa}Cc(e+76|0,f)}Cc(e+76|0,65534);l=oc(r);v[114578]=0;R(795,r|0,l+v[e+76>>2]|0);d=v[114578];v[114578]=0;if((d|0)==1){break qa}h=0;if(!v[e+76>>2]){break ra}while(1){va:{v[114578]=0;f=T(485,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break va}d=f<<16>>16;if((d|0)>=0){v[114578]=0;R(794,r|0,d+ca&65535);d=v[114578];v[114578]=0;if((d|0)==1){break va}}h=h+1|0;if(h>>>0<y[e+76>>2]){continue}break ra}break}g=P()|0;O()|0;break la}g=P()|0;O()|0;break la}g=P()|0;O()|0;break la}wa:{if(!w[e+80|0]){break wa}v[114578]=0;U(6,e+56|0,2,e+80|0);d=v[114578];v[114578]=0;xa:{if((d|0)!=1){v[114578]=0;R(487,r|0,e+56|0);d=v[114578];v[114578]=0;if((d|0)==1){break xa}yb(e+56|0);break wa}g=P()|0;O()|0;break la}g=P()|0;O()|0;yb(e+56|0);break la}if(!(w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24))){break oa}d=w[e+112|0]|w[e+113|0]<<8|(w[e+114|0]<<16|w[e+115|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){break pa}}g=P()|0;O()|0;break la}if(!f){break oa}while(1){ya:{v[114578]=0;f=Q(796,b|0,e+72|0)|0;d=v[114578];v[114578]=0;za:{Aa:{if((d|0)!=1){if(!f){break oa}d=w[ka|0];v[114578]=0;U(343,e+56|0,b|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break Aa}d=w[e+72|0]|w[e+73|0]<<8;v[114578]=0;f=T(797,l+((d<<8|d>>>8)&65535)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ma}u[e+54>>1]=f;if((w[e+72|0]|w[e+73|0]<<8)==65535){break ya}d=x[e+54>>1];if(oc(r)>>>0>d>>>0){break za}Bb(e+56|0);break oa}g=P()|0;O()|0;break la}g=P()|0;O()|0;break la}Ba:{if(w[G|0]==1){d=65535}else{if(w[G|0]!=2){break Ba}v[114578]=0;i=T(485,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ma}v[114578]=0;f=Q(798,E|0,e+54|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ma}u[f>>1]=i;d=65534}oa=rc(r,x[e+54>>1]),pa=d,u[oa>>1]=pa}Bb(e+56|0);continue}break}Bb(e+56|0)}te(e+32|0);if(Jb(e+32|0,e+128|0)){continue}break}break ka}g=P()|0;O()|0;break la}g=P()|0;O()|0;Bb(e+56|0)}hR(m);break M}h=0;g=1}hR(m);if(g){h=o>>>(j>>>25&1)|0;break U}zp(E);if(!h){break e}break T}g=P()|0;O()|0;break M}v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;Ca:{if((d|0)!=1){g=0;h=32;if(!x[a+480188>>1]){break U}while(1){d=w[(e+g|0)+810|0];v[114578]=0;t[e+152|0]=d;t[e+80|0]=64;f=Q(393,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ca}u[((g<<5)+a|0)+480286>>1]=w[f|0];g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break}break U}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}j=w[e+807|0];d=w[e+804|0]|w[e+805|0]<<8;z=w[e+807|0]&64;F=w[e+808|0]&32;n=(w[e+808|0]&31)+1|0;oa=a,pa=gR((d<<8|d>>>8)&65535,z>>>6|0,F>>>5|0,n),v[oa+480204>>2]=pa;oa=a,pa=Cd(w[e+809|0],1,32),v[oa+480196>>2]=pa;if(F){v[a+480216>>2]=n;v[a+480220>>2]=n<<2}Da:{Ea:{if(w[e+826|0]){d=w[e+826|0];v[114578]=0;t[e+152|0]=d;t[e+80|0]=64;f=Q(393,e+152|0,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ea}v[a+480200>>2]=w[f|0]<<2}v[a+480228>>2]=h;v[a+480232>>2]=h;v[a+480208>>2]=v[a+480208>>2]&-3|(w[e+807|0]>>>4^-1)&2;Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if(!(w[e+508|0]|w[e+509|0]<<8|(w[e+510|0]<<16|w[e+511|0]<<24))){break Qa}d=w[e+508|0]|w[e+509|0]<<8|(w[e+510|0]<<16|w[e+511|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Qa}d=w[e+512|0]|w[e+513|0]<<8|(w[e+514|0]<<16|w[e+515|0]<<24);v[114578]=0;W(482,b|0,k|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(w[ia|0]<2){break Qa}v[114578]=0;U(13,e+152|0,2,k|0);d=v[114578];v[114578]=0;if((d|0)==1){break Oa}v[114578]=0;R(487,r|0,e+152|0);d=v[114578];v[114578]=0;if((d|0)==1){break Na}yb(e+152|0)}d=w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24);Ra:{if((d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))>>>0<2){break Ra}d=w[e+476|0]|w[e+477|0]<<8|(w[e+478|0]<<16|w[e+479|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Ra}d=w[e+480|0]|w[e+481|0]<<8|(w[e+482|0]<<16|w[e+483|0]<<24);v[114578]=0;aa(584,ba|0,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))-1|0,4)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}}if(!(w[e+520|0]|w[e+521|0]<<8|(w[e+522|0]<<16|w[e+523|0]<<24))){break Da}d=w[e+520|0]|w[e+521|0]<<8|(w[e+522|0]<<16|w[e+523|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Da}v[114578]=0;f=Q(258,b|0,12)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if(!f){break Da}v[114578]=0;Q(340,b|0,6)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}v[114578]=0;f=T(485,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Pa}if((f|0)!=1){break Da}v[114578]=0;i=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break La}if(!i){break Da}v[114578]=0;f=Q(258,b|0,i|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break La}if(f){break Ma}break Da}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}g=P()|0;O()|0;yb(e+152|0);break M}cd(e+152|0,ba);v[114578]=0;aa(584,ba|0,b|0,i|0,4)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ga}if(!Wc(e+152|0)){v[114578]=0;f=W(799,e+56|0,2,13)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ka}v[114578]=0;U(800,e+80|0,e+152|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ja}v[114578]=0;U(801,e+40|0,e+80|0,ba|0);d=v[114578];v[114578]=0;if((d|0)==1){break Ia}Gb(ba,e+40|0);yb(e+40|0);yb(e+80|0);yb(f)}yb(e+152|0);break Da}g=P()|0;O()|0;break M}g=P()|0;O()|0;break Fa}g=P()|0;O()|0;break Ha}g=P()|0;O()|0;yb(e+80|0)}yb(f);break Fa}g=P()|0;O()|0}yb(e+152|0);break M}g=P()|0;O()|0;break M}Sa:{if(!(w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24))|w[e+855|0]<2){break Sa}o=0;if(!x[a+480188>>1]){break Sa}while(1){d=w[e+532|0]|w[e+533|0]<<8|(w[e+534|0]<<16|w[e+535|0]<<24);v[114578]=0;f=Q(256,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))+(o<<2)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break N}Ta:{if(!f){break Ta}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break N}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break N}h=0;i=0;if(!f){break Ta}while(1){Ua:{v[114578]=0;f=Q(258,b|0,8)|0;d=v[114578];v[114578]=0;Va:{Wa:{Xa:{if((d|0)!=1){if(!f){break Ua}v[114578]=0;Q(802,b|0,e+152|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Xa}if(!(w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24))){break Ua}d=(w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24))&-225;switch((d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))-1|0){case 1:break Va;case 0:break Wa;default:continue}}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);h=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);continue}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);i=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);continue}break}if(!h|!i){break Ta}v[114578]=0;f=Q(256,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break O}if(!f){break Ta}v[114578]=0;W(635,b|0,((o<<5)+a|0)+480289|0,i|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break O}}o=o+1|0;if(o>>>0<x[a+480188>>1]){continue}break}}f=w[e+544|0]|w[e+545|0]<<8;v[114578]=0;s=f<<8|f>>>8;R(403,N|0,ca+s&65535);d=v[114578];v[114578]=0;Ya:{if((d|0)==1){break Ya}Za:{if(f){A=j&16;I=ca&65535;d=s&65535;M=d>>>0>1?d:1;i=0;while(1){_a:{if(!Y){break _a}d=w[e+872|0]|w[e+873|0]<<8|(w[e+874|0]<<16|w[e+875|0]<<24);v[114578]=0;f=Q(256,b|0,(d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))+(i<<2)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Za}if(!f){break _a}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Za}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Za}if(!f){break _a}da=Wb(e+136|0);v[114578]=0;ga=T(277,e+80|0)|0;d=v[114578];v[114578]=0;$a:{ab:{if((d|0)!=1){l=w[e+855|0];if(l){break ab}v[114578]=0;Q(803,b|0,e+152|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}u[e+128>>1]=w[e+152|0];ha=w[_|0]+1|0;d=48;break $a}g=P()|0;O()|0;break P}j=t[e+806|0];v[114578]=0;Q(804,b|0,e+32|0)|0;d=v[114578];v[114578]=0;bb:{cb:{if((d|0)!=1){d=w[e+32|0]|w[e+33|0]<<8;u[e+128>>1]=d<<8|d>>>8;d=w[C|0]|w[C+1|0]<<8;ha=((d<<8|d>>>8)&65535)+1|0;d=c;if(!(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))){break bb}h=v[b+8>>2];d=w[c|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;Q(805,b|0,e+152|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}d=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}if(!f){break cb}d=w[e+160|0]|w[e+161|0]<<8|(w[e+162|0]<<16|w[e+163|0]<<24);v[114578]=0;W(482,b|0,da|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)!=1){break cb}break Q}break Q}db:{if(!(w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24))){break db}d=w[e+168|0]|w[e+169|0]<<8|(w[e+170|0]<<16|w[e+171|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}if(!f){break db}v[114578]=0;f=T(494,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;f=Q(256,b|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}if(!f){break db}v[114578]=0;U(343,e+56|0,b|0,B(x[e+128>>1],ha)|0);d=v[114578];v[114578]=0;if((d|0)==1){break Q}Wd(ga,e+56|0);Bb(e+56|0)}v[114578]=0;Q(256,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}}d=j+(l>>>0<3?48:24)|0}v[114578]=0;j=i+I|0;h=W(404,N|0,j&65535,ha|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Q}if(h){K=_b(N,j);v[114578]=0;Q(496,K|0,da|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Q}jg(e+128|0,x[a+480188>>1]);D=0;while(1){v[114578]=0;g=W(472,K|0,D|0,0)|0;f=v[114578];v[114578]=0;eb:{fb:{if((f|0)!=1){o=0;if(x[e+128>>1]){break fb}break eb}break Q}while(1){gb:{if(!w[e+855|0]){v[114578]=0;R(806,e+152|0,b|0);f=v[114578];v[114578]=0;if((f|0)!=1){j=dd(e+152|0);f=Bf(e+152|0);h=w[e+152|0];t[g+1|0]=h>>>3&16|w[j|0]>>>4|h>>>1&32;t[g+3|0]=w[j|0]&15;t[g+5|0]=w[f|0];f=h&63;h=f?f+d|0:0;break gb}break Q}v[114578]=0;R(595,e+152|0,b|0);f=v[114578];v[114578]=0;hb:{ib:{if((f|0)!=1){p=dd(e+152|0);m=Bf(e+152|0);l=Sh(e+152|0);v[114578]=0;h=T(389,ga|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Q}t[g+4|0]=h;j=w[e+152|0];f=j&127;if(!f){break ib}h=d+f|0;break hb}break Q}h=0;if((j|0)!=128){break hb}t[g|0]=254}t[g+1|0]=w[p|0]&63;t[g+3|0]=w[m|0];t[g+5|0]=w[l|0]}if(h-1>>>0<=119){t[g|0]=h}v[114578]=0;fa(807,g|0,(z|0)!=0|0,(F|0)!=0|0,n|0,(A|0)!=0|0);f=v[114578];v[114578]=0;if((f|0)!=1){$=(h|0)>84&ja|$;g=g+6|0;o=o+1|0;if(x[e+128>>1]<=(o&65535)>>>0){break eb}continue}break}break Q}D=D+1|0;if((ha|0)!=(D|0)){continue}break}}Bb(ga);yb(da)}i=i+1|0;if((M|0)!=(i|0)){continue}break}}oa=e,pa=vn(E),v[oa+80>>2]=pa;oa=e,pa=Hi(E),v[oa+56>>2]=pa;jb:{while(1){v[114578]=0;f=Q(808,e+80|0,e+56|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break R}kb:{lb:{mb:{nb:{ob:{pb:{if(!f){if(!(w[e+464|0]|w[e+465|0]<<8|(w[e+466|0]<<16|w[e+467|0]<<24))){break pb}d=w[e+464|0]|w[e+465|0]<<8|(w[e+466|0]<<16|w[e+467|0]<<24);v[114578]=0;f=Q(256,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24))|0;d=v[114578];v[114578]=0;if((d|0)==1){break Ya}if(!f){break pb}ca=s+ca|0;zp(E);break T}v[114578]=0;h=T(809,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ob}d=x[h>>1];if(!d){g=0;break nb}v[114578]=0;f=Q(546,r|0,d-1&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break kb}g=x[h>>1];if(!f){break nb}v[114578]=0;g=Q(810,r|0,g-1&65535)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break mb}break kb}zp(E);break S}g=P()|0;O()|0;break M}if(x[h+2>>1]==(g+1|0)){break lb}v[114578]=0;g=W(811,N|0,1,0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break kb}if((g|0)==65535){break lb}oa=rc(r,x[h>>1]),pa=g,u[oa>>1]=pa}i=_b(N,g);d=x[h+2>>1];v[114578]=0;f=T(812,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jb}v[114578]=0;f=W(498,e+152|0,12,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jb}d=Gn(Ne(f,v[_b(N,g)+12>>2]-1|0));v[114578]=0;Q(499,i|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break jb}s=(s&65535)>>>0>g>>>0?s:g+1|0}v[114578]=0;T(813,e+80|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}break R}break}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}g=P()|0;O()|0;break M}ma=ma+1|0;if(w[ia|0]>(ma&255)>>>0){continue}break}}v[114578]=0;R(489,la|0,0);b=v[114578];v[114578]=0;if((b|0)!=1){if(!($&1)){k=x[a+480192>>1];if(k){g=1;while(1){c=(((g&65535)<<2)+a|0)+900380|0;b=v[c>>2];if(b){Xb(ut(b));k=x[a+480192>>1]}v[c>>2]=0;g=g+1|0;if((g&65535)>>>0<=(k&65535)>>>0){continue}break}}u[a+480192>>1]=0}qb:{rb:{sb:{tb:{ub:{vb:{wb:{if(na){v[114578]=0;c=Q(2,e+152|0,14917)|0;b=v[114578];v[114578]=0;if((b|0)==1){break wb}v[114578]=0;U(646,a|0,2,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break vb}yb(c)}k=14964;switch(w[e+855|0]){case 3:break rb;case 2:break sb;case 1:break tb;case 0:break ub;default:break qb}}g=P()|0;O()|0;break g}g=P()|0;O()|0;yb(c);break g}k=x[a+480188>>1]>4?14965:14986;break qb}k=15e3;break qb}k=15018;break qb}k=15036}v[114578]=0;c=Q(2,e+16|0,15063)|0;b=v[114578];v[114578]=0;xb:{yb:{zb:{Ab:{Bb:{if((b|0)!=1){v[114578]=0;R(219,e+80|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break Bb}v[114578]=0;U(537,e+152|0,e+80|0,e+855|0);b=v[114578];v[114578]=0;if((b|0)==1){break Ab}Gb(a+1304436|0,e+152|0);yb(e+152|0);Ib(e+80|0);yb(c);v[114578]=0;c=Q(2,e+152|0,15079)|0;b=v[114578];v[114578]=0;if((b|0)==1){break yb}Gb(a+1304448|0,c);yb(c);v[114578]=0;Q(238,a+1304460|0,k|0)|0;b=v[114578];v[114578]=0;g=1;if((b|0)==1){break xb}v[a+1304496>>2]=2;break d}g=P()|0;O()|0;break g}g=P()|0;O()|0;break zb}g=P()|0;O()|0;Ib(e+80|0)}yb(c);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break g}g=P()|0;O()|0;break M}g=P()|0;O()|0;Bb(ga)}yb(da);break M}g=P()|0;O()|0;break M}g=P()|0;O()|0}zp(E);break g}g=P()|0;O()|0;break g}g=P()|0;O()|0}dR(J)}Bb(e+832|0);S(g|0);L()}g=0}dR(J)}Bb(e+832|0)}jb=e+912|0;return g|0}V(0)|0;O()|0;Ab();L()}function Es(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,$=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ja=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0;i=jb-176|0;jb=i;e=jb-16|0;jb=e;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[e+12>>2]=0;W(1372,a+8|0,e+12|0,e+8|0)|0;h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){jb=e+16|0;break b}break a}n=i+144|0;t[n+26|0]=0;u[n+24>>1]=0;v[n+16>>2]=0;v[n+20>>2]=-1;v[n+8>>2]=-1;v[n+12>>2]=-1;v[n>>2]=0;v[n+4>>2]=0;M=v[d+16>>2];ba=w[d+6|0];ka=b+484360|0;if(ba>>>0>=Nh(ka)>>>0){ba=w[ka+16|0]}la=a;D=Di(ka,ba);v[114578]=0;q=Q(1332,i+104|0,b|0)|0;a=v[114578];v[114578]=0;c:{if((a|0)!=1){h=v[q+4>>2];v[114578]=0;Y=W(1333,i+72|0,b|0,ba|0)|0;a=v[114578];v[114578]=0;d:{if((a|0)!=1){e:{f:{f=x[d+4>>1];g:{if(f>>>0>=oc(D)>>>0){break g}while(1){v[114578]=0;a=Q(546,D|0,f&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}if(a){break g}v[d>>2]=0;f=f+1|0;u[d+4>>1]=f;if(oc(D)>>>0>(f&65535)>>>0){continue}break}}a=v[d>>2];v[h+52>>2]=a;v[h+48>>2]=a;v[n+16>>2]=a;u[h+64>>1]=f;u[h+62>>1]=f;u[n+24>>1]=f;J=i- -64|0;Qf(J);qa=Gt(i+56|0);h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{ra=c&7;ta=(ra|0)!=7;r:{if(ta){break r}v[114578]=0;W(1334,J|0,1,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1334,J|0,2,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1334,J|0,3,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1334,J|0,28,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1334,J|0,35,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1334,J|0,37,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1334,J|0,36,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1334,J|0,38,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1335,qa|0,12,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;W(1335,qa|0,13,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}e=q+20|0;if(x[b+480188>>1]){f=0;while(1){if(w[((f<<5)+b|0)+480281|0]&4){Ba=Rc(e,f),Ca=-1,v[Ba+16>>2]=Ca}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}if((M|0)!=2){break r}a=x[d+12>>1];if(oc(D)>>>0<=a>>>0){break r}a=x[rc(D,a)>>1];v[114578]=0;l=b+484344|0;g=Q(444,l|0,a|0)|0;E=v[114578];v[114578]=0;if((E|0)==1){break h}if(!g){break r}g=_b(l,a);E=v[d+8>>2];v[114578]=0;g=Q(1336,g|0,E|0)|0;z=v[114578];v[114578]=0;if((z|0)==1){break h}if(!g){break r}g=0;a=_b(l,a);v[114578]=0;f=W(472,a|0,E|0,0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break i}if(!x[b+480188>>1]){break r}while(1){s:{t:{u:{switch(w[f|0]-253|0){case 0:if(x[b+480192>>1]){break t}break;case 1:case 2:break t;default:break u}}v[114578]=0;a=T(553,f|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}if(!a){break s}if(Fs(f)){break s}}Ba=Rc(e,g),Ca=-1,v[Ba+16>>2]=Ca}f=f+6|0;g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break}}$=h- -64|0;H=h+48|0;_=h+68|0;va=h+44|0;sa=q+8|0;ca=c&1;p=q+20|0;s=b+1074308|0;I=b+484344|0;wa=(M|0)!=3;ua=(M|0)!=2;E=0;while(1){v[h+48>>2]=v[h+52>>2];a=x[h+64>>1];u[h+62>>1]=a;v[114578]=0;a=Q(546,D|0,a|0)|0;e=v[114578];v[114578]=0;v:{if((e|0)!=1){w:{if(!a){break w}if(y[h+48>>2]<y[_b(I,x[rc(D,x[h+62>>1])>>1])+12>>2]){break w}v[H>>2]=0;Eb(i,s,63);if(Cb(i)){a=v[h+56>>2];v[h+56>>2]=0;v[h+48>>2]=a}a=x[h+64>>1]+1|0;u[h+62>>1]=a;u[h+64>>1]=a}if(A[q+32>>3]<A[d+8>>3]|wa){break v}t[n+26|0]=1;break k}a=P()|0;O()|0;break e}e=x[h+62>>1];a=h;x:{if(oc(D)>>>0>e>>>0){e=x[rc(D,x[h+62>>1])>>1];break x}e=65535}u[a+60>>1]=e;v[114578]=0;a=Q(444,I|0,e&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!(x[h+60>>1]==65535|ua|a|x[h+62>>1]!=x[d+12>>1])){t[n+26|0]=1;break k}y:{if(x[h+60>>1]<Ce(I)>>>0){break y}while(1){a=h;z=a;z:{A:{if(x[a+60>>1]!=65535){e=x[h+62>>1];if(oc(D)>>>0>e>>>0){break A}}if(x[D+28>>1]==x[h+62>>1]){break y}e=x[D+28>>1];break z}e=x[h+62>>1]+1|0}u[z+62>>1]=e;a=h;B:{if(oc(D)>>>0>(e&65535)>>>0){e=x[rc(D,x[h+62>>1])>>1];break B}e=65535}u[a+60>>1]=e;u[h+64>>1]=x[h+62>>1];v[114578]=0;a=Q(444,I|0,e&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}C:{if(a){break C}a=x[h+62>>1];v[114578]=0;a=aa(1337,Y|0,a|0,0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}if(!a){break C}if(M>>>0<=1){a=x[h+62>>1];v[n+8>>2]=0;u[n+20>>1]=a;if(!M){break y}}v[114578]=0;a=aa(1338,Y|0,$|0,H|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!a){break y}A[n>>3]=A[q+32>>3];v[114578]=0;R(1339,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[$>>1];v[114578]=0;Z(1340,q|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}a=x[h+64>>1];u[h+62>>1]=a;Ba=h,Ca=x[rc(D,a)>>1],u[Ba+60>>1]=Ca;v[h+52>>2]=v[h+48>>2];break y}if(x[h+60>>1]>=Ce(I)>>>0){continue}break}}if(x[$>>1]==65535){break k}a=x[h+60>>1];v[114578]=0;a=Q(444,I|0,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!a){if(x[D+28>>1]==x[h+62>>1]){if(!M){break k}v[114578]=0;a=aa(1338,Y|0,$|0,H|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!a){break k}A[n>>3]=A[q+32>>3];v[114578]=0;R(1339,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[$>>1];v[114578]=0;Z(1340,q|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[h+52>>2]=v[h+48>>2];continue}u[h+64>>1]=x[h+62>>1]+1;continue}if(y[h+48>>2]>=y[_b(I,x[h+60>>1])+12>>2]){v[H>>2]=0}a=x[h+62>>1];if(!((a|0)!=x[d+12>>1]|ua|v[H>>2]!=v[d+8>>2])){t[n+26|0]=1;break k}e=v[H>>2];v[114578]=0;a=aa(1337,Y|0,a|0,e|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(a){if(M>>>0<=1){u[n+20>>1]=x[h+62>>1];v[n+8>>2]=v[h+48>>2];if(!M){break k}}v[114578]=0;a=aa(1338,Y|0,$|0,H|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!a){break k}A[n>>3]=A[q+32>>3];v[114578]=0;R(1339,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[$>>1];v[114578]=0;Z(1340,q|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[h+52>>2]=v[h+48>>2];continue}u[n+22>>1]=x[h+62>>1];a=v[h+48>>2];v[n+12>>2]=a;v[h+52>>2]=a+1;D:{E:{if(a>>>0>=y[_b(I,x[h+60>>1])+12>>2]){v[H>>2]=0;break E}if(v[H>>2]){break D}}f=0;if(!x[b+480188>>1]){break D}while(1){G=A[q+32>>3];Ba=Rc(p,f),Da=G,A[Ba>>3]=Da;a=v[h>>2];Ba=Rc(p,f),Ca=a,v[Ba+8>>2]=Ca;f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}a=_b(I,x[h+60>>1]);e=v[h+48>>2];v[114578]=0;f=W(472,a|0,e|0,0)|0;a=v[114578];v[114578]=0;F:{G:{H:{if((a|0)!=1){g=0;K=0;da=0;if(!x[b+480188>>1]){break G}while(1){I:{Eb(i,s,77);J:{if(Ba=Cb(i),Ca=0,Ea=v[((g<<5)+b|0)+480280>>2]&1024,Ea?Ba:Ca){break J}v[114578]=0;a=T(1341,f|0)|0;e=v[114578];v[114578]=0;K:{L:{M:{if((e|0)==1){break M}if(a){N:{if(!ca){break N}a=w[f+1|0];if(a-251>>>0<5|!a){break N}v[114578]=0;a=T(1342,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break M}v[114578]=0;e=T(1343,f|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break I}u[i+48>>1]=e;t[i|0]=w[f+1|0];u[i+2>>1]=x[i+48>>1];v[114578]=0;e=Q(1344,sa|0,i|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break I}u[e>>1]=a}jt((B(g,896)+h|0)+1418|0);break J}a=B(g,896)+h|0;e=a+1422|0;l=w[f+4|0]|w[f+5|0]<<8;t[e|0]=l;t[e+1|0]=l>>>8;a=a+1418|0;e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;O:{switch(w[f+3|0]-16|0){case 0:a=w[f+5|0];v[114578]=0;U(1345,b|0,h|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break M}break J;case 3:break K;case 4:break L;case 1:break O;default:break J}}Eb(i,s,5);if(!Cb(i)){break J}a=w[f+5|0];if(!a){break J}v[114578]=0;U(1345,b|0,h|0,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){break J}}a=P()|0;O()|0;break e}a=w[f+5|0];e=a&240;if((e|0)==96){da=(a&15)+da|0;break J}if((e|0)!=224|K){break J}a=w[f+5|0]&15;if(v[b+480180>>2]&2){K=0;if(!a){break J}}K=a+1|0;break J}a=w[f+5|0];if((a&240)!=224){break J}K=(a&15)+1|0}f=f+6|0;g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break H}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}g=da;if(K){break F}}K=1;da=g}F=B(v[h+40>>2]+da|0,K);g=0;P:{if(!x[b+480188>>1]){l=0;na=0;oa=0;fa=0;ga=0;break P}N=F-1|0;z=F-K|0;ha=B(z,1e4);ga=0;fa=0;oa=0;na=0;l=0;Q:{while(1){R:{f=0;k=B(g,896)+h|0;a=k+1418|0;S:{if(w[a|0]){break S}e=a;if(w[a+1|0]|w[a+2|0]){break S}f=!w[e+3|0]}T:{if(f){break T}Eb(i,s,77);if(Ba=Cb(i),Ca=0,Ea=v[((g<<5)+b|0)+480280>>2]&1024,Ea?Ba:Ca){break T}f=w[k+1423|0];pa=k+1421|0;m=w[pa|0];e=w[a|0];j=k+1419|0;o=w[j|0];if(o){t[k+1429|0]=0;t[k+1433|0]=o;Ba=Rc(p,g),Ca=255,t[Ba+21|0]=Ca}v[114578]=0;o=T(553,a|0)|0;r=v[114578];v[114578]=0;if((r|0)==1){break R}if(o){t[k+1429|0]=e}v[114578]=0;r=T(553,a|0)|0;o=v[114578];v[114578]=0;if((o|0)==1){break R}o=k+608|0;U:{V:{W:{X:{Y:{Z:{if(w[j|0]?0:!r){break Z}j=k+1433|0;r=w[j|0];if(x[b+480192>>1]){if(x[b+480192>>1]<r>>>0){break Z}j=v[((w[j|0]<<2)+b|0)+900380>>2];if(!j){break Z}_:{if(!(t[j+15|0]&1)){break _}r=v[j+8>>2];v[114578]=0;U(1346,o|0,r|0,b|0);r=v[114578];v[114578]=0;if((r|0)!=1){break _}a=P()|0;O()|0;break e}if(!be(e)){break Z}r=x[ed(j+236|0,e-1|0)>>1]}if(!r|x[b+480190>>1]<r>>>0){break Z}e=B(r,104)+b|0;if(!(w[e+484414|0]&32)){break Z}e=x[e+484408>>1];v[114578]=0;U(1346,o|0,e|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break Y}}$:{aa:{ba:{r=k+1420|0;e=w[r|0];switch(e-1|0){case 1:break W;case 2:case 3:break aa;case 0:break ba;default:break $}}a=w[k+1422|0];Ba=Rc(p,g),Ca=a,t[Ba+21|0]=Ca;break W}a=w[k+1422|0];if(!a){break W}t[k+1462|0]=a;break W}if((e|0)==11){break X}break W}a=P()|0;O()|0;break e}if(!w[k+1422|0]){break W}gy(i,b,a,0);a=hc(i);v[k+1384>>2]=v[i>>2]<<2;if(!w[a|0]){break W}m=0;break V}ca:{switch(m-12|0){case 0:a=v[h+48>>2];e=x[h+60>>1];v[114578]=0;a=ea(1347,b|0,e|0,a|0,g&65535,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break R}v[h+56>>2]=0;u[h+64>>1]=a;if(!(v[b+480180>>2]&5?0:oa)){v[h+52>>2]=0}fa=1;if(!ca){ga=1;break T}v[k+1412>>2]=0;t[k+1469|0]=0;ga=1;break U;case 2:v[114578]=0;a=aa(1348,b|0,h|0,g&65535,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Q}if((a|0)==-1){m=14;break V}v[h+52>>2]=a;if(!ga){u[h+64>>1]=x[h+62>>1]+1}oa=1;if(!ca){break T}v[k+1412>>2]=0;t[k+1469|0]=0;break U;case 5:Eb(i,s,5);m=17;if(Cb(i)){break V}a=v[h+48>>2];e=x[h+60>>1];v[114578]=0;a=ea(1347,b|0,e|0,a|0,g&65535,0)|0;e=v[114578];v[114578]=0;da:{ea:{if((e|0)!=1){a=B(a,1e4);if(!ca|!(v[b+480180>>2]&16777250)){break da}if(a>>>0<1e4){break ea}t[k+1463|0]=(a>>>0)/1e4;break da}a=P()|0;O()|0;break e}a=B(w[k+1463|0],1e4)}e=(a>>>0)/1e4|0;fa:{if(a>>>0>319999){break fa}j=B(ha,e&15);a=v[h+44>>2];if((e&240)==16){a=a+j|0;break fa}e=a-j|0;a=a>>>0<e>>>0?0:e}v[h+44>>2]=a;a=v[v[b+8>>2]+20>>2];e=v[v[b+8>>2]+24>>2];Eb(i,s,8);Yn(va,B(a,1e4),Cb(i)?255e4:B(e,1e4));break V;case 8:m=20;ga:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break V}v[k+696>>2]=v[k+696>>2]&-257|((f|0)==145)<<8;break V;case 1:t[k+1464|0]=f&15;break V;case 2:e=g;a=e;if(v[b+480180>>2]==2){e=x[b+480188>>1]-1|0;a=0}if(!(f&15)){fa=0;l=1;j=e&65535;if(j>>>0<(a&65535)>>>0){break V}while(1){G=A[q+32>>3];e=a&65535;Ba=Rc(p,e),Da=G,A[Ba>>3]=Da;l=v[h>>2];Ba=Rc(p,e),Ca=l,v[Ba+8>>2]=Ca;l=v[h+48>>2];Ba=Rc(p,e),Ca=l,v[Ba+12>>2]=Ca;v[(B(e,896)+h|0)+1412>>2]=v[h+48>>2];l=1;a=a+1|0;if(j>>>0>=(a&65535)>>>0){continue}break}break V}Eb(i,s,16);if(!(Cb(i)|v[b+480180>>2]==2)){fa=0;na=1;break V}na=1;fa=0;e=e&65535;if(e>>>0<(a&65535)>>>0){break V}j=v[H>>2]+1|0;while(1){v[(B(a&65535,896)+h|0)+1412>>2]=j;a=a+1|0;if(e>>>0>=(a&65535)>>>0){continue}break};break V;case 6:break ga;default:break V}}t[k+1472|0]=f&15;break V;case 7:m=19;a=f&240;if((a|0)!=240){if((a|0)!=96){break V}if(f&15){Ba=h,Ca=v[Rc(p,g)+12>>2],v[Ba+56>>2]=Ca;na=1;break V}G=A[q+32>>3];Ba=Rc(p,g),Da=G,A[Ba>>3]=Da;a=v[h>>2];Ba=Rc(p,g),Ca=a,v[Ba+8>>2]=Ca;a=v[h+48>>2];Ba=Rc(p,g),Ca=a,v[Ba+12>>2]=Ca;v[k+1412>>2]=v[h+48>>2];l=1;break V}t[k+1472|0]=f&15;break V;case 1:case 3:case 4:case 6:break V;default:break ca}}if((m|0)!=28){break V}if((f&240)==160){Eb(i,s,58);m=28;if(Cb(i)){break V}t[k+1464|0]=f&15;break V}m=28}if(!ca){break T}ha:{ia:{ja:{ka:{la:{ma:{na:{switch(m-2|0){case 0:if(!f){break U}Eb(i,s,90);if(!Cb(i)){t[k+1440|0]=f}t[k+1439|0]=f;break U;case 1:if(!f){break U}Eb(i,s,90);if(!Cb(i)){t[k+1439|0]=f}t[k+1440|0]=f;break U;case 2:if(!f){break U}v[k+1384>>2]=f<<2;break U;case 8:if(!f){break U}v[k+1272>>2]=f<<8;break U;case 4:case 9:if(!f){break U}t[k+1437|0]=f;break U;case 11:Ba=Rc(p,g),Ca=f,t[Ba+21|0]=Ca;break U;case 21:a=f<<(!(v[b+480180>>2]&59593760)&f<<24>>24>-1)&255;if(a>>>0<=128){v[_>>2]=a<<1;break U}if(v[b+480180>>2]&16777250){break U}v[_>>2]=256;break U;case 22:Eb(i,s,9);oa:{if(Cb(i)){a=k+1445|0;if(f){t[a|0]=f;break oa}f=w[a|0];break oa}if(f){t[h+1445|0]=f;break oa}f=w[h+1445|0]}a=_;e=f&240;j=f&15;pa:{if(!(!e|(j|0)!=15)){m=v[_>>2]+(e>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break pa}m=v[_>>2]-(j<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!j|(e|0)!=240)){break pa}m=v[_>>2]+B(z,(f>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(e){break pa}m=v[_>>2]-B(z,j<<(v[b+480180>>2]&59593760?1:2))|0}v[a>>2]=m;ce(_,0,256);break U;case 19:if(f>>>0>64){break U}v[k+1368>>2]=f;break U;case 20:a=k+1444|0;qa:{if(f){t[a|0]=f;break qa}f=w[a|0]}j=k+1368|0;e=v[j>>2];a=f;m=a&240;f=a&15;ra:{if(!(!m|(f|0)!=15)){v[i>>2]=e+(a>>>4|0);break ra}if(!(!f|(m|0)!=240)){v[i>>2]=e-f;break ra}if(f){v[i>>2]=e-B(f,z);break ra}v[i>>2]=e+B(z,a>>>4|0)}ce(i,0,64);v[j>>2]=v[i>>2];break U;case 7:zl(b,o,f,8);break U;case 25:break ha;case 6:break ia;case 24:break ja;case 3:break ka;case 5:break la;case 18:break ma;case 17:break na;default:break U}}if(!x[b+480188>>1]|f>>>0>15){break ma}e=(f&1)<<14;a=0;while(1){j=B(a,896)+h|0;v[j+696>>2]=(e|v[j+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((f&240)!=128){break U}zl(b,o,f&15,4);break U}if(f){t[k+1437|0]=f}f=0}rk(o,f);break U}KM(b,o,f);break U}JM(o,f);break U}IM(o,f)}sa:{ta:{switch(w[r|0]-2|0){case 0:zl(b,o,w[k+1422|0],6);break sa;case 5:Eb(i,s,53);e=Cb(i);a=w[k+1422|0];if(e){t[k+1451|0]=a&15;break sa}rk(o,a<<4);break sa;case 6:break ta;default:break sa}}rk(o,w[k+1422|0])}ua:{va:{wa:{xa:{a=w[pa|0];switch(a-5|0){case 3:break va;case 0:case 2:break wa;case 1:break T;default:break xa}}switch(a-26|0){case 1:break ua;case 0:break wa;default:break T}}ya:{if(v[b+480180>>2]&16777248){a=F;if(!(w[b+480208|0]&4)){break ya}}a=z}e=w[k+1451|0];Eb(i,s,21);f=Cb(i);k=k+1447|0;a=B(a,e);t[k|0]=w[k|0]+(f?a<<2:a);break T}za:{if(v[b+480180>>2]&16777248){a=F;if(!(w[b+480208|0]&4)){break za}}a=z}e=w[k+1454|0];Eb(i,s,21);f=Cb(i);k=k+1448|0;a=B(a,e);t[k|0]=w[k|0]+(f?a<<2:a);break T}a=k+1449|0;t[a|0]=w[a|0]+B(N,w[k+1457|0]);v[114578]=0;R(1349,b|0,o|0);a=v[114578];v[114578]=0;if((a|0)==1){break R}}g=g+1|0;if(g>>>0<x[b+480188>>1]){continue}break P}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}if(v[h+40>>2]==65535?v[b+480180>>2]==4:0){break k}v[h+32>>2]=v[b+480216>>2];if(HM(_b(I,x[h+60>>1]))){Ba=h,Ca=v[_b(I,x[h+60>>1])+16>>2],v[Ba+32>>2]=Ca}v[114578]=0;z=Q(1350,b|0,h|0)|0;a=v[114578];v[114578]=0;Aa:{Ba:{if((a|0)!=1){a=B(F,z);A[q+32>>3]=+(a>>>0)/+y[b+24620>>2]+A[q+32>>3];v[h>>2]=a+v[h>>2];if(!(!x[b+480188>>1]|ta)){m=0;pa=(E|0)!=0&(E|0)!=(z|0);xa=K-1|0;while(1){Ca:{if(v[Rc(p,m)+16>>2]==-1){break Ca}r=1;Da:{Ea:{j=B(m,896)+h|0;N=j+1421|0;switch(w[N|0]-4|0){case 0:case 2:break Da;default:break Ea}}r=w[j+1420|0]==11}if(w[j+1419|0]){v[j+1268>>2]=0}f=j+1423|0;a=w[f|0];v[114578]=0;ha=j+1418|0;g=T(553,ha|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break o}k=j+608|0;e=a&15;o=0;Fa:{if(!g){break Fa}Ga:{Ha:{Ia:{if(!r){break Ia}if(!w[Rc(p,m)+20|0]){break Ia}g=v[j+1308>>2];v[114578]=0;g=jo(1351,b,k,g,0);o=mb;ja=v[114578];v[114578]=0;if((ja|0)==1){break Ha}v[j+616>>2]=g;v[j+620>>2]=o}t[j+1432|0]=w[j+1429|0];ja=j+1300|0;za=v[ja>>2];g=w[j+1433|0];if(!g){break Ga}v[114578]=0;ma(1352,b|0,k|0,g|0,r|0,1,1);g=v[114578];v[114578]=0;if((g|0)!=1){break Ga}break n}a=P()|0;O()|0;break e}g=w[ha|0];v[114578]=0;ia(1353,b|0,k|0,g|0,r|0,1,0,65535);g=v[114578];v[114578]=0;if((g|0)==1){break n}g=a>>>4|0;Ba=Rc(p,m),Ca=1,t[Ba+20|0]=Ca;Aa=!(v[b+480180>>2]&16777250);o=w[N|0];Ja:{if(!((o-19&255)>>>0>1|e>>>0>=F>>>0)){a=e;if((w[f|0]&-16)==208){break Ja}}a=g>>>0<F>>>0?(o|0)==33?g:0:0}o=a;if(!(Aa|(!o|K>>>0<2))){o=B(v[h+40>>2]+da|0,xa)+o|0}if(!r){Ba=Rc(p,m),Ca=0,v[Ba+16>>2]=Ca}a=w[N|0];Ka:{La:{if((a|0)==9){break La}Ma:{if((a|0)!=19){if((g|0)!=8|(a|0)!=20){break Ma}break La}if((g|0)==8){break La}}if(w[j+1420|0]!=2){break Ka}}v[ja>>2]=za}Na:{Oa:{switch(a-39|0){default:if((a|0)!=10){break Na}t[i|0]=0;a=v[h+48>>2];g=x[h+60>>1];v[114578]=0;g=ea(1347,b|0,g|0,a|0,m&65535,i|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){if(!w[i|0]){a=g<<8;if(!a){a=v[j+1272>>2]}g=(w[j+1464|0]<<16)+a|0}v[114578]=0;U(1354,b|0,k|0,g|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Fa}}a=P()|0;O()|0;break e;case 2:a=v[j+684>>2];g=w[f|0];v[114578]=0;g=Fma(a,0,g,0);a=mb;ja=a>>>8|0;a=Gg(790,(a&255)<<24|g>>>8,ja);g=v[114578];v[114578]=0;if((g|0)==1){break n}v[114578]=0;U(1354,b|0,k|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}break Fa;case 1:break Na;case 0:break Oa}}if(!v[j+712>>2]){break Na}v[114578]=0;X(1355,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break n}a=w[f|0];v[114578]=0;U(1356,h|0,k|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}o=v[h+40>>2]-1|0;break Fa}if(w[j+1420|0]!=15){break Fa}a=w[j+1422|0];if(a>>>0>9){break Fa}g=v[j+712>>2];if(!g){break Fa}Pa:{if(!a){g=v[j+1272>>2];break Pa}g=v[(g+(a<<2)|0)- -64>>2];v[j+1272>>2]=g}v[114578]=0;U(1354,b|0,k|0,g|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Fa}a=P()|0;O()|0;break e}Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{switch(w[ha|0]-253|0){case 0:if(x[b+480192>>1]){break Za}break;case 1:case 2:break Za;default:break _a}}g=w[N|0];if((g-19&255)>>>0<=1){if(e>>>0>=F>>>0){a=l;break Xa}a=l;if((w[f|0]&-16)==192){break Za}break Xa}a=g&255;if((a|0)==33&(e|0)!=0&e+o>>>0<F>>>0){break Za}e=l;if((a|0)!=25){break Ya}}g=w[N|0];e=1}if((g&255)==13){break Wa}a=e}if(w[j+1420|0]==1){v[j+1296>>2]=w[j+1422|0]<<2}if((!v[j+712>>2]|a)&1){break Va}e=0;g=g&255;if(g>>>0>42){break Sa}e=a;break Ta}v[j+1296>>2]=w[f|0]<<2;if(!((!v[j+712>>2]|e)&1)){break Ua}a=e}if(a&1){break Qa}break Ra}g=13}Eb(i,J,g);$a:{if(Cb(i)){break $a}if(w[N|0]!=19){break Sa}a=w[f|0]&240;if((a|0)==32){break $a}if((a|0)!=16){break Sa}}e=1}a=j+1420|0;if(w[a|0]<16){Pj(i,qa,w[a|0]);if(!((Cb(i)|e)&1)){break Ra}break Qa}if(e&1){break Qa}}if(pa){v[114578]=0;X(1355,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break o}}ab:{bb:{cb:{a=w[N|0];if(a-6>>>0>=2){db:{switch(a-19|0){case 1:break bb;case 0:break cb;default:break db}}if((a|0)!=11){break ab}}if(!F|(v[b+480180>>2]==1?!w[f|0]:0)){break ab}a=j+1480|0;g=0;while(1){t[a|0]=!g|w[a|0]&254;dn(b,k,w[f|0]);g=g+1|0;if((F|0)!=(g|0)){continue}break}break ab}g=w[f|0];if(!(g&15)){if(!(v[b+480180>>2]&1048580)){break ab}g=w[f|0]}a=j+1480|0;t[a|0]=w[a|0]|1;a=g&240;if((a|0)!=176){if((a|0)!=160){break ab}bp(b,k,g&15,0);break ab}ap(b,k,g&15,0);break ab}eb:{fb:{gb:{a=w[f|0];switch(a-158|0){case 1:break fb;case 0:break gb;default:break eb}}v[114578]=0;X(1355,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break o}v[j+696>>2]=v[j+696>>2]&-129;break ab}v[114578]=0;X(1355,q|0,m&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break o}v[j+696>>2]=v[j+696>>2]|128;if(!v[j+684>>2]|v[k+4>>2]){break ab}v[114578]=0;a=T(553,ha|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break o}if(w[j+696|0]&2?!a:0){break ab}e=v[j+684>>2]-1|0;a=k;v[a>>2]=-1;v[a+4>>2]=e;break ab}if((a&240)!=112|a>>>0<115){break ab}v[114578]=0;U(1357,k|0,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break o}}a=j+1480|0;t[a|0]=w[a|0]|1;hb:{ib:{jb:{kb:{e=j+1420|0;switch(w[e|0]-3|0){case 0:case 1:break ib;case 3:break jb;case 2:break kb;default:break hb}}a=w[j+1422|0];Eb(i,s,41);bp(b,k,a,Cb(i));break hb}a=w[j+1422|0];Eb(i,s,41);ap(b,k,a,Cb(i));break hb}f=w[j+1422|0];lb:{if(f){break lb}Eb(i,s,41);f=0;if(!Cb(i)){break lb}f=w[j+1462|0];if(!f){break hb}}if(!F){break hb}e=w[e|0]==3?f<<4:f;f=0;while(1){t[a|0]=!f|w[a|0]&254;dn(b,k,e&255);f=f+1|0;if((F|0)!=(f|0)){continue}break}}if(r){a=v[Rc(p,m)+16>>2];e=Rc(p,m);v[e+16>>2]=v[e+16>>2]+F;v[114578]=0;X(1355,q|0,m&65535,z|0,(a+o|0)+1|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Ca}a=P()|0;O()|0;break e}a=Rc(p,m);v[a+16>>2]=v[a+16>>2]+(F-o|0);break Ca}v[114578]=0;Z(1358,k|0);a=v[114578];v[114578]=0;if((a|0)==1){break o}Ba=Rc(p,m),Ca=0,v[Ba+16>>2]=Ca}m=m+1|0;if(m>>>0<x[b+480188>>1]){continue}break}}if(!na){break Aa}Eb(i,s,68);if(Ba=Cb(i),Ca=0,Ea=ga|oa,Ea?Ba:Ca){break Aa}Eb(i+48|0,s,49);if(Cb(i+48|0)&ga){break Aa}Eb(i+40|0,s,103);E=z;if(Cb(i+40|0)&fa){continue}f=0;g=jb-16|0;jb=g;l=g+8|0;e=jb-16|0;jb=e;v[114578]=0;a=i;T(1375,a+4|0)|0;E=v[114578];v[114578]=0;mb:{if((E|0)!=1){v[114578]=0;v[e+12>>2]=0;W(1376,a+8|0,e+12|0,l|0)|0;l=v[114578];v[114578]=0;if((l|0)!=1){break mb}break a}break a}Ba=a,Ca=hc(a),v[Ba>>2]=Ca;jb=e+16|0;jb=g+16|0;e=i;if(!x[b+480188>>1]){break Ba}while(1){nb:{g=B(f,896)+h|0;a=w[g+1423|0];g=w[g+1421|0];ob:{if(!(a>>>0<192?!((g|0)!=20|a>>>0<177):0)){if(a>>>0<97|a>>>0>111|(g|0)!=19){break ob}}G=A[Rc(p,f)>>3];v[114578]=0;A[i+48>>3]=G;g=Q(1359,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break nb}if(!v[g>>2]){v[114578]=0;g=Q(1359,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break nb}v[g>>2]=1}v[114578]=0;g=Q(1359,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break nb}g=v[g>>2];v[114578]=0;a=Q(1360,g|0,(a&15)+1|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break nb}v[114578]=0;g=Q(1359,e|0,i+48|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break nb}v[g>>2]=a}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break Ba}break}break p}a=P()|0;O()|0;break e}Ba=i,Ca=vn(e),v[Ba+40>>2]=Ca;Ba=i,Ca=Hi(e),v[Ba+32>>2]=Ca;while(1){v[114578]=0;a=Q(1361,i+40|0,i+32|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}if(!a){pb:{if(v[b+480180>>2]!=32){break pb}f=0;if(!x[b+480188>>1]){break pb}while(1){a=B(f,896)+h|0;if(!(w[a+1421|0]!=20|(w[a+1423|0]+79&255)>>>0>14)){G=A[q+32>>3];Ba=Rc(p,f),Da=G,A[Ba>>3]=Da;a=v[h>>2];Ba=Rc(p,f),Ca=a,v[Ba+8>>2]=Ca}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}zM(e);break Aa}v[114578]=0;a=T(1362,i+40|0)|0;g=v[114578];v[114578]=0;qb:{rb:{if((g|0)!=1){g=zb(a);G=A[q+32>>3];A[q+32>>3]=(G-A[a>>3])*+(v[g>>2]-1|0)+G;f=0;if(x[b+480188>>1]){break rb}break qb}break p}while(1){if(A[Rc(p,f)>>3]!=A[a>>3]){f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break qb}break}a=v[h>>2];l=Rc(p,f);v[h>>2]=v[h>>2]+B(v[g>>2]-1|0,a-v[l+8>>2]|0);Eb(i+48|0,s,16);if(Ba=!Cb(i+48|0),Ca=0,Ea=v[b+480180>>2]!=2,Ea?Ba:Ca){break qb}G=A[q+32>>3];Ba=Rc(p,f),Da=G,A[Ba>>3]=Da;a=v[h>>2];Ba=Rc(p,f),Ca=a,v[Ba+8>>2]=Ca;a=v[h+48>>2];Ba=Rc(p,f),Ca=a+1|0,v[Ba+12>>2]=Ca}v[114578]=0;T(1363,i+40|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){continue}break}break p}E=z;continue}}a=P()|0;O()|0;break e}a=P()|0;O()|0;zM(e);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}sb:{tb:{if(!(!x[b+480188>>1]|(ra|0)!=7)){e=0;while(1){if(v[Rc(p,e)+16>>2]!=-1){v[114578]=0;X(1355,q|0,e&65535,E|0,-1);a=v[114578];v[114578]=0;if((a|0)==1){break tb}}e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}if(w[n+26|0]){u[n+20>>1]=x[h+62>>1];v[n+8>>2]=v[h+48>>2]}A[n>>3]=A[q+32>>3];v[114578]=0;R(1339,la|0,n|0);a=v[114578];v[114578]=0;if((a|0)==1){break sb}ub:{vb:{if(!ca){break vb}wb:{if(!(M?!w[n+26|0]:0)){a=b+1074376|0;FM(a,h);fy(a);a=0;v[b+1074400>>2]=0;t[b+1074464|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1304392|0;if(rd(d)){e=v[d>>2];v[114578]=0;Z(1364,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break sb}}xb:{if(x[b+480188>>1]){h=(ra|0)==7;while(1){e=B(a,896)+b|0;g=w[e+1075805|0];if(g){t[e+1075808|0]=g}if(!(w[Rc(p,a)+21|0]==255|h)){g=Rc(p,a);v[114578]=0;t[i|0]=64;g=Q(393,g+21|0,i|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break xb}v[e+1075672>>2]=w[g|0]<<2}yb:{g=e+1075088|0;l=v[g>>2];if(!l|!(w[l+35|0]&2)){break yb}if(!rd(d)){break yb}l=v[d>>2];g=v[g>>2];v[114578]=0;z=l;l=a&65535;U(1365,z|0,l|0,g+68|0);g=v[114578];v[114578]=0;if((g|0)!=1){g=v[d>>2];v[114578]=0;U(1366,g|0,l|0,1);g=v[114578];v[114578]=0;if((g|0)!=1){break yb}}a=P()|0;O()|0;break e}v[e+1075e3>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=ez(i);Ba=i,Ca=vn(sa),v[Ba+40>>2]=Ca;Ba=i,Ca=Hi(sa),v[Ba+32>>2]=Ca;zb:{while(1){Ab:{v[114578]=0;a=Q(1367,i+40|0,i+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ab}if(!a){g=250;a=d;e=a;Bb:{Cb:{while(1){if(v[e>>2]){break Cb}e=e+4|0;g=g-32|0;if(g>>>0>31){continue}break}a=(v[a+28>>2]&67108863)!=0;break Bb}a=1}if(!a){break wb}a=0;while(1){Eb(i+48|0,d,a);Db:{if(!Cb(i+48|0)){break Db}e=v[(B(a,160)+b|0)+906300>>2];h=v[v[e>>2]+172>>2];v[114578]=0;Z(h|0,e|0);e=v[114578];v[114578]=0;if((e|0)!=1){break Db}a=P()|0;O()|0;break e}a=a+1|0;if((a|0)!=250){continue}break}break wb}v[114578]=0;e=T(1368,i+40|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break zb}h=w[e|0]-1&255;a=v[(B(h,160)+b|0)+906300>>2];if(a){Eb(i+48|0,d,h);if(!Cb(i+48|0)){v[114578]=0;W(1369,d|0,h|0,1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ub}h=v[v[a>>2]+168>>2];v[114578]=0;R(h|0,a|0,-1);h=v[114578];v[114578]=0;if((h|0)==1){break ub}}h=x[e+2>>1];g=v[v[a>>2]+44>>2];e=x[e+4>>1];v[114578]=0;ya(g|0,a|0,h|0,C(C(C(e>>>0)*C(.0010010009864345193))));a=v[114578];v[114578]=0;if((a|0)==1){break ub}}v[114578]=0;T(1370,i+40|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){continue}}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}if((c|0)==3){break wb}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074444>>2]=v[b+480200>>2]}if(w[ka+16|0]==(ba|0)){break vb}v[114578]=0;R(489,ka|0,ba|0);a=v[114578];v[114578]=0;if((a|0)==1){break sb}}if(c&9){v[114578]=0;R(1371,b+1304360|0,Y|0);a=v[114578];v[114578]=0;if((a|0)==1){break sb}}$o(Y);EM(q);jb=i+176|0;return}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}$o(Y);break d}a=P()|0;O()|0}EM(q);break c}a=P()|0;O()|0}Hl(la);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function wia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=jb-1728|0;jb=d;Jc(b);n=jb-16|0;jb=n;j=d+1600|0;bQ(n+8|0,j);i=Hb(n+8|0);e=b;g=nc(e,ac(n,n+8|0));if((i|0)==(g|0)){$b(e,Hb(n+8|0))}jb=n+16|0;e=(g|0)==(i|0);if(!e){cQ(j)}a:{if(!e){break a}if(!hQ(d+1600|0)){break a}if(!Qb(b,id(256,0))){break a}b:{if(!c){break b}Hd(a,1048576);wi(a);f=Ub(d+1584|0,16384);v[114578]=0;R(219,d+1328|0,f|0);e=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((e|0)!=1){C=d+1608|0;v[d+160>>2]=w[C+1|0];e=w[C|0];v[114578]=0;v[d+24>>2]=e;R(660,d+88|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break r}v[114578]=0;X(645,d+240|0,d+1328|0,d+160|0,d+88|0);e=v[114578];v[114578]=0;if((e|0)==1){break q}Gb(a+1304436|0,d+240|0);yb(d+240|0);yb(d+88|0);Ib(d+1328|0);yb(f);e=Ub(d+240|0,16401);Gb(a+1304448|0,e);yb(e);yg(d+88|0,2,d+1610|0);Ic(d+1328|0,d+88|0);v[114578]=0;U(13,d+240|0,7,d+1328|0);e=v[114578];v[114578]=0;if((e|0)==1){break k}Gb(a+1304460|0,d+240|0);yb(d+240|0);yb(d+1328|0);v[a+1304496>>2]=7;Xt(d+1328|0,2,d+1642|0);Ic(d+240|0,d+1328|0);Gb(a+1304400|0,d+240|0);yb(d+240|0);e=d+1712|0;u[a+480188>>1]=w[e|0]|w[e+1|0]<<8;e=Cd(w[d+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=e;H=d+1722|0;u[a+480192>>1]=w[H|0]|w[H+1|0]<<8;r=d+1724|0;u[a+480190>>1]=w[r|0]|w[r+1|0]<<8;e=Cd(w[d+1717|0],1,32);v[a+480216>>2]=e;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=e<<2;lu(b,d+1328|0);D=a+484360|0;p=d+1706|0;eq(Vb(D),d+1328|0,w[p|0]|w[p+1|0]<<8,65535,65535);e=d+1708|0;Oe(Vb(D),w[e|0]|w[e+1|0]<<8);ud(d+1312|0,b,hg(b));v[114578]=0;f=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}v[114578]=0;U(343,d+1296|0,b|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}E=x[a+480188>>1];v[114578]=0;s=Q(258,d+1312|0,274)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}if(s){u[a+480188>>1]=x[a+480188>>1]+8}n=c&1;if(!n){break l}e=d+1710|0;e=w[e|0]|w[e+1|0]<<8;v[114578]=0;R(403,a+484344|0,e|0);e=v[114578];v[114578]=0;if((e|0)!=1){break l}break f}h=P()|0;O()|0;break o}h=P()|0;O()|0;break p}h=P()|0;O()|0;yb(d+88|0)}Ib(d+1328|0)}yb(f);break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;break e}l=a+484344|0;z=d+1718|0;q=d+1710|0;if(!(w[q|0]|w[q+1|0]<<8)){break g}e=0;while(1){v[114578]=0;g=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break h}v[114578]=0;v[d+160>>2]=g;g=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}v[114578]=0;U(343,d+240|0,b|0,g+1&-2);f=v[114578];v[114578]=0;if((f|0)==1){break i}Cc(d+160|0,1024);s:{if(!n){break s}f=v[d+160>>2];if(!f){break s}v[114578]=0;g=W(404,l|0,e&65535,f|0)|0;f=v[114578];v[114578]=0;t:{if((f|0)!=1){if(!g){break s}h=0;if(t[z|0]&1){o=0;while(1){v[114578]=0;g=Q(258,d+240|0,1)|0;f=v[114578];v[114578]=0;u:{if((f|0)!=1){if(!g){break s}v[114578]=0;f=T(389,d+240|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break j}m=0;if((f|0)!=255){break u}v[114578]=0;m=T(389,d+240|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;f=T(389,d+240|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break u}}break j}break j}v:{if(!(f&127)){break v}g=_b(l,e);v[114578]=0;g=W(472,g|0,o|0,h&65535)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[d+88|0]=0;t[d+89|0]=0;t[d+90|0]=0;t[d+91|0]=0;t[d+91|0]=0;t[d+92|0]=0;t[d+93|0]=0;t[d+94|0]=0;if(f&1){v[114578]=0;j=T(389,d+240|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[d+88|0]=j}if(f&2){v[114578]=0;j=T(389,d+240|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[d+89|0]=j}if(f&4){v[114578]=0;j=T(389,d+240|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[d+90|0]=j}if(f&8){v[114578]=0;j=T(389,d+240|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[d+91|0]=j}if(f&16){v[114578]=0;j=T(389,d+240|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[d+92|0]=j}if(f&32){v[114578]=0;j=T(389,d+240|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[d+93|0]=j}if(f&64){v[114578]=0;i=T(389,d+240|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}t[d+94|0]=i}v[114578]=0;j=Q(896,g|0,d+88|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}v[114578]=0;v[d+24>>2]=m;v[d+224>>2]=v[d+160>>2]+(o^-1);i=Q(333,d+24|0,d+224|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}A=j|A;j=v[i>>2];if(!j){break v}k=1;f=g;while(1){f=B(x[a+480188>>1],6)+f|0;i=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[f|0]=i;t[f+1|0]=i>>>8;t[f+2|0]=i>>>16;t[f+3|0]=i>>>24;i=w[g+4|0]|w[g+5|0]<<8;t[f+4|0]=i;t[f+5|0]=i>>>8;if((j|0)==(k|0)){break v}k=k+1|0;continue}}o=(m+o|0)+1|0;f=v[d+160>>2];if(o>>>0>=f>>>0){while(1){h=h+1|0;o=o-f|0;if(f>>>0<=o>>>0){continue}break}}if((h&65535)>>>0<E>>>0){continue}break}break s}F=0;if(v[d+160>>2]){break t}break s}break j}while(1){f=_b(l,e);v[114578]=0;j=Q(497,f|0,F|0)|0;f=v[114578];v[114578]=0;w:{x:{if((f|0)!=1){f=0;if(E){break x}break w}break j}while(1){y:{v[114578]=0;Q(897,d+240|0,d+88|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break y}v[114578]=0;i=Q(896,j+B(f,6)|0,d+88|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break y}A=i|A;f=f+1|0;if((E|0)!=(f|0)){continue}break w}break}break j}F=F+1|0;if(F>>>0<y[d+160>>2]){continue}break}}Bb(d+240|0);e=e+1|0;if(e>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}break g}h=P()|0;O()|0;yb(d+1328|0);break c}h=P()|0;O()|0;Bb(d+240|0);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0;break e}e=d+1714|0;z:{if((w[e|0]|w[e+1|0]<<8)>>>0<=1|(w[e|0]|w[e+1|0]<<8)>>>0>4999){break z}if(A&1){e=w[e|0]|w[e+1|0]<<8;v[114578]=0;f=Gg(460,((e>>>1|0)+11025e5>>>0)/(e>>>0)|0,0);e=v[114578];v[114578]=0;if((e|0)==1){break f}v[a+480224>>2]=0;v[a+480204>>2]=f;break z}i=v[a+480216>>2];g=v[a+480196>>2];f=w[e|0]|w[e+1|0]<<8;v[a+480224>>2]=2;e=a;G=2646e7/+(B(f,B(g,i))>>>0);A:{if(G<4294967296&G>=0){f=~~G>>>0;break A}f=0}v[e+480204>>2]=f}e=x[a+480188>>1];v[114578]=0;t[d+240|0]=0;I=W(898,d+1280|0,e|0,d+240|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){n=a+1304412|0;j=a+1304424|0;i=d+240|3;F=0;B:{C:{D:{E:{F:{while(1){v[114578]=0;f=Q(258,d+1296|0,8)|0;e=v[114578];v[114578]=0;G:{if((e|0)!=1){if(f){break G}if(x[a+480188>>1]){f=0;while(1){e=t[xc(I,f)|0];H:{if((e|0)<=(f|0)|(e|0)>=x[a+480188>>1]){break H}j=((e<<5)+a|0)+480288|0;i=w[j|0];if(!i){break H}g=((f<<5)+a|0)+480288|0;e=w[g|0];if(!e){t[g|0]=i;break H}k=(B(e-1&255,160)+a|0)+906300|0;if((Ij(k)|0)!=255){while(1){k=(B(Ij(k),160)+a|0)+906300|0;if((Ij(k)|0)!=255){continue}break}}g=k+28|0;e=w[j|0]-1&255;e=e>>>0<250?e+128|0:0;t[g|0]=e;t[g+1|0]=e>>>8;t[g+2|0]=e>>>16;t[g+3|0]=e>>>24}f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}v[d+232>>2]=0;v[d+236>>2]=0;v[d+224>>2]=0;v[d+228>>2]=0;v[d+216>>2]=0;v[d+220>>2]=0;v[d+208>>2]=0;v[d+212>>2]=0;I:{J:{K:{L:{M:{N:{if(s){v[114578]=0;Q(899,d+1312|0,d+240|0)|0;e=v[114578];v[114578]=0;O:{if((e|0)!=1){k=0;while(1){e=x[a+480192>>1];v[114578]=0;i=Q(900,a|0,e+1&65535)|0;e=v[114578];v[114578]=0;P:{Q:{R:{S:{T:{U:{V:{if((e|0)!=1){e=k<<1;f=e+(d+224|0)|0;u[f>>1]=i;h=e+(d+208|0)|0;g=d+e|0;e=g+242|0;u[h>>1]=w[e|0]|w[e+1|0]<<8;if((i|0)==65535){break Q}e=w[g+242|0]|w[g+243|0]<<8;v[114578]=0;f=W(456,a|0,i|0,e+1&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break V}if(!f){break P}v[114578]=0;R(509,d+160|0,16418);e=v[114578];v[114578]=0;if((e|0)==1){break U}v[114578]=0;v[d+24>>2]=k+1;U(901,d+88|0,d+160|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break T}v[114578]=0;Q(371,f+492|0,d+88|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break S}yb(d+88|0);Ib(d+160|0);break P}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}h=P()|0;O()|0;break R}h=P()|0;O()|0;yb(d+88|0)}Ib(d+160|0);break B}u[f>>1]=0}k=k+1|0;if((k|0)!=8){continue}break}break O}h=P()|0;O()|0;break B}e=w[d+240|0]|w[d+241|0]<<8;f=0;v[114578]=0;n=Q(397,d+160|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break I}if(w[d+240|0]|w[d+241|0]<<8){while(1){v[114578]=0;g=T(359,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break K}v[114578]=0;U(343,d+88|0,b|0,g<<5);e=v[114578];v[114578]=0;if((e|0)==1){break L}Wd(tc(n,f),d+88|0);Bb(d+88|0);f=f+1|0;if(f>>>0<(w[d+240|0]|w[d+241|0]<<8)>>>0){continue}break}}e=w[q|0]|w[q+1|0]<<8;m=0;v[114578]=0;s=W(902,d+88|0,e|0,16428)|0;e=v[114578];v[114578]=0;if((e|0)==1){break M}if(w[p|0]|w[p+1|0]<<8){while(1){i=d+m|0;W:{if(w[i+258|0]>=(w[d+240|0]|w[d+241|0]<<8)>>>0){break W}if(x[rc(Vb(D),m)>>1]>=(w[q|0]|w[q+1|0]<<8)>>>0){break W}e=x[rc(Vb(D),m)>>1];X:{if(x[rc(s,e)>>1]==65535){f=w[i+258|0];J=rc(s,e),K=f,u[J>>1]=K;break X}if(x[rc(s,e)>>1]==w[i+258|0]){break X}v[114578]=0;f=W(903,l|0,e|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break N}if((f|0)==65535){break X}J=rc(Vb(D),m),K=f,u[J>>1]=K;e=f}v[114578]=0;g=Q(444,l|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break N}if(!g){break W}j=tc(n,w[i+258|0]);Jc(j);v[114578]=0;g=T(255,j|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break N}if(!v[_b(l,e)+12>>2]){break W}i=g>>>5|0;o=0;while(1){g=_b(l,e);f=x[a+480188>>1];v[114578]=0;f=W(472,g|0,o|0,f-8&65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break N}k=0;while(1){Qh(d+24|0);g=x[d+28>>1];t[f+4|0]=g;t[f+5|0]=g>>>8;g=v[d+24>>2];t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;Y:{if(i>>>0<=o>>>0){break Y}v[114578]=0;Q(904,j|0,d+24|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break N}if(t[d+24|0]>-1){break Y}t[f|0]=61;t[f+1|0]=w[(d+224|0)+(k<<1)|0];g=w[d+24|0]&31;t[d+72|0]=g;if(g){Ue(d+72|0,15);t[f+3|0]=20;t[f+5|0]=w[d+72|0]|208}t[f+2|0]=1;t[f+4|0]=w[d+25|0]+3>>>2}f=f+6|0;k=k+1|0;if((k|0)!=8){continue}break}o=o+1|0;if(o>>>0<y[_b(l,e)+12>>2]){continue}break}}m=m+1|0;if(m>>>0<(w[p|0]|w[p+1|0]<<8)>>>0){continue}break}}kf(s);hd(n)}Z:{if(!(w[z|0]&2)){break Z}E=w[z|0]&8?x[a+480188>>1]:E;if(!(w[q|0]|w[q+1|0]<<8)){break Z}f=0;i=((E&65535)+((w[C|0]|w[C+1|0]<<8)>>>0>591?F:0)|0)+((w[z|0]|w[z+1|0]<<8|(w[z+2|0]<<16|w[z+3|0]<<24))>>>4&1)|0;while(1){k=0;_:{if(!i){break _}while(1){$:{v[114578]=0;g=Q(258,b|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break $}if(!g){break _}e=w[C|0]|w[C+1|0]<<8;v[114578]=0;R(905,e|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break $}k=k+1|0;if((i|0)!=(k|0)){continue}break _}break}h=P()|0;O()|0;break B}f=f+1|0;if(f>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}}v[114578]=0;z=Q(397,d+192|0,255)|0;e=v[114578];v[114578]=0;aa:{ba:{ca:{da:{ea:{fa:{if((e|0)!=1){F=d+88|7;D=d+88|1;s=d+88|4;p=d+88|2;n=d+88|3;e=0;while(1){f=e;v[114578]=0;Q(906,b|0,d+160|0)|0;e=v[114578];v[114578]=0;ga:{ha:{ia:{ja:{if((e|0)!=1){v[114578]=0;g=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ja}e=w[C|0]|w[C+1|0]<<8;v[114578]=0;g=(g|0)==32?428:g;g=g?e>>>0>513?g+4|0:g:g;U(343,d+240|0,b|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break ia}e=f+1|0;m=Ze(d+24|0,Wd(tc(z,f),d+240|0));Bb(d+240|0);if(f>>>0>=(w[H|0]|w[H+1|0]<<8)>>>0){break ga}v[114578]=0;f=e&65535;l=W(456,a|0,f|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break ha}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}if(!l){break ga}v[114578]=0;U(746,d+88|0,2,d+160|0);f=v[114578];v[114578]=0;ka:{la:{ma:{if((f|0)==1){break ma}v[114578]=0;R(417,d+240|0,d+88|0);f=v[114578];v[114578]=0;if((f|0)==1){break ma}v[114578]=0;Q(371,l+492|0,d+240|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break la}yb(d+240|0);if(!g){break ga}v[114578]=0;Q(907,m|0,d+240|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break da}A=0;if((w[C|0]|w[C+1|0]<<8)>>>0<513){break ka}v[114578]=0;A=T(359,m|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break ka}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break ba}h=P()|0;O()|0;yb(d+240|0);break ba}h=3;na:{if((w[C|0]|w[C+1|0]<<8)>>>0<514){break na}v[114578]=0;h=T(392,m|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break na}h=P()|0;O()|0;break ba}v[l>>2]=w[d+342|0]|w[d+343|0]<<8;t[l+16|0]=w[((w[d+344|0]|w[d+345|0]<<8)&3)+16430|0];t[l+17|0]=w[(w[d+345|0]&3)+16430|0];t[l+18|0]=w[((w[d+344|0]|w[d+345|0]<<8)>>>12&3)+16434|0];E=0;oa:{pa:{qa:{ra:{while(1){sa:{if(!(h&1)){break sa}v[114578]=0;Q(908,m|0,d+88|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ra}v[114578]=0;g=Q(376,l|0,w[E+16438|0])|0;f=v[114578];v[114578]=0;if((f|0)==1){break qa}f=g;if(!(t[d+88|0]&1)|(E|0)!=3){i=w[g+12|0]&-17}else{i=w[g+12|0]|16}t[f+12|0]=i;t[g+12|0]=w[g+12|0]&254|t[d+88|0]&1;t[g+12|0]=w[g+12|0]&251|w[d+88|0]<<1&4;t[g+12|0]=w[g+12|0]&253|w[d+88|0]>>>1&2;f=w[D|0];v[114578]=0;t[d+72|0]=f;t[d+56|0]=16;i=Q(393,d+72|0,d+56|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break pa}f=w[i|0];v[114578]=0;R(591,g|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break pa}f=w[p|0];t[g+15|0]=f;t[g+16|0]=f;t[g+13|0]=w[n|0];t[g+14|0]=w[s|0];f=0;if(!Kb(g)){break sa}while(1){j=(d+88|0)+(f<<2)|0;i=w[j+8|0]|w[j+9|0]<<8;J=Pb(g,f),K=i,u[J>>1]=K;i=Cd(w[j+10|0]|w[j+11|0]<<8,0,64);J=Pb(g,f),K=i,t[J+2|0]=K;f=f+1|0;if(Kb(g)>>>0>f>>>0){continue}break}}h=h>>>1|0;E=E+1|0;if((E|0)!=4){continue}break}if(!(t[l+60|0]&1|w[l+16|0]==3)){v[l>>2]=32767}v[114578]=0;U(909,l|0,127,1);f=v[114578];v[114578]=0;if((f|0)==1){break fa}v[114578]=0;U(910,l|0,0,1);f=v[114578];v[114578]=0;if((f|0)==1){break fa}if(!A){break ga}v[114578]=0;Q(911,m|0,d+88|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}if(!(A&2)){break oa}f=w[p|0]|w[p+1|0]<<8;v[114578]=0;g=ib(912,a|0,+(f>>>0))|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}v[114578]=0;U(909,l|0,g|0,1);f=v[114578];v[114578]=0;if((f|0)==1){break ca}f=w[s|0];v[114578]=0;U(910,l|0,f|0,1);f=v[114578];v[114578]=0;if((f|0)!=1){break oa}break ca}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break ba}h=P()|0;O()|0;break ba}t[l+25|0]=w[D|0]==1;if(!(A&4)){break ga}t[l+31|0]=w[F|0]+1;t[l+34|0]=w[d+96|0]+1;if(t[d+96|0]<=-1){t[l+30|0]=w[d+103|0]+1}if(w[d+100|0]){f=0;j=l+108|0;while(1){g=f+1|0;v[d+72>>2]=g+t[d+100|0];fQ(d+72|0);i=v[d+72>>2];J=fc(j,f),K=i,t[J|0]=K;f=g;if(f>>>0<128){continue}break}}v[114578]=0;R(777,l|0,0);f=v[114578];v[114578]=0;if((f|0)==1){break ca}}Bb(m);if((e|0)!=255){continue}break}s=ez(d+88|0);g=d+24|4;F=ez(d+160|0);k=0;ta:{ua:{while(1){v[114578]=0;Q(906,b|0,d+240|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ta}v[114578]=0;f=T(392,b|0)|0;e=v[114578];v[114578]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{if((e|0)!=1){v[114578]=0;U(343,d+72|0,b|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ca}if((w[r|0]|w[r+1|0]<<8)>>>0>k>>>0){v[114578]=0;U(746,d+56|0,2,d+240|0);e=v[114578];v[114578]=0;if((e|0)==1){break va}v[114578]=0;R(417,d+24|0,d+56|0);e=v[114578];v[114578]=0;if((e|0)==1){break va}v[114578]=0;Q(371,((k<<5)+a|0)+946332|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ba}yb(d+24|0)}if(!f|(w[r|0]|w[r+1|0]<<8)>>>0<=k>>>0){break wa}v[114578]=0;i=B(k+1|0,104)+a|0;f=i+484380|0;R(388,f|0,32);e=v[114578];v[114578]=0;if((e|0)==1){break Aa}v[114578]=0;Q(913,d+72|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break za}v[f>>2]=w[d+24|0]|w[d+25|0]<<8|(w[d+26|0]<<16|w[d+27|0]<<24);v[i+484404>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(w[d+32|0]>=2){e=i+484414|0;u[e>>1]=x[e>>1]|1;v[f>>2]=v[f>>2]>>>1}if(w[d+33|0]>=2){e=i+484414|0;u[e>>1]=x[e>>1]|64;v[f>>2]=v[f>>2]>>>1}A=2;Da:{if(w[d+35|0]!=1){A=6;if(w[d+35|0]!=2){break Da}}e=i+484414|0;u[e>>1]=x[e>>1]|A}v[i+484384>>2]=w[d+36|0]|w[d+37|0]<<8|(w[d+38|0]<<16|w[d+39|0]<<24);v[i+484388>>2]=w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24);u[i+484410>>1]=(w[d+44|0]|w[d+45|0]<<8)>>>7;if(w[d+46|0]!=128){break ya}e=i+484414|0;o=x[e>>1]|256;u[e>>1]=o;break xa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;yb(d+24|0);break ua}h=P()|0;O()|0;break ua}h=P()|0;O()|0;break ua}u[i+484408>>1]=t[d+46|0]+128;o=x[i+484414>>1]}e=i+484414|0;u[e>>1]=o|32;t[i+484416|0]=w[d+47|0];if(w[d+34|0]&2){Eb(d+56|0,F,k);ge(d+56|0,1)}if(w[d+34|0]&5){u[e>>1]=x[e>>1]|16384}if(!(w[d+34|0]&8)){break wa}Eb(d+56|0,s,k);ge(d+56|0,1);f=0;while(1){e=f<<1;Ea:{if(x[e+(d+208|0)>>1]!=(k|0)){break Ea}e=v[((x[e+(d+224|0)>>1]<<2)+a|0)+900380>>2];if(!e){break Ea}t[e+14|0]=0}f=f+1|0;if((f|0)!=8){continue}break}}Bb(d+72|0);k=k+1|0;if((k|0)==256){break ea}continue}break}h=P()|0;O()|0}Bb(d+72|0);break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break B}h=P()|0;O()|0;break ba}Fa:{if(!(w[H|0]|w[H+1|0]<<8)){break Fa}h=0;Ga:{Ha:{while(1){Ia:{e=tc(z,h);v[114578]=0;f=T(255,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ia}Ja:{if(!f){h=h+1|0;break Ja}e=tc(z,h);Jc(e);v[114578]=0;Q(907,e|0,d+240|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ha}f=jb-16|0;jb=f;r=d+24|0;v[r>>2]=0;v[r+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(922,r+8|0,f+12|0,f+8|0)|0;e=v[114578];v[114578]=0;Ka:{if((e|0)!=1){jb=f+16|0;break Ka}V(0)|0;O()|0;Ab();L()}e=w[d+240|0]|w[d+241|0]<<8;v[114578]=0;W(914,b|0,r|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ga}h=h+1|0;p=v[((h<<2)+a|0)+900380>>2];if(!(!p|w[p+34|0])){v[p+4>>2]=32;v[114578]=0;R(777,p|0,0);e=v[114578];v[114578]=0;if((e|0)==1){break Ga}j=p+108|0;i=p+236|0;f=0;while(1){e=d+f|0;La:{if(w[e+242|0]>=(w[d+240|0]|w[d+241|0]<<8)>>>0){break La}n=Uk(r,w[e+242|0]);e=w[n|0];D=e+1|0;g=f+12|0;J=ed(i,g),K=D,u[J>>1]=K;if(e>>>0>=x[a+480190>>1]){break La}e=B(D,104)+a|0;t[e+484418|0]=w[d+338|0]&3;t[e+484419|0]=w[d+339|0];t[e+484420|0]=w[d+340|0];t[e+484421|0]=w[d+341|0];u[e+484412>>1]=w[n+1|0]<<1;t[e+484417|0]=w[n+2|0];e=D-1|0;Eb(d+72|0,s,e);if(Cb(d+72|0)){t[p+14|0]=0}Eb(d+72|0,F,e);if(!Cb(d+72|0)){break La}J=fc(j,g),K=61,t[J|0]=K}f=f+1|0;if((f|0)!=96){continue}break}}eQ(r)}if((w[H|0]|w[H+1|0]<<8)>>>0>h>>>0){continue}break Fa}break}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break aa}h=P()|0;O()|0;eQ(r);break aa}Ma:{Na:{if(!(c&2)|!x[a+480190>>1]){break Na}k=1;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{while(1){j=B(k,104)+a|0;i=j+484416|0;g=t[i|0];f=j+484417|0;c=t[f|0];v[114578]=0;e=j+484380|0;ra(915,e|0,+((+(c|0)*.0078125-+(g-49|0))*.08333333333333333));c=v[114578];v[114578]=0;if((c|0)==1){break Ma}t[f|0]=0;t[i|0]=0;Ya:{c=x[j+484414>>1];Za:{if(!(c&16384)){c=ad(d+240|0,c&1?16:8,c&64?3:1,0,12);v[114578]=0;W(402,c|0,e|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break Za}h=P()|0;O()|0;break aa}v[114578]=0;e=T(392,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Ya}v[114578]=0;Q(340,b|0,12)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Ya}f=Wb(d+240|0);v[114578]=0;W(482,b|0,f|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Xa}v[114578]=0;Q(372,j+484423|0,f|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Xa}v[114578]=0;e=Q(2,d+8|0,16442)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Wa}v[114578]=0;R(219,d+72|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break Va}v[d+4>>2]=k;c=Nz(a);v[114578]=0;U(13,d+56|0,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break Ua}v[114578]=0;X(645,d+24|0,d+72|0,d+4|0,d+56|0);c=v[114578];v[114578]=0;if((c|0)==1){break Ta}v[114578]=0;U(646,a|0,2,d+24|0);c=v[114578];v[114578]=0;if((c|0)==1){break Sa}yb(d+24|0);yb(d+56|0);Ib(d+72|0);yb(e);yb(f)}if(x[a+480190>>1]<=k>>>0){break Na}k=k+1|0;continue}break}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break Oa}h=P()|0;O()|0;break Oa}h=P()|0;O()|0;break Pa}h=P()|0;O()|0;break Qa}h=P()|0;O()|0;break Ra}h=P()|0;O()|0;yb(d+24|0)}yb(d+56|0)}Ib(d+72|0)}yb(e)}yb(f);break aa}hd(z);qq(I);Bb(d+1296|0);Bb(d+1312|0);break b}h=P()|0;O()|0;break aa}h=P()|0;O()|0;break ba}h=P()|0;O()|0}Bb(m)}hd(z);break B}h=P()|0;O()|0;kf(s);break J}h=P()|0;O()|0;break J}h=P()|0;O()|0;break J}h=P()|0;O()|0}hd(n);break B}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}v[114578]=0;m=T(392,d+1296|0)|0;f=v[114578];v[114578]=0;e=a;_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{if((f|0)!=1){v[114578]=0;g=T(392,d+1296|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break mb}v[114578]=0;U(343,d+88|0,d+1296|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break mb}if((m|0)<=844387157){if((m|0)==4674381){break cb}if((m|0)==5068115){break bb}if(A&1|(m|0)!=726487106){break $a}v[a+480224>>2]=2;v[114578]=0;G=+la(916,d+88|0);f=v[114578];v[114578]=0;if((f|0)==1){break _a}if(G==0){break $a}G=2646e7/(G*+(B(v[a+480216>>2],v[a+480196>>2])>>>0));if(!(G<4294967296&G>=0)){break lb}f=~~G>>>0;break kb}if((m|0)<=1314144591){if((m|0)==844387158){break ab}if((m|0)!=1280004692){break $a}o=0;if(!x[a+480188>>1]){break $a}while(1){v[114578]=0;f=Q(258,d+88|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(!f){break $a}g=Wb(d+240|0);v[114578]=0;W(597,d+88|0,g|0,-1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ib}f=Tb(g);e=Fb(g);v[114578]=0;X(416,d+24|0,3,f|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break hb}v[114578]=0;R(417,d+160|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break hb}v[114578]=0;Q(380,((o<<5)+a|0)+480289|0,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break gb}yb(d+160|0);yb(g);o=o+1|0;if(o>>>0<x[a+480188>>1]){continue}break}break $a}if((m|0)==1397445204){break jb}if((m|0)!=1314144592){break $a}f=0;if(!(w[q|0]|w[q+1|0]<<8)){break $a}while(1){v[114578]=0;g=Q(258,d+88|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break eb}if(!g){break $a}v[114578]=0;g=Q(917,l|0,f&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break eb}if(!g){break $a}g=Wb(d+240|0);v[114578]=0;W(597,d+88|0,g|0,-1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break db}e=_b(l,f);v[114578]=0;Q(496,e|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break db}yb(g);f=f+1|0;if(f>>>0<(w[q|0]|w[q+1|0]<<8)>>>0){continue}break}break $a}h=P()|0;O()|0;break B}h=P()|0;O()|0;break B}f=0}v[e+480204>>2]=f;break $a}v[114578]=0;f=T(359,d+88|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}v[a+480232>>2]=f>>>9;v[a+480228>>2]=f>>>8;f=0;if(!x[a+480188>>1]){break $a}while(1){v[114578]=0;g=Q(918,d+88|0,d+240|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break F}if(g){u[((f<<5)+a|0)+480286>>1]=(w[d+240|0]|w[d+241|0]<<8)>>>10;e=w[i|0];J=xc(I,f),K=e,t[J|0]=K}f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}break $a}h=P()|0;O()|0;break fb}h=P()|0;O()|0;break fb}h=P()|0;O()|0;yb(d+160|0)}yb(g);break C}h=P()|0;O()|0;break C}h=P()|0;O()|0;yb(g);break C}v[114578]=0;Q(340,d+88|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}v[114578]=0;f=T(332,d+88|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}v[114578]=0;aa(584,j|0,d+88|0,f|0,2)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break $a}break D}v[114578]=0;Q(919,d+88|0,d+24|0)|0;e=v[114578];v[114578]=0;nb:{if((e|0)!=1){f=Wb(d+240|0);v[114578]=0;W(597,d+88|0,f|0,-1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break nb}if(Ht(f,16405)){v[114578]=0;U(13,d+160|0,7,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break nb}Gb(n,d+160|0);yb(d+160|0)}yb(f);break $a}h=P()|0;O()|0;break C}h=P()|0;O()|0;yb(f);break C}v[114578]=0;F=T(392,d+88|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}}Bb(d+88|0);continue}break}h=P()|0;O()|0;break C}h=P()|0;O()|0;break C}h=P()|0;O()|0;break C}h=P()|0;O()|0}Bb(d+88|0)}qq(I);break e}h=P()|0;O()|0;break e}h=P()|0;O()|0}Bb(d+1296|0)}Bb(d+1312|0)}S(h|0);L()}f=1}jb=d+1728|0;return f|0}function l1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=C(0),A=C(0),D=0,E=0,F=0,G=0,H=0,I=C(0),J=0,K=C(0),M=0,N=C(0),O=0,P=0,Q=0,R=C(0),S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=C(0),aa=0,ba=0,ca=0,da=0,ea=C(0),fa=C(0),ga=C(0),ia=C(0),ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0;da=jb-16|0;jb=da;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<1){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{h=b+e|0;if(w[h|0]!=79|(w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))!=(w[84480]|w[84481]<<8|(w[84482]<<16|w[84483]<<24))){break f}i=b+26|0;if((i|0)>=(a|0)){break e}m=b+27|0;p=e+i|0;c=w[p|0];if((a|0)<=(m+c|0)){break e}j=c+27|0;f=0;if(c){while(1){j=w[e+(f+m|0)|0]+j|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){f=yw(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}c=23;while(1){f=yw(f,0);if((c|0)!=26){c=c+1|0;continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=j-26;v[c+1424>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);if(w[e+(i+w[p|0]|0)|0]==255){f=-1}else{f=w[h+6|0]|w[h+7|0]<<8|(w[h+8|0]<<16|w[h+9|0]<<24)}v[c+1436>>2]=i;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<1){break b}}a=0;while(1){h=d+B(a,20)|0;p=h+1432|0;c=v[p>>2];f=0;m=v[h+1436>>2];i=b-m|0;k=h+1428|0;j=v[k>>2];i=(i|0)<(j|0)?i:j;if((i|0)>=1){while(1){c=yw(c,w[e+(f+m|0)|0]);l=f+1|0;f=l;if((i|0)!=(l|0)){continue}break}}f=j-i|0;v[k>>2]=f;v[p>>2]=c;g:{if(!f){f=c;c=h+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=i+m|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;h=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=h;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!MG(a)){v[f>>2]=0;b=0;break a}ja=jb-16|0;jb=ja;i=da+4|0;k=i;m=a;c=m;v[c+1504>>2]=0;v[c+1508>>2]=0;h:{if(v[c+96>>2]){break h}g=c;i:{j:{k:{if(v[c+1380>>2]!=-1){break k}p=Ae(g);if(v[g+96>>2]){break i}if((p|0)!=79){break j}if((Ae(g)|0)!=103){break j}if((Ae(g)|0)!=103){break j}if((Ae(g)|0)!=83){break j}if(!HG(g)){break i}if(!(t[g+1375|0]&1)){break k}t[g+1376|0]=0;v[g+1384>>2]=0;dc(g,32);break i}h=uw(g);break i}dc(g,30)}if(!h){break h}if(jc(c,1)){dc(c,35);break h}n=ja;l:{m:{if(!(v[c+84>>2]!=v[c+92>>2]?v[c+80>>2]:0)){g=jc(c,ml(v[c+408>>2]-1|0));if((g|0)==-1|(g|0)>=v[c+408>>2]){break h}v[ja+12>>2]=g;l=c+B(g,6)|0;if(!w[l+412|0]){j=v[c+112>>2];g=j>>1;break m}j=v[c+116>>2];g=j>>1;h=jc(c,1);F=jc(c,1);if(!w[l+412|0]|h){break m}v[k>>2]=j-v[c+112>>2]>>2;h=v[c+112>>2]+j>>2;break l}ha(50440,50496,3137,50528);L()}v[k>>2]=0;h=g}v[n+8>>2]=h;n:{if(!(!w[l+412|0]|F)){g=B(j,3);v[da+8>>2]=g-v[c+112>>2]>>2;j=g+v[c+112>>2]>>2;break n}v[da+8>>2]=g}v[ja+4>>2]=j;j=1}c=0;if(j){W=v[i>>2];pa=v[da+8>>2];oa=v[ja+4>>2];ra=i;p=0;P=jb-2368|0;jb=P;J=v[m+404>>2];qa=m+B(v[ja+12>>2],6)|0;r=w[qa+413|0];Q=J+B(r,40)|0;X=Q;Z=v[(m+(w[qa+412|0]<<2)|0)+104>>2];o:{p:{j=v[m+4>>2];q:{if((j|0)>0){while(1){c=w[(v[X+4>>2]+B(p,3)|0)+2|0];Y=(P+1344|0)+(p<<2)|0;v[Y>>2]=0;g=w[(c+Q|0)+9|0];if(!x[(m+(g<<1)|0)+132>>1]){dc(m,21);c=0;break q}h=v[m+260>>2];r:{s:{if(jc(m,1)){c=2;j=v[(m+(p<<2)|0)+996>>2];i=h+B(g,1596)|0;n=v[(w[i+1588|0]<<2)+50668>>2];g=ml(n)-1|0;za=j,Aa=jc(m,g),u[za>>1]=Aa;za=j,Aa=jc(m,g),u[za+2>>1]=Aa;l=0;if(w[i|0]){while(1){M=w[(i+l|0)+1|0];h=M+i|0;k=w[h+33|0];g=0;D=w[h+49|0];t:{if(!D){break t}h=v[m+124>>2]+B(w[h+65|0],2096)|0;if(v[m+1396>>2]<=9){dk(m)}o=v[m+1392>>2];g=u[(h+((o&1023)<<1)|0)+36>>1];u:{if((g|0)>=0){E=o;o=w[g+v[h+8>>2]|0];v[m+1392>>2]=E>>>o;G=v[m+1396>>2]-o|0;o=(G|0)<0;v[m+1396>>2]=o?0:G;g=o?-1:g;break u}g=ll(m,h)}if(!w[h+23|0]){break t}g=v[v[h+2088>>2]+(g<<2)>>2]}if(k){F=-1<<D^-1;h=c+k|0;while(1){o=0;k=u[((i+(M<<4)|0)+((g&F)<<1)|0)+82>>1];v:{if((k|0)<0){break v}k=v[m+124>>2]+B(k&65535,2096)|0;if(v[m+1396>>2]<=9){dk(m)}G=v[m+1392>>2];o=u[(k+((G&1023)<<1)|0)+36>>1];w:{if((o|0)>=0){E=G;G=w[o+v[k+8>>2]|0];v[m+1392>>2]=E>>>G;O=v[m+1396>>2]-G|0;G=(O|0)<0;v[m+1396>>2]=G?0:O;o=G?-1:o;break w}o=ll(m,k)}if(!w[k+23|0]){break v}o=v[v[k+2088>>2]+(o<<2)>>2]}g=g>>D;u[j+(c<<1)>>1]=o;c=c+1|0;if((h|0)!=(c|0)){continue}break}c=h}l=l+1|0;if(l>>>0<w[i|0]){continue}break}}if(v[m+1396>>2]!=-1){break s}}v[Y>>2]=1;break r}u[P+320>>1]=257;h=i+1592|0;c=v[i+1592>>2];if((c|0)>=3){g=2;while(1){c=i+338|0;k=g<<1;D=k+i|0;G=w[D+1088|0];o=G<<1;l=x[c+o>>1];Y=w[D+1089|0];M=Y<<1;F=u[j+o>>1];D=u[M+j>>1]-F|0;o=D>>31;c=(B(x[c+k>>1]-l|0,o^o+D)|0)/(x[c+M>>1]-l|0)|0;o=F+((D|0)<0?0-c|0:c)|0;D=k+j|0;k=x[D>>1];x:{y:{if(k){t[Y+(P+320|0)|0]=1;t[G+(P+320|0)|0]=1;t[(P+320|0)+g|0]=1;c=k<<16>>16;l=n-o|0;if((c|0)>=((l|0)<(o|0)?l:o)<<1){if((l|0)>(o|0)){break x}o=n+(k^-1)|0;break y}if(c&1){o=o-(c+1>>>1|0)|0;break y}o=(c>>1)+o|0;break y}t[(P+320|0)+g|0]=0}u[D>>1]=o}c=v[h>>2];g=g+1|0;if((c|0)>(g|0)){continue}break}}o=0;if((c|0)<=0){break r}while(1){if(!w[(P+320|0)+o|0]){u[j+(o<<1)>>1]=65535;c=v[h>>2]}o=o+1|0;if((o|0)<(c|0)){continue}break}}j=v[m+4>>2];p=p+1|0;if((j|0)>(p|0)){continue}break}}z:{A:{c=v[m+80>>2];if(!(v[m+84>>2]!=v[m+92>>2]?c:0)){lc(P+320|0,P+1344|0,j<<2);h=x[Q>>1];if(h){i=v[X+4>>2];o=0;while(1){p=i+B(o,3)|0;g=w[p+1|0];p=(P+1344|0)+(w[p|0]<<2)|0;if(!(v[(P+1344|0)+(g<<2)>>2]?v[p>>2]:0)){v[(P+1344|0)+(g<<2)>>2]=0;v[p>>2]=0}o=o+1|0;if((h|0)!=(o|0)){continue}break}}Y=Z>>1;ma=J+B(r,40)|0;if(w[ma+8|0]){c=0;while(1){B:{if((j|0)<1){g=0;break B}p=v[X+4>>2];o=0;g=0;while(1){if(w[(p+B(o,3)|0)+2|0]==(c|0)){n=g+P|0;h=o<<2;C:{if(v[h+(P+1344|0)>>2]){i=0;h=1;break C}i=v[(h+m|0)+800>>2];h=0}t[n|0]=h;v[(P+256|0)+(g<<2)>>2]=i;g=g+1|0}o=o+1|0;if((o|0)!=(j|0)){continue}break}}_=P+256|0;D=P;T=jb-16|0;jb=T;i=m;F=v[i+4>>2];l=v[i+396>>2];k=w[(c+ma|0)+24|0];O=l+B(k,24)|0;p=v[O+4>>2];j=Y;na=x[(i+(k<<1)|0)+268>>1];h=j<<((na|0)==2);n=h>>>0>p>>>0?p:h;p=v[O>>2];S=(n-(h>>>0>p>>>0?p:h)>>>0)/y[O+8>>2]|0;n=S<<2;h=B(F,n+4|0);E=v[v[i+124>>2]+B(w[O+13|0],2096)>>2];wa=v[i+92>>2];D:{if(v[i+80>>2]){h=Im(i,h);F=v[i+4>>2];break D}h=pd(h)}p=0;if((F|0)>=1){r=(F<<2)+h|0;while(1){v[(p<<2)+h>>2]=r;r=n+r|0;p=p+1|0;if((p|0)!=(F|0)){continue}break}}p=h;E:{F:{G:{H:{I:{if((g|0)>=1){n=j<<2;h=0;while(1){if(!w[h+D|0]){Rb(v[_+(h<<2)>>2],0,n)}h=h+1|0;if((h|0)!=(g|0)){continue}break}if((g|0)==1){break F}if((na|0)==2){break I}break F}if((na|0)!=2){break F}break H}h=0;if((g|0)<=0){break H}while(1){n=(g|0)==(h|0);if(!w[h+D|0]){break G}h=h+1|0;if((h|0)!=(g|0)){continue}break}break E}n=!g}if(n){break E}D=l+B(k,24)|0;o=D;J=(g|0)!=2;G=(S|0)<1;M=(g|0)<3;n=0;while(1){J:{if(!J){l=0;F=0;if(G){break J}while(1){h=v[O>>2]+B(v[O+8>>2],l)|0;v[T+12>>2]=h&1;v[T+8>>2]=h>>1;if(!n){k=v[i+124>>2]+B(w[O+13|0],2096)|0;if(v[i+1396>>2]<=9){dk(i)}r=v[i+1392>>2];h=u[(k+((r&1023)<<1)|0)+36>>1];K:{if((h|0)>=0){ka=r;r=w[h+v[k+8>>2]|0];v[i+1392>>2]=ka>>>r;H=v[i+1396>>2]-r|0;r=(H|0)<0;v[i+1396>>2]=r?0:H;h=r?-1:h;break K}h=ll(i,k)}h=w[k+23|0]?v[v[k+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break E}v[v[p>>2]+(F<<2)>>2]=v[v[D+16>>2]+(h<<2)>>2]}L:{if((l|0)>=(S|0)){break L}h=0;if((E|0)<1){break L}while(1){k=v[O+8>>2];r=u[(v[o+20>>2]+(w[v[v[p>>2]+(F<<2)>>2]+h|0]<<4)|0)+(n<<1)>>1];M:{if((r|0)>=0){if(GG(i,v[i+124>>2]+B(r&65535,2096)|0,_,2,T+12|0,T+8|0,j,k)){break M}break E}k=v[O>>2]+(k+B(k,l)|0)|0;v[T+8>>2]=k>>1;v[T+12>>2]=k&1}l=l+1|0;if((S|0)<=(l|0)){break L}h=h+1|0;if((E|0)>(h|0)){continue}break}}F=F+1|0;if((l|0)<(S|0)){continue}break}break J}if(M){break J}l=0;F=0;if(G){break J}while(1){k=v[O>>2]+B(v[O+8>>2],l)|0;h=(k|0)/(g|0)|0;v[T+12>>2]=k-B(g,h);v[T+8>>2]=h;if(!n){k=v[i+124>>2]+B(w[O+13|0],2096)|0;if(v[i+1396>>2]<=9){dk(i)}r=v[i+1392>>2];h=u[(k+((r&1023)<<1)|0)+36>>1];N:{if((h|0)>=0){ka=r;r=w[h+v[k+8>>2]|0];v[i+1392>>2]=ka>>>r;H=v[i+1396>>2]-r|0;r=(H|0)<0;v[i+1396>>2]=r?0:H;h=r?-1:h;break N}h=ll(i,k)}h=w[k+23|0]?v[v[k+2088>>2]+(h<<2)>>2]:h;if((h|0)==-1){break E}v[v[p>>2]+(F<<2)>>2]=v[v[D+16>>2]+(h<<2)>>2]}O:{if((l|0)>=(S|0)){break O}h=0;if((E|0)<1){break O}while(1){k=v[O+8>>2];r=u[(v[o+20>>2]+(w[v[v[p>>2]+(F<<2)>>2]+h|0]<<4)|0)+(n<<1)>>1];P:{if((r|0)>=0){if(GG(i,v[i+124>>2]+B(r&65535,2096)|0,_,g,T+12|0,T+8|0,j,k)){break P}break E}k=v[O>>2]+(k+B(k,l)|0)|0;r=(k|0)/(g|0)|0;v[T+8>>2]=r;v[T+12>>2]=k-B(g,r)}l=l+1|0;if((S|0)<=(l|0)){break O}h=h+1|0;if((E|0)>(h|0)){continue}break}}F=F+1|0;if((l|0)<(S|0)){continue}break}}n=n+1|0;if((n|0)!=8){continue}break}break E}sa=l+B(k,24)|0;ka=sa;xa=(S|0)<1;aa=0;while(1){if(!xa){l=0;ta=(g|0)<1;ya=ta|(aa|0)!=0;F=0;while(1){h=0;if(!ya){while(1){if(!w[h+D|0]){j=v[i+124>>2]+B(w[O+13|0],2096)|0;if(v[i+1396>>2]<=9){dk(i)}n=v[i+1392>>2];k=u[(j+((n&1023)<<1)|0)+36>>1];Q:{if((k|0)>=0){o=n;n=w[k+v[j+8>>2]|0];v[i+1392>>2]=o>>>n;o=v[i+1396>>2]-n|0;n=(o|0)<0;v[i+1396>>2]=n?0:o;n=n?-1:k;break Q}n=ll(i,j)}n=w[j+23|0]?v[v[j+2088>>2]+(n<<2)>>2]:n;if((n|0)==-1){break E}v[v[p+(h<<2)>>2]+(l<<2)>>2]=v[v[sa+16>>2]+(n<<2)>>2]}h=h+1|0;if((h|0)!=(g|0)){continue}break}}R:{if((F|0)>=(S|0)){break R}n=0;if((E|0)<1){break R}while(1){h=0;if(!ta){while(1){S:{if(w[h+D|0]){break S}k=h<<2;j=u[(v[ka+20>>2]+(w[v[v[k+p>>2]+(l<<2)>>2]+n|0]<<4)|0)+(aa<<1)>>1];if((j|0)<0){break S}r=i;j=v[i+124>>2]+B(j&65535,2096)|0;ba=v[k+_>>2];V=v[O+8>>2];o=v[O>>2]+B(V,F)|0;T:{U:{V:{if(na){H=0;J=1;if((V|0)<=0){break T}while(1){la=ba+(o<<2)|0;M=V-H|0;k=0;q=C(0);ca=EG(r,j);W:{if((ca|0)<0){break W}G=j;k=v[j>>2];U=(k|0)<(M|0)?k:M;ca=B(k,ca);X:{Y:{if(w[j+22|0]){M=0;if((U|0)>0){break Y}break X}M=0;if((U|0)<=0){break X}while(1){k=la+(M<<2)|0;z[k>>2]=z[k>>2]+z[v[G+28>>2]+(M+ca<<2)>>2];k=1;M=M+1|0;if((U|0)!=(M|0)){continue}break}break W}while(1){k=la+(M<<2)|0;q=C(z[v[G+28>>2]+(M+ca<<2)>>2]+q);z[k>>2]=z[k>>2]+q;q=C(z[G+12>>2]+q);k=1;M=M+1|0;if((U|0)!=(M|0)){continue}break}break W}k=1}if(!k){break V}k=v[j>>2];o=k+o|0;H=k+H|0;if((V|0)>(H|0)){continue}break}break T}H=0;G=(V|0)/v[j>>2]|0;if((G|0)<=0){break U}la=ba+(o<<2)|0;while(1){ca=la+(H<<2)|0;U=V-(o+H|0)|0;M=G;k=0;q=C(0);ua=EG(r,j);Z:{if((ua|0)<0){break Z}k=1;J=j;ba=v[j>>2];va=(U|0)>(ba|0)?ba:U;if((va|0)<1){break Z}ba=B(ba,ua);U=0;while(1){k=ca+(B(M,U)<<2)|0;A=C(z[v[J+28>>2]+(U+ba<<2)>>2]+q);z[k>>2]=z[k>>2]+A;q=w[J+22|0]?A:q;k=1;U=U+1|0;if((va|0)!=(U|0)){continue}break}}if(!k){break V}H=H+1|0;if((G|0)!=(H|0)){continue}break}break U}J=0;break T}J=1}if(!J){break E}}h=h+1|0;if((h|0)!=(g|0)){continue}break}}F=F+1|0;if((S|0)<=(F|0)){break R}n=n+1|0;if((E|0)>(n|0)){continue}break}}l=l+1|0;if((F|0)<(S|0)){continue}break}}aa=aa+1|0;if((aa|0)!=8){continue}break}}if(!v[i+80>>2]){Xb(p)}v[i+92>>2]=wa;jb=T+16|0;c=c+1|0;if(c>>>0<w[ma+8|0]){j=v[m+4>>2];continue}break}c=v[m+80>>2]}if(!(v[m+84>>2]!=v[m+92>>2]?c:0)){j=x[Q>>1];if(j){h=(Y|0)>1?Y:1;g=m+800|0;while(1){c=j;j=c-1|0;if((Z|0)>=2){i=v[X+4>>2]+B(j,3)|0;p=v[g+(w[i+1|0]<<2)>>2];i=v[g+(w[i|0]<<2)>>2];o=0;while(1){k=o<<2;l=k+p|0;s=z[l>>2];k=i+k|0;q=z[k>>2];_:{if(!(q<=C(0))){if(!(s<=C(0))){A=C(q-s);break _}A=q;q=C(s+q);break _}if(!(s<=C(0))){A=C(s+q);break _}A=q;q=C(q-s)}z[k>>2]=q;z[l>>2]=A;o=o+1|0;if((h|0)!=(o|0)){continue}break}}if((c|0)>1){continue}break}}o=0;if(v[m+4>>2]<=0){break z}T=Y<<2;while(1){g=o<<2;h=g+m|0;c=h;$:{if(v[g+(P+320|0)>>2]){Rb(v[c+800>>2],0,T);break $}g=Z;i=v[c+800>>2];M=v[h+996>>2];p=1;c=m;h=w[(Q+w[(v[Q+4>>2]+B(o,3)|0)+2|0]|0)+9|0];aa:{if(!x[(c+(h<<1)|0)+132>>1]){dc(c,21);break aa}G=g>>1;D=v[c+260>>2]+B(h,1596)|0;c=B(w[D+1588|0],u[M>>1]);g=0;n=v[D+1592>>2];if((n|0)>=2){S=D+1592|0;H=D+1588|0;while(1){h=w[(p+D|0)+838|0]<<1;j=u[h+M>>1];if((j|0)>=0){j=B(w[H|0],j&65535);h=x[(h+D|0)+338>>1];if((h|0)!=(g|0)){k=i;l=g;n=j-c|0;r=h-g|0;J=(n|0)/(r|0)|0;ba:{O=(h|0)>(G|0)?G:h;if((O|0)<=(g|0)){break ba}g=k+(l<<2)|0;z[g>>2]=z[g>>2]*z[((c&255)<<2)+50880>>2];g=l+1|0;if((O|0)<=(g|0)){break ba}l=(n|0)>-1?1:-1;E=n;n=n>>31;E=E+n^n;n=J>>31;n=E-B(r,n+J^n)|0;F=n;while(1){E=k+(g<<2)|0;ka=E;A=z[E>>2];E=(r|0)>(F|0);c=(c+J|0)+(E?0:l)|0;z[ka>>2]=A*z[((c&255)<<2)+50880>>2];g=g+1|0;if((O|0)==(g|0)){break ba}F=n+(F-(E?0:r)|0)|0;continue}}n=v[S>>2];g=h}c=j}p=p+1|0;if((n|0)>(p|0)){continue}break}}if((g|0)<(G|0)){q=z[(c<<2)+50880>>2];while(1){c=i+(g<<2)|0;z[c>>2]=z[c>>2]*q;g=g+1|0;if((G|0)!=(g|0)){continue}break}}}}o=o+1|0;c=v[m+4>>2];if((o|0)<(c|0)){continue}break}break A}ha(50440,50496,3319,50688);L()}ha(50440,50496,3286,50688);L()}o=0;if((c|0)<=0){break z}while(1){aa=w[qa+412|0];D=Z;V=D>>1;g=V<<2;G=m;na=v[m+92>>2];p=v[(m+(o<<2)|0)+800>>2];c=V<<2;X=p+c|0;ca:{if(v[m+80>>2]){k=Im(G,g);break ca}k=pd(g)}i=(k+c|0)-8|0;j=v[(G+(aa<<2)|0)+1068>>2];da:{if(!V){g=j;break da}c=p;g=j;while(1){z[i+4>>2]=C(z[g>>2]*z[c>>2])-C(z[g+4>>2]*z[c+8>>2]);z[i>>2]=C(z[g>>2]*z[c+8>>2])+C(z[g+4>>2]*z[c>>2]);g=g+8|0;i=i-8|0;c=c+16|0;if((X|0)!=(c|0)){continue}break}}if(i>>>0>=k>>>0){c=((V<<2)+p|0)-12|0;while(1){z[i+4>>2]=C(z[g+4>>2]*z[c>>2])-C(z[g>>2]*z[c+8>>2]);z[i>>2]=C(z[g>>2]*C(-z[c>>2]))-C(z[g+4>>2]*z[c+8>>2]);c=c-16|0;g=g+8|0;i=i-8|0;if(k>>>0<=i>>>0){continue}break}}U=D>>2;if((D|0)>=16){c=U<<2;i=c+k|0;h=c+p|0;g=(j+(V<<2)|0)-32|0;l=p;c=k;while(1){q=z[c>>2];A=z[i>>2];s=z[c+4>>2];I=z[i+4>>2];z[h+4>>2]=s+I;z[h>>2]=z[c>>2]+z[i>>2];s=C(I-s);q=C(A-q);z[l+4>>2]=C(z[g+16>>2]*s)-C(z[g+20>>2]*q);z[l>>2]=C(z[g+20>>2]*s)+C(z[g+16>>2]*q);q=z[c+8>>2];A=z[i+8>>2];s=z[c+12>>2];I=z[i+12>>2];z[h+12>>2]=s+I;z[h+8>>2]=z[c+8>>2]+z[i+8>>2];s=C(I-s);q=C(A-q);z[l+12>>2]=C(z[g>>2]*s)-C(z[g+4>>2]*q);z[l+8>>2]=C(z[g+4>>2]*s)+C(z[g>>2]*q);c=c+16|0;i=i+16|0;l=l+16|0;h=h+16|0;g=g-32|0;if(j>>>0<=g>>>0){continue}break}}n=ml(D);g=D>>4;h=V-1|0;c=D>>3;i=0-c|0;FG(g,p,h,i,j);FG(g,p,h-U|0,i,j);_=D>>5;g=0-g|0;zo(_,p,h,g,j,16);zo(_,p,h-c|0,g,j,16);zo(_,p,h-(c<<1)|0,g,j,16);zo(_,p,h+B(c,-3)|0,g,j,16);l=2;if((n|0)>=10){c=n-4>>1;l=(c|0)>3?c:3;i=2;while(1){c=i;i=c+1|0;r=2<<c;if((r|0)>=1){J=8<<c;M=D>>c+4;g=0;c=D>>c+2;F=0-(c>>1)|0;while(1){zo(M,p,h-B(c,g)|0,F,j,J);g=g+1|0;if((r|0)!=(g|0)){continue}break}}if((i|0)!=(l|0)){continue}break}}ma=n-7|0;if((ma|0)>(l|0)){while(1){c=l;l=c+1|0;g=D>>c+6;if((g|0)>=1){M=2<<c;F=8<<c;ba=F<<2;O=D>>c+2;T=0-(O>>1)|0;i=j;c=h;while(1){S=p;H=c;E=T;r=i;J=F;Q=O;n=M;if((n|0)>=1){la=r+B(J,12)|0;q=z[la>>2];ca=J<<3;A=z[ca+r>>2];J=r+(J<<2)|0;s=z[J>>2];I=z[la+4>>2];K=z[r+(ca|4)>>2];ea=z[J+4>>2];fa=z[r+4>>2];ga=z[r>>2];r=S+(H<<2)|0;J=r+(E<<2)|0;S=0-Q<<2;while(1){H=J-4|0;R=z[H>>2];ia=z[J>>2];$=z[r>>2];z[r>>2]=ia+$;E=r-4|0;N=z[E>>2];z[E>>2]=z[H>>2]+N;N=C(N-R);R=C($-ia);z[H>>2]=C(N*ga)+C(R*fa);z[J>>2]=C(R*ga)-C(N*fa);H=J-12|0;ia=z[H>>2];E=r-8|0;N=z[E>>2];Q=E;E=J-8|0;$=z[E>>2];z[Q>>2]=$+N;Q=r-12|0;R=z[Q>>2];z[Q>>2]=z[H>>2]+R;R=C(R-ia);N=C(N-$);z[H>>2]=C(R*s)+C(N*ea);z[E>>2]=C(N*s)-C(R*ea);H=J-20|0;ia=z[H>>2];E=r-16|0;N=z[E>>2];Q=E;E=J-16|0;$=z[E>>2];z[Q>>2]=$+N;Q=r-20|0;R=z[Q>>2];z[Q>>2]=z[H>>2]+R;R=C(R-ia);N=C(N-$);z[H>>2]=C(R*A)+C(N*K);z[E>>2]=C(N*A)-C(R*K);H=J-28|0;ia=z[H>>2];E=r-24|0;N=z[E>>2];Q=E;E=J-24|0;$=z[E>>2];z[Q>>2]=$+N;Q=r-28|0;R=z[Q>>2];z[Q>>2]=z[H>>2]+R;R=C(R-ia);N=C(N-$);z[H>>2]=C(R*q)+C(N*I);z[E>>2]=C(N*q)-C(R*I);J=J+S|0;r=r+S|0;H=(n|0)>1;n=n-1|0;if(H){continue}break}}c=c-8|0;i=(ba<<2)+i|0;n=(g|0)>1;g=g-1|0;if(n){continue}break}}if((l|0)!=(ma|0)){continue}break}}c=p;g=D;if((0-(_<<4)|0)<=-1){c=c+(h<<2)|0;h=c-(_<<6)|0;q=z[j+(g>>3<<2)>>2];while(1){g=c-32|0;s=z[g>>2];I=z[c>>2];z[c>>2]=s+I;i=c-4|0;A=z[i>>2];j=i;i=c-36|0;K=z[i>>2];z[j>>2]=K+A;z[g>>2]=I-s;z[i>>2]=A-K;i=c-8|0;A=z[i>>2];j=i;i=c-40|0;I=z[i>>2];z[j>>2]=I+A;j=c-12|0;s=z[j>>2];n=j;j=c-44|0;K=z[j>>2];z[n>>2]=K+s;s=C(s-K);A=C(A-I);z[i>>2]=C(s+A)*q;z[j>>2]=C(s-A)*q;i=c-20|0;A=z[i>>2];j=c-52|0;s=z[j>>2];l=c-16|0;I=z[l>>2];n=l;l=c-48|0;K=z[l>>2];z[n>>2]=I+K;z[i>>2]=s+A;z[l>>2]=A-s;z[j>>2]=K-I;i=c-60|0;A=z[i>>2];j=c-28|0;s=z[j>>2];l=c-24|0;I=z[l>>2];n=l;l=c-56|0;K=z[l>>2];z[n>>2]=I+K;z[j>>2]=A+s;A=C(s-A);s=C(K-I);z[l>>2]=C(A+s)*q;z[i>>2]=C(s-A)*q;DG(c);DG(g);c=c+-64|0;if(h>>>0<c>>>0){continue}break}}l=V-4|0;g=(k+(U<<2)|0)-16|0;if(k>>>0<=g>>>0){i=k+(l<<2)|0;c=v[(G+(aa<<2)|0)+1100>>2];while(1){h=(x[c>>1]<<2)+p|0;z[i+12>>2]=z[h>>2];z[i+8>>2]=z[h+4>>2];z[g+12>>2]=z[h+8>>2];z[g+8>>2]=z[h+12>>2];h=(x[c+2>>1]<<2)+p|0;z[i+4>>2]=z[h>>2];z[i>>2]=z[h+4>>2];z[g+4>>2]=z[h+8>>2];z[g>>2]=z[h+12>>2];c=c+4|0;i=i-16|0;g=g-16|0;if(k>>>0<=g>>>0){continue}break}}i=k+(V<<2)|0;j=i-16|0;if(k>>>0<j>>>0){c=v[(G+(aa<<2)|0)+1084>>2];h=i;g=k;while(1){q=z[c+4>>2];n=h-4|0;A=z[n>>2];s=z[g+4>>2];I=C(A+s);K=z[c>>2];ea=z[g>>2];r=h-8|0;fa=z[r>>2];ga=C(ea-fa);N=C(C(q*I)-C(K*ga));A=C(s-A);z[g+4>>2]=N+A;q=C(C(K*I)+C(q*ga));s=C(fa+ea);z[g>>2]=q+s;z[n>>2]=N-A;z[r>>2]=s-q;q=z[c+12>>2];h=h-12|0;A=z[h>>2];s=z[g+12>>2];I=C(A+s);K=z[c+8>>2];ea=z[g+8>>2];fa=z[j>>2];ga=C(ea-fa);N=C(C(q*I)-C(K*ga));A=C(s-A);z[g+12>>2]=N+A;q=C(C(K*I)+C(q*ga));s=C(fa+ea);z[g+8>>2]=q+s;z[j>>2]=s-q;z[h>>2]=N-A;c=c+16|0;g=g+16|0;h=j;j=h-16|0;if(g>>>0<j>>>0){continue}break}}j=i-32|0;if(k>>>0<=j>>>0){g=v[(G+(aa<<2)|0)+1076>>2]+(V<<2)|0;c=(l<<2)+p|0;h=((D<<2)+p|0)-16|0;while(1){q=z[g-4>>2];A=z[i-8>>2];s=z[g-8>>2];I=z[i-4>>2];K=C(C(q*A)-C(s*I));z[p>>2]=K;z[c+12>>2]=-K;q=C(C(s*C(-A))-C(I*q));z[X>>2]=q;z[h+12>>2]=q;q=z[g-12>>2];A=z[i-16>>2];s=z[g-16>>2];I=z[i-12>>2];K=C(C(q*A)-C(s*I));z[p+4>>2]=K;z[c+8>>2]=-K;q=C(C(s*C(-A))-C(I*q));z[X+4>>2]=q;z[h+8>>2]=q;q=z[g-20>>2];A=z[i-24>>2];s=z[g-24>>2];I=z[i-20>>2];K=C(C(q*A)-C(s*I));z[p+8>>2]=K;z[c+4>>2]=-K;q=C(C(s*C(-A))-C(I*q));z[X+8>>2]=q;z[h+4>>2]=q;q=z[g-28>>2];A=z[j>>2];g=g-32|0;s=z[g>>2];I=z[i-28>>2];K=C(C(q*A)-C(s*I));z[p+12>>2]=K;z[c>>2]=-K;q=C(C(s*C(-A))-C(I*q));z[X+12>>2]=q;z[h>>2]=q;h=h-16|0;c=c-16|0;X=X+16|0;p=p+16|0;i=j;j=i-32|0;if(k>>>0<=j>>>0){continue}break}}if(!v[G+80>>2]){Xb(k)}v[G+92>>2]=na;o=o+1|0;if((o|0)<v[m+4>>2]){continue}break}}JG(m);ea:{if(w[m+1377|0]){v[m+1060>>2]=0-Y;t[m+1377|0]=0;v[m+1064>>2]=1;v[m+1412>>2]=Z-oa;break ea}c=v[m+1412>>2];if(!c){break ea}g=pa-W|0;if((g|0)<=(c|0)){v[m+1412>>2]=c-g;v[ra>>2]=pa;W=pa;break ea}W=c+W|0;v[ra>>2]=W;v[m+1412>>2]=0}c=v[m+1064>>2];fa:{ga:{ha:{if(v[m+1388>>2]==v[m+1404>>2]){ia:{if(!c|!(w[m+1375|0]&4)){break ia}c=v[m+1408>>2];g=v[m+1060>>2];if(c>>>0>=g+(oa-W|0)>>>0){break ia}g=c-g|0;c=(c>>>0<g>>>0?0:g)+W|0;c=(c|0)>(oa|0)?oa:c;v[da+12>>2]=c;v[m+1060>>2]=c+v[m+1060>>2];break fa}v[m+1064>>2]=1;v[m+1060>>2]=v[m+1408>>2]+(W-Y|0);break ha}if(!c){break ga}}v[m+1060>>2]=v[m+1060>>2]+(pa-W|0)}if(v[m+84>>2]!=v[m+92>>2]?v[m+80>>2]:0){break p}v[da+12>>2]=oa}c=1}jb=P+2368|0;break o}ha(50440,50496,3435,50688);L()}}jb=ja+16|0;if(!c){ja:{ka:{la:{c=v[a+100>>2];switch(c-32|0){case 0:break ka;case 3:break la;default:break ja}}v[a+100>>2]=0;while(1){if(za=0,Aa=(Lg(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ja}v[a+100>>2]=0;while(1){if(za=0,Aa=(Lg(a)|0)!=-1,Ba=v[a+96>>2],Ba?za:Aa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}p=da;k=v[p+12>>2];D=v[p+4>>2];n=D;g=v[p+8>>2];j=0;ma:{na:{c=a;l=v[c+992>>2];oa:{if(!l){i=v[c+4>>2];m=0;break oa}i=l<<1;h=c+1092|0;pa:{qa:{if((i|0)==v[c+112>>2]){break qa}h=0;if((i|0)!=v[m+116>>2]){break pa}h=m+1096|0}h=v[h>>2]}if(!h){break na}i=v[c+4>>2];if((i|0)>=1){m=(l|0)<1;while(1){if(!m){Z=c+(j<<2)|0;o=Z;i=0;while(1){P=v[Z+800>>2]+(i+n<<2)|0;W=i<<2;z[P>>2]=C(z[h+(l+(i^-1)<<2)>>2]*z[W+v[o+928>>2]>>2])+C(z[h+W>>2]*z[P>>2]);i=i+1|0;if((l|0)!=(i|0)){continue}break}i=v[c+4>>2]}j=j+1|0;if((j|0)<(i|0)){continue}break}}m=v[c+992>>2]}l=k-g|0;v[c+992>>2]=l;if((i|0)>=1){j=0;while(1){if((g|0)<(k|0)){Z=c+(j<<2)|0;o=Z;i=0;h=g;while(1){z[v[o+928>>2]+(i<<2)>>2]=z[v[Z+800>>2]+(h<<2)>>2];i=i+1|0;h=g+i|0;if((i|0)!=(l|0)){continue}break}i=v[c+4>>2]}j=j+1|0;if((j|0)<(i|0)){continue}break}}if(!m){break na}i=c;j=v[c+1416>>2];c=((g|0)>(k|0)?k:g)-n|0;v[i+1416>>2]=j+c;break ma}c=0}g=c;v[p+12>>2]=c;h=v[a+4>>2];if((h|0)>=1){c=0;while(1){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(D<<2);c=c+1|0;if((h|0)!=(c|0)){continue}break}}if(d){v[d>>2]=h}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}jb=da+16|0;return b|0}function tg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,D=0;d=jb-2928|0;jb=d;a:{b:{if(wq(c)){Cc(b,268435456);o=v[c+8>>2];i=d+2904|0;e=i;v[e>>2]=0;v[e+4>>2]=0;Oi(e+8|0);v[d+2900>>2]=0;e=d;c:{d:{e:{f:{g:{h:{i:{if(w[a+3|0]-4>>>0<=4){v[114578]=0;g=T(332,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}v[d+2900>>2]=g;break i}g=w[a+3|0];if(g>>>0>18){break i}g=1<<g;j:{if(!(g&126991)){if(g&396800){break j}break i}if(!w[a|0]){break i}}f=v[b>>2];v[114578]=0;f=Q(643,a|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}v[114578]=0;U(855,d+736|0,c|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break g}f=d+736|0;g=v[f+4>>2];v[i>>2]=v[f>>2];v[i+4>>2]=g;g=i+8|0;PM(g);f=f+8|0;El(g,f);v[g>>2]=v[f>>2];v[g+4>>2]=v[f+4>>2];h=v[zb(f)>>2];s=zb(g),D=h,v[s>>2]=D;s=zb(f),D=0,v[s>>2]=D;v[f>>2]=0;v[f+4>>2]=0;Ec(d+736|0);v[114578]=0;f=T(414,i|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}v[d+2900>>2]=v[i>>2]}k:{g=w[a+3|0];if(g>>>0>18){break k}g=1<<g;l:{if(!(g&126991)){if(!(g&396800)){break k}g=1;break l}g=w[a|0]!=0}if(!g|y[b>>2]<262145){break k}g=v[d+2900>>2];h=w[a+3|0];v[114578]=0;v[d+720>>2]=((h|0)==11)<<4;h=Q(33,d+720|0,d+2900|0)|0;k=v[114578];v[114578]=0;if((k|0)!=1){v[d+736>>2]=g-v[h>>2];g=w[a+3|0];if(g>>>0>16){break f}m:{if(!(1<<g&126991)){if((g|0)==11){break m}break f}if(!(w[a|0]&7)){break f}}g=v[d+736>>2];if(g>>>0<=2147483647){g=g<<1;break e}g=-1;break e}a=P()|0;O()|0;break a}n:{if(!(w[a+3|0]==4|w[a+3|0]==5|w[a+3|0]==8)){if(w[a+3|0]!=7){break n}}v[114578]=0;v[d+736>>2]=v[d+2900>>2];g=T(1260,a|0)|0;h=v[114578];v[114578]=0;e=d;o:{p:{if((h|0)!=1){h=v[d+736>>2];g=8/(g>>>0)|0;if(h>>>0>4294967295/(g>>>0)>>>0){break p}g=B(g,h);break o}a=P()|0;O()|0;break a}g=-1}v[e+736>>2]=g;Cc(b,g);break d}if(w[a+3|0]!=6){break d}e=0;if(y[d+2900>>2]<10){break c}v[114578]=0;Q(340,c|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}v[114578]=0;g=T(392,c|0)|0;h=v[114578];v[114578]=0;e=d;q:{r:{s:{if((h|0)!=1){v[d+720>>2]=g;g=v[d+2900>>2];v[114578]=0;v[d+2896>>2]=g;g=Q(333,d+720|0,d+2896|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break s}v[d+736>>2]=v[g>>2];fg(c,8);g=v[d+736>>2];if(g>>>0>50529027){break r}g=B(g,85);break q}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=-1}v[e+736>>2]=g;Cc(b,(g>>>0)/(w[a|0]>>>3>>>0)|0);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}v[114578]=0;h=T(1260,a|0)|0;g=v[114578];v[114578]=0;t:{u:{if((g|0)!=1){v:{w:{switch(w[a+3|0]){default:g=0;break v;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:g=w[a|0];break v;case 9:g=16;break v;case 11:g=4;break v;case 10:case 17:case 18:break w}}g=8}h=B(g,h)>>>3|0;g=h-1|0;k=v[d+736>>2];if(g>>>0>-1-k>>>0){break u}g=g+k|0;break t}a=P()|0;O()|0;break a}g=-1}g=(g>>>0)/(h>>>0)|0}v[e+736>>2]=g;Cc(b,g)}if(!v[b>>2]){e=0;break c}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[114578]=0;e=T(466,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!e){e=0;v[b>>2]=0;break c}e=ad(d+736|0,8,1,0,11);v[114578]=0;e=Q(1261,a|0,e|0)|0;g=v[114578];v[114578]=0;x:{y:{z:{A:{B:{C:{D:{if((g|0)!=1){if(!e){break z}e=0;v[114578]=0;a=Q(1262,c|0,d+736|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}if(!a){break x}a=v[b>>2];v[114578]=0;v[d+720>>2]=a+1>>>1;a=T(332,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}Cc(d+720|0,a);v[114578]=0;a=T(856,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break C}e=v[d+720>>2];if(e){break B}e=16;break x}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];f=0;while(1){f=w[d+736|w[a|0]&15]+f|0;t[b|0]=f;f=w[d+736|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=f;e=e-1|0;if(!e){break y}a=a+1|0;b=b+2|0;continue}}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=5?w[a+3|0]!=4:0)){a=w[a+3|0];v[114578]=0;a=aa(1263,d+1808|0,c|0,b|0,(a|0)==5|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}Bb(a);e=v[c+8>>2]-o|0;break x}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[114578]=0;Q(340,c|0,4)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}v[114578]=0;a=T(392,c|0)|0;e=v[114578];v[114578]=0;E:{F:{G:{if((e|0)!=1){v[114578]=0;v[d+720>>2]=a;e=T(389,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}v[114578]=0;U(1264,d+736|0,c|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break E}Cc(d+720|0,v[d+736>>2]);v[114578]=0;a=v[d+720>>2];f=T(414,d+736|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){g=v[d+736>>2];h=v[b+20>>2];b=Aj(b);v[114578]=0;fa(1265,f|0,g|0,h|0,b|0,e<<24>>24);b=v[114578];v[114578]=0;if((b|0)!=1){break F}}a=P()|0;O()|0;Ec(d+736|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=a+9|0;Ec(d+736|0);break x}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[d+2900>>2];e=x[Al(d+1800|0)>>1];v[114578]=0;e=aa(1266,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}H:{I:{J:{K:{L:{M:{N:{if(!(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16)){e=0;v[114578]=0;f=Q(258,c|0,8)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!f){break x}v[114578]=0;f=T(392,c|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}v[d+2900>>2]=f;if(f>>>0<4){break x}v[114578]=0;U(343,d+720|0,c|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break H}f=hm(d+736|0,d+720|0);Bb(d+720|0);v[114578]=0;k=T(1267,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}if(!v[b>>2]){break L}h=w[a|0];a=0;p=(h|0)!=16;g=0;while(1){O:{if(p){break O}v[114578]=0;q=Q(260,f|0,8)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break O}a=V(76880)|0;break M}v[114578]=0;r=Q(260,f|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break N}v[114578]=0;e=Q(260,f|0,1)|0;j=v[114578];v[114578]=0;if((j|0)==1){break N}P:{Q:{R:{if(!e){e=8;while(1){v[114578]=0;j=Q(260,f|0,1)|0;n=v[114578];v[114578]=0;if((n|0)==1){break P}if(j){break R}e=e+16|0;continue}}v[114578]=0;e=Q(260,f|0,3)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break Q}break N}v[114578]=0;j=Q(260,f|0,4)|0;n=v[114578];v[114578]=0;if((n|0)==1){break N}e=e+j|0}g=(g&255)+(((r?-1:0)^e)&255)|0;S:{if((h|0)!=16){t[v[b+20>>2]+a|0]=g;break S}u[v[b+20>>2]+(a<<1)>>1]=q&255|g<<8}a=a+1|0;if(a>>>0<y[b>>2]){continue}break L}break}a=V(76880)|0;break M}T:{U:{V:{W:{X:{if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){e=0;if(y[d+2900>>2]<5){break x}a=v[b+20>>2];v[114578]=0;a=T(467,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break X}v[114578]=0;a=T(1268,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}b=Aj(b);v[114578]=0;e=W(1269,c|0,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=8|w[a+1|0]!=1)){Y:{Z:{_:{$:{aa:{a=w[a+3|0];switch(a|0){case 2:break Z;case 1:break _;case 0:break $;default:break aa}}e=0;switch(a-10|0){case 0:break Y;case 2:break Z;default:break x}}v[114578]=0;e=W(1270,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1271,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}a=v[d+2900>>2];e=w[ly(d+712|0)|0];v[114578]=0;e=aa(1272,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1273,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=8|w[a+1|0]!=3)){ba:{ca:{da:{ea:{g=w[a+3|0];switch(g|0){case 2:break ba;case 1:break da;case 0:break ea;default:break ca}}v[114578]=0;e=W(1274,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1275,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if((g|0)!=12){break x}}e=v[d+2900>>2];g=w[ly(d+704|0)|0];v[114578]=0;e=aa(1276,b|0,f|0,e|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break x}f=v[b>>2]<<1;if((f|0)<1){break x}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break x}if(!(w[a|0]!=8|w[a+1|0]!=2)){e=0;fa:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1277,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1278,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break fa;default:break x}}a=v[d+2900>>2];e=w[ly(d+696|0)|0];v[114578]=0;e=aa(1279,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){ga:{ha:{ia:{ja:{a=w[a+3|0];switch(a|0){case 1:break ia;case 0:break ja;case 2:break ga;default:break ha}}v[114578]=0;e=W(1280,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1281,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if((a|0)!=12){break x}}a=v[d+2900>>2];e=x[Al(d+688|0)>>1];v[114578]=0;e=aa(1282,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;ka:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1283,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1284,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break ka;default:break x}}a=v[d+2900>>2];e=x[Al(d+680|0)>>1];v[114578]=0;e=aa(1285,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){la:{ma:{na:{oa:{g=w[a+3|0];switch(g|0){case 2:break la;case 1:break na;case 0:break oa;default:break ma}}v[114578]=0;e=W(1286,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;e=W(1287,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if((g|0)!=12){break x}}e=v[d+2900>>2];g=x[Al(d+672|0)>>1];v[114578]=0;e=aa(1288,b|0,f|0,e|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(w[a+3|0]!=12){break x}f=v[b>>2];if(f<<1<1){break x}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break x}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){e=0;pa:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1289,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1290,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break pa;default:break x}}a=v[d+2900>>2];e=x[Al(d+664|0)>>1];v[114578]=0;e=aa(1291,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){e=0;qa:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1292,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1293,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break qa;default:break x}}a=v[d+2900>>2];e=x[Al(d+656|0)>>1];v[114578]=0;e=aa(1294,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){e=0;ra:{switch(w[a+3|0]){case 0:v[114578]=0;e=W(1295,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 1:v[114578]=0;e=W(1296,b|0,f|0,v[d+2900>>2])|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x;case 2:break ra;default:break x}}a=v[d+2900>>2];e=x[Al(d+648|0)>>1];v[114578]=0;e=aa(1297,b|0,f|0,a|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d>>1]=x[d+640>>1];e=aa(1298,b|0,f|0,e|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+2>>1]=x[d+632>>1];e=aa(1299,b|0,f|0,e|0,d+2|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+4>>1]=x[d+624>>1];e=aa(1300,b|0,f|0,e|0,d+4|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+6>>1]=x[d+616>>1];e=aa(1301,b|0,f|0,e|0,d+6|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+8>>1]=x[d+608>>1];e=aa(1302,b|0,f|0,e|0,d+8|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+10>>1]=x[d+600>>1];e=aa(1303,b|0,f|0,e|0,d+10|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+12>>1]=x[d+592>>1];e=aa(1304,b|0,f|0,e|0,d+12|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+14>>1]=x[d+584>>1];e=aa(1305,b|0,f|0,e|0,d+14|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+16>>1]=x[d+576>>1];e=aa(1306,b|0,f|0,e|0,d+16|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+18>>1]=x[d+568>>1];e=aa(1307,b|0,f|0,e|0,d+18|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+20>>1]=x[d+560>>1];e=aa(1308,b|0,f|0,e|0,d+20|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+22>>1]=x[d+552>>1];e=aa(1309,b|0,f|0,e|0,d+22|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+24>>1]=x[d+544>>1];e=aa(1310,b|0,f|0,e|0,d+24|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+26>>1]=x[d+536>>1];e=aa(1311,b|0,f|0,e|0,d+26|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+28>>1]=x[d+528>>1];e=aa(1312,b|0,f|0,e|0,d+28|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+30>>1]=x[d+520>>1];e=aa(1313,b|0,f|0,e|0,d+30|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+32>>1]=x[d+512>>1];e=aa(1314,b|0,f|0,e|0,d+32|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+34>>1]=x[d+504>>1];e=aa(1315,b|0,f|0,e|0,d+34|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;u[d+36>>1]=x[d+496>>1];e=aa(1316,b|0,f|0,e|0,d+36|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;u[d+38>>1]=x[d+488>>1];e=aa(1317,b|0,f|0,e|0,d+38|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=24|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[d+736>>2]=-2147483648;e=v[d+2900>>2];sa:{if(!w[a+2|0]){v[114578]=0;v[d+48>>2]=v[d+480>>2];v[d+476>>2]=0;a=v[d+476>>2];v[d+40>>2]=v[d+472>>2];v[d+44>>2]=a;e=ea(1318,b|0,f|0,e|0,d+736|0,d+40|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break sa}break T}v[114578]=0;v[d- -64>>2]=v[d+464>>2];v[d+460>>2]=0;a=v[d+460>>2];v[d+56>>2]=v[d+456>>2];v[d+60>>2]=a;e=ea(1319,b|0,f|0,e|0,d+736|0,d+56|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break T}}if(!e){break x}a=v[d+736>>2];if((a|0)==-2147483648){break x}f=x[b+32>>1];v[114578]=0;f=Fma(f,0,a,0)+1073741824|0;a=mb;a=f>>>0<1073741824?a+1|0:a;a=Gg(790,(a&2147483647)<<1|f>>>31,a>>>31|0);f=v[114578];v[114578]=0;if((f|0)==1){break T}s=b,D=Cd(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=16)){v[d+736>>2]=-2147483648;e=v[d+2900>>2];ta:{if(!w[a+2|0]){v[114578]=0;v[d+80>>2]=v[d+448>>2];v[d+444>>2]=0;a=v[d+444>>2];v[d+72>>2]=v[d+440>>2];v[d+76>>2]=a;e=ea(1320,b|0,f|0,e|0,d+736|0,d+72|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break ta}break U}v[114578]=0;v[d+96>>2]=v[d+432>>2];v[d+428>>2]=0;a=v[d+428>>2];v[d+88>>2]=v[d+424>>2];v[d+92>>2]=a;e=ea(1321,b|0,f|0,e|0,d+736|0,d+88|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break U}}if(!e){break x}a=v[d+736>>2];if((a|0)==-2147483648){break x}f=x[b+32>>1];v[114578]=0;a=Fma(f,0,a,0)+1073741824|0;f=mb;f=a>>>0<1073741824?f+1|0:f;a=Gg(790,(f&2147483647)<<1|a>>>31,f>>>31|0);f=v[114578];v[114578]=0;if((f|0)==1){break U}s=b,D=Cd(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[d+736>>2]=1065353216;e=v[d+2900>>2];ua:{if(!w[a+2|0]){v[114578]=0;v[d+412>>2]=0;v[d+416>>2]=1065353216;a=v[d+420>>2];v[d+112>>2]=v[d+416>>2];v[d+116>>2]=a;a=v[d+412>>2];v[d+104>>2]=v[d+408>>2];v[d+108>>2]=a;e=ea(1322,b|0,f|0,e|0,d+736|0,d+104|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break ua}break V}v[114578]=0;v[d+396>>2]=0;v[d+400>>2]=1065353216;a=v[d+404>>2];v[d+128>>2]=v[d+400>>2];v[d+132>>2]=a;a=v[d+396>>2];v[d+120>>2]=v[d+392>>2];v[d+124>>2]=a;e=ea(1323,b|0,f|0,e|0,d+736|0,d+120|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break V}}if(!e){break x}l=z[d+736>>2];if(l==C(1)){break x}l=gn(C(l*C(x[b+32>>1])),C(1),C(64));v[114578]=0;a=gb(1324,C(l))|0;f=v[114578];v[114578]=0;if((f|0)==1){break V}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=64|(w[a+1|0]!=2?w[a+1|0]!=1:0)|w[a+3|0]!=15)){v[d+736>>2]=0;v[d+740>>2]=1072693248;e=v[d+2900>>2];va:{if(!w[a+2|0]){v[114578]=0;v[d+376>>2]=0;v[d+380>>2]=1072693248;v[d+368>>2]=0;v[d+372>>2]=0;v[d+144>>2]=0;v[d+148>>2]=0;v[d+152>>2]=0;v[d+156>>2]=1072693248;a=v[d+388>>2];v[d+160>>2]=v[d+384>>2];v[d+164>>2]=a;a=v[d+364>>2];v[d+136>>2]=v[d+360>>2];v[d+140>>2]=a;e=ea(1325,b|0,f|0,e|0,d+736|0,d+136|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break va}break W}v[114578]=0;v[d+344>>2]=0;v[d+348>>2]=1072693248;v[d+336>>2]=0;v[d+340>>2]=0;v[d+176>>2]=0;v[d+180>>2]=0;v[d+184>>2]=0;v[d+188>>2]=1072693248;a=v[d+356>>2];v[d+192>>2]=v[d+352>>2];v[d+196>>2]=a;a=v[d+332>>2];v[d+168>>2]=v[d+328>>2];v[d+172>>2]=a;e=ea(1326,b|0,f|0,e|0,d+736|0,d+168|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break W}}if(!e){break x}m=A[d+736>>3];if(m==1){break x}m=jy(m*+x[b+32>>1],1,64);v[114578]=0;a=za(1327,+m)|0;f=v[114578];v[114578]=0;if((f|0)==1){break W}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+320>>2]=939524096;a=v[d+324>>2];v[d+200>>2]=v[d+320>>2];v[d+204>>2]=a;e=aa(1328,b|0,f|0,e|0,d+200|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;v[d+312>>2]=939524096;a=v[d+316>>2];v[d+208>>2]=v[d+312>>2];v[d+212>>2]=a;e=aa(1329,b|0,f|0,e|0,d+208|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+304>>2]=939524096;a=v[d+308>>2];v[d+216>>2]=v[d+304>>2];v[d+220>>2]=a;e=aa(1330,b|0,f|0,e|0,d+216|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;v[d+296>>2]=939524096;a=v[d+300>>2];v[d+224>>2]=v[d+296>>2];v[d+228>>2]=a;e=aa(1331,b|0,f|0,e|0,d+224|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14)){e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+288>>2]=872415232;a=v[d+292>>2];v[d+232>>2]=v[d+288>>2];v[d+236>>2]=a;e=aa(1328,b|0,f|0,e|0,d+232|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}v[114578]=0;v[d+280>>2]=872415232;a=v[d+284>>2];v[d+240>>2]=v[d+280>>2];v[d+244>>2]=a;e=aa(1329,b|0,f|0,e|0,d+240|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}e=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break x}e=v[d+2900>>2];if(!w[a+2|0]){v[114578]=0;v[d+272>>2]=872415232;a=v[d+276>>2];v[d+248>>2]=v[d+272>>2];v[d+252>>2]=a;e=aa(1330,b|0,f|0,e|0,d+248|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break x}break b}v[114578]=0;v[d+264>>2]=872415232;a=v[d+268>>2];v[d+256>>2]=v[d+264>>2];v[d+260>>2]=a;e=aa(1331,b|0,f|0,e|0,d+256|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break x}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break I}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break K}}e=k+4|0;Bb(f);break x}a=P()|0;O()|0;break I}a=P()|0;O()|0}Bb(f);break a}a=P()|0;O()|0;break a}e=v[d+720>>2]+16|0}v[114578]=0;Q(256,c|0,e+o|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}}Ec(i)}jb=d+2928|0;return e|0}a=P()|0;O()|0}Ec(i);S(a|0);L()}function KT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-304|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if(!Ff(b,d+296|0)){break S}if(!uA(d+296|0)){break S}if(!c){r=1;break S}s=Lk(d+280|0,b);v[114578]=0;U(474,d+264|0,s|0,1);b=v[114578];v[114578]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{if((b|0)!=1){v[114578]=0;U(475,d+128|0,d+264|0,1229866575);b=v[114578];v[114578]=0;if((b|0)==1){break ea}v[114578]=0;r=Q(476,d+128|0,d+248|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break ga}Bb(d+128|0);if(!r){break T}v[114578]=0;R(449,a|0,524288);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Z(477,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break fa}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;Bb(d+128|0);break b}v[a+480208>>2]=12;b=w[d+256|0]|w[d+257|0]<<8;G=a,H=Cd((b<<8|b>>>8)&65535,1,127),u[G+480188>>1]=H;b=w[d+248|0]|w[d+249|0]<<8;v[114578]=0;u[d+128>>1]=b<<8|b>>>8;u[d+216>>1]=255;b=Q(478,d+128|0,d+216|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+248|2;b=w[b|0]|w[b+1|0]<<8;v[114578]=0;u[d+128>>1]=b<<8|b>>>8;u[d+216>>1]=3999;b=Q(478,d+128|0,d+216|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}u[a+480190>>1]=x[b>>1];v[114578]=0;b=a+1074308|0;W(479,b|0,6,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}v[114578]=0;Q(480,b|0,21)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}v[114578]=0;Q(480,b|0,13)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=Q(2,d+128|0,12385)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}Gb(a+1304436|0,b);yb(b);v[114578]=0;b=Q(2,d+128|0,12401)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}Gb(a+1304448|0,b);yb(b);v[114578]=0;g=Q(2,d+232|0,12405)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;R(219,d+216|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break j}v[114578]=0;R(481,d+200|0,d+296|4);b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;R(481,d+184|0,d+296|5);b=v[114578];v[114578]=0;if((b|0)==1){break n}v[114578]=0;X(222,d+128|0,d+216|0,d+200|0,d+184|0);b=v[114578];v[114578]=0;if((b|0)==1){break o}Gb(a+1304460|0,d+128|0);yb(d+128|0);yb(d+184|0);yb(d+200|0);Ib(d+216|0);yb(g);v[a+1304496>>2]=2;v[114578]=0;U(475,d+216|0,d+264|0,1312902469);b=v[114578];v[114578]=0;if((b|0)==1){break p}v[114578]=0;b=T(255,d+216|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break r}v[114578]=0;g=a+1304400|0;W(482,d+216|0,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;U(475,d+200|0,d+264|0,1397706311);b=v[114578];v[114578]=0;if((b|0)==1){break s}b=a+484360|0;Xp(Vb(b));ha:{e=d+248|4;f=w[e|0]|w[e+1|0]<<8;ia:{if(!f){break ia}e=0;f=(f<<8|f>>>8)&65535;while(1){v[114578]=0;h=Q(258,d+200|0,46)|0;i=v[114578];v[114578]=0;ja:{if((i|0)!=1){if(!h){break ia}v[114578]=0;W(483,d+200|0,d+128|0,44)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(!Wc(g)){break ja}v[114578]=0;Q(484,g|0,d+128|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break ja}}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}v[114578]=0;h=T(485,d+200|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break ha}if(!nd(Vb(b))){v[114578]=0;i=T(486,b|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break ha}if((i|0)==255){break ia}}i=Vb(b);v[114578]=0;U(6,d+184|0,2,d+128|0);k=v[114578];v[114578]=0;if((k|0)==1){break u}v[114578]=0;R(487,i|0,d+184|0);i=v[114578];v[114578]=0;if((i|0)==1){break v}yb(d+184|0);i=Vb(b);v[114578]=0;ea(488,i|0,d+200|0,h|0,65535,65535)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ha}e=e+1|0;if(f>>>0>(e&65535)>>>0){continue}break}}v[114578]=0;R(489,b|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break w}v[114578]=0;U(475,d+184|0,d+264|0,1229869908);b=v[114578];v[114578]=0;if((b|0)==1){break x}v[114578]=0;b=T(490,d+184|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break G}ka:{if(!b){break ka}if(x[a+480192>>1]){g=1;while(1){v[114578]=0;Q(491,d+184|0,d+128|0)|0;b=v[114578];v[114578]=0;la:{ma:{na:{if((b|0)!=1){b=w[d+158|0]|w[d+159|0]<<8;v[114578]=0;b=W(456,a|0,g&65535,(b<<8|b>>>8)&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break na}if(!b){break la}e=w[d+158|0]|w[d+159|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>3999){break la}v[114578]=0;U(492,d+16|0,2,d+128|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;R(417,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)!=1){break ma}}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}v[114578]=0;Q(371,b+492|0,d- -64|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break z}yb(d- -64|0);v[114578]=0;U(492,d+16|0,2,d+128|0);e=v[114578];v[114578]=0;if((e|0)==1){break A}v[114578]=0;R(417,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break A}e=w[d+158|0]|w[d+159|0]<<8;v[114578]=0;Q(371,((((e<<8|e>>>8)&65535)<<5)+a|0)+946300|0,d- -64|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break B}yb(d- -64|0);v[b>>2]=0;e=w[d+174|0]|w[d+175|0]<<8;v[b+8>>2]=(e<<8|e>>>8)+128&65535;Cc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=w[d+158|0]|w[d+159|0]<<8;v[114578]=0;b=B((b<<8|b>>>8)&65535,104)+a|0;R(388,b+484380|0,0);e=v[114578];v[114578]=0;if((e|0)==1){break C}e=w[d+160|0]|w[d+161|0]<<8;v[114578]=0;u[d+64>>1]=e<<8|e>>>8;u[d+16>>1]=64;e=Q(478,d- -64|0,d+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}u[b+484410>>1]=x[e>>1]<<2;e=w[d+162|0]|w[d+163|0]<<8|(w[d+164|0]<<16|w[d+165|0]<<24);v[b+484404>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(w[d+170|0]|w[d+171|0]<<8|(w[d+172|0]<<16|w[d+173|0]<<24))|!(w[d+177|0]&3)){break la}e=w[d+166|0]|w[d+167|0]<<8|(w[d+168|0]<<16|w[d+169|0]<<24);h=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+484384>>2]=h;e=w[d+170|0]|w[d+171|0]<<8|(w[d+172|0]<<16|w[d+173|0]<<24);f=b+484414|0;u[f>>1]=x[f>>1]|2;v[b+484388>>2]=h+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));if(!(w[d+177|0]&2)){break la}u[f>>1]=x[f>>1]|4}g=g+1|0;if(x[a+480192>>1]>=(g&65535)>>>0){continue}break}}v[114578]=0;U(475,d+112|0,d+264|0,1447382614);b=v[114578];v[114578]=0;if((b|0)==1){break G}v[114578]=0;X(493,d+112|0,0,a|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break E}Bb(d+112|0);v[114578]=0;U(475,d+96|0,d+264|0,1346719318);b=v[114578];v[114578]=0;if((b|0)==1){break G}v[114578]=0;X(493,d+96|0,1,a|0,w[d+300|0]>2|0);b=v[114578];v[114578]=0;if((b|0)==1){break F}Bb(d+96|0);if(!x[a+480192>>1]){break ka}b=1;while(1){g=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!g|t[g+60|0]&1)){v[g>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}Bb(d+184|0);v[114578]=0;U(475,d+128|0,d+264|0,1346458708);b=v[114578];v[114578]=0;if((b|0)==1){break H}v[114578]=0;b=T(339,d+128|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break J}if(!(c&1)|b^1){break da}v[114578]=0;U(475,d+184|0,d+264|0,1347305805);b=v[114578];v[114578]=0;if((b|0)==1){break K}v[114578]=0;Q(340,d+184|0,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break M}k=d+248|6;b=w[k|0]|w[k+1|0]<<8;g=0;v[114578]=0;m=a+484344|0;R(403,m|0,(b<<8|b>>>8)&65535);b=v[114578];v[114578]=0;if((b|0)==1){break M}b=jb-16|0;jb=b;e=d+80|0;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(520,e+8|0,b+12|0,b+8|0)|0;f=v[114578];v[114578]=0;oa:{if((f|0)!=1){jb=b+16|0;break oa}V(0)|0;O()|0;Ab();L()}if(!(w[k|0]|w[k+1|0]<<8)){break ca}z=d+16|5;A=d+16|3;C=d+16|4;D=d+16|2;E=d+16|1;b=0;while(1){v[114578]=0;y=T(485,d+128|0)|0;f=v[114578];v[114578]=0;pa:{qa:{ra:{sa:{ta:{if((f|0)!=1){v[114578]=0;f=T(494,d+128|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ta}v[114578]=0;U(343,d- -64|0,d+128|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break sa}v[114578]=0;f=W(404,m|0,g&65535,y|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ra}if(!f){break pa}o=Wb(d+48|0);v[114578]=0;W(495,d+184|0,o|0,-1)|0;f=v[114578];v[114578]=0;if((f|0)!=1){f=_b(m,g);v[114578]=0;Q(496,f|0,o|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break qa}}break P}b=P()|0;O()|0;break N}b=P()|0;O()|0;break N}b=P()|0;O()|0;break N}b=P()|0;O()|0;break O}f=_b(m,g);v[114578]=0;p=Q(497,f|0,0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break P}FT(e);n=0;ua:{while(1){v[114578]=0;f=Q(258,d- -64|0,1)|0;h=v[114578];v[114578]=0;va:{wa:{xa:{if((h|0)!=1){if(!f){break ua}v[114578]=0;i=T(389,d- -64|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break P}if(i){break wa}G=d,H=bc(e),v[G+40>>2]=H;G=d,H=cc(e),v[G+32>>2]=H;if(Jb(d+40|0,d+32|0)){break xa}break va}break P}while(1){ya:{f=v[d+40>>2];h=_b(m,g);i=w[f+1|0];f=w[f|0];v[114578]=0;f=W(498,d+16|0,f|0,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break ya}f=Ne(f,n);v[114578]=0;Q(499,h|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ya}te(d+40|0);if(Jb(d+40|0,d+32|0)){continue}break va}break}break P}Qh(d+16|0);q=x[a+480188>>1];v[114578]=0;f=T(389,d- -64|0)|0;h=v[114578];v[114578]=0;za:{if((h|0)==1){break za}h=B(i-1|0,6)+p|0;Aa:{if(!(f&1)){break Aa}v[114578]=0;j=T(389,d- -64|0)|0;l=v[114578];v[114578]=0;Ba:{if((l|0)!=1){if(!j){break Aa}if((j|0)!=31){break Ba}t[(i>>>0>q>>>0?d+16|0:h)|0]=255;break Aa}break P}if(j>>>0>253){break Aa}t[(i>>>0>q>>>0?d+16|0:h)|0]=(B(j>>>4|0,12)+(j&15)|0)+13}if(f&2){v[114578]=0;j=T(389,d- -64|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break za}t[(i>>>0>q>>>0?E:h+1|0)|0]=j}if(!(f&60)){continue}t[d+15|0]=0;t[d+14|0]=0;t[d+13|0]=0;t[d+12|0]=0;if(f&4){v[114578]=0;j=T(389,d- -64|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break P}t[d+14|0]=j}if(f&8){v[114578]=0;j=T(389,d- -64|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break P}t[d+12|0]=j}if(f&16){v[114578]=0;j=T(389,d- -64|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break P}t[d+15|0]=j}if(f&32){v[114578]=0;f=T(389,d- -64|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break P}t[d+13|0]=f}ET(d+15|0,d+13|0);ET(d+14|0,d+12|0);f=w[d+14|0];if(!(w[d+15|0]==13|f?(f|0)!=13:0)){lh(d+15|0,d+14|0);lh(d+13|0,d+12|0)}v[114578]=0;fa(500,d+32|0,d+15|0,d+13|0,d+14|0,d+12|0);f=v[114578];v[114578]=0;Ca:{if((f|0)==1){break Ca}v[114578]=0;f=Q(501,w[d+32|0],w[d+33|0])|0;j=v[114578];v[114578]=0;if((j|0)==1){break Ca}Da:{if(!f){break Da}G=d,H=bc(e),v[G+40>>2]=H;Md(d+8|0,d+40|0);v[114578]=0;W(502,e|0,v[d+8>>2],d+32|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break Da}break P}f=i>>>0>q>>>0;t[(f?D:h+2|0)|0]=w[d+15|0];t[(f?C:h+4|0)|0]=w[d+13|0];i=w[d+14|0];t[(f?A:h+3|0)|0]=i;t[(f?z:h+5|0)|0]=w[d+12|0];if((i|0)==40){F=1;continue}if((i|0)!=31){continue}b=1;continue}break P}break P}FT(e);n=n+1|0;if(y>>>0<=n>>>0){break ua}f=_b(m,g);v[114578]=0;p=Q(497,f|0,n|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){continue}break}break P}yb(o)}Bb(d- -64|0);g=g+1|0;f=w[k|0]|w[k+1|0]<<8;if(g>>>0<((f<<8|f>>>8)&65535)>>>0){continue}break}break ba}b=P()|0;O()|0;break t}b=P()|0;O()|0;break b}e=0;if(c&4){break aa}break U}b=0}DT(e);Bb(d+184|0);if(!(c&4)){break $}e=0;p=(b|0)!=0;if(!F){break aa}g=x[a+480188>>1];if(!g){e=1;break aa}b=0;while(1){e=1;f=(b<<5)+a|0;t[f+480288|0]=1;f=f+480280|0;v[f>>2]=v[f>>2]|67108864;b=b+1|0;if((g|0)!=(b|0)){continue}break}}v[114578]=0;v[d+64>>2]=-1778364416;v[d+68>>2]=-16756736;U(475,d+184|0,d+264|0,1146310725);b=v[114578];v[114578]=0;Ea:{Fa:{Ga:{if((b|0)!=1){v[114578]=0;b=T(490,d+184|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Ea}if(!b){break Fa}v[114578]=0;f=T(485,d+184|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Z}if(f){break Ga}g=e;break _}b=P()|0;O()|0;break I}b=0;g=e;while(1){v[114578]=0;h=T(389,d+184|0)|0;i=v[114578];v[114578]=0;Ha:{Ia:{if((i|0)!=1){if(x[a+480188>>1]<=b>>>0){break Ha}if(!e){break Ia}i=((b<<5)+a|0)+480280|0;v[i>>2]=v[i>>2]&-67108865|((h|0)!=0)<<26;break Ha}break Z}if(h){break Ha}g=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((f|0)!=(b|0)){continue}break}break _}Bb(d+184|0);if(!e){break W}break X}break Z}if(!b){break U}break V}v[114578]=0;Q(503,d+184|0,d- -64|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break Y}}b=P()|0;O()|0;Bb(d+184|0);break I}Bb(d+184|0);if(!(g&1)){break W}}v[114578]=0;Z(504,a+906300|0);b=v[114578];v[114578]=0;Ja:{Ka:{La:{Ma:{Na:{Oa:{if((b|0)==1){break Oa}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[114578]=0;v[d+184>>2]=0;b=a+906332|0;U(505,b|0,b+16|0,d+184|0);b=v[114578];v[114578]=0;if((b|0)==1){break Na}v[114578]=0;g=Q(85,d+184|0,12427)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Ma}v[114578]=0;Q(506,a+906348|0,g|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break La}yb(g);v[114578]=0;g=Q(85,d+184|0,12432)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Ka}v[114578]=0;Q(507,a+906380|0,g|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break Ja}yb(g);v[114578]=0;b=a+906304|0;R(508,b|0,8);g=v[114578];v[114578]=0;if((g|0)==1){break Oa}AT(d+184|0,w[d+65|0],w[d+67|0],w[d+69|0],w[d+71|0]);g=v[d+188>>2];b=v[b>>2];e=v[d+184>>2];t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=g;t[b+5|0]=g>>>8;t[b+6|0]=g>>>16;t[b+7|0]=g>>>24;break W}b=P()|0;O()|0;break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(g);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(g);break I}if(!p){break U}}b=0;Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{while(1){kb:{v[114578]=0;v[d+48>>2]=B(b,127)>>>5;R(509,d- -64|0,12453);g=v[114578];v[114578]=0;if((g|0)==1){break kb}v[114578]=0;R(510,d+16|0,d+48|0);g=v[114578];v[114578]=0;if((g|0)==1){break jb}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);g=v[114578];v[114578]=0;if((g|0)==1){break ib}v[114578]=0;g=(b<<5)+a|0;R(512,d+80|0,g+902204|0);e=v[114578];v[114578]=0;if((e|0)==1){break hb}v[114578]=0;Q(471,d+80|0,d+184|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break hb}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);v[114578]=0;R(509,d- -64|0,12462);e=v[114578];v[114578]=0;if((e|0)==1){break eb}v[114578]=0;R(510,d+16|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break db}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break cb}v[114578]=0;R(512,d+80|0,g+903228|0);e=v[114578];v[114578]=0;if((e|0)==1){break bb}v[114578]=0;Q(471,d+80|0,d+184|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break bb}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);v[114578]=0;R(509,d- -64|0,12471);e=v[114578];v[114578]=0;if((e|0)==1){break _a}v[114578]=0;R(510,d+16|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break Za}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ya}v[114578]=0;R(512,d+80|0,g+904252|0);e=v[114578];v[114578]=0;if((e|0)==1){break Xa}v[114578]=0;Q(471,d+80|0,d+184|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Xa}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);v[114578]=0;R(509,d- -64|0,12480);e=v[114578];v[114578]=0;if((e|0)==1){break Ua}v[114578]=0;R(510,d+16|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ta}v[114578]=0;U(511,d+184|0,d- -64|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break Sa}v[114578]=0;R(512,d+80|0,g+905276|0);g=v[114578];v[114578]=0;if((g|0)==1){break Ra}v[114578]=0;Q(471,d+80|0,d+184|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Ra}yb(d+184|0);yb(d+16|0);Ib(d- -64|0);b=b+1|0;if((b|0)!=32){continue}break U}break}b=P()|0;O()|0;break I}b=P()|0;O()|0;break fb}b=P()|0;O()|0;break gb}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break $a}b=P()|0;O()|0;break ab}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break Va}b=P()|0;O()|0;break Wa}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;break Pa}b=P()|0;O()|0;break Qa}b=P()|0;O()|0;yb(d+184|0)}yb(d+16|0)}Ib(d- -64|0);break I}v[114578]=0;U(475,d+184|0,d+264|0,1397575756);b=v[114578];v[114578]=0;if((b|0)==1){break Q}v[114578]=0;b=T(339,d+184|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break R}e=1;if(!(!x[a+480190>>1]|(!(c&2)|b^1))){c=1;while(1){v[114578]=0;b=T(494,d+184|0)|0;g=v[114578];v[114578]=0;lb:{if((g|0)!=1){v[114578]=0;g=T(494,d+184|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break R}if(!(b&7)){break lb}e=(B(e,104)+a|0)+484380|0;v[e>>2]=g;b=ad(d- -64|0,b&4?32:b&2?16:8,1,1,0);v[114578]=0;W(402,b|0,e|0,d+184|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break lb}break R}break R}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}Bb(d+184|0);Bb(d+128|0);Bb(d+200|0);Bb(d+216|0)}pA(d+264|0);Bb(s)}jb=d+304|0;return r|0}b=P()|0;O()|0;Bb(d+184|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(o)}Bb(d- -64|0)}DT(e);break L}b=P()|0;O()|0}Bb(d+184|0);break I}b=P()|0;O()|0;break I}b=P()|0;O()|0}Bb(d+128|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break y}b=P()|0;O()|0;Bb(d+96|0);break y}b=P()|0;O()|0;Bb(d+112|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(d- -64|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(d- -64|0)}Bb(d+184|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;yb(d+184|0);break t}b=P()|0;O()|0}Bb(d+200|0);break q}b=P()|0;O()|0;break q}b=P()|0;O()|0}Bb(d+216|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d+184|0);break m}b=P()|0;O()|0}yb(d+200|0);break k}b=P()|0;O()|0}Ib(d+216|0);break i}b=P()|0;O()|0}yb(g);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}pA(d+264|0)}Bb(s);S(b|0);L()}function Mha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=jb-320|0;jb=d;Jc(b);a:{if(!Mt(b,d+304|0)){break a}if(!GP(d+304|0)){break a}p=Lk(d+288|0,b);m=$y(d+272|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[114578]=0;X(952,d|0,p|0,1,1413891155);b=v[114578];v[114578]=0;if((b|0)==1){break r}break t}v[114578]=0;U(953,d|0,p|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break s}}b=m;if(v[b>>2]){Id(b);wP(b);up(b);Xf(zb(b),v[b>>2],We(b));s=zb(b),y=0,v[s>>2]=y;v[b>>2]=0;v[b+4>>2]=0}El(m,d);v[m>>2]=v[d>>2];v[m+4>>2]=v[d+4>>2];b=v[zb(d)>>2];s=zb(m),y=b,v[s>>2]=y;s=zb(d),y=0,v[s>>2]=y;v[d>>2]=0;v[d+4>>2]=0;Gl(d);v[114578]=0;U(954,d|0,m|0,1413891155);b=v[114578];v[114578]=0;u:{v:{if((b|0)!=1){v[114578]=0;e=Q(955,d|0,16779)|0;b=v[114578];v[114578]=0;if((b|0)==1){break v}Bb(d);if(!c){break b}if(!(e^1)){break u}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Bb(d);break c}v[114578]=0;R(449,a|0,4194304);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[114578]=0;U(954,d+256|0,m|0,1280592212);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;b=T(255,d+256|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}v[114578]=0;W(679,d+256|0,a+1304400|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}n=a+484360|0;Xp(Vb(n));b=jb-16|0;jb=b;k=d+240|0;e=k;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(975,e+8|0,b+12|0,b+8|0)|0;e=v[114578];v[114578]=0;w:{if((e|0)!=1){jb=b+16|0;break w}V(0)|0;O()|0;Ab();L()}v[114578]=0;t[d+239|0]=0;U(956,d+224|0,m|0,1196314451);b=v[114578];v[114578]=0;if((b|0)==1){break i}s=d,y=bc(d+224|0),v[s+216>>2]=y;s=d,y=cc(d+224|0),v[s+208>>2]=y;x:{y:{z:{A:{B:{C:{if(!Jb(d+216|0,d+208|0)){break C}o=d+12|0;f=d+24|0;q=d+44|0;while(1){e=Lk(d+192|0,v[d+216>>2]);v[114578]=0;g=Q(957,d+192|0,d+176|0)|0;b=v[114578];v[114578]=0;D:{E:{F:{G:{H:{I:{if((b|0)!=1){b=1;if(!(g&w[d+185|0]==1)){break D}s=a,y=Cd(w[d+186|0],x[a+480188>>1],127),u[s+480188>>1]=y;v[114578]=0;h=T(958,d|0)|0;b=v[114578];v[114578]=0;J:{K:{L:{M:{if((b|0)!=1){v[114578]=0;U(959,d+160|0,1,d+176|0);b=v[114578];v[114578]=0;if((b|0)==1){break M}v[114578]=0;R(417,d+120|0,d+160|0);b=v[114578];v[114578]=0;if((b|0)==1){break M}v[114578]=0;R(960,d+152|0,q|0);b=v[114578];v[114578]=0;if((b|0)==1){break L}v[114578]=0;Q(471,d+152|0,d+120|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break L}yb(d+120|0);if(nd(Vb(n))){break J}v[114578]=0;b=T(486,n|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break K}if((b|0)!=255){break J}b=2;break E}e=P()|0;O()|0;break k}e=P()|0;O()|0;break l}e=P()|0;O()|0;yb(d+120|0);break l}e=P()|0;O()|0;break l}b=Vb(n);v[114578]=0;U(6,d+120|0,4,q|0);g=v[114578];v[114578]=0;N:{O:{P:{if((g|0)!=1){v[114578]=0;R(487,b|0,d+120|0);b=v[114578];v[114578]=0;if((b|0)==1){break P}yb(d+120|0);v[114578]=0;U(953,d+160|0,e|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break O}s=d,y=bc(d+160|0),v[s+144>>2]=y;s=d,y=cc(d+160|0),v[s+136>>2]=y;if(Jb(d+144|0,d+136|0)){break N}break H}e=P()|0;O()|0;break l}e=P()|0;O()|0;yb(d+120|0);break l}e=P()|0;O()|0;break l}Q:{R:{while(1){S:{e=v[d+144>>2];b=Ze(d+120|0,zb(e));g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);v[d+152>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[d+156>>2]=g;l=1;T:{e=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);if((e|0)!=1212960847){if((e|0)!=1312903248){break T}e=0;if(!x[a+480188>>1]){break T}U:{while(1){v[114578]=0;g=Q(258,b|0,2)|0;i=v[114578];v[114578]=0;if((i|0)==1){break U}if(!g){break T}v[114578]=0;R(473,d+96|0,b|0);g=v[114578];v[114578]=0;V:{W:{X:{Y:{if((g|0)!=1){g=dd(d+96|0);switch(w[d+96|0]){case 4:break W;case 2:break X;case 0:break Y;default:break V}}break I}g=w[g|0];s=xc(d,e),y=g^128,t[s|0]=y;ee(d+104|0,f,e);ge(d+104|0,0);break V}s=xc(d,e),y=128,t[s|0]=y;ee(d+104|0,f,e);ge(d+104|0,1);break V}s=xc(d,e),y=128,t[s|0]=y;ee(d+104|0,f,e);ge(d+104|0,0)}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}break T}break I}if(_y(d+152|0)>>>0<9){break T}i=0;v[114578]=0;Q(340,b|0,2)|0;e=v[114578];v[114578]=0;g=65535;if((e|0)==1){break S}while(1){v[114578]=0;e=Q(258,b|0,1)|0;j=v[114578];v[114578]=0;Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((j|0)!=1){if(!e){break T}v[114578]=0;e=T(389,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}switch(e|0){case 0:break T;case 14:break _;case 13:break $;case 12:break ba;case 8:break ca;case 7:break da;case 4:break ea;case 1:break fa;default:break aa}}break I}if(x[d+36>>1]==65535){e=Vb(n);v[114578]=0;e=T(544,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}u[d+36>>1]=e}e=Vb(n);v[114578]=0;e=T(544,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}v[114578]=0;u[d+38>>1]=e;e=Q(961,b|0,d+239|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}ga:{ha:{switch(e-254|0){case 1:v[114578]=0;e=da(962)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break ga}break I;case 0:break ha;default:break ga}}v[114578]=0;e=da(963)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}}j=Vb(n);v[114578]=0;R(794,j|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break I}g=(g&65535)==65535?i:g;break Z}v[114578]=0;e=T(359,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}if(e>>>0>=(g&65535)>>>0){u[d+40>>1]=e-g}Oe(Vb(n),x[d+40>>1]);break Z}v[114578]=0;e=T(389,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}t[d+43|0]=e;break Z}v[114578]=0;e=T(389,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}t[d+42|0]=e;break Z}v[114578]=0;e=Q(919,b|0,d+104|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break I}if(!(e&!w[d+104|0])|w[d+105|0]!=255|(w[d+106|0]|w[d+107|0])){break aa}if(w[d+108|0]!=1){break aa}if(!w[d+109|0]){break Z}}l=0;break T}v[114578]=0;R(806,d+112|0,b|0);e=v[114578];v[114578]=0;ia:{ja:{ka:{la:{if((e|0)!=1){e=dd(d+112|0);j=Bf(d+112|0);if(w[d+112|0]>=Ac(d)>>>0){break Z}switch(w[j|0]){case 4:break ja;case 2:break ka;case 0:break la;default:break ia}}break I}e=w[e|0];s=xc(d,w[d+112|0]),y=e^128,t[s|0]=y;ee(d+104|0,f,w[d+112|0]);ge(d+104|0,0);break ia}s=xc(d,w[d+112|0]),y=128,t[s|0]=y;ee(d+104|0,f,w[d+112|0]);ge(d+104|0,1);break ia}s=xc(d,w[d+112|0]),y=128,t[s|0]=y;ee(d+104|0,f,w[d+112|0]);ge(d+104|0,0)}ma:{if(r){break ma}r=0;if(!wk(k)){break Z}if(w[xc(DP(k),w[d+112|0])|0]!=w[xc(d,w[d+112|0])|0]){break ma}ee(d+104|0,DP(k)+24|0,w[d+112|0]);e=Cb(d+104|0);ee(d+96|0,f,w[d+112|0]);if((Cb(d+96|0)|0)==(e|0)){break Z}}r=1;break Z}v[114578]=0;R(473,d+104|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break Q}e=dd(d+104|0);j=w[d+104|0];if(Ac(o)>>>0<=j>>>0){break Z}e=w[e|0];s=xc(o,w[d+104|0]),y=(e>>>2|0)+1|0,t[s|0]=y}i=i+1|0;continue}}Bb(b);if(!l){break R}Ik(d+144|0);if(Jb(d+144|0,d+136|0)){continue}break H}break}break I}b=1;break F}break I}e=P()|0;O()|0;break k}e=P()|0;O()|0;Bb(b);break G}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break F}b=Vb(n);v[114578]=0;Z(964,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){b=0;v[114578]=0;R(965,k|0,h|0);e=v[114578];v[114578]=0;if((e|0)!=1){break F}}e=P()|0;O()|0}Gl(d+160|0);break l}Gl(d+160|0)}Zy(h)}Bb(d+192|0);if(!b){Tf(d+216|0);if(Jb(d+216|0,d+208|0)){continue}break C}break}e=0;if((b|0)!=2){break B}}e=0;v[114578]=0;R(489,n|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break q}if(nd(k)){break B}if(c&2){v[114578]=0;U(956,d+192|0,m|0,1347244868);b=v[114578];v[114578]=0;if((b|0)==1){break x}s=d,y=bc(d+192|0),v[s+176>>2]=y;s=d,y=cc(d+192|0),v[s+152>>2]=y;f=w[d+239|0];if(Jb(d+176|0,d+152|0)){e=a+480190|0;g=d+13|0;l=d+17|0;while(1){b=v[d+176>>2];na:{oa:{pa:{qa:{ra:{if(!f){v[114578]=0;h=Q(966,b|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break ra}if(!h){break na}h=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=h+1;if(h>>>0>3998){break pa}v[114578]=0;h=Q(454,e|0,d+104|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break ra}u[a+480190>>1]=x[h>>1];v[114578]=0;R(967,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);h=v[114578];v[114578]=0;if((h|0)==1){break ra}v[114578]=0;U(968,d+160|0,1,g|0);h=v[114578];v[114578]=0;sa:{ta:{if((h|0)==1){break ta}v[114578]=0;R(417,d+120|0,d+160|0);h=v[114578];v[114578]=0;if((h|0)==1){break ta}v[114578]=0;Q(371,((x[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break sa}yb(d+120|0);break pa}e=P()|0;O()|0;break oa}e=P()|0;O()|0;yb(d+120|0);break oa}v[114578]=0;h=Q(969,b|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break qa}if(!h){break na}h=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=h+1;if(h>>>0>3998){break pa}v[114578]=0;h=Q(454,e|0,d+104|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break qa}u[a+480190>>1]=x[h>>1];v[114578]=0;R(970,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);h=v[114578];v[114578]=0;if((h|0)==1){break qa}v[114578]=0;U(968,d+160|0,1,l|0);h=v[114578];v[114578]=0;ua:{va:{if((h|0)==1){break va}v[114578]=0;R(417,d+120|0,d+160|0);h=v[114578];v[114578]=0;if((h|0)==1){break va}v[114578]=0;Q(371,((x[d+104>>1]<<5)+a|0)+946300|0,d+120|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break ua}yb(d+120|0);break pa}e=P()|0;O()|0;break oa}e=P()|0;O()|0;yb(d+120|0);break oa}e=P()|0;O()|0;break oa}e=P()|0;O()|0;break oa}if((x[d+104>>1]-1&65535)>>>0>3998){break na}h=ad(d,8,1,0,2);v[114578]=0;W(402,h|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break na}e=P()|0;O()|0}hd(d+192|0);break j}Tf(d+176|0);if(Jb(d+176|0,d+152|0)){continue}break}}hd(d+192|0)}b=0;s=a,y=w[Fl(k,0)+43|0],v[s+480196>>2]=y;s=a,y=B(w[Fl(k,0)+42|0],1e4),v[s+480204>>2]=y;Oe(Vb(n),x[Fl(k,0)+40>>1]);if(x[a+480188>>1]){while(1){v[114578]=0;e=(b<<5)+a|0;f=e+480280|0;Z(434,f|0);g=v[114578];v[114578]=0;if((g|0)==1){break y}s=e+480286|0,y=w[xc(Fl(k,0)+12|0,b)|0],u[s>>1]=y;s=e+480284|0,y=w[xc(Fl(k,0),b)|0],u[s>>1]=y;ee(d,Fl(k,0)+24|0,b);e=Cb(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}wa:{if(w[d+239|0]){v[114578]=0;Q(2,d|0,16788)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break wa}break m}v[114578]=0;Q(2,d|0,16832)|0;b=v[114578];v[114578]=0;if((b|0)==1){break m}}Gb(a+1304436|0,d);yb(d);v[114578]=0;b=Q(2,d|0,16866)|0;f=v[114578];v[114578]=0;e=1;if((f|0)==1){break z}Gb(a+1304448|0,b);yb(b);v[a+1304496>>2]=4;if(!(c&1)|!x[a+480188>>1]){break B}v[114578]=0;U(956,d+192|0,m|0,1146045008);b=v[114578];v[114578]=0;if((b|0)==1){break n}b=od(d+192|0);v[114578]=0;h=a+484344|0;R(403,h|0,b&65535);b=v[114578];v[114578]=0;if((b|0)==1){break p}s=d,y=bc(d+192|0),v[s+120>>2]=y;s=d,y=cc(d+192|0),v[s+160>>2]=y;if(Jb(d+120|0,d+160|0)){while(1){g=v[d+120>>2];v[114578]=0;b=T(255,g|0)|0;c=v[114578];v[114578]=0;xa:{ya:{za:{if((c|0)==1){break za}v[114578]=0;c=T(392,g|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break za}if((b|0)!=(c|0)){break xa}v[114578]=0;b=Q(971,g|0,8)|0;c=v[114578];v[114578]=0;if((c|0)==1){break za}if(b){break ya}break xa}e=P()|0;O()|0;break o}v[114578]=0;o=Q(961,g|0,d+239|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){v[114578]=0;i=T(359,g|0)|0;b=v[114578];v[114578]=0;Aa:{if((b|0)==1){break Aa}v[114578]=0;b=W(404,h|0,o|0,i|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Aa}l=0;if(!(b&(i|0)!=0)){break xa}while(1){Ba:{b=_b(h,o);v[114578]=0;c=Q(497,b|0,l|0)|0;b=v[114578];v[114578]=0;Ca:{Da:{Ea:{if((b|0)!=1){v[114578]=0;b=T(359,g|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ea}if(b>>>0<3){break Ca}v[114578]=0;U(343,d|0,g|0,b-2|0);b=v[114578];v[114578]=0;if((b|0)!=1){break Da}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}while(1){v[114578]=0;b=Q(258,d|0,3)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ba}if(b){v[114578]=0;R(473,d+176|0,d|0);b=v[114578];v[114578]=0;Fa:{Ga:{Ha:{Ia:{if((b|0)!=1){b=dd(d+176|0);u[d+152>>1]=x[a+480188>>1]-1;b=w[b|0];v[114578]=0;u[d+104>>1]=b;b=Q(478,d+152|0,d+104|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ba}e=x[b>>1];b=t[d+176|0];if((b|0)>-1){break Fa}v[114578]=0;b=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}if(w[d+239|0]){break Ha}if((b|0)!=255){break Ia}b=254;break Ga}break Ba}if(b>>>0>128){break Ga}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ga}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[d+176|0]}if(b&64){v[114578]=0;b=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}t[(c+B(e,6)|0)+1|0]=b+1;b=w[d+176|0]}if(b&32){v[114578]=0;b=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}t[d+152|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;v[114578]=0;t[d+104|0]=127;f=Q(393,d+152|0,d+104|0)|0;q=v[114578];v[114578]=0;if((q|0)==1){break Ba}t[b+4|0]=w[f|0]+1>>>1;b=w[d+176|0]}if(!(b&16)){continue}v[114578]=0;R(473,d+152|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break Ba}b=c+B(e,6)|0;f=w[dd(d+152|0)|0];t[b+5|0]=f;Ja:{switch(w[d+152|0]-1|0){case 0:t[(c+B(e,6)|0)+3|0]=11;if(!w[d+239|0]){t[b+5|0]=f<<3|15;continue}t[b+5|0]=f<<4|15;continue;case 1:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f<<4;continue}t[b+5|0]=f<<3&240;continue;case 2:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1|240;continue;case 3:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f&15;continue}if(f>>>0<=1){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1&15;continue;case 10:t[(c+B(e,6)|0)+3|0]=2;s=b,y=gt(f,w[d+239|0])|240,t[s+5|0]=y;continue;case 11:t[(c+B(e,6)|0)+3|0]=2;s=b,y=gt(f,w[d+239|0]),t[s+5|0]=y;continue;case 12:t[(c+B(e,6)|0)+3|0]=3;s=b,y=gt(f,w[d+239|0])|240,t[s+5|0]=y;continue;case 13:t[(c+B(e,6)|0)+3|0]=3;s=b,y=gt(f,w[d+239|0]),t[s+5|0]=y;continue;case 14:t[(c+B(e,6)|0)+3|0]=4;if(w[d+239|0]){continue}t[b+5|0]=(f&252)>>>2;continue;case 16:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&1|16;continue;case 15:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=f&240;continue;case 17:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=(f&240)>>>4;continue;case 18:t[(c+B(e,6)|0)+3|0]=20;continue;case 20:t[(c+B(e,6)|0)+3|0]=5;continue;case 21:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|48;continue;case 22:t[(c+B(e,6)|0)+3|0]=7;t[b+5|0]=f|240;continue;case 23:t[(c+B(e,6)|0)+3|0]=7;continue;case 30:t[(c+B(e,6)|0)+3|0]=8;continue;case 31:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|64;continue;case 40:t[(c+B(e,6)|0)+3|0]=10;v[114578]=0;e=T(389,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ba}t[b+5|0]=e;v[114578]=0;Q(340,d|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}break Ba;case 41:t[(c+B(e,6)|0)+3|0]=15;continue;case 42:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|192;continue;case 43:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|208;continue;case 50:t[(c+B(e,6)|0)+3|0]=12;t[b+5|0]=(f&254)>>>1;v[114578]=0;Q(340,d|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}break Ba;case 51:t[(c+B(e,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|176;continue;case 53:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|224;continue;case 60:t[(c+B(e,6)|0)+3|0]=16;continue;case 61:t[(c+B(e,6)|0)+3|0]=17;continue;case 70:t[(c+B(e,6)|0)+3|0]=1;continue;case 71:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|32;continue;case 72:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|128;continue;default:break Ja}}t[(c+B(e,6)|0)+3|0]=0;continue}break}Bb(d)}l=l+1|0;if((i|0)!=(l|0)){continue}break xa}break}e=P()|0;O()|0;Bb(d);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}Tf(d+120|0);if(Jb(d+120|0,d+160|0)){continue}break}}Ka:{if(wk(k)>>>0<2){break Ka}if(!wk(k)){break Ka}e=0;while(1){b=Di(n,e&255);c=Fl(k,e);f=x[rc(b,x[c+36>>1])>>1];v[114578]=0;f=Q(444,h|0,f|0)|0;g=v[114578];v[114578]=0;La:{Ma:{if((g|0)!=1){if(!f){break La}f=x[c+36>>1];v[114578]=0;f=Q(810,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break Ma}}e=P()|0;O()|0;break o}if(!(!r|!x[a+480188>>1])){l=c+24|0;b=0;while(1){ee(d,l,b);i=Cb(d);g=_b(h,f);Na:{if(i){v[114578]=0;i=W(498,d|0,20,145)|0;o=v[114578];v[114578]=0;if((o|0)!=1){i=Uh(Fn(Ne(i,0),b&65535));v[114578]=0;Q(499,g|0,i|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break Na}}e=P()|0;O()|0;break o}i=w[xc(c,b)|0];v[114578]=0;i=W(498,d|0,9,i|0)|0;o=v[114578];v[114578]=0;if((o|0)!=1){i=Uh(Fn(Ne(i,0),b&65535));v[114578]=0;Q(499,g|0,i|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break Na}}e=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=_b(h,f);g=w[c+43|0];v[114578]=0;g=W(498,d|0,16,g|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break A}g=Uh(Ne(g,0));v[114578]=0;Q(499,b|0,g|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break A}b=_b(h,f);c=w[c+42|0];v[114578]=0;c=W(498,d|0,17,c|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){c=Uh(Ne(c,0));v[114578]=0;Q(499,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break La}}e=P()|0;O()|0;break o}e=e+1|0;if(wk(k)>>>0>e>>>0){continue}break}}hd(d+192|0);e=1}hd(d+224|0);CP(k);Bb(d+256|0);break b}e=P()|0;O()|0;break o}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break j}e=P()|0;O()|0}hd(d+192|0);break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}Zy(h)}Bb(d+192|0)}hd(d+224|0);break h}e=P()|0;O()|0}CP(k);break f}e=P()|0;O()|0}Bb(d+256|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Gl(m);Bb(p);S(e|0);L()}Gl(m);Bb(p)}jb=d+320|0;return e|0}function k1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=C(0),F=0,G=0,I=0,J=C(0),K=0,M=0,N=0,O=0,P=0,Q=0,R=C(0);s=jb-1520|0;jb=s;g=Rb(s+8|0,0,1512);if(e){f=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=f;e=f&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[s+56|0]=1;v[s+48>>2]=a+b;v[s+40>>2]=a;b=0;p=jb-1024|0;jb=p;f=s+8|0;t[f+1377|0]=1;a:{if(!Dr(f)){break a}e=w[f+1375|0];if(!(e&2)){dc(f,34);break a}if(e&4){dc(f,34);break a}if(e&1){dc(f,34);break a}if(v[f+1116>>2]!=1){dc(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!ww(f,p+1018|0,6)|w[p+1018|0]!=102|(w[p+1019|0]!=105|w[p+1020|0]!=115)){break b}if(w[p+1021|0]!=104|w[p+1022|0]!=101|w[p+1023|0]!=97){break b}if((Ae(f)|0)!=100){break b}if(Ae(f)){break b}dc(f,38);break a}dc(f,34);break a}if((Ae(f)|0)!=1){dc(f,34);break a}if(!ww(f,p+1018|0,6)){dc(f,10);break a}if(!vw(p+1018|0)){dc(f,34);break a}if(li(f)){dc(f,34);break a}e=Ae(f);v[f+4>>2]=e;if(!e){dc(f,34);break a}if(e>>>0>=17){dc(f,5);break a}e=li(f);v[f>>2]=e;if(!e){dc(f,34);break a}li(f);li(f);li(f);e=Ae(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-6>>>0>=8){dc(f,20);break a}if((e<<24)-1610612736>>24<=-1){dc(f,20);break a}if(g>>>0>h>>>0){dc(f,20);break a}if(!(Ae(f)&1)){dc(f,34);break a}if(!Dr(f)){break a}if(!uw(f)){break a}if(!tw(f)){break a}c:{d:{if((Lg(f)|0)==3){while(1){P=(p+1018|0)+b|0,Q=Lg(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!vw(p+1018|0)){dc(f,20);break c}g=sw(f);e=Td(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=Lg(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=sw(f);v[f+24>>2]=b;b=Td(f,b<<2);v[f+28>>2]=b;e=v[f+24>>2];if(!(b?0:(e|0)>=1)){e:{if((e|0)>0){while(1){g=sw(f);b=Td(f,g+1|0);h=i<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=Lg(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;i=i+1|0;if((i|0)<v[f+24>>2]){continue}break}}if(!(Lg(f)&1)){dc(f,20);break c}LG(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=tw(f);LG(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!uw(f)){break a}if(!MG(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){g=e<<24;h=1;while(1){g=g>>31&79764919^g<<1;if((h|0)!=8){h=h+1|0;continue}break}v[(e<<2)+457184>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((Lg(f)|0)==5){while(1){P=(p+1018|0)+b|0,Q=Lg(f),t[P|0]=Q;b=b+1|0;if((b|0)!=6){continue}break}if(!vw(p+1018|0)){dc(f,20);break c}b=jc(f,8)+1|0;v[f+120>>2]=b;b=Td(f,B(b,2096));v[f+124>>2]=b;if(!b){dc(f,3);break c}Rb(b,0,B(v[f+120>>2],2096));f:{g:{if(v[f+120>>2]>=1){while(1){b=v[f+124>>2];if((jc(f,8)&255)!=66){dc(f,20);break c}if((jc(f,8)&255)!=67){dc(f,20);break c}if((jc(f,8)&255)!=86){dc(f,20);break c}g=b+B(M,2096)|0;P=g,Q=jc(f,8)&255|jc(f,8)<<8,v[P>>2]=Q;P=g,Q=jc(f,8)&255|(jc(f,8)<<8&65280|jc(f,8)<<16),v[P+4>>2]=Q;q=g+4|0;e=g;h=jc(f,1);b=0;h:{if(h){break h}b=jc(f,1)}t[e+23|0]=b;if(!(v[g>>2]|!v[q>>2])){dc(f,20);break c}e=v[q>>2];i:{if(b&255){e=Im(f,e);break i}e=Td(f,e);v[g+8>>2]=e}if(!e){dc(f,3);break c}j:{if(!h){b=0;k=0;i=v[q>>2];if((i|0)<=0){break j}while(1){k:{l:{if(w[g+23|0]){if(!jc(f,1)){break l}}h=jc(f,5)+1|0;t[b+e|0]=h;if((h&255)!=32){k=k+1|0;break k}dc(f,20);break c}t[b+e|0]=255}b=b+1|0;i=v[q>>2];if((b|0)<(i|0)){continue}break}break j}h=jc(f,5);k=0;b=0;i=v[q>>2];if((i|0)<1){break j}while(1){o=jc(f,ml(i-b|0));h=h+1|0;if((h|0)>=32){dc(f,20);break c}i=b+o|0;if((i|0)>v[q>>2]){dc(f,20);break c}Rb(b+e|0,h,o);b=i;i=v[q>>2];if((b|0)<(i|0)){continue}break}}m:{n:{if(w[g+23|0]){if(i>>2>(k|0)){break n}b=g;h=f;if(v[f+16>>2]<(i|0)){v[f+16>>2]=i;i=v[q>>2]}k=b;b=Td(h,i);v[k+8>>2]=b;if(!b){dc(f,3);break c}lc(b,e,v[q>>2]);ki(f,e,v[q>>2]);e=v[g+8>>2];t[g+23|0]=0}h=0;b=0;i=0;k=v[q>>2];if((k|0)>=1){while(1){i=((w[b+e|0]-11&255)>>>0<244)+i|0;b=b+1|0;if((k|0)!=(b|0)){continue}break}}v[g+2092>>2]=i;b=Td(f,k<<2);v[g+32>>2]=b;if(b){i=g+2092|0;break m}dc(f,3);break c}v[g+2092>>2]=k;i=g+2092|0;o:{if(!k){h=0;break o}b=Td(f,k);v[g+8>>2]=b;if(!b){dc(f,3);break c}b=Im(f,v[i>>2]<<2);v[g+32>>2]=b;if(!b){dc(f,3);break c}h=Im(f,v[i>>2]<<2);if(h){break o}dc(f,3);break c}b=v[q>>2]+(v[i>>2]<<3)|0;if(b>>>0<=y[f+16>>2]){break m}v[f+16>>2]=b}k=g;o=e;r=v[q>>2];j=h;l=0;b=jb-128|0;jb=b;A=Rb(b,0,128);p:{q:{r:{s:{if((r|0)<1){break s}while(1){if(w[l+o|0]!=255){break s}l=l+1|0;if((r|0)!=(l|0)){continue}break}break r}if((l|0)!=(r|0)){break q}}b=1;if(!v[k+2092>>2]){break p}ha(52010,50496,1088,52033);L()}b=l+o|0;CG(k,0,l,0,w[b|0],j);m=w[b|0];if(m){b=1;while(1){v[A+(b<<2)>>2]=1<<32-b;n=(b|0)==(m|0);b=b+1|0;if(!n){continue}break}}I=1;n=l+1|0;if((r|0)<=(n|0)){b=1;break p}t:{u:{v:{while(1){w:{l=n+o|0;m=w[l|0];x:{if((m|0)==255){break x}b=m;if(!b){break t}while(1){K=A+(b<<2)|0;F=v[K>>2];if(!F){F=(b|0)>1;b=b-1|0;if(F){continue}break t}break}if(b>>>0>=32){break w}v[K>>2]=0;CG(k,kl(F),n,I,m,j);I=I+1|0;l=w[l|0];if((l|0)==(b|0)){break x}if(l>>>0>31){break v}if((b|0)>=(l|0)){break x}while(1){m=A+(l<<2)|0;if(v[m>>2]){break u}v[m>>2]=F+(1<<32-l);l=l-1|0;if((l|0)>(b|0)){continue}break}}b=1;n=n+1|0;if((r|0)!=(n|0)){continue}break p}break}ha(52051,50496,1111,52033);L()}ha(52068,50496,1116,52033);L()}ha(52095,50496,1118,52033);L()}b=0}jb=A+128|0;if(!b){if(w[g+23|0]){ki(f,h,0)}dc(f,20);break c}b=v[i>>2];if(b){b=Td(f,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){dc(f,3);break c}b=Td(f,(v[i>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){dc(f,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;j=e;m=h;l=0;n=0;y:{b=g;if(w[b+23|0]){n=v[b+2092>>2];if((n|0)<=0){break y}while(1){k=l<<2;P=k+v[b+2084>>2]|0,Q=kl(v[k+v[b+32>>2]>>2]),v[P>>2]=Q;l=l+1|0;n=v[b+2092>>2];if((l|0)<(n|0)){continue}break}break y}if(v[b+4>>2]>=1){while(1){if(BG(b,w[j+l|0])){P=v[b+2084>>2]+(n<<2)|0,Q=kl(v[v[b+32>>2]+(l<<2)>>2]),v[P>>2]=Q;n=n+1|0}l=l+1|0;if((l|0)<v[b+4>>2]){continue}break}}if(v[b+2092>>2]==(n|0)){break y}ha(52113,50496,1185,52136);L()}nG(v[b+2084>>2],n,2302);v[v[b+2084>>2]+(v[b+2092>>2]<<2)>>2]=-1;z:{n=w[b+23|0];F=v[b+(n?2092:4)>>2];if((F|0)<1){break z}k=0;while(1){A:{o=k;l=b;if(n&255){o=v[m+(k<<2)>>2]}K=w[j+o|0];B:{if(!BG(l,K)){break B}N=k<<2;o=kl(v[N+v[b+32>>2]>>2]);r=v[b+2084>>2];l=0;n=v[b+2092>>2];if((n|0)>=2){while(1){A=n>>>1|0;O=A+l|0;I=o>>>0<y[r+(O<<2)>>2];l=I?l:O;n=I?A:n-A|0;if((n|0)>1){continue}break}}n=l<<2;if((o|0)!=v[n+r>>2]){break A}if(w[b+23|0]){v[n+v[b+2088>>2]>>2]=v[m+N>>2];t[v[b+8>>2]+l|0]=K;break B}v[n+v[b+2088>>2]>>2]=k}k=k+1|0;if((F|0)==(k|0)){break z}n=w[b+23|0];continue}break}ha(52159,50496,1215,52136);L()}}if(w[g+23|0]){ki(f,h,v[i>>2]<<2);ki(f,v[g+32>>2],v[i>>2]<<2);ki(f,e,v[q>>2]);v[g+32>>2]=0}b=g;Rb(b+36|0,255,2048);e=v[b+(w[b+23|0]?2092:4)>>2];if((e|0)>=1){e=(e|0)<32767?e:32767;o=(e|0)>1?e:1;k=v[b+8>>2];e=0;while(1){C:{if(w[e+k|0]>10){break C}D:{if(w[b+23|0]){h=kl(v[v[b+2084>>2]+(e<<2)>>2]);break D}h=v[v[b+32>>2]+(e<<2)>>2]}if(h>>>0>1023){break C}while(1){u[(b+(h<<1)|0)+36>>1]=e;k=v[b+8>>2];h=(1<<w[k+e|0])+h|0;if(h>>>0<1024){continue}break}}e=e+1|0;if((o|0)!=(e|0)){continue}break}}b=jc(f,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){dc(f,20);break c}if(b){P=g,R=KG(jc(f,32)),z[P+12>>2]=R;P=g,R=KG(jc(f,32)),z[P+16>>2]=R;P=g,Q=jc(f,4)+1|0,t[P+20|0]=Q;P=g,Q=jc(f,1),t[P+22|0]=Q;h=v[g>>2];k=v[q>>2];E:{if(w[g+21|0]==1){G=H(qw(+C(C(vo(+C(k|0)))/C(h|0))));F:{if(D(G)<2147483648){b=~~G;break F}b=-2147483648}e=b;G=H(kw(+C(C(b|0)+C(1)),h));G:{if(D(G)<2147483648){b=~~G;break G}b=-2147483648}b=e+((b|0)<=(k|0))|0;E=C(b|0);H:{if(!(kw(+C(E+C(1)),h)<=+(k|0))){G=H(kw(+E,h));I:{if(D(G)<2147483648){e=~~G;break I}e=-2147483648}b=(e|0)>(k|0)?-1:b;break H}b=-1}if((b|0)>-1){break E}dc(f,20);break c}b=B(h,k)}v[g+24>>2]=b;if(!b){dc(f,20);break c}e=Im(f,b<<1);if(!e){break f}b=0;h=v[g+24>>2];if((h|0)>0){while(1){h=jc(f,w[g+20|0]);if((h|0)==-1){ki(f,e,v[g+24>>2]<<1);dc(f,20);break c}u[e+(b<<1)>>1]=h;b=b+1|0;h=v[g+24>>2];if((b|0)<(h|0)){continue}break}}J:{if(w[g+21|0]==1){k=w[g+23|0];K:{if(k){b=v[i>>2];if(b){break K}break J}b=v[q>>2]}b=Td(f,B(v[g>>2],b)<<2);v[g+28>>2]=b;if(!b){ki(f,e,v[g+24>>2]<<1);dc(f,3);break c}l=v[(k?i:q)>>2];if((l|0)>=1){q=g+2088|0;E=C(0);o=0;while(1){i=o;i=k?v[v[q>>2]+(i<<2)>>2]:i;b=1;j=0;L:{h=v[g>>2];if((h|0)<1){break L}while(1){J=C(C(z[g+12>>2]+E)+C(z[g+16>>2]*C(x[e+(((i>>>0)/(b>>>0)>>>0)%y[g+24>>2]<<1)>>1])));z[v[g+28>>2]+(B(h,o)+j<<2)>>2]=J;E=w[g+22|0]?J:E;h=v[g>>2];j=j+1|0;if((h|0)<=(j|0)){break L}m=v[g+24>>2];Fma(m,0,b,0);if(!mb){b=B(b,m);continue}else{ki(f,e,m<<1);dc(f,20);break c}}}o=o+1|0;if((l|0)!=(o|0)){continue}break}}t[g+21|0]=2;h=v[g+24>>2];break J}b=Td(f,h<<2);v[g+28>>2]=b;h=v[g+24>>2];if(!b){break g}if((h|0)<1){break J}E=C(z[g+12>>2]+C(z[g+16>>2]*C(x[e>>1])));z[b>>2]=E;b=1;h=v[g+24>>2];if((h|0)<=1){break J}J=C(0);while(1){J=w[g+22|0]?E:J;E=C(C(z[g+12>>2]+J)+C(z[g+16>>2]*C(x[e+(b<<1)>>1])));z[v[g+28>>2]+(b<<2)>>2]=E;b=b+1|0;h=v[g+24>>2];if((b|0)<(h|0)){continue}break}}ki(f,e,h<<1)}M=M+1|0;if((M|0)<v[f+120>>2]){continue}break}}M:{e=jc(f,6)+1&255;if(!e){break M}b=1;while(1){if(!jc(f,16)){if((b|0)==(e|0)){break M}b=b+1|0;continue}break}dc(f,20);break c}b=jc(f,6)+1|0;v[f+128>>2]=b;b=Td(f,B(b,1596));v[f+260>>2]=b;if(b){o=0;if(v[f+128>>2]<=0){break d}k=0;N:while(1){b=jc(f,16);u[((o<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){dc(f,20);break c}if(!b){e=v[f+260>>2]+B(o,1596)|0;P=e,Q=jc(f,8),t[P|0]=Q;P=e,Q=jc(f,16),u[P+2>>1]=Q;P=e,Q=jc(f,16),u[P+4>>1]=Q;P=e,Q=jc(f,6),t[P+6|0]=Q;P=e,Q=jc(f,8),t[P+7|0]=Q;b=(jc(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){P=b+g|0,Q=jc(f,8),t[P|0]=Q;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}dc(f,4);break c}m=v[f+260>>2]+B(o,1596)|0;g=jc(f,5);t[m|0]=g;b=-1;i=0;e=0;if(g&255){while(1){g=jc(f,4);t[(e+m|0)+1|0]=g;g=g&255;b=(b|0)<(g|0)?g:b;e=e+1|0;if(e>>>0<w[m|0]){continue}break}while(1){g=i+m|0;P=g,Q=jc(f,3)+1|0,t[P+33|0]=Q;e=jc(f,2);t[g+49|0]=e;O:{if(e&255){e=jc(f,8);t[g+65|0]=e;if(v[f+120>>2]<=(e&255)){dc(f,20);break c}if(w[g+49|0]==31){break O}}e=0;while(1){P:{h=jc(f,8)-1|0;u[((m+(i<<4)|0)+(e<<1)|0)+82>>1]=h;if(v[f+120>>2]<=h<<16>>16){break P}e=e+1|0;if((e|0)<1<<w[g+49|0]){continue}break O}break}dc(f,20);break c}e=(b|0)!=(i|0);i=i+1|0;if(e){continue}break}}j=2;P=m,Q=jc(f,2)+1|0,t[P+1588|0]=Q;b=jc(f,4);v[m+1592>>2]=2;h=0;u[m+338>>1]=0;t[m+1589|0]=b;u[m+340>>1]=1<<b;i=m+1592|0;e=w[m|0];Q:{if(e){b=m+1589|0;while(1){g=m+w[(h+m|0)+1|0]|0;if(w[g+33|0]){e=1;while(1){j=jc(f,w[b|0]);u[(m+(v[i>>2]<<1)|0)+338>>1]=j;j=v[i>>2]+1|0;v[i>>2]=j;if(w[g+33|0]>e>>>0){e=e+1|0;continue}break}e=w[m|0]}h=h+1|0;if(h>>>0<(e&255)>>>0){continue}break}if((j|0)<1){break Q}}e=0;while(1){b=x[(m+(e<<1)|0)+338>>1];g=(p+16|0)+(e<<2)|0;u[g+2>>1]=e;u[g>>1]=b;e=e+1|0;j=v[i>>2];if((e|0)<(j|0)){continue}break}}h=m+338|0;nG(p+16|0,j,2301);e=0;j=v[i>>2];b=j-1|0;b=(b|0)>0?b:0;while(1){if((b|0)==(e|0)){e=0;R:{if((j|0)<=0){break R}while(1){t[(e+m|0)+838|0]=w[((p+16|0)+(e<<2)|0)+2|0];e=e+1|0;j=v[i>>2];if((e|0)<(j|0)){continue}break}e=2;if((j|0)<=2){break R}while(1){v[p+12>>2]=0;v[p+8>>2]=0;b=h;j=0;g=e;if((e|0)>=1){q=b+(g<<1)|0;r=-1;n=65536;while(1){A=b+(j<<1)|0;l=x[A>>1];if(!((r|0)>=(l|0)|x[q>>1]<=l>>>0)){v[p+12>>2]=j;l=x[A>>1];r=l}if(!((l|0)>=(n|0)|x[q>>1]>=l>>>0)){v[p+8>>2]=j;n=x[A>>1]}j=j+1|0;if((g|0)!=(j|0)){continue}break}}b=m+(e<<1)|0;t[b+1088|0]=v[p+12>>2];t[b+1089|0]=v[p+8>>2];e=e+1|0;j=v[i>>2];if((e|0)<(j|0)){continue}break}}k=(j|0)>(k|0)?j:k;o=o+1|0;if((o|0)<v[f+128>>2]){continue N}o=k<<1;break d}g=x[(p+16|0)+(e<<2)>>1];e=e+1|0;if((g|0)!=x[(p+16|0)+(e<<2)>>1]){continue}break}break}dc(f,20);break c}dc(f,3);break c}ki(f,e,h<<1);dc(f,3);break c}dc(f,3);break c}dc(f,20);break c}dc(f,3);break c}dc(f,3);break c}dc(f,3);break c}dc(f,20);break c}b=jc(f,6)+1|0;v[f+264>>2]=b;b=Td(f,B(b,24));v[f+396>>2]=b;if(!b){dc(f,3);break c}i=0;Rb(b,0,B(v[f+264>>2],24));S:{if(v[f+264>>2]>=1){while(1){b=v[f+396>>2];e=jc(f,16);u[((i<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){dc(f,20);break c}j=b+B(i,24)|0;P=j,Q=jc(f,24),v[P>>2]=Q;b=jc(f,24);v[j+4>>2]=b;if(b>>>0<y[j>>2]){dc(f,20);break c}P=j,Q=jc(f,24)+1|0,v[P+8>>2]=Q;P=j,Q=jc(f,6)+1|0,t[P+12|0]=Q;b=jc(f,8);t[j+13|0]=b;T:{U:{if(v[f+120>>2]>(b&255)){b=0;if(w[j+12|0]){break U}e=0;break T}dc(f,20);break c}while(1){g=jc(f,3);e=(p+16|0)+b|0;h=0;V:{if(!jc(f,1)){break V}h=jc(f,5)<<3}t[e|0]=h+g;b=b+1|0;e=w[j+12|0];if(b>>>0<e>>>0){continue}break}}b=Td(f,e<<4);v[j+20>>2]=b;if(!b){break S}if(w[j+12|0]){h=0;while(1){e=w[(p+16|0)+h|0];b=0;while(1){W:{if(e>>>b&1){g=jc(f,8);m=b<<1;k=h<<4;u[m+(k+v[j+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[m+(k+v[j+20>>2]|0)>>1]){break W}dc(f,20);break c}u[(v[j+20>>2]+(h<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}h=h+1|0;if(h>>>0<w[j+12|0]){continue}break}}b=Td(f,v[(v[f+124>>2]+B(w[j+13|0],2096)|0)+4>>2]<<2);v[j+16>>2]=b;if(!b){dc(f,3);break c}k=0;Rb(b,0,v[(v[f+124>>2]+B(w[j+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];e=w[j+13|0];if(v[(b+B(e,2096)|0)+4>>2]>0){while(1){g=v[B(e,2096)+b>>2];b=Td(f,g);h=k<<2;v[h+v[j+16>>2]>>2]=b;X:{e=v[h+v[j+16>>2]>>2];if(e){if((g|0)<1){break X}b=g-1|0;t[e+b|0]=(k>>>0)%w[j+12|0];e=k;if((g|0)==1){break X}while(1){g=b-1|0;m=w[j+12|0];e=(e|0)/(m|0)|0;t[g+v[h+v[j+16>>2]>>2]|0]=(e|0)%(m|0);m=(b|0)>1;b=g;if(m){continue}break}break X}dc(f,3);break c}k=k+1|0;b=v[f+124>>2];e=w[j+13|0];if((k|0)<v[(b+B(e,2096)|0)+4>>2]){continue}break}}i=i+1|0;if((i|0)<v[f+264>>2]){continue}break}}b=jc(f,6)+1|0;v[f+400>>2]=b;b=Td(f,B(b,40));v[f+404>>2]=b;if(!b){dc(f,3);break c}h=0;Rb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>=1){while(1){b=v[f+404>>2];if(jc(f,16)){dc(f,20);break c}g=b+B(h,40)|0;b=Td(f,B(v[f+4>>2],3));v[g+4>>2]=b;if(!b){dc(f,3);break c}b=g;if(jc(f,1)){e=jc(f,4)+1|0}else{e=1}t[b+8|0]=e;Y:{if(jc(f,1)){b=jc(f,8)+1|0;u[g>>1]=b;Z:{e=v[f+4>>2];b=b&65535;if((e|0)>=(b|0)){i=0;if(b){break Z}break Y}dc(f,20);break c}while(1){e=jc(f,ml(e-1|0));b=B(i,3);t[b+v[g+4>>2]|0]=e;e=jc(f,ml(v[f+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=e;e=v[f+4>>2];b=b+v[g+4>>2]|0;k=w[b|0];if((e|0)<=(k|0)){dc(f,20);break c}b=w[b+1|0];if((b|0)>=(e|0)){dc(f,20);break c}if((b|0)!=(k|0)){i=i+1|0;if(i>>>0>=x[g>>1]){break Y}continue}break}dc(f,20);break c}u[g>>1]=0}if(jc(f,2)){dc(f,20);break c}i=v[f+4>>2];_:{$:{b=w[g+8|0];if(b>>>0<=1){e=0;if((i|0)>0){while(1){t[(v[g+4>>2]+B(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<v[f+4>>2]){continue}break}b=w[g+8|0]}if(!(b&255)){break _}break $}e=0;if((i|0)<=0){break $}while(1){aa:{b=jc(f,4);i=B(e,3);t[(i+v[g+4>>2]|0)+2|0]=b;if(w[(i+v[g+4>>2]|0)+2|0]>=w[g+8|0]){break aa}e=e+1|0;if((e|0)<v[f+4>>2]){continue}break $}break}dc(f,20);break c}b=0;while(1){jc(f,8);i=b+g|0;e=i;P=e,Q=jc(f,8),t[P+9|0]=Q;i=jc(f,8);t[e+24|0]=i;if(v[f+128>>2]<=w[e+9|0]){dc(f,20);break c}if(v[f+264>>2]>(i&255)){b=b+1|0;if(b>>>0>=w[g+8|0]){break _}continue}break}dc(f,20);break c}h=h+1|0;if((h|0)<v[f+400>>2]){continue}break}}b=jc(f,6)+1|0;v[f+408>>2]=b;e=0;ba:{if((b|0)<=0){break ba}while(1){b=B(e,6)+f|0;P=b,Q=jc(f,1),t[P+412|0]=Q;P=b,Q=jc(f,16),u[P+414>>1]=Q;P=b,Q=jc(f,16),u[P+416>>1]=Q;g=jc(f,8);t[b+413|0]=g;if(x[b+414>>1]){dc(f,20);break c}if(x[b+416>>1]){dc(f,20);break c}if(v[f+400>>2]>(g&255)){e=e+1|0;if((e|0)>=v[f+408>>2]){break ba}continue}break}dc(f,20);break c}JG(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>=1){while(1){e=(b<<2)+f|0;P=e,Q=Td(f,v[f+116>>2]<<2),v[P+800>>2]=Q;P=e,Q=Td(f,v[f+116>>2]<<1&2147483646),v[P+928>>2]=Q;g=Td(f,o);v[e+996>>2]=g;h=v[e+800>>2];if(!(g?!(!h|!v[e+928>>2]):0)){dc(f,3);break c}Rb(h,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!IG(f,0,v[f+112>>2])){break a}if(!IG(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];h=v[f+116>>2];v[f+108>>2]=h;g=(h|0)/2|0;r=f;k=h<<1&2147483646;o=k;m=v[f+264>>2];e=4;ca:{if((m|0)<1){break ca}l=v[f+396>>2];j=0;i=0;while(1){h=l+B(i,24)|0;q=v[h+4>>2];e=g>>>0>q>>>0?q:g;q=v[h>>2];h=(e-(g>>>0>q>>>0?q:g)>>>0)/y[h+8>>2]|0;j=(h|0)>(j|0)?h:j;i=i+1|0;if((m|0)!=(i|0)){continue}break}e=(j<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<k>>>0?o:e;v[r+12>>2]=e;da:{ea:{if(!v[f+80>>2]){break ea}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break da}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break ea}dc(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}ha(51940,50496,4182,51996);L()}dc(f,3)}b=0}jb=p+1024|0;fa:{ga:{if(!b){v[d>>2]=v[s+104>>2]?1:v[s+108>>2];break ga}b=Td(s+8|0,1512);if(b){P=c,Q=v[lc(b,s+8|0,1512)+32>>2]-a|0,v[P>>2]=Q;v[d>>2]=0;break fa}NG(s+8|0)}b=0}jb=s+1520|0;return b|0}function Bla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;d=jb-288|0;jb=d;Jc(b);g=jb-16|0;jb=g;i=d+264|0;Jt(g+8|0,i);f=b;l=Hb(g+8|0);j=nc(b,ac(g,g+8|0));if((l|0)==(j|0)){$b(f,Hb(g+8|0))}jb=g+16|0;f=(j|0)==(l|0);if(!f){OS(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!f){break u}if(!RS(d+264|0)){break u}if(!c){e=1;break u}Hd(a,1024);wi(a);v[a+480208>>2]=v[a+480208>>2]|12;wg(a+1074308|0,21);if(w[d+280|0]|w[d+281|0]<<8){e=w[d+280|0]|w[d+281|0]<<8;v[a+480204>>2]=B((e<<8|e>>>8)&65535,1e4)}if(w[d+278|0]|w[d+279|0]<<8){e=w[d+278|0]|w[d+279|0]<<8;v[a+480196>>2]=(e<<8|e>>>8)&65535}if(!w[d+274|0]){lj(a,1)}e=d+264|4;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);sA(b,a+1304400|0,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))-14|0);b=Lk(d+160|0,b);v[114578]=0;U(579,d+248|0,b|0,1);e=v[114578];v[114578]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((e|0)!=1){Bb(b);v[114578]=0;U(580,d+160|0,d+248|0,1395544366);b=v[114578];v[114578]=0;if((b|0)==1){break E}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break L}if(!b){break F}v[114578]=0;b=T(485,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break L}v[114578]=0;e=T(485,d+160|0)|0;f=v[114578];v[114578]=0;N:{if((f|0)==1){break N}v[114578]=0;Q(340,d+160|0,4)|0;f=v[114578];v[114578]=0;if((f|0)==1){break N}f=a+484360|0;g=Vb(f);v[114578]=0;ea(581,g|0,d+160|0,b|0,65535,65535)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break M}}break L}e=P()|0;O()|0;Bb(b);break a}Oe(Vb(f),e);Bb(d+160|0);v[114578]=0;U(580,d+160|0,d+248|0,1346458708);b=v[114578];v[114578]=0;if((b|0)==1){break K}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}if(!b){break H}v[114578]=0;b=T(485,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}u[a+480188>>1]=b;if((b-1&65535)>>>0>31){break H}v[114578]=0;b=T(485,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}v[114578]=0;p=a+484344|0;R(403,p|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break J}v[114578]=0;l=T(494,d+160|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break J}switch(l-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}e=P()|0;O()|0;Bb(d+160|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+160|0);break b}if(!l){break G}}Bb(d+160|0);break A}Bb(d+160|0);v[114578]=0;U(580,d+232|0,d+248|0,1398157625);b=v[114578];v[114578]=0;if((b|0)==1){break D}v[114578]=0;b=T(490,d+232|0)|0;e=v[114578];v[114578]=0;O:{if((e|0)==1){break O}if(!b){break B}v[114578]=0;Q(340,d+232|0,2)|0;b=v[114578];v[114578]=0;if((b|0)==1){break O}v[114578]=0;e=T(494,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}b=a;f=b;r=(+(e>>>0)*2.3283064365386963e-10+ +(y[b+480204>>2]/1e4>>>0))*1e4;P:{if(r<4294967296&r>=0){b=~~r>>>0;break P}b=0}v[f+480204>>2]=b;v[114578]=0;Q(582,d+232|0,d+160|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}e=(d+160|0)+(b<<1)|0;e=w[e|0]|w[e+1|0]<<8;v[114578]=0;v[d+96>>2]=(e<<8|e>>>8)&65535;v[d+80>>2]=180;e=Q(464,d+96|0,d+80|0)|0;f=v[114578];v[114578]=0;Q:{if((f|0)==1){break Q}e=v[e>>2];v[114578]=0;e=e-90|0;f=e>>31;e=Gg(460,Gma(e<<7|45,f<<7|e>>>25,90,0),mb);f=v[114578];v[114578]=0;if((f|0)==1){break Q}u[((b<<5)+a|0)+480284>>1]=e+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}Bb(d+160|0);break A}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}v[114578]=0;Q(340,d+232|0,16)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=Q(258,d+232|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(b){v[114578]=0;b=T(485,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;u[d+96>>1]=b;u[d+80>>1]=256;b=Q(478,d+96|0,d+80|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[114578]=0;Q(340,d+232|0,128)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=Q(582,d+232|0,d+96|0)|0;e=v[114578];v[114578]=0;R:{if((e|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break R}e=(d+96|0)+(b<<1)|0;e=w[e|0]|w[e+1|0]<<8;v[114578]=0;v[d+80>>2]=(e<<8|e>>>8)&65535;v[d+56>>2]=128;e=Q(464,d+80|0,d+56|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[e>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break R}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}Bb(d+232|0);v[114578]=0;U(580,d+160|0,d+248|0,1413830740);b=v[114578];v[114578]=0;S:{T:{if((b|0)!=1){v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(!b){break S}v[114578]=0;Q(583,d+160|0,d+96|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}if((w[d+106|0]|w[d+107|0]<<8)!=65535){break T}v[114578]=0;Q(340,d+160|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break T}break d}e=P()|0;O()|0;break b}v[114578]=0;b=T(332,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;aa(584,a+1304424|0,d+160|0,b|0,2)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}}Bb(d+160|0);v[114578]=0;U(580,d+96|0,d+248|0,1229869908);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;b=T(490,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if(b){v[114578]=0;b=T(485,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}U:{e=b<<16>>16;f=e&32767;if(f>>>0>3999){break U}v[114578]=0;b=Q(258,d+96|0,B(f,(e>>>14&2)+50|0)|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break y}if(!b){break U}u[a+480190>>1]=f;g=a+480190|0;if(!f){break z}i=d+178|0;b=1;j=(e|0)>-1;V:{W:{while(1){X:{e=b;Y:{Z:{_:{if(!j){v[114578]=0;e=T(485,d+96|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break _}e=e+1|0}v[114578]=0;u[d+56>>1]=e;Q(585,d+96|0,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if((x[d+56>>1]-1&65535)>>>0>3998){break Y}v[114578]=0;e=Q(454,g|0,d+56|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break Z}}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}u[a+480190>>1]=x[e>>1];h=x[d+56>>1];e=w[d+282|0]|w[d+283|0]<<8|(w[d+284|0]<<16|w[d+285|0]<<24);v[114578]=0;X(586,d+160|0,(B(h,104)+a|0)+484380|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24),l|0);e=v[114578];v[114578]=0;if((e|0)==1){break X}v[114578]=0;U(587,d+80|0,2,i|0);e=v[114578];v[114578]=0;if((e|0)==1){break W}v[114578]=0;R(417,d+232|0,d+80|0);e=v[114578];v[114578]=0;if((e|0)==1){break W}v[114578]=0;Q(371,((x[d+56>>1]<<5)+a|0)+946300|0,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break V}yb(d+232|0)}e=b&65535;b=b+1|0;if(e>>>0<f>>>0){continue}break z}break}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;yb(d+232|0);break f}Bb(d+96|0);break A}break w}e=P()|0;O()|0;break f}e=0;break v}v[114578]=0;b=T(485,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break x}}e=P()|0;O()|0;break f}if((b|0)==4){b=x[g>>1];v[114578]=0;u[d+160>>1]=b;u[d+232>>1]=255;b=Q(478,d+160|0,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}u[a+480192>>1]=x[b>>1];v[114578]=0;U(580,d+232|0,d+248|0,1229278806);b=v[114578];v[114578]=0;if((b|0)==1){break i}g=d+80|4;i=d+80|3;j=d+80|5;h=d+80|7;while(1){v[114578]=0;b=Q(258,d+96|0,15)|0;e=v[114578];v[114578]=0;$:{if((e|0)!=1){aa:{if(b){v[114578]=0;Q(588,d+96|0,d+80|0)|0;b=v[114578];v[114578]=0;ba:{if((b|0)!=1){b=w[d+80|0]|w[d+81|0]<<8;if(x[a+480192>>1]<=((b<<8|b>>>8)&65535)>>>0){continue}b=w[d+80|0]|w[d+81|0]<<8;b=B((b<<8|b>>>8)&65535,104)+a|0;t[b+484524|0]=w[d+88|0];e=w[h|0];t[b+484523|0]=255;t[b+484525|0]=e;b=w[d+80|0]|w[d+81|0]<<8;e=w[d+80|0]|w[d+81|0]<<8;v[114578]=0;e=W(456,a|0,(b<<8|b>>>8)+1&65535,(e<<8|e>>>8)+1&65535)|0;b=v[114578];v[114578]=0;if((b|0)==1){break aa}if(!e){continue}b=w[j|0]|w[j+1|0]<<8;v[114578]=0;u[d+160>>1]=b<<8|b>>>8;u[d+56>>1]=4095;b=Q(478,d+160|0,d+56|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}v[e>>2]=x[b>>1];if(w[i|0]==255){continue}b=w[i|0];v[114578]=0;b=Q(256,d+232|0,B(b,34)+2|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}if(!b){continue}v[114578]=0;Q(589,d+232|0,d+160|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break aa}t[e+60|0]=w[e+60|0]|1;b=w[d+160|0]|w[d+161|0]<<8;v[d+56>>2]=(b<<8|b>>>8)&65535;v[114578]=0;v[d+76>>2]=3;v[d+64>>2]=240;v[d+60>>2]=16;v[d+72>>2]=d+56;b=v[d+76>>2];v[d+8>>2]=v[d+72>>2];v[d+12>>2]=b;b=T(590,d+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break aa}v[114578]=0;f=e+48|0;R(591,f|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break aa}b=0;if(Kb(f)){break ba}break $}break aa}while(1){ca:{t[d+56|0]=64;o=(d+160|0)+(b<<1)|0;n=w[o+2|0];v[114578]=0;t[d+48|0]=n;n=Q(393,d+56|0,d+48|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break ca}n=w[n|0];E=Pb(f,b),F=n,t[E+2|0]=F;o=w[o+3|0];E=Pb(f,b),F=o,u[E>>1]=F;b=b+1|0;if(Kb(f)>>>0>b>>>0){continue}break $}break}break aa}Bb(d+232|0);break w}}e=P()|0;O()|0;Bb(d+232|0);break f}if(w[g|0]!=255){t[e+60|0]=w[e+60|0]|4;b=w[g|0];t[e+63|0]=b;t[e- -64|0]=b}if(nd(f)){continue}t[e+60|0]=w[e+60|0]|2;b=Kb(f)-1|0;t[e+61|0]=b;t[e+62|0]=b;continue}}}Bb(d+96|0);v[114578]=0;U(592,d+96|0,d+248|0,1145131092);b=v[114578];v[114578]=0;if((b|0)==1){break j}E=d,F=bc(d+96|0),v[E+48>>2]=F;E=d,F=cc(d+96|0),v[E+40>>2]=F;if(Jb(d+48|0,d+40|0)){A=c&1;o=d+232|4;n=(l|0)!=841887798;C=(l|0)!=841887796;while(1){i=v[d+48>>2];v[114578]=0;Q(340,i|0,4)|0;b=v[114578];v[114578]=0;da:{ea:{fa:{if((b|0)!=1){v[114578]=0;e=T(485,i|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;j=T(485,i|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break m}j=n?j:(j>>>0)/y[a+480196>>2]|0;if(!A|e>>>0>255){break da}v[114578]=0;b=W(404,p|0,e|0,j|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}if(!b){break da}if(n){break ea}v[114578]=0;Q(340,i|0,4)|0;b=v[114578];v[114578]=0;if((b|0)==1){break m}h=0;if(!x[a+480188>>1]){break da}while(1){v[114578]=0;b=T(485,i|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break fa}v[114578]=0;U(343,d+160|0,i|0,b+(b&1)&65535);b=v[114578];v[114578]=0;if((b|0)==1){break n}v[d+232>>2]=0;v[d+236>>2]=0;f=0;ga:{while(1){v[114578]=0;b=Q(258,d+160|0,6)|0;g=v[114578];v[114578]=0;if((g|0)==1){break o}if(!(b&y[d+232>>2]<j>>>0)){break ga}b=_b(p,e);v[114578]=0;b=W(472,b|0,v[d+232>>2],h&65535)|0;g=v[114578];v[114578]=0;ha:{ia:{if((g|0)!=1){v[114578]=0;R(593,d+56|0,d+160|0);g=v[114578];v[114578]=0;if((g|0)==1){break o}g=dd(d+56|0);s=Bf(d+56|0);q=Sh(d+56|0);m=hc(d+56|0);D=d+61|0;k=t[d+56|0];if((k-1&255)>>>0>95){break ia}t[b|0]=k+13;if(!v[d+236>>2]){break ha}t[b+3|0]=19;v[114578]=0;v[d+80>>2]=15;k=Q(464,o|0,d+80|0)|0;z=v[114578];v[114578]=0;if((z|0)==1){break o}t[b+5|0]=w[k|0]|208;break ha}break o}if((k|0)>-1){break ha}if(v[d+236>>2]){t[b+3|0]=19;v[114578]=0;v[d+80>>2]=15;k=Q(464,o|0,d+80|0)|0;z=v[114578];v[114578]=0;if((z|0)!=1){t[b+5|0]=w[k|0]|192;break ha}break o}t[b|0]=254}if(w[g|0]){t[b+2|0]=1;v[114578]=0;t[d+80|0]=64;g=Q(393,g|0,d+80|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break o}t[b+4|0]=w[g|0]}g=w[s|0];if(g){t[b+1|0]=g}g=w[q|0];if(g|w[m|0]){t[b+3|0]=g;t[b+5|0]=w[m|0];v[114578]=0;Z(574,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break o}}b=w[D|0];if(b&128){v[114578]=0;g=T(389,d+160|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break o}b=g|b<<8&32512}g=v[a+480196>>2];v[114578]=0;f=b+f|0;U(594,d+80|0,f|0,g|0);b=v[114578];v[114578]=0;if((b|0)!=1){b=v[d+84>>2];v[d+232>>2]=v[d+80>>2];v[d+236>>2]=b;continue}break}break o}Bb(d+160|0);h=h+1|0;if(x[a+480188>>1]>(h&65535)>>>0){continue}break}break da}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}b=_b(p,e);v[114578]=0;b=W(472,b|0,0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}h=0;if(!j){break da}while(1){e=0;ja:{if(!x[a+480188>>1]){break ja}while(1){ka:{v[114578]=0;R(595,d+160|0,i|0);f=v[114578];v[114578]=0;if((f|0)==1){break ka}la:{if(!C){v[d+232>>2]=v[d+160>>2];m=dd(d+232|0);k=Bf(d+232|0);s=Sh(d+232|0);f=t[d+232|0];if((f|0)>=1){t[b|0]=(B((f&240)>>>4|0,12)+(f&15)|0)+12}g=b;f=w[m|0];q=f>>>2|0;if(q){t[b+2|0]=1;t[b+4|0]=q-1;f=w[m|0]}t[g+1|0]=f<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[s|0];break la}v[114578]=0;f=v[d+160>>2];v[d+36>>2]=f;v[d+20>>2]=f;R(596,d+20|0,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break ka}f=fc(d+160|0,0);t[b+1|0]=w[b+1|0]|w[f|0]&48}v[114578]=0;Z(574,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break ka}f=w[b+3|0];ma:{if(f>>>0>11){break ma}f=1<<f;na:{if(!(f&2240)){if(!(f&12)){break ma}if(!w[b+5|0]){break na}break ma}f=w[b+5|0];g=f&240;if(g){t[b+5|0]=g;break ma}if(f){break ma}}t[b+3|0]=0}b=b+6|0;e=e+1|0;if(x[a+480188>>1]>(e&65535)>>>0){continue}break ja}break}e=P()|0;O()|0;break k}h=h+1|0;if((h|0)!=(j|0)){continue}break}}Tf(d+48|0);if(Jb(d+48|0,d+40|0)){continue}break}}hd(d+96|0);v[114578]=0;U(580,d+160|0,d+248|0,1346458702);b=v[114578];v[114578]=0;if((b|0)==1){e=P()|0;O()|0;break b}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((e|0)!=1){if(b){f=Wb(d+96|0);b=0;Ca:{while(1){Da:{v[114578]=0;e=Q(258,d+160|0,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Da}if(!e){break Ca}if(Ce(p)>>>0<=b>>>0){break Ca}v[114578]=0;W(597,d+160|0,f|0,32)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Da}e=_b(p,b);v[114578]=0;Q(496,e|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Da}b=b+1|0;continue}break}e=P()|0;O()|0;yb(f);break Ba}yb(f)}Bb(d+160|0);v[114578]=0;U(580,d+160|0,d+248|0,1414679374);b=v[114578];v[114578]=0;if((b|0)==1){break Aa}v[114578]=0;b=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break wa}if(!b){break xa}f=Wb(d+96|0);b=0;while(1){v[114578]=0;e=Q(258,d+160|0,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break za}if(!e|x[a+480188>>1]<=b>>>0){break ya}v[114578]=0;W(597,d+160|0,f|0,32)|0;e=v[114578];v[114578]=0;if((e|0)==1){break za}v[114578]=0;Q(380,((b<<5)+a|0)+480289|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break za}b=b+1|0;continue}}e=P()|0;O()|0}Bb(d+160|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(f);break va}yb(f)}Bb(d+160|0);v[114578]=0;U(592,d+160|0,d+248|0,1145129300);b=v[114578];v[114578]=0;if((b|0)==1){break ua}E=d,F=bc(d+160|0),v[E+96>>2]=F;E=d,F=cc(d+160|0),v[E+232>>2]=F;if(Jb(d+96|0,d+232|0)){e=c&2;while(1){b=v[d+96>>2];v[114578]=0;c=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}if(!(!e|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=ad(d+80|0,f&1?16:8,f&64?2:1,1,0);v[114578]=0;W(402,f|0,c+484484|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break p}}Tf(d+96|0);if(Jb(d+96|0,d+232|0)){continue}break}}hd(d+160|0);b=gd(d+96|0);if((l|0)!=841887798){break sa}v[114578]=0;c=Q(2,d+160|0,12790)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ta}Gb(b,c);yb(c);break ra}e=P()|0;O()|0}Bb(d+160|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break q}v[114578]=0;U(580,d+160|0,d+248|0,1447383635);c=v[114578];v[114578]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{if((c|0)!=1){v[114578]=0;c=T(490,d+160|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break qa}if(!c){break Fa}v[114578]=0;e=T(494,d+160|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break Ka}v[114578]=0;c=Q(2,d+24|0,12810)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Ja}v[114578]=0;R(219,d+80|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ia}v[114578]=0;v[d+56>>2]=e>>>4;v[d+48>>2]=e&15;X(598,d+232|0,d+80|0,d+56|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ha}Gb(b,d+232|0);yb(d+232|0);Ib(d+80|0);break Ea}e=P()|0;O()|0;break q}e=P()|0;O()|0;break r}e=P()|0;O()|0;break r}e=P()|0;O()|0;break Ga}e=P()|0;O()|0;Ib(d+80|0)}yb(c);break r}v[114578]=0;c=Q(2,d+232|0,12832)|0;e=v[114578];v[114578]=0;if((e|0)==1){break t}Gb(b,c)}yb(c);Bb(d+160|0)}v[114578]=0;c=Q(2,d+160|0,12832)|0;e=v[114578];v[114578]=0;if((e|0)==1){break pa}Gb(a+1304436|0,c);yb(c);v[114578]=0;c=Q(2,d+160|0,12848)|0;e=v[114578];v[114578]=0;if((e|0)==1){break oa}Gb(a+1304448|0,c);yb(c);Gb(a+1304460|0,b);v[a+1304496>>2]=2;yb(b);e=1;break v}e=P()|0;O()|0;break r}e=P()|0;O()|0;break q}e=P()|0;O()|0;break q}$z(d+248|0)}jb=d+288|0;return e|0}e=P()|0;O()|0;break r}e=P()|0;O()|0;break k}Bb(d+160|0)}yb(b);break b}e=P()|0;O()|0;hd(d+160|0);break b}e=P()|0;O()|0;Bb(d+160|0);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0}hd(d+96|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0}Bb(d+96|0);break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+160|0);break b}e=P()|0;O()|0;Bb(d+232|0)}$z(d+248|0)}S(e|0);L()}function xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-528|0;jb=d;Jc(b);a:{if(!Bn(b,d+448|0)){break a}if(!MO(d+448|0)){break a}if(!Qb(b,id(LO(d+448|0),mb))){break a}b:{if(!c){break b}Hd(a,4);wi(a);v[a+1074368>>2]=4;l=gd(d+432|0);c:{d:{j=d+486|0;e:{if(!(qd(j,17536,20)|(w[d+508|0]|w[d+509|0]<<8|(w[d+510|0]<<16|w[d+511|0]<<24))!=276)){e=48;if((w[d+506|0]|w[d+507|0]<<8)>>>0<260){break e}v[114578]=0;f=W(625,d+465|0,0,20)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}e=f?1154:34;break e}if(!qd(j,17557,20)){e=1;break e}v[114578]=0;U(747,d+416|0,3,j|0);f=v[114578];v[114578]=0;f:{g:{h:{if((f|0)==1){break h}v[114578]=0;R(417,d+72|0,d+416|0);f=v[114578];v[114578]=0;if((f|0)==1){break h}v[114578]=0;U(13,d+144|0,4,d+72|0);f=v[114578];v[114578]=0;if((f|0)==1){break g}Gb(l,d+144|0);yb(d+144|0);yb(d+72|0);if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))!=1852141647|(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))!=542396493){break f}e=1048;break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;yb(d+72|0);break c}if(!qd(j,17587,12)){e=16;if((x[d+498>>1]|x[d+500>>1]<<16)==538976288&(x[d+502>>1]|x[d+504>>1]<<16)==538976288){break e}v[a+1074368>>2]=5;break e}if(!qd(j,17601,20)){e=48;break e}if(!qd(j,17622,15)){v[114578]=0;f=a+1074308|0;Q(480,f|0,54)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;Q(480,f|0,51)|0;f=v[114578];v[114578]=0;e=16;if((f|0)==1){break d}break e}if(!qd(j,17638,14)){v[114578]=0;Q(480,a+1074308|0,57)|0;f=v[114578];v[114578]=0;e=16;if((f|0)!=1){break e}break d}e=qd(j,17653,11)?16:256}v[114578]=0;s=d+465|0;U(747,d+72|0,3,s|0);f=v[114578];v[114578]=0;i:{if((f|0)==1){break i}v[114578]=0;R(417,d+144|0,d+72|0);f=v[114578];v[114578]=0;if((f|0)==1){break i}Gb(a+1304400|0,d+144|0);yb(d+144|0);v[a+480260>>2]=1;v[a+480264>>2]=31999;q=a+484360|0;Oe(Vb(q),w[d+514|0]|w[d+515|0]<<8);u[a+480188>>1]=w[d+516|0]|w[d+517|0]<<8;f=w[d+520|0]|w[d+521|0]<<8;v[114578]=0;u[d+144>>1]=f;u[d+72>>1]=255;f=Q(478,d+144|0,d+72|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){u[a+480192>>1]=x[f>>1];if(w[d+524|0]|w[d+525|0]<<8){v[a+480196>>2]=w[d+524|0]|w[d+525|0]<<8}if(w[d+526|0]|w[d+527|0]<<8){f=v[19814];F=a,G=Cd(B(w[d+526|0]|w[d+527|0]<<8,1e4),B(v[f+20>>2],1e4),B(v[f+24>>2],1e4)),v[F+480204>>2]=G}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+522|0]|w[d+523|0]<<8)<<4&16;f=(w[d+522|0]|w[d+523|0]<<8)<<3&32768;v[a+480208>>2]=f|v[a+480208>>2]&-32769;g=Vb(q);k=w[d+512|0]|w[d+513|0]<<8;v[114578]=0;ea(581,g|0,b|0,k|0,65535,65535)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}h=f>>>15|0?(e|0)==34?146:e:e;if(!(h&1024|(w[d+512|0]|w[d+513|0]<<8))){f=Vb(q);v[114578]=0;U(1032,f|0,1,0);f=v[114578];v[114578]=0;if((f|0)==1){break d}}f=w[d+508|0]|w[d+509|0]<<8|(w[d+510|0]<<16|w[d+511|0]<<24);v[114578]=0;Q(256,b|0,f+60|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}if((w[d+506|0]|w[d+507|0]<<8)>>>0>=260){v[114578]=0;U(1033,b|0,d+448|0,a|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}}t[d+415|0]=0;z=c&2;f=jb-16|0;jb=f;n=d+416|0;g=n;v[g>>2]=0;v[g+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(1055,g+8|0,f+12|0,f+8|0)|0;g=v[114578];v[114578]=0;j:{if((g|0)!=1){jb=f+16|0;break j}V(0)|0;O()|0;Ab();L()}k:{l:{if(x[a+480192>>1]){D=d+90|0;E=d+177|0;k=d+173|0;e=1;f=-1;m=1;m:{while(1){v[114578]=0;g=T(392,b|0)|0;i=v[114578];v[114578]=0;n:{o:{p:{q:{r:{s:{if((i|0)!=1){fg(b,4);v[114578]=0;W(1034,b|0,d+144|0,(g?g:263)|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break m}t:{if((h|0)==1){if((w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))==245){v[a+1074304>>2]=16777381;v[114578]=0;g=Q(2,d+72|0,17665)|0;h=v[114578];v[114578]=0;if((h|0)!=1){Gb(l,g);yb(g);h=17;break t}e=P()|0;O()|0;break k}h=16;if((w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))!=263){break t}v[a+1074304>>2]=16777395;v[114578]=0;g=Q(2,d+72|0,17691)|0;h=v[114578];v[114578]=0;if((h|0)!=1){Gb(l,g);yb(g);h=17;break t}e=P()|0;O()|0;break k}if(w[d+171|0]|w[d+172|0]<<8){break t}u:{if(!(h&2)|(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))!=263){break u}g=k;if(w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)){break u}h=h|16;break t}if(!(!(h&256)|(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))==29)){h=h&-257;break t}if(!(h&160)){break t}h=(w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24))==33?h:0}v[114578]=0;g=W(456,a|0,m&65535,0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break m}if(!g){break n}i=((e<<2)+a|0)+900380|0;g=v[i>>2];v[114578]=0;R(1035,d+144|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break m}g=w[d+170|0];v:{if((f|0)==-1){f=g;break v}if(!(h&32)|(f|0)==(g|0)){break v}h=h&-161|128}if(!(w[d+171|0]|w[d+172|0]<<8)){break n}g=w[d+385|0];e=w[d+386|0];p=w[d+387|0]|w[d+388|0]<<8;o=w[d+391|0];r=w[d+171|0]|w[d+172|0]<<8;v[114578]=0;U(1036,d+128|0,a|0,r|0);r=v[114578];v[114578]=0;if((r|0)==1){break s}h=o|(p|(e|g))?h&-4:h;e=12;while(1){g=x[ed(v[i>>2]+236|0,e)>>1];if(oc(d+128|0)>>>0>g>>>0){g=x[rc(d+128|0,x[ed(v[i>>2]+236|0,e)>>1])>>1];F=ed(v[i>>2]+236|0,e),G=g,u[F>>1]=G}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+506|0]|w[d+507|0]<<8)>>>0>259){Kb(n);IO(n);Qg(n)}g=w[d+171|0]|w[d+172|0]<<8;v[114578]=0;g=Q(1037,d+112|0,g|0)|0;e=v[114578];v[114578]=0;w:{if((e|0)!=1){e=0;if(w[d+171|0]|w[d+172|0]<<8){break w}break r}e=P()|0;O()|0;break p}x:{y:{z:{A:{while(1){v[114578]=0;Q(1038,b|0,d+72|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break x}v[114578]=0;R(1039,d+56|0,d+72|0);i=v[114578];v[114578]=0;B:{if((i|0)==1){break B}v[114578]=0;R(1040,n|0,d+56|0);i=v[114578];v[114578]=0;if((i|0)==1){break B}i=w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24);F=Pb(g,e),G=i,v[F>>2]=G;p=w[d+89|0];if(oc(d+128|0)>>>0>e>>>0){i=x[rc(d+128|0,e)>>1];v[114578]=0;o=(B(i,104)+a|0)+484380|0;R(1041,d+72|0,o|0);r=v[114578];v[114578]=0;if((r|0)==1){break A}v[114578]=0;R(1042,E|0,o|0);o=v[114578];v[114578]=0;if((o|0)==1){break A}v[114578]=0;U(587,d+40|0,3,D|0);o=v[114578];v[114578]=0;if((o|0)==1){break z}v[114578]=0;R(417,d+56|0,d+40|0);o=v[114578];v[114578]=0;if((o|0)==1){break z}v[114578]=0;Q(371,((i<<5)+a|0)+946300|0,d+56|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break y}yb(d+56|0);h=(h&2)>>>1|0?(w[d+86|0]&3)==3?h|4:h:h}A=p|A;e=e+1|0;if(e>>>0>=(w[d+171|0]|w[d+172|0]<<8)>>>0){break r}continue}break}e=P()|0;O()|0;break q}e=P()|0;O()|0;break q}e=P()|0;O()|0;break q}e=P()|0;O()|0;yb(d+56|0);break q}e=P()|0;O()|0;break q}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}if((w[d+506|0]|w[d+507|0]<<8)>>>0<260){break o}e=0;if(!(w[d+171|0]|w[d+172|0]<<8)){break o}C:{while(1){D:{p=w[Pb(n,e)+3|0];i=v[Pb(g,e)>>2];v[114578]=0;U(343,d+72|0,b|0,((p|0)==11?(i+1>>>1|0)+16|0:i)|0);i=v[114578];v[114578]=0;if((i|0)==1){break D}if(!(!z|oc(d+128|0)>>>0<=e>>>0)){p=x[rc(d+128|0,e)>>1];i=Pb(n,e);i=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);v[114578]=0;v[d+36>>2]=i;v[d+4>>2]=i;i=aa(1043,(B(p,104)+a|0)+484380|0,d+4|0,d+72|0,d+415|0)|0;p=v[114578];v[114578]=0;if((p|0)==1){break C}C=i^1|C}Bb(d+72|0);e=e+1|0;if(e>>>0<(w[d+171|0]|w[d+172|0]<<8)>>>0){continue}break o}break}e=P()|0;O()|0;break q}e=P()|0;O()|0;Bb(d+72|0)}oe(g)}kf(d+128|0);break k}oe(g);kf(d+128|0)}m=m+1|0;e=m&65535;if(e>>>0<=x[a+480192>>1]){continue}break}g=!(A&255);break l}e=P()|0;O()|0;break k}f=-1;g=1}E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if(!(!(h&2)|!g)){v[114578]=0;k=W(625,s|0,0,20)|0;e=v[114578];v[114578]=0;if((e|0)==1){break V}h=k?h|16:h}W:{if((w[d+506|0]|w[d+507|0]<<8)>>>0>259){break W}if(c&3){v[114578]=0;U(1033,b|0,d+448|0,a|0);c=v[114578];v[114578]=0;if((c|0)==1){break V}}if(!z|!x[a+480190>>1]){break W}c=1;e=1;while(1){k=Pb(n,c-1|0);v[114578]=0;W(402,k|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break U}e=e+1|0;c=e&65535;if(c>>>0<=x[a+480190>>1]){continue}break}}if(C&1){v[114578]=0;c=Q(2,d+144|0,17716)|0;k=v[114578];v[114578]=0;if((k|0)==1){break T}v[114578]=0;U(646,a|0,2,c|0);k=v[114578];v[114578]=0;if((k|0)==1){break S}yb(c)}v[114578]=0;c=Q(618,b|0,17799)|0;k=v[114578];v[114578]=0;if((k|0)==1){break V}if(c){v[114578]=0;c=T(392,b|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break V}v[114578]=0;aa(584,a+1304424|0,b|0,c|0,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break V}h=h|16}v[114578]=0;k=Q(618,b|0,17804)|0;c=v[114578];v[114578]=0;if((c|0)==1){break E}if(k){v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;e=a+901404|0;W(1044,b|0,e|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break E}v[114578]=0;Z(633,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break E}h=h|16}v[114578]=0;c=Q(618,b|0,17809)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(c){v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break R}u[d+144>>1]=c>>>5;e=a+484344|0;c=Ce(e);v[114578]=0;u[d+72>>1]=c;c=Q(478,d+144|0,d+72|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break Q}m=x[c>>1];if(m){c=0;while(1){v[114578]=0;W(868,b|0,d+144|0,32)|0;i=v[114578];v[114578]=0;if((i|0)==1){break P}i=_b(e,c);v[114578]=0;Q(869,i|0,d+144|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break P}c=c+1|0;if((m|0)!=(c|0)){continue}break}}h=h|16}v[114578]=0;c=Q(618,b|0,17814)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(c){v[114578]=0;c=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break O}u[d+144>>1]=(c>>>0)/20;c=x[a+480188>>1];v[114578]=0;u[d+72>>1]=c;c=Q(478,d+144|0,d+72|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break N}c=x[c>>1];if(c){e=0;while(1){v[114578]=0;W(635,b|0,((e<<5)+a|0)+480289|0,20)|0;m=v[114578];v[114578]=0;if((m|0)==1){break J}e=e+1|0;if((c|0)!=(e|0)){continue}break}}h=h|16}v[114578]=0;c=Q(258,b|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(c){c=v[b+8>>2];v[114578]=0;Q(636,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break I}h=(c|0)==v[b+8>>2]?h:h|16}if(!(h&16)){break K}if(!(h&4)){break L}v[a+1074304>>2]=17367040;v[114578]=0;c=Q(2,d+144|0,17819)|0;e=v[114578];v[114578]=0;if((e|0)==1){break M}Gb(l,c);yb(c);break K}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;yb(c);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}if(!(h&2)){break K}v[a+1074304>>2]=18219008;v[114578]=0;c=Q(2,d+144|0,17840)|0;e=v[114578];v[114578]=0;if((e|0)==1){break H}Gb(l,c);yb(c)}X:{Y:{Z:{_:{$:{aa:{ba:{if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))==1852141647&(w[j+4|0]|w[j+5|0]<<8|(w[j+6|0]<<16|w[j+7|0]<<24))==542396493){v[114578]=0;c=W(1045,d+144|0,d+494|0,12)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ba}v[114578]=0;U(13,d+72|0,1,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break aa}v[114578]=0;e=T(1046,d+72|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break $}v[a+1074304>>2]=e;yb(d+72|0);v[a+1074368>>2]=y[a+1074304>>2]<19007257?4:5;yb(c);h=24}if(!(!v[a+1074304>>2]|h&8)){v[a+1074368>>2]=0;Ft(a+1074308|0)}c=h&32;ca:{if(!c){break ca}v[a+1074368>>2]=5;if(!k){v[114578]=0;Z(634,a+901404|0);k=v[114578];v[114578]=0;if((k|0)==1){break E}}if((w[d+506|0]|w[d+507|0]<<8)>>>0<260){break ca}v[114578]=0;W(479,a+1074308|0,4,1)|0;k=v[114578];v[114578]=0;if((k|0)==1){break E}}if(!Wc(l)){break X}if(!(g&(h&256)>>>8)|f+1>>>0>1){break Y}v[114578]=0;c=Q(2,d+144|0,17868)|0;f=v[114578];v[114578]=0;if((f|0)==1){break Z}Gb(l,c);yb(c);break X}e=P()|0;O()|0;break k}e=P()|0;O()|0;break _}e=P()|0;O()|0;yb(d+72|0)}yb(c);break k}e=P()|0;O()|0;break k}if(c){v[114578]=0;c=Q(2,d+144|0,17880)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Gb(l,c);yb(c);break X}e=P()|0;O()|0;break k}v[114578]=0;c=Q(2,d+144|0,17908)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}Gb(l,c);yb(c)}t[d+40|0]=0;da:{if(x[a+480192>>1]){v[114578]=0;c=Q(652,a|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break da}t[d+40|0]=c}v[114578]=0;X(653,a|0,b|0,1,d+40|0);b=v[114578];v[114578]=0;if((b|0)==1){break da}c=a+1074304|0;if(!(!w[d+40|0]|y[c>>2]>=18284544)){v[c>>2]=18284544}ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{b=v[c>>2];if(b>>>0>=18284544){v[114578]=0;b=Q(2,d+72|0,17578)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ra}v[114578]=0;R(1047,d+128|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break qa}v[114578]=0;U(3,d+144|0,b|0,d+128|0);f=v[114578];v[114578]=0;if((f|0)==1){break pa}Gb(l,d+144|0);yb(d+144|0);yb(d+128|0);yb(b);b=v[c>>2]}sa:{if(!b|y[c>>2]>=19005954){break sa}v[114578]=0;b=a+484344|0;c=Q(444,b|0,254)|0;f=v[114578];v[114578]=0;if((f|0)==1){break da}if(!c){c=Vb(q);v[114578]=0;R(1048,c|0,254);c=v[114578];v[114578]=0;if((c|0)==1){break da}}v[114578]=0;b=Q(444,b|0,255)|0;c=v[114578];v[114578]=0;if((c|0)==1){break da}if(b){break sa}b=Vb(q);v[114578]=0;c=da(962)|0;f=v[114578];v[114578]=0;if((f|0)==1){break da}v[114578]=0;U(1049,b|0,255,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break da}}if(!w[d+415|0]){break ea}v[114578]=0;b=Q(2,d+144|0,17916)|0;c=v[114578];v[114578]=0;if((c|0)==1){break na}Gb(a+1304436|0,b);yb(b);v[114578]=0;b=Q(2,d+144|0,17937)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ma}Gb(a+1304448|0,b);yb(b);v[114578]=0;b=Q(2,d+24|0,17941)|0;c=v[114578];v[114578]=0;if((c|0)==1){break la}v[114578]=0;R(219,d+72|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break ka}v[d+112>>2]=w[d+507|0];c=w[d+506|0];v[114578]=0;v[d+56>>2]=c;R(660,d+128|0,d+56|0);c=v[114578];v[114578]=0;if((c|0)==1){break ja}v[114578]=0;X(645,d+144|0,d+72|0,d+112|0,d+128|0);c=v[114578];v[114578]=0;if((c|0)==1){break ia}Gb(a+1304472|0,d+144|0);yb(d+144|0);yb(d+128|0);Ib(d+72|0);yb(b);v[114578]=0;c=Q(2,d+144|0,17962)|0;b=v[114578];v[114578]=0;if((b|0)==1){break fa}Gb(a+1304484|0,c);break F}e=P()|0;O()|0;break k}e=P()|0;O()|0;break oa}e=P()|0;O()|0;yb(d+128|0)}yb(b);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break ga}e=P()|0;O()|0;break ha}e=P()|0;O()|0;yb(d+128|0)}Ib(d+72|0)}yb(b);break k}e=P()|0;O()|0;break k}v[114578]=0;b=Q(2,d+8|0,17941)|0;c=v[114578];v[114578]=0;ta:{ua:{va:{wa:{xa:{ya:{if((c|0)!=1){v[114578]=0;R(219,d+72|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break ya}v[d+112>>2]=w[d+507|0];c=w[d+506|0];v[114578]=0;v[d+56>>2]=c;R(660,d+128|0,d+56|0);c=v[114578];v[114578]=0;if((c|0)==1){break xa}v[114578]=0;X(645,d+144|0,d+72|0,d+112|0,d+128|0);c=v[114578];v[114578]=0;if((c|0)==1){break wa}Gb(a+1304436|0,d+144|0);yb(d+144|0);yb(d+128|0);Ib(d+72|0);yb(b);v[114578]=0;c=Q(2,d+144|0,17962)|0;b=v[114578];v[114578]=0;if((b|0)==1){break ta}Gb(a+1304448|0,c);break F}e=P()|0;O()|0;break k}e=P()|0;O()|0;break ua}e=P()|0;O()|0;break va}e=P()|0;O()|0;yb(d+128|0)}Ib(d+72|0)}yb(b);break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}e=P()|0;O()|0;break k}yb(c);Gb(a+1304460|0,l);v[a+1304496>>2]=v[a+1074304>>2]?7:4;JO(n);yb(l);break b}e=P()|0;O()|0}JO(n);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}yb(l);S(e|0);L()}e=1}jb=d+528|0;return e|0}function oF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;s=jb-48|0;jb=s;a:{if(c>>>0<=2){c=c<<2;I=v[c+59820>>2];H=v[c+59808>>2];while(1){c=v[b+4>>2];b:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=$c(b)}if(fl(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=$c(b)}e:{f:{while(1){if(t[f+59736|0]==(c|32)){g:{if(f>>>0>6){break g}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=$c(b)}f=f+1|0;if((f|0)!=8){continue}break f}break}if((f|0)!=3){if((f|0)==8){break f}if(!d|f>>>0<4){break e}if((f|0)==8){break f}}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(!d|f>>>0<4){break f}while(1){if(c){v[b+4>>2]=v[b+4>>2]-1}f=f-1|0;if(f>>>0>3){continue}break}}b=s;k=jb-16|0;jb=k;i=(p(C(C(n|0)*C(N))),j(2));c=i&2147483647;h:{if(c-8388608>>>0<=2130706431){d=c;c=c>>>7|0;f=d<<25;d=c+1065353216|0;break h}f=i;d=f>>>7|0;f=f<<25;d=d|2147418112;if(c>>>0>=2139095040){break h}f=0;d=0;if(!c){break h}d=c;c=E(c);qf(k,d,0,0,0,c+81|0);h=v[k>>2];g=v[k+4>>2];f=v[k+8>>2];d=v[k+12>>2]^65536|16265-c<<16}v[b>>2]=h;v[b+4>>2]=g;v[b+8>>2]=f;v[b+12>>2]=i&-2147483648|d;jb=k+16|0;h=v[s+8>>2];g=v[s+12>>2];l=v[s>>2];i=v[s+4>>2];break a}i:{j:{k:{if(f){break k}f=0;while(1){if(t[f+59745|0]!=(c|32)){break k}l:{if(f>>>0>1){break l}c=v[b+4>>2];if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=$c(b)}f=f+1|0;if((f|0)!=3){continue}break}break j}m:{switch(f|0){case 0:n:{if((c|0)!=48){break n}f=v[b+4>>2];o:{if(f>>>0<y[b+104>>2]){v[b+4>>2]=f+1;f=w[f|0];break o}f=$c(b)}if((f&-33)==88){f=jb-432|0;jb=f;i=v[b+104>>2];c=b;b=v[c+4>>2];p:{if(i>>>0>b>>>0){v[c+4>>2]=b+1;b=w[b|0];break p}b=$c(c)}q:{r:{while(1){if((b|0)!=48){s:{if((b|0)!=46){break q}b=v[c+4>>2];if(b>>>0>=y[c+104>>2]){break s}v[c+4>>2]=b+1;b=w[b|0];break r}}else{b=v[c+4>>2];if(b>>>0<y[c+104>>2]){k=1;v[c+4>>2]=b+1;b=w[b|0]}else{k=1;b=$c(c)}continue}break}b=$c(c)}e=1;if((b|0)!=48){break q}while(1){b=m;m=b-1|0;u=u-(b>>>0<1)|0;b=v[c+4>>2];t:{if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0];break t}b=$c(c)}if((b|0)==48){continue}break}k=1}i=1073676288;while(1){u:{z=b|32;v:{w:{J=b-48|0;if(J>>>0<10){break w}if(z-97>>>0>5?(b|0)!=46:0){break u}if((b|0)!=46){break w}if(e){break u}e=1;m=h;u=g;break v}b=(b|0)>57?z-87|0:J;x:{if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){x=b+(x<<4)|0;break x}if((g|0)<0?1:(g|0)<=0?h>>>0<=28:0){og(f+48|0,b);td(f+32|0,F,G,l,i,0,0,0,1073414144);F=v[f+32>>2];G=v[f+36>>2];l=v[f+40>>2];i=v[f+44>>2];td(f+16|0,F,G,l,i,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2]);Zf(f,q,r,A,D,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2]);A=v[f+8>>2];D=v[f+12>>2];q=v[f>>2];r=v[f+4>>2];break x}if(!b|o){break x}td(f+80|0,F,G,l,i,0,0,0,1073610752);Zf(f- -64|0,q,r,A,D,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2]);A=v[f+72>>2];D=v[f+76>>2];o=1;q=v[f+64>>2];r=v[f+68>>2]}b=h+1|0;k=b>>>0<1?g+1|0:g;h=b;g=k;k=1}b=v[c+4>>2];if(b>>>0<y[c+104>>2]){v[c+4>>2]=b+1;b=w[b|0]}else{b=$c(c)}continue}break}y:{z:{A:{if(!k){if(!v[c+104>>2]){if(d){break z}break A}b=v[c+4>>2];v[c+4>>2]=b-1;if(!d){break A}v[c+4>>2]=b-2;if(!e){break z}v[c+4>>2]=b-3;break z}if((g|0)<0?1:(g|0)<=0?h>>>0<=7:0){l=h;i=g;while(1){x=x<<4;k=l+1|0;i=k>>>0<1?i+1|0:i;l=k;if((k|0)!=8|i){continue}break}}B:{if((b&-33)==80){l=nF(c,d);b=mb;i=b;if(l|(b|0)!=-2147483648){break B}if(d){l=0;i=0;if(!v[c+104>>2]){break B}v[c+4>>2]=v[c+4>>2]-1;break B}q=0;r=0;Bh(c,0,0);c=0;b=0;break y}l=0;i=0;if(!v[c+104>>2]){break B}v[c+4>>2]=v[c+4>>2]-1}if(!x){gi(f+112|0,+(n|0)*0);q=v[f+112>>2];r=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break y}b=e?m:h;c=(e?u:g)<<2|b>>>30;b=l+(b<<2)|0;c=c+i|0;c=b>>>0<l>>>0?c+1|0:c;h=b-32|0;g=c-(b>>>0<32)|0;b=g;if((b|0)>0?1:(b|0)>=0?h>>>0>0-I>>>0:0){v[114552]=68;og(f+160|0,n);td(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);td(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);q=v[f+128>>2];r=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break y}b=I-226|0;c=h>>>0>=b>>>0;b=b>>31;if((b|0)<(g|0)?1:(g|0)>=(b|0)?c:0){if((x|0)>-1){while(1){Zf(f+416|0,q,r,A,D,0,0,0,-1073807360);c=sF(q,r,A,D,1073610752);b=(c|0)<0;Zf(f+400|0,q,r,A,D,b?q:v[f+416>>2],b?r:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=h;h=b-1|0;g=g-(b>>>0<1)|0;A=v[f+408>>2];D=v[f+412>>2];q=v[f+400>>2];r=v[f+404>>2];x=x<<1|(c|0)>-1;if((x|0)>-1){continue}break}}b=h;c=I;d=(b-c|0)+32|0;c=g-((c>>31)+(b>>>0<c>>>0)|0)|0;c=d>>>0<32?c+1|0:c;b=d;c=((c|0)<0?1:(c|0)<=0?b>>>0<H>>>0:0)?(b|0)>0?b:0:H;C:{if((c|0)>=113){og(f+384|0,n);m=v[f+392>>2];u=v[f+396>>2];F=v[f+384>>2];G=v[f+388>>2];g=0;b=0;break C}gi(f+352|0,$h(1,144-c|0));og(f+336|0,n);F=v[f+336>>2];G=v[f+340>>2];m=v[f+344>>2];u=v[f+348>>2];rF(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],F,G,m,u);K=v[f+376>>2];L=v[f+380>>2];g=v[f+372>>2];b=v[f+368>>2]}c=!(x&1)&((el(q,r,A,D,0,0,0,0)|0)!=0&(c|0)<32);Am(f+320|0,c+x|0);td(f+304|0,F,G,m,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);Zf(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,g,K,L);td(f+288|0,c?0:q,c?0:r,c?0:A,c?0:D,F,G,m,u);Zf(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);Tv(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],b,g,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];g=v[f+252>>2];if(!el(b,c,d,g,0,0,0,0)){v[114552]=68}qF(f+224|0,b,c,d,g,h);q=v[f+224>>2];r=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break y}v[114552]=68;og(f+208|0,n);td(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);td(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);q=v[f+176>>2];r=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2];break y}Bh(c,0,0)}gi(f+96|0,+(n|0)*0);q=v[f+96>>2];r=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2]}v[s+16>>2]=q;v[s+20>>2]=r;v[s+24>>2]=b;v[s+28>>2]=c;jb=f+432|0;h=v[s+24>>2];g=v[s+28>>2];l=v[s+16>>2];i=v[s+20>>2];break a}if(!v[b+104>>2]){break n}v[b+4>>2]=v[b+4>>2]-1}m=b;f=c;x=n;b=0;n=0;e=jb-8976|0;jb=e;K=H+I|0;L=0-K|0;D:{E:{while(1){if((f|0)!=48){F:{if((f|0)!=46){break D}c=v[m+4>>2];if(c>>>0>=y[m+104>>2]){break F}v[m+4>>2]=c+1;f=w[c|0];break E}}else{c=v[m+4>>2];if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0]}else{f=$c(m)}n=1;continue}break}f=$c(m)}o=1;if((f|0)!=48){break D}h=-1;g=-1;while(1){c=v[m+4>>2];G:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break G}f=$c(m)}if((f|0)==48){c=h;h=c-1|0;g=g-(c>>>0<1)|0;continue}break}n=1}v[e+784>>2]=0;H:{I:{k=(f|0)==46;c=f-48|0;J:{K:{L:{if(!(c>>>0>9?!k:0)){while(1){M:{if(k&1){if(!o){h=l;g=i;o=1;break M}k=!n;break L}k=i;i=l+1|0;k=i>>>0<1?k+1|0:k;l=i;i=k;if((b|0)<=2044){J=(f|0)==48?J:l;k=(e+784|0)+(b<<2)|0;n=k;if(z){c=(B(v[k>>2],10)+f|0)-48|0}v[n>>2]=c;n=1;f=z+1|0;c=(f|0)==9;z=c?0:f;b=b+c|0;break M}if((f|0)==48){break M}v[e+8960>>2]=v[e+8960>>2]|1;J=18396}c=v[m+4>>2];N:{if(c>>>0<y[m+104>>2]){v[m+4>>2]=c+1;f=w[c|0];break N}f=$c(m)}k=(f|0)==46;c=f-48|0;if(k|c>>>0<10){continue}break}}h=o?h:l;g=o?g:i;if(!(!n|(f&-33)!=69)){c=nF(m,d);f=mb;k=f;if(c|(f|0)!=-2147483648){d=g+k|0;h=c+h|0;d=h>>>0<c>>>0?d+1|0:d;g=d;break I}if(!d){break J}if(!v[m+104>>2]){break I}v[m+4>>2]=v[m+4>>2]-1;break I}k=!n;if((f|0)<0){break K}}if(!v[m+104>>2]){break K}v[m+4>>2]=v[m+4>>2]-1}if(!k){break I}v[114552]=28}l=0;i=0;Bh(m,0,0);c=0;b=0;break H}c=v[e+784>>2];if(!c){gi(e,+(x|0)*0);l=v[e>>2];i=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break H}if(!((h|0)!=(l|0)|(g|0)!=(i|0)|((i|0)>0?1:(i|0)>=0?l>>>0>9:0)|(c>>>H|0?(H|0)<=30:0))){og(e+48|0,x);Am(e+32|0,c);td(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);l=v[e+16>>2];i=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break H}if((g|0)>0?1:(g|0)>=0?h>>>0>(I|0)/-2>>>0:0){v[114552]=68;og(e+96|0,x);td(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);td(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);l=v[e+64>>2];i=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break H}c=I-226|0;d=h>>>0<c>>>0;c=c>>31;if((c|0)>(g|0)?1:(g|0)<=(c|0)?d:0){v[114552]=68;og(e+144|0,x);td(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);td(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);l=v[e+112>>2];i=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break H}if(z){if((z|0)<=8){d=(e+784|0)+(b<<2)|0;c=v[d>>2];while(1){c=B(c,10);z=z+1|0;if((z|0)!=9){continue}break}v[d>>2]=c}b=b+1|0}O:{o=h;if((J|0)>(h|0)|(J|0)>=9|(h|0)>17){break O}if((o|0)==9){og(e+192|0,x);Am(e+176|0,v[e+784>>2]);td(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);l=v[e+160>>2];i=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break H}if((o|0)<=8){og(e+272|0,x);Am(e+256|0,v[e+784>>2]);td(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);og(e+224|0,v[(0-o<<2)+59808>>2]);pF(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);l=v[e+208>>2];i=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break H}c=(B(o,-3)+H|0)+27|0;d=v[e+784>>2];if(d>>>c|0?(c|0)<=30:0){break O}og(e+352|0,x);Am(e+336|0,d);td(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);og(e+304|0,v[(o<<2)+59736>>2]);td(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);l=v[e+288>>2];i=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break H}while(1){c=b;b=c-1|0;if(!v[(e+784|0)+(b<<2)>>2]){continue}break}z=0;b=(o|0)%9|0;P:{if(!b){b=0;break P}d=(o|0)>-1?b:b+9|0;Q:{if(!c){b=0;c=0;break Q}h=v[(0-d<<2)+59808>>2];i=1e9/(h|0)|0;k=0;f=0;b=0;while(1){g=k;k=(e+784|0)+(f<<2)|0;l=v[k>>2];n=(l>>>0)/(h>>>0)|0;g=g+n|0;v[k>>2]=g;g=!g&(b|0)==(f|0);b=g?b+1&2047:b;o=g?o-9|0:o;k=B(i,l-B(h,n)|0);f=f+1|0;if((f|0)!=(c|0)){continue}break}if(!k){break Q}v[(e+784|0)+(c<<2)>>2]=k;c=c+1|0}o=(o-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;R:{while(1){if((o|0)!=36|y[l>>2]>=10384593?(o|0)>=36:0){break R}f=c+2047|0;h=0;while(1){k=0;f=f&2047;n=(e+784|0)+(f<<2)|0;g=v[n>>2];d=g>>>3|0;g=h+(g<<29)|0;i=d;i=g>>>0<h>>>0?i+1|0:i;h=g;g=i;if(!g&h>>>0>=1000000001|g){k=Ima(h,g,1e9,0);h=h-Fma(k,mb,1e9,0)|0}v[n>>2]=h;d=h?c:f;h=(b|0)==(f|0);d=(f|0)!=(c-1&2047)?c:h?c:d;if(!h){f=f-1|0;h=k;c=d;continue}break}z=z-29|0;if(!k){continue}break}b=b-1&2047;if((d|0)==(b|0)){c=(e+784|0)+((d+2046&2047)<<2)|0;h=c;i=v[c>>2];c=d-1&2047;v[h>>2]=i|v[(e+784|0)+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=k;continue}break}S:{T:while(1){d=c+1&2047;g=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(o|0)>45?9:1;U:{while(1){n=b;f=0;V:{while(1){W:{b=f+n&2047;if((b|0)==(c|0)){break W}b=v[(e+784|0)+(b<<2)>>2];i=v[(f<<2)+59760>>2];if(b>>>0<i>>>0){break W}if(b>>>0>i>>>0){break V}f=f+1|0;if((f|0)!=4){continue}}break}if((o|0)!=36){break V}h=0;g=0;f=0;l=0;i=0;while(1){b=f+n&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}td(e+768|0,h,g,l,i,0,0,1342177280,1075633366);Am(e+752|0,v[(e+784|0)+(b<<2)>>2]);Zf(e+736|0,v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2],v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2]);l=v[e+744>>2];i=v[e+748>>2];h=v[e+736>>2];g=v[e+740>>2];f=f+1|0;if((f|0)!=4){continue}break}og(e+720|0,x);td(e+704|0,h,g,l,i,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];i=v[e+716>>2];h=0;g=0;q=v[e+704>>2];r=v[e+708>>2];o=z+113|0;d=o-I|0;f=(d|0)<(H|0);b=f?(d|0)>0?d:0:H;if((b|0)<=112){break U}m=0;break S}z=h+z|0;b=c;if((n|0)==(c|0)){continue}break}k=1e9>>>h|0;l=-1<<h^-1;f=0;b=n;while(1){i=f;f=(e+784|0)+(n<<2)|0;m=v[f>>2];i=i+(m>>>h|0)|0;v[f>>2]=i;i=!i&(b|0)==(n|0);b=i?b+1&2047:b;o=i?o-9|0:o;f=B(k,l&m);n=n+1&2047;if((n|0)!=(c|0)){continue}break}if(!f){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=f;c=d;continue T}v[g>>2]=v[g>>2]|1;b=d;continue}break}break}gi(e+656|0,$h(1,225-b|0));rF(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],q,r,l,i);F=v[e+696>>2];G=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];gi(e+640|0,$h(1,113-b|0));xD(e+672|0,q,r,l,i,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);h=v[e+672>>2];g=v[e+676>>2];m=v[e+680>>2];u=v[e+684>>2];Tv(e+624|0,q,r,l,i,h,g,m,u);Zf(e+608|0,A,D,F,G,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];i=v[e+620>>2];q=v[e+608>>2];r=v[e+612>>2]}k=n+4&2047;X:{if((k|0)==(c|0)){break X}k=v[(e+784|0)+(k<<2)>>2];Y:{if(k>>>0<=499999999){if((n+5&2047)==(c|0)?!k:0){break Y}gi(e+496|0,+(x|0)*.25);Zf(e+480|0,h,g,m,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);m=v[e+488>>2];u=v[e+492>>2];h=v[e+480>>2];g=v[e+484>>2];break Y}if((k|0)!=5e8){gi(e+592|0,+(x|0)*.75);Zf(e+576|0,h,g,m,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);m=v[e+584>>2];u=v[e+588>>2];h=v[e+576>>2];g=v[e+580>>2];break Y}M=+(x|0);if((n+5&2047)==(c|0)){gi(e+528|0,M*.5);Zf(e+512|0,h,g,m,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);m=v[e+520>>2];u=v[e+524>>2];h=v[e+512>>2];g=v[e+516>>2];break Y}gi(e+560|0,M*.75);Zf(e+544|0,h,g,m,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);m=v[e+552>>2];u=v[e+556>>2];h=v[e+544>>2];g=v[e+548>>2]}if((b|0)>111){break X}xD(e+464|0,h,g,m,u,0,0,0,1073676288);if(el(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break X}Zf(e+448|0,h,g,m,u,0,0,0,1073676288);m=v[e+456>>2];u=v[e+460>>2];h=v[e+448>>2];g=v[e+452>>2]}Zf(e+432|0,q,r,l,i,h,g,m,u);Tv(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,F,G);l=v[e+424>>2];i=v[e+428>>2];q=v[e+416>>2];r=v[e+420>>2];Z:{if((-2-K|0)>=(o&2147483647)){break Z}v[e+408>>2]=l;v[e+412>>2]=i&2147483647;v[e+400>>2]=q;v[e+404>>2]=r;td(e+384|0,q,r,l,i,0,0,0,1073610752);k=sF(v[e+400>>2],v[e+404>>2],v[e+408>>2],v[e+412>>2],1081081856);c=(k|0)<0;l=c?l:v[e+392>>2];i=c?i:v[e+396>>2];q=c?q:v[e+384>>2];r=c?r:v[e+388>>2];z=((k|0)>-1)+z|0;if((el(h,g,m,u,0,0,0,0)|0)!=0&(c?f:f&(b|0)!=(d|0))?0:(z+110|0)<=(L|0)){break Z}v[114552]=68}qF(e+368|0,q,r,l,i,z);l=v[e+368>>2];i=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[s+32>>2]=l;v[s+36>>2]=i;v[s+40>>2]=b;v[s+44>>2]=c;jb=e+8976|0;h=v[s+40>>2];g=v[s+44>>2];l=v[s+32>>2];i=v[s+36>>2];break a;case 3:break j;default:break m}}if(v[b+104>>2]){v[b+4>>2]=v[b+4>>2]-1}break i}_:{c=v[b+4>>2];$:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break $}c=$c(b)}if((c|0)==40){f=1;break _}g=2147450880;if(!v[b+104>>2]){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];aa:{if(c>>>0<y[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break aa}c=$c(b)}if(!(c-97>>>0>=26?!(c-48>>>0<10|c-65>>>0<26|(c|0)==95):0)){f=f+1|0;continue}break}g=2147450880;if((c|0)==41){break a}c=v[b+104>>2];if(c){v[b+4>>2]=v[b+4>>2]-1}if(d){if(!f){break a}while(1){f=f-1|0;if(c){v[b+4>>2]=v[b+4>>2]-1}if(f){continue}break}break a}}v[114552]=28;Bh(b,0,0)}g=0}v[a>>2]=l;v[a+4>>2]=i;v[a+8>>2]=h;v[a+12>>2]=g;jb=s+48|0}function _ja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-288|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!eu(b,d+280|0)){break x}if(!DR(d+280|0)){break x}if(!c){y=1;break x}C=Lk(d+264|0,b);v[114578]=0;U(743,d+248|0,C|0,0);b=v[114578];v[114578]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{if((b|0)!=1){v[114578]=0;U(744,d+232|0,d+248|0,20041);b=v[114578];v[114578]=0;if((b|0)==1){break N}v[114578]=0;b=T(339,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(!b){break y}v[114578]=0;b=Q(745,d+232|0,d+136|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}if(!b){break y}v[114578]=0;R(449,a|0,16384);b=v[114578];v[114578]=0;if((b|0)==1){break E}v[a+480208>>2]=8;v[114578]=0;b=a+1074308|0;W(479,b|0,9,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;Q(480,b|0,21)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;Q(480,b|0,30)|0;b=v[114578];v[114578]=0;if((b|0)==1){break E}v[114578]=0;b=Q(2,d+16|0,14652)|0;e=v[114578];v[114578]=0;if((e|0)==1){break K}Gb(a+1304436|0,b);yb(b);v[114578]=0;b=Q(2,d+16|0,14664)|0;e=v[114578];v[114578]=0;if((e|0)==1){break J}Gb(a+1304448|0,b);yb(b);v[114578]=0;e=Q(2,d+120|0,14668)|0;b=v[114578];v[114578]=0;if((b|0)==1){break I}b=w[d+284|0];switch(b-16|0){case 1:break H;case 0:break M;default:break L}}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}v[114578]=0;Q(2,d+104|0,14683)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break F}break e}if(!b){break G}v[114578]=0;Q(2,d+104|0,14698)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}break F}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[114578]=0;Q(2,d+104|0,14681)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break F}break e}v[114578]=0;Q(2,d+104|0,14687)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}}v[114578]=0;U(3,d+16|0,e|0,d+104|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}Gb(a+1304460|0,d+16|0);yb(d+16|0);yb(d+104|0);yb(e);v[a+1304496>>2]=4;v[114578]=0;U(746,d+120|0,3,d+136|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;R(417,d+16|0,d+120|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}Gb(a+1304400|0,d+16|0);yb(d+16|0);v[114578]=0;U(747,d+104|0,3,d+168|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;R(417,d+120|0,d+104|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;U(13,d+16|0,4,d+120|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}Gb(a+1304412|0,d+16|0);yb(d+16|0);yb(d+120|0);v[a+480200>>2]=w[d+192|0]+1;G=a,H=Cd(w[d+193|0],1,255),v[G+480196>>2]=H;G=a,H=B(Cd(w[d+194|0],4,255),1e4),v[G+480204>>2]=H;b=a+484360|0;e=Vb(b);f=w[d+188|0]|w[d+189|0]<<8;v[114578]=0;ea(581,e|0,d+232|0,f|0,65535,65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}Oe(Vb(b),w[d+190|0]|w[d+191|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[114578]=0;e=(b<<5)+a|0;f=e+480280|0;Z(434,f|0);g=v[114578];v[114578]=0;if((g|0)==1){break j}g=b+d|0;i=w[g+195|0]<<1&254;u[e+480284>>1]=(i|0)==254?256:i;O:{if(t[g+195|0]<=-1){v[f>>2]=v[f>>2]|1024;break O}u[a+480188>>1]=b+1}v[114578]=0;W(748,d+232|0,e+480289|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[114578]=0;U(744,d+16|0,d+248|0,17741);b=v[114578];v[114578]=0;if((b|0)==1){break k}Wd(d+232|0,d+16|0);Bb(d+16|0);v[114578]=0;b=T(255,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}v[114578]=0;aa(584,a+1304424|0,d+232|0,b|0,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break E}v[114578]=0;U(744,d+16|0,d+248|0,21321);b=v[114578];v[114578]=0;if((b|0)==1){break l}Wd(d+232|0,d+16|0);Bb(d+16|0);v[114578]=0;b=T(339,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}P:{if(b){v[114578]=0;U(744,d+16|0,d+248|0,16723);b=v[114578];v[114578]=0;if((b|0)==1){break m}v[114578]=0;k=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}Q:{if(!k){break Q}l=c&2;while(1){v[114578]=0;e=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}if(!e){break Q}v[114578]=0;b=Q(258,d+232|0,56)|0;f=v[114578];v[114578]=0;if((f|0)==1){break n}if(!b){break Q}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[114578]=0;b=B(e,104)+a|0;f=b+484380|0;R(388,f|0,0);g=v[114578];v[114578]=0;if((g|0)==1){break n}v[114578]=0;W(548,d+232|0,((e<<5)+a|0)+946300|0,32)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}v[114578]=0;W(551,d+232|0,b+484423|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}R:{if(w[d+284|0]<=15){v[114578]=0;e=T(359,d+232|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break R}break n}v[114578]=0;e=T(392,d+232|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break n}}v[b+484404>>2]=e<<1;v[114578]=0;e=T(392,d+232|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break n}v[f>>2]=e;v[114578]=0;g=T(392,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=g;v[114578]=0;g=T(392,d+232|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break n}i=b+484388|0;v[i>>2]=g;if(g){j=b+484414|0;u[j>>1]=x[j>>1]|2;v[i>>2]=g+v[e>>2]}v[114578]=0;g=T(389,d+232|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break P}if(w[d+284|0]<=15){u[b+484410>>1]=g}v[114578]=0;g=T(389,d+232|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break n}j=8;if(g&1){j=b+484414|0;u[j>>1]=x[j>>1]|1;v[f>>2]=v[f>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[i>>2]=v[i>>2]>>>1;j=16}b=b+484414|0;u[b>>1]=x[b>>1]&65531|g<<1&4;b=ad(d+120|0,j,1,0,((g&12)!=0)<<3);S:{if(!l){break S}v[114578]=0;W(402,b|0,f|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break S}break n}h=h+1|0;if(k>>>0>(h&255)>>>0){continue}break}}Bb(d+16|0)}v[114578]=0;U(744,d+16|0,d+248|0,18761);b=v[114578];v[114578]=0;if((b|0)==1){break q}Wd(d+232|0,d+16|0);Bb(d+16|0);v[114578]=0;b=T(339,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break E}T:{U:{V:{W:{if(b){k=Ez(d+120|0);l=Ez(d+104|0);j=Ez(d+88|0);v[114578]=0;U(744,d+72|0,d+248|0,17750);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(749,d+72|0,k|0);b=v[114578];v[114578]=0;if((b|0)==1){break s}Bb(d+72|0);v[114578]=0;U(744,d+56|0,d+248|0,17744);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(749,d+56|0,l|0);b=v[114578];v[114578]=0;if((b|0)==1){break t}Bb(d+56|0);v[114578]=0;U(744,d+40|0,d+248|0,17734);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(749,d+40|0,j|0);b=v[114578];v[114578]=0;if((b|0)==1){break u}Bb(d+40|0);h=0;v[114578]=0;n=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break v}if(n){s=d+16|4;y=d+16|2;p=d+16|6;q=d+16|5;r=d+16|3;e=d+16|1;while(1){v[114578]=0;R(473,d|0,d+232|0);b=v[114578];v[114578]=0;if((b|0)==1){break A}m=dd(d);X:{Y:{Z:{if(!w[d|0]){break Z}b=w[m|0];v[114578]=0;b=Q(258,d+232|0,B(b,14)+32|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}if(!b){break Z}b=w[d|0];v[114578]=0;i=W(456,a|0,b|0,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break p}if(i){break Y}}b=w[m|0];v[114578]=0;Q(340,d+232|0,B(b,14)+32|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break X}break p}v[114578]=0;W(548,d+232|0,i+492|0,32)|0;b=v[114578];v[114578]=0;if((b|0)==1){break p}if(!w[m|0]){break X}z=i+88|0;A=i+68|0;D=i+48|0;E=i+236|0;g=0;b=0;while(1){v[114578]=0;Q(750,d+232|0,d+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break w}_:{if(!w[d+16|0]|x[a+480190>>1]<w[d+16|0]){break _}f=e;if(w[e|0]>128){t[f|0]=128}if(w[e|0]>=(b&255)>>>0){while(1){f=w[d+16|0];G=ed(E,b&255),H=f,u[G>>1]=H;b=b+1|0;if(w[e|0]>=(b&255)>>>0){continue}break}}b=w[e|0];f=w[r|0];v[114578]=0;U(751,D|0,f|0,k|0);f=v[114578];v[114578]=0;if((f|0)==1){break w}f=w[q|0];v[114578]=0;U(751,A|0,f|0,l|0);f=v[114578];v[114578]=0;if((f|0)==1){break w}f=w[d+29|0];v[114578]=0;U(751,z|0,f|0,j|0);f=v[114578];v[114578]=0;if((f|0)==1){break w}v[i>>2]=(w[p|0]|w[p+1|0]<<8)+1>>>1;f=w[d+16|0];$:{if(w[r|0]&64){u[(B(f,104)+a|0)+484410>>1]=w[y|0];break $}o=(B(f,104)+a|0)+484414|0;u[o>>1]=x[o>>1]|32768}o=w[s|0];v[114578]=0;u[d+38>>1]=o<<1;u[d+36>>1]=254;o=Q(478,d+38|0,d+36|0)|0;F=v[114578];v[114578]=0;if((F|0)==1){break W}b=b+1|0;f=B(f,104)+a|0;u[f+484408>>1]=x[o>>1];t[f+484418|0]=w[(w[d+27|0]&3)+14699|0];t[f+484419|0]=w[d+26|0];t[f+484420|0]=w[d+25|0];t[f+484421|0]=w[d+24|0];if(!(w[q|0]&64)){break _}f=f+484414|0;u[f>>1]=x[f>>1]|32}g=g+1|0;if(w[m|0]>(g&255)>>>0){continue}break}}h=h+1|0;if(n>>>0>(h&255)>>>0){continue}break}}wn(j);wn(l);wn(k)}y=1;l=Mp(d+120|0);if(!(c&1)){break z}v[114578]=0;U(744,d+16|0,d+248|0,21076);b=v[114578];v[114578]=0;if((b|0)!=1){b=Wd(d+232|0,d+16|0);v[114578]=0;b=T(339,b|0)|0;c=v[114578];v[114578]=0;aa:{ba:{ca:{da:{ea:{fa:{if((c|0)!=1){Bb(d+16|0);ga:{if(!b){break ga}v[114578]=0;c=T(359,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break fa}v[114578]=0;R(752,l|0,c+1|0);b=v[114578];v[114578]=0;if((b|0)==1){break fa}if(!c){break ga}b=1;while(1){v[114578]=0;e=T(359,d+232|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ea}v[114578]=0;U(343,d+16|0,d+232|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break ea}Wd(tc(l,b),d+16|0);e=(b|0)==(c|0);Bb(d+16|0);b=b+1|0;if(!e){continue}break}}v[114578]=0;U(744,d+16|0,d+248|0,16720);b=v[114578];v[114578]=0;if((b|0)==1){break da}b=Wd(d+232|0,d+16|0);v[114578]=0;b=T(339,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ca}Bb(d+16|0);if(!b){break aa}k=0;v[114578]=0;m=T(389,d+232|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break C}if(m){while(1){g=32;ha:{if(w[d+284|0]>=16){v[114578]=0;Q(753,d+232|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break V}if(!(w[d+16|0]>32|x[a+480188>>1]>=w[d+16|0])){u[a+480188>>1]=w[d+16|0]}g=w[d+16|0];if(!g){break ha}}e=0;while(1){v[114578]=0;b=T(359,d+232|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break U}if(!(!b|x[a+480188>>1]>(e&65535)>>>0)){u[a+480188>>1]=e+1}e=e+1|0;if((e&65535)>>>0<g>>>0){continue}break}}k=k+1|0;if(m>>>0>(k&65535)>>>0){continue}break}}v[114578]=0;Q(256,d+232|0,1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ba}break C}b=P()|0;O()|0;Bb(d+16|0);break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;Bb(d+16|0);break B}v[114578]=0;n=a+484344|0;R(403,n|0,m|0);b=v[114578];v[114578]=0;if((b|0)==1){break C}if(!m){break aa}D=d+16|2;E=d+16|1;c=0;while(1){p=Wb(d+104|0);k=64;q=32;if(w[d+284|0]>=16){v[114578]=0;Q(753,d+232|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break D}q=w[d+16|0];b=w[E|0];v[114578]=0;U(754,d|0,3,D|0);e=v[114578];v[114578]=0;if((e|0)==1){break D}v[114578]=0;R(417,d+88|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break D}Gb(p,d+88|0);yb(d+88|0);k=b+1|0}v[114578]=0;b=W(404,n|0,c&65535,k|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}ia:{if(!b){v[114578]=0;Q(340,d+232|0,q<<1)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ia}break D}b=_b(n,c);v[114578]=0;Q(496,b|0,p|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break D}r=0;if(!q){break ia}while(1){v[114578]=0;b=T(359,d+232|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}ja:{if(!b){break ja}if(od(l)>>>0<=b>>>0){break ja}s=r&65535;if(s>>>0>=x[a+480188>>1]){break ja}i=tc(l,b);Jc(i);f=0;while(1){v[114578]=0;b=Q(258,i|0,1)|0;e=v[114578];v[114578]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){if(!b){break ja}b=_b(n,c);v[114578]=0;b=W(472,b|0,f|0,s|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}v[114578]=0;g=T(389,i|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}e=g>>>2|0;switch((g&3)-1|0){case 2:break ma;case 1:break na;case 0:break oa;default:break pa}}break D}f=(e+f|0)+1|0;break ka}if(!f){f=0;break ka}g=_b(n,c);v[114578]=0;g=W(472,g|0,f-1|0,s|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){while(1){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=h;t[b+1|0]=h>>>8;t[b+2|0]=h>>>16;t[b+3|0]=h>>>24;h=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=h;t[b+5|0]=h>>>8;f=f+1|0;if(k>>>0<=f>>>0){break ka}b=B(x[a+480188>>1],6)+b|0;h=e&255;e=e-1|0;if(h){continue}break ka}}break D}if(e>>>0>=f>>>0){break la}g=_b(n,c);v[114578]=0;e=W(472,g|0,e|0,s|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break T}g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=g;t[b+1|0]=g>>>8;t[b+2|0]=g>>>16;t[b+3|0]=g>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break la}if(e&1){v[114578]=0;g=T(389,i|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break T}t[b|0]=g>>>0>120?-1:g}if(e&2){v[114578]=0;g=T(389,i|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break T}t[b+1|0]=g}j=0;g=0;if(e&4){v[114578]=0;g=T(389,i|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break D}}z=0;if(e&8){v[114578]=0;h=T(389,i|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break D}z=h>>>4|0;j=h&15}A=0;h=0;if(e&16){v[114578]=0;h=T(389,i|0)|0;o=v[114578];v[114578]=0;if((o|0)==1){break D}}if(e&32){v[114578]=0;A=T(389,i|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}}v[114578]=0;ma(755,b|0,g|0,j|0,z|0,h|0,A|0);b=v[114578];v[114578]=0;if((b|0)==1){break D}}f=f+1|0}if(f>>>0<k>>>0){continue}break}}r=r+1|0;if((r&65535)>>>0<q>>>0){continue}break}}yb(p);c=c+1|0;if((m|0)!=(c|0)){continue}break}}v[114578]=0;U(744,d+16|0,d+248|0,20048);b=v[114578];v[114578]=0;qa:{ra:{sa:{if((b|0)!=1){b=Wd(d+232|0,d+16|0);v[114578]=0;b=T(339,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break sa}Bb(d+16|0);if(!b){break z}a=a+484344|0;if(!Ce(a)){break z}while(1){v[114578]=0;b=Q(258,d+232|0,16)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ra}if(!b){break z}v[114578]=0;W(756,d+232|0,d+16|0,16)|0;b=v[114578];v[114578]=0;if((b|0)==1){break qa}b=_b(a,0);v[114578]=0;Q(757,b|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break qa}if(Ce(a)){continue}break}break z}b=P()|0;O()|0;break B}b=P()|0;O()|0;Bb(d+16|0);break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=P()|0;O()|0;break o}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}break D}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(p);break B}b=P()|0;O()|0}hd(l);break c}b=P()|0;O()|0;break o}hd(l)}Bb(d+232|0);Dz(d+248|0);Bb(C)}jb=d+288|0;return y|0}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;Bb(d+40|0);break o}b=P()|0;O()|0;Bb(d+56|0);break o}b=P()|0;O()|0;Bb(d+72|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break c}b=P()|0;O()|0}wn(j);wn(l);wn(k);break c}b=P()|0;O()|0;Bb(d+16|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+120|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+104|0);break d}b=P()|0;O()|0}yb(e)}Bb(d+232|0)}Dz(d+248|0)}Bb(C);S(b|0);L()}function Yga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,X=0,Y=0,Z=0;f=jb-416|0;jb=f;Jc(b);e=jb-16|0;jb=e;n=f+208|0;VO(e+8|0,n);k=b;h=Hb(e+8|0);g=nc(b,ac(e,e+8|0));if((h|0)==(g|0)){$b(k,Hb(e+8|0))}jb=e+16|0;k=(g|0)==(h|0);if(!k){WO(n)}a:{if(!k){break a}if(!_O(f+208|0)){break a}if(!c){d=1;break a}Hd(a,134217728);d=Ub(f+192|0,17360);v[114578]=0;R(219,f+144|0,d|0);k=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((k|0)!=1){v[114578]=0;o=f+208|4;U(1003,f+16|0,f+144|0,o|0);k=v[114578];v[114578]=0;if((k|0)==1){break r}Gb(a+1304436|0,f+16|0);yb(f+16|0);Ib(f+144|0);yb(d);d=Ub(f+16|0,17384);Gb(a+1304448|0,d);yb(d);v[a+480188>>2]=4;v[a+1304496>>2]=2;d=w[f+344|0]|w[f+345|0]<<8;v[a+480196>>2]=(d<<8|d>>>8)&65535;d=w[f+348|0]|w[f+349|0]<<8;v[a+480260>>2]=56;v[a+480264>>2]=13696;Y=a,Z=ZO((d<<8|d>>>8)&65535),v[Y+480204>>2]=Z;In(Vb(a+484360|0),f+216|0,w[f+208|6],65535,65535);r=a+480190|0;d=jb-16|0;jb=d;p=f+176|0;k=p;v[k>>2]=0;v[k+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1018,k+8|0,d+12|0,d+8|0)|0;k=v[114578];v[114578]=0;s:{if((k|0)!=1){jb=d+16|0;break s}V(0)|0;O()|0;Ab();L()}q=Ql(f+160|0);k=0;if(w[f+408|0]|w[f+409|0]<<8){break p}break o}a=P()|0;O()|0;break q}a=P()|0;O()|0;Ib(f+144|0)}yb(d);break d}while(1){v[114578]=0;d=T(485,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}u[f+120>>1]=d;if((d-1&65535)>>>0>=3999){break c}d=w[f+410|0]|w[f+411|0]<<8;d=(d<<8|d>>>8)&65535;t:{if((w[o|0]|w[o+1|0]<<8)!=512){break t}v[114578]=0;d=T(494,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}d=d-2|0}v[114578]=0;U(343,f+144|0,b|0,d|0);d=v[114578];v[114578]=0;u:{v:{w:{if((d|0)!=1){v[114578]=0;d=Q(454,r|0,f+120|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break w}A=x[d>>1];u[a+480190>>1]=A;v[114578]=0;d=B(x[f+120>>1],104)+a|0;n=d+484380|0;R(388,n|0,1);e=v[114578];v[114578]=0;x:{if((e|0)==1){break x}e=w[o|0]|w[o+1|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>1){break v}v[114578]=0;W(1004,f+144|0,d+484423|0,31)|0;e=v[114578];v[114578]=0;if((e|0)==1){break x}v[114578]=0;Q(340,f+144|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break x}v[114578]=0;W(390,f+144|0,((x[f+120>>1]<<5)+a|0)+946300|0,30)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break u}}a=P()|0;O()|0;break f}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}e=Wb(f+16|0);v[114578]=0;W(597,f+144|0,e|0,257)|0;h=v[114578];v[114578]=0;y:{z:{if((h|0)==1){break z}v[114578]=0;Q(372,d+484423|0,e|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break z}v[114578]=0;Q(340,f+144|0,1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break z}v[114578]=0;W(597,f+144|0,e|0,31)|0;h=v[114578];v[114578]=0;if((h|0)==1){break z}v[114578]=0;Q(371,((x[f+120>>1]<<5)+a|0)+946300|0,e|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break z}if(!(v[f+152>>2]&1)){break y}v[114578]=0;Q(340,f+144|0,1)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break y}}a=P()|0;O()|0;yb(e);break f}yb(e)}v[114578]=0;Q(1005,f+144|0,f+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}v[114578]=0;R(1006,f+16|0,n|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}if((w[o|0]|w[o+1|0]<<8)==512){t[d+484417|0]=w[f+34|0]<<3}A:{if(!(w[o|0]|w[o+1|0]<<8)){break A}v[114578]=0;R(386,q|0,A|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}v[114578]=0;R(1007,p|0,A|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}n=sd(p,x[f+120>>1]-1|0);e=n;wc(e);XO(e);ft(e);v[114578]=0;e=T(485,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break j}v[114578]=0;h=Q(258,b|0,e<<3)|0;g=v[114578];v[114578]=0;if((g|0)==1){break j}if(!h){break l}v[114578]=0;R(1008,n|0,e|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}g=0;v[f+136>>2]=0;if(!e){if(!(w[d+484414|0]&2)){break A}e=v[d+484384>>2];v[f+128>>2]=e;d=v[d+484388>>2];v[114578]=0;v[f+132>>2]=d-e;R(1009,n|0,f+128|0);d=v[114578];v[114578]=0;if((d|0)!=1){break A}a=P()|0;O()|0;break f}while(1){v[114578]=0;d=T(494,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break k}v[114578]=0;v[f+128>>2]=d;d=T(494,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break k}v[114578]=0;v[f+132>>2]=d;R(1009,n|0,f+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break k}g=g+1|0;if(e>>>0>(g&65535)>>>0){continue}break}}Bb(f+144|0);k=k+1|0;d=w[f+408|0]|w[f+409|0]<<8;if((k&65535)>>>0<((d<<8|d>>>8)&65535)>>>0){continue}break}}C=128;if(w[o|0]|w[o+1|0]<<8){break m}v[114578]=0;C=T(485,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break m}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}k=a+480188|0;D=w[f+208|7];u[f+126>>1]=4;B:{C:{D:{if(!(w[o|0]|w[o+1|0]<<8)){g=x[k>>1];break D}e=v[b+8>>2];E:{if(!C){break E}d=0;while(1){v[114578]=0;n=T(485,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break C}if((n|0)==65535){break E}v[114578]=0;D=T(485,b|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break C}v[114578]=0;n=T(485,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break C}v[114578]=0;u[f+126>>1]=n;n=Q(454,k|0,f+126|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break C}u[k>>1]=x[n>>1];v[114578]=0;Q(340,b|0,B(x[f+126>>1],D)<<2)|0;n=v[114578];v[114578]=0;if((n|0)==1){break C}d=d+1|0;if((d&65535)>>>0<C>>>0){continue}break}}d=0;v[114578]=0;Q(256,b|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break B}g=x[k>>1];if(g>>>0>127){break b}}v[114578]=0;G=Q(1010,f+144|0,g&65535)|0;d=v[114578];v[114578]=0;if((d|0)!=1){F:{if(!C){break F}K=a+484344|0;X=c&1;H=w[f+347|0];k=0;n=0;while(1){d=n;if(w[o|0]|w[o+1|0]<<8){v[114578]=0;d=T(485,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}if((d|0)==65535){break F}v[114578]=0;D=T(485,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}v[114578]=0;e=T(485,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}u[f+126>>1]=e}E=D&65535;G:{H:{I:{if(!X){break I}v[114578]=0;M=d&65535;d=W(404,K|0,M|0,E|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}if(!d){break I}s=0;if(E){break H}break G}v[114578]=0;Q(340,b|0,B(x[f+126>>1],E)<<2)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break G}break g}while(1){d=_b(K,M);v[114578]=0;l=Q(497,d|0,s|0)|0;d=v[114578];v[114578]=0;J:{if((d|0)!=1){g=0;z=0;K:{L:{switch((H&3)-1|0){case 0:z=!(s&3);break K;case 1:z=!(s&1);break K;case 2:break L;default:break K}}z=(s&3)!=3}I=0;if(!x[f+126>>1]){break J}while(1){d=v[G>>2];v[114578]=0;R(595,f+128|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break g}j=B(g,9)+d|0;d=dd(f+128|0);h=Bf(f+128|0);i=Sh(f+128|0);m=B(g,6)+l|0;t[m+1|0]=w[f+128|0];e=w[d|0];t[m|0]=e;d=w[i|0];t[m+5|0]=d;i=m+5|0;if(e){t[m|0]=e+25;t[j+8|0]=0;t[j|0]=0;t[j+1|0]=0;t[j+2|0]=0;t[j+3|0]=0;t[j+4|0]=0;t[j+5|0]=0;t[j+6|0]=0;t[j+7|0]=0;d=w[i|0]}e=d;J=w[h|0];M:{if(J>>>0>=240){d=e|(J&15)<<8;if(d){d=ZO(d);v[114578]=0;d=za(1011,+(+(d>>>0)*1e-4))|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[i|0]=d;t[m+3|0]=17;break M}break g}t[m+3|0]=0;break M}F=e>>>4|0;N=e<<4;h=F|N;N:{switch(J|0){case 0:e=B(g,6)+l|0;if(d){t[e+3|0]=1;break M}t[e+3|0]=0;break M;case 1:t[(B(g,6)+l|0)+3|0]=2;break M;case 2:t[(B(g,6)+l|0)+3|0]=3;break M;case 3:v[114578]=0;t[f+16|0]=15;d=Q(393,i|0,f+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[j|0]=w[d|0]|16;t[j+7|0]=0;t[j+1|0]=0;t[j+2|0]=0;t[(B(g,6)+l|0)+3|0]=0;break M}break g;case 4:v[114578]=0;t[f+16|0]=15;d=Q(393,i|0,f+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[j|0]=w[d|0]|32;t[j+7|0]=0;t[j+1|0]=0;t[j+2|0]=0;t[(B(g,6)+l|0)+3|0]=0;break M}break g;case 5:t[j+7|0]=0;t[j+2|0]=0;t[j+1|0]=d;t[j|0]=0;t[(B(g,6)+l|0)+3|0]=0;break M;case 6:t[j+7|0]=0;t[j+2|0]=d;t[j|0]=0;t[j+1|0]=0;t[(B(g,6)+l|0)+3|0]=0;break M;case 7:t[(B(g,6)+l|0)+3|0]=23;k=0;break M;case 8:t[(B(g,6)+l|0)+3|0]=0;k=h;break M;case 9:t[(B(g,6)+l|0)+3|0]=19;v[114578]=0;t[f+16|0]=15;d=Q(393,i|0,f+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[i|0]=w[d|0]|16;break M}break g;case 10:t[(B(g,6)+l|0)+3|0]=19;v[114578]=0;t[f+16|0]=15;d=Q(393,i|0,f+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[i|0]=w[d|0]|32;break M}break g;case 11:t[j+3|0]=h;t[(B(g,6)+l|0)+3|0]=0;break M;case 12:e=B(g,6)+l|0;t[e+4|0]=d;t[e+2|0]=1;t[j+3|0]=0;t[e+3|0]=0;break M;case 13:h=B(g,6)+l|0;O:{P:{if(e&240){t[(B(g,6)+l|0)+2|0]=4;d=(d&240)>>>4|0;break P}if(!(e&15)){break O}t[(B(g,6)+l|0)+2|0]=3;d=d&15}t[h+4|0]=d}t[j+3|0]=0;t[(B(g,6)+l|0)+3|0]=0;break M;case 14:t[(B(g,6)+l|0)+3|0]=19;t[i|0]=!d;break M;case 15:t[(B(g,6)+l|0)+3|0]=16;t[i|0]=(d&240)>>>4;H=d&15;break M;case 16:t[j+5|0]=0;t[j+4|0]=d;t[(B(g,6)+l|0)+3|0]=0;break M;case 17:t[j+6|0]=e&15?d:0;t[(B(g,6)+l|0)+3|0]=0;break M;case 18:t[(B(g,6)+l|0)+3|0]=14;break M;case 19:t[j+8|0]=0;t[j+7|0]=d;t[j+2|0]=0;t[j|0]=0;t[j+1|0]=0;t[(B(g,6)+l|0)+3|0]=0;break M;case 20:t[(B(g,6)+l|0)+3|0]=12;break M;case 22:Q:{d=w[m+1|0];R:{if(!d){break R}if(wc(p)>>>0<d>>>0){break R}d=sd(p,w[m+1|0]-1|0);e=w[i|0]-1|0;t[i|0]=e;v[114578]=0;Q(1012,f+16|0,0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}v[f+120>>2]=9;d=wc(d);v[114578]=0;v[f+12>>2]=d;d=Q(33,f+120|0,f+12|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Q}if(y[d>>2]<=(e&255)>>>0){break R}d=B(g,6)+l|0;t[d+2|0]=15;t[d+4|0]=w[i|0]}t[(B(g,6)+l|0)+3|0]=0;break M}break g;case 23:d=w[m+1|0];S:{if(!d){break S}if(wc(p)>>>0<d>>>0){break S}d=sd(p,w[m+1|0]-1|0);e=w[i|0]-1|0;t[i|0]=e;if(wc(d)>>>0<=(e&255)>>>0){break S}T:{if(x[sd(d,w[i|0])+8>>1]){break T}if(!En(a)){break T}e=x[r>>1]+1|0;u[r>>1]=e;Y=sd(d,w[i|0]),Z=e,u[Y+8>>1]=Z}Y=m,Z=w[sd(d,w[i|0])+8|0],t[Y+1|0]=Z}t[(B(g,6)+l|0)+3|0]=0;break M;case 24:U:{d=w[m+1|0];V:{if(!d){break V}if(wc(p)>>>0<d>>>0){break V}d=sd(p,w[m+1|0]-1|0);e=w[i|0]-1|0;t[i|0]=e;v[114578]=0;Q(1012,f+16|0,0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}v[f+120>>2]=9;d=wc(d);v[114578]=0;v[f+12>>2]=d;d=Q(33,f+120|0,f+12|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break U}if(y[d>>2]>(e&255)>>>0){d=B(g,6)+l|0;t[d+2|0]=15;t[d+4|0]=w[i|0]}W:{if(x[rc(q,w[m+1|0]-1|0)>>1]){break W}if(!En(a)){break W}d=x[r>>1]+1|0;u[r>>1]=d;Y=rc(q,w[m+1|0]-1|0),Z=d,u[Y>>1]=Z}Y=m,Z=w[rc(q,w[m+1|0]-1|0)|0],t[Y+1|0]=Z}t[(B(g,6)+l|0)+3|0]=0;break M}break g;case 25:d=w[m+1|0];X:{if(!d){break X}if(wc(p)>>>0<d>>>0){break X}d=sd(p,w[m+1|0]-1|0);e=w[i|0]-1|0;t[i|0]=e;if(wc(d)>>>0<=(e&255)>>>0){break X}Y:{if(x[sd(d,w[i|0])+10>>1]){break Y}if(!En(a)){break Y}e=x[r>>1]+1|0;u[r>>1]=e;Y=sd(d,w[i|0]),Z=e,u[Y+10>>1]=Z}Y=m,Z=w[sd(d,w[i|0])+10|0],t[Y+1|0]=Z}t[(B(g,6)+l|0)+3|0]=0;break M;case 29:t[(B(g,6)+l|0)+3|0]=11;t[i|0]=h;if(e&15){t[i|0]=N|15;break M}if(!F){break M}t[i|0]=F|240;break M;case 32:if(e&240){t[j+3|0]=F;t[(B(g,6)+l|0)+3|0]=0;break M}t[(B(g,6)+l|0)+3|0]=19;t[i|0]=d&15|192;break M;case 33:t[(B(g,6)+l|0)+3|0]=19;v[114578]=0;t[f+16|0]=15;d=Q(393,i|0,f+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[i|0]=w[d|0]|208;break M}break g;case 34:t[(B(g,6)+l|0)+3|0]=19;v[114578]=0;t[f+16|0]=15;d=Q(393,i|0,f+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[i|0]=w[d|0]|144;break M}break g;case 73:t[(B(g,6)+l|0)+3|0]=10;break M;case 78:if((d&112|128)==224){t[(B(g,6)+l|0)+3|0]=19;break M}t[(B(g,6)+l|0)+3|0]=0;break M;case 79:e=B(g,6)+l|0;if(d>>>0<=31){t[e+3|0]=16;H=0;break M}t[e+3|0]=17;break M;default:break N}}t[(B(g,6)+l|0)+3|0]=0}d=0;e=w[j+3|0];if(!(w[m+2|0]|!e)){Z:{if(e>>>0>=16){t[m+2|0]=5;t[m+4|0]=e>>>4;break Z}t[m+2|0]=6;t[m+4|0]=e}d=1}_:{if(w[m+3|0]){break _}e=w[j+1|0];if(e){t[m+3|0]=2;t[i|0]=e;break _}e=w[j+2|0];if(e){t[m+3|0]=3;t[i|0]=e;break _}e=w[j|0];if(e){t[m+3|0]=19;t[i|0]=e;break _}e=w[j+7|0];if(e){t[m+3|0]=4;t[j+8|0]=e;t[i|0]=e;break _}e=w[j+4|0];if(e){t[m+3|0]=5;t[j+5|0]=e;t[i|0]=e;break _}e=d;d=w[j+3|0];if(!(e|!d)){t[m+3|0]=11;t[i|0]=d;if(d&15){t[i|0]=d|240;break _}if(!(d&240)){break _}t[i|0]=d|15;break _}d=w[j+6|0];if(d){t[m+3|0]=8;t[i|0]=d;break _}if(z){t[m+3|0]=20;t[i|0]=97;z=0;break _}z=0;d=k&255;if(!d|I){break _}t[m+3|0]=24;t[i|0]=k;if(k&15){t[i|0]=k|240;I=1;break _}I=1;if(!(d&240)){break _}t[i|0]=k|15}g=g+1|0;if(g>>>0<x[f+126>>1]){continue}break}break J}break g}s=s+1|0;if((E|0)!=(s|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<C>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break g}if(w[o|0]|w[o+1|0]<<8){$:{while(1){v[114578]=0;d=Q(258,b|0,2)|0;k=v[114578];v[114578]=0;if((k|0)==1){break g}if(!d){break $}v[114578]=0;d=T(485,b|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break g}if((d|0)==65535){break $}v[114578]=0;Q(340,b|0,2)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;d=T(494,b|0)|0;k=v[114578];v[114578]=0;if((k|0)!=1){v[114578]=0;Q(340,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break g}v[114578]=0;Q(340,b|0,34)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}}aa:{if(!(!(c&2)|!A)){d=1;k=1;while(1){c=(B(d,104)+a|0)+484380|0;ba:{if(!v[c>>2]){break ba}e=ad(f+16|0,8,1,0,0);v[114578]=0;W(402,e|0,c|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break aa}if(wc(p)>>>0<d>>>0){break ba}d=d-1|0;e=sd(p,d);v[114578]=0;R(1013,c|0,e|0);e=v[114578];v[114578]=0;ca:{if((e|0)!=1){if(!x[rc(q,d)>>1]){break ca}e=x[rc(q,d)>>1];n=v[c>>2];v[114578]=0;fa(1014,c|0,(B(e,104)+a|0)+484380|0,0,n|0,0);e=v[114578];v[114578]=0;if((e|0)!=1){break ca}}break g}d=sd(p,d);Y=f,Z=bc(d),v[Y+16>>2]=Z;Y=f,Z=cc(d),v[Y+128>>2]=Z;if(!Jb(f+16|0,f+128|0)){break ba}while(1){d=v[f+16>>2];e=x[d+8>>1];if(e){n=v[d+4>>2];h=v[d>>2];v[114578]=0;fa(1014,c|0,(B(e,104)+a|0)+484380|0,h|0,n|0,1);e=v[114578];v[114578]=0;if((e|0)==1){break g}}e=x[d+10>>1];if(e){n=v[d+4>>2];d=v[d>>2];v[114578]=0;fa(1014,c|0,(B(e,104)+a|0)+484380|0,d|0,n|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break g}}zn(f+16|0);if(Jb(f+16|0,f+128|0)){continue}break}}k=k+1|0;d=k&65535;if(A>>>0>=d>>>0){continue}break}}Py(G);d=1;break b}break g}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}Bb(f+144|0);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Py(G);break e}Bb(f+144|0)}kf(q);YO(p)}S(a|0);L()}d=0}kf(q);YO(p)}jb=f+416|0;return d|0}function XG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0;K=jb-144|0;jb=K;a:{b:{c:{if(d>>>0<=e>>>0){j=v[f>>2];N=g&4;M=N?-1:j+((d^-1)+e|0)|0;E=M+1|0;if(!(E&M)){break c}}v[f>>2]=0;v[c>>2]=0;k=-3;break b}F=e+j|0;D=v[c>>2];z=D+b|0;G=v[a+60>>2];r=v[a+40>>2];j=v[a+36>>2];A=v[a+32>>2];m=v[a+56>>2];i=v[a+4>>2];l=b;p=e;s=-1;k=-1;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{q=v[a>>2];switch(q|0){case 35:break i;case 17:break j;case 21:break k;case 37:break l;case 34:break m;case 42:break q;case 41:break r;case 53:break s;case 52:break t;case 51:break u;case 38:break v;case 27:break w;case 26:break x;case 25:break y;case 24:break z;case 23:break A;case 18:break B;case 16:break C;case 14:break D;case 11:break E;case 9:break F;case 7:break G;case 6:break H;case 3:break I;case 32:break J;case 5:break K;case 2:break M;case 1:break N;case 0:break O;case 36:break f;case 39:break g;case 10:break h;default:break d}}v[a+28>>2]=1;m=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;r=0;j=0;A=0;i=0;if(g&1){break N}break L}if((D|0)<=0){v[a>>2]=1;break e}v[a+8>>2]=w[b|0];l=b+1|0}if(l>>>0>=z>>>0){v[a>>2]=2;k=g&2?1:-4;break d}j=w[l|0];v[a+12>>2]=j;h=v[a+8>>2];k=(((j|h<<8)>>>0)%31|j&32)!=0|(h&15)!=8;j=1;l=l+1|0;if(!N){q=36;h=256<<(h>>>4);if(!(k|(h>>>0>32768|h>>>0>E>>>0))){break L}break f}q=36;if(k){break f}}h=0;break p}if((D|0)<=0){v[a>>2]=5;break e}l=b+1|0;m=w[b|0]<<i|m;i=i+8|0;h=2;break p}if((D|0)<=0){v[a>>2]=32;break e}l=b+1|0;m=w[b|0]<<i|m;C=j;i=i+8|0;break o}h=1;break p}h=4;break p}h=3;break p}h=7;break p}h=9;break p}h=10;break p}h=11;break p}h=12;break p}h=13;break p}h=14;break p}h=15;break p}h=16;break p}h=17;break p}h=8;break p}h=5;break p}h=6;break p}h=18;break p}n=2;break n}n=1;break n}P:while(1){Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{switch(h|0){case 0:j=C;if(i>>>0>2){break Fa}h=1;continue;case 17:break na;case 16:break oa;case 15:break pa;case 14:break qa;case 13:break ra;case 12:break sa;case 11:break ta;case 10:break ua;case 9:break va;case 8:break xa;case 7:break ya;case 6:break za;case 5:break Aa;case 4:break Ca;case 3:break Da;case 2:break Ea;case 1:break Ga;default:break ma}}while(1){if(l>>>0>=z>>>0){v[a>>2]=3;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;C=j}j=m&7;v[a+20>>2]=j;H=1;h=j>>>1|0;v[a+24>>2]=h;i=i-3|0;m=m>>>3|0;k=0;j=C;switch(h|0){case 0:break la;case 1:break wa;case 3:break h;default:break ia}}h=i&-8;m=m>>>(i&7)|0;j=0;i=0;break ja}if(l>>>0<z>>>0){break Ba}v[a>>2]=7;k=g&2?1:-4;break d}while(1){if(l>>>0>=z>>>0){v[a>>2]=6;k=g&2?1:-4;break d}m=w[l|0]<<i|m;o=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(o){continue}break}l=k;i=1;break ja}t[(a+j|0)+10528|0]=w[l|0];l=l+1|0;h=i;i=2;break ja}while(1){if(l>>>0>=z>>>0){v[a>>2]=51;k=g&2?1:-4;break d}m=w[l|0]<<i|m;o=i>>>0>4294967287;k=l+1|0;l=k;h=i+8|0;i=h;if(o){continue}break}l=k;break S}if(p>>>0<F>>>0){t[p|0]=A;j=j-1|0;p=p+1|0;h=i;break W}s=2;q=52;break f}if(p>>>0<F>>>0){break ka}s=2;q=9;break f}if(l>>>0>=z>>>0){v[a>>2]=38;k=g&2?1:-4;break d}h=F-p|0;k=z-l|0;h=h>>>0<k>>>0?h:k;h=h>>>0<j>>>0?h:j;j=j-h|0;p=lc(p,l,h)+h|0;l=h+l|0;break V}v[a+44>>2]=288;v[a+48>>2]=32;h=a+3552|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3560|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3568|0;v[h>>2]=84215045;v[h+4>>2]=84215045;h=a+3576|0;v[h>>2]=84215045;v[h+4>>2]=84215045;Rb(a- -64|0,8,144);Rb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;break _}while(1){if(l>>>0>=z>>>0){v[a>>2]=11;k=g&2?1:-4;break d}m=w[l|0]<<i|m;k=l+1|0;l=k;h=i+8|0;i=h;I=t[j+42396|0];if(h>>>0<I>>>0){continue}break}l=k;k=j;i=h;j=1;break aa}while(1){if(l>>>0>=z>>>0){v[a>>2]=14;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(i>>>0<3){continue}break}l=h;h=1;break $}if(l>>>0>=z>>>0){v[a>>2]=16;k=g&2?1:-4;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break ha}break ga}while(1){if(l>>>0>=z>>>0){v[a>>2]=18;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(r>>>0>i>>>0){continue}break}O=A-16|0;l=h;h=3;break Z}if(l>>>0>=z>>>0){v[a>>2]=23;k=g&2?1:-4;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break fa}break ea}if(p>>>0>=F>>>0){s=2;q=24;break f}t[p|0]=j;p=p+1|0;n=m;break Y}while(1){if(l>>>0>=z>>>0){v[a>>2]=25;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(r>>>0>i>>>0){continue}break}l=h;h=3;break X}if(l>>>0>=z>>>0){v[a>>2]=26;k=g&2?1:-4;break d}m=w[l|0]<<i|m;l=l+1|0;i=i+8|0;if(i>>>0<15){break da}break ca}while(1){if(l>>>0>=z>>>0){v[a>>2]=27;k=g&2?1:-4;break d}m=w[l|0]<<i|m;h=l+1|0;l=h;i=i+8|0;if(r>>>0>i>>>0){continue}break}l=h;h=6;break X}if(p>>>0>=F>>>0){s=2;q=53;break f}t[p|0]=w[(G-A&M)+d|0];p=p+1|0;G=G+1|0;break ba}h=2;continue}h=8;continue}while(1){Ha:{Ia:{Ja:{Ka:{La:{switch(i|0){case 0:if(j>>>0>3){break Ka}if(!h){i=0;h=3;continue P}i=h;if(h>>>0>7){break Ia}h=4;continue P;case 1:t[(a+j|0)+10528|0]=m;h=h-8|0;m=m>>>8|0;break Ha;default:break La}}j=j+1|0;break Ja}i=h;j=x[a+10528>>1];if((j|0)==(x[a+10530>>1]^65535)){break W}break g}i=0;continue}i=1;continue}i=2;continue}}j=0;break aa}h=1;break Z}h=2;break Z}h=0;break X}h=1;break X}h=4;break X}h=5;break X}h=7;break X}while(1){Ma:{Na:{Oa:{if(!j){if(k>>>0>2){break Oa}j=k;I=t[j+42396|0];if(I>>>0<=i>>>0){break Ma}h=9;continue P}j=k<<2;v[(j+a|0)+44>>2]=v[j+42384>>2]+((-1<<I^-1)&m);k=k+1|0;i=i-I|0;m=m>>>I|0;break Na}j=0;Rb(a+7040|0,0,288);h=0;break $}j=0;continue}j=1;continue}}while(1){Pa:{Qa:{Ra:{if(!h){if(y[a+52>>2]<=j>>>0){break Ra}if(i>>>0>2){break Pa}h=10;continue P}t[(w[j+42448|0]+a|0)+7040|0]=m&7;j=j+1|0;i=i-3|0;m=m>>>3|0;break Qa}v[a+52>>2]=19;H=v[a+24>>2];C=j;break _}h=0;continue}h=1;continue}}h=0}while(1){Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{switch(h|0){case 0:j=0;if((H|0)<0){n=m;j=C;break Y}D=Rb(K,0,64);k=B(H,3488)+a|0;Rb(k+352|0,0,3200);q=v[a+24>>2];h=v[((q<<2)+a|0)+44>>2];if(h){while(1){o=D+(w[(j+k|0)- -64|0]<<2)|0;v[o>>2]=v[o>>2]+1;j=j+1|0;if((h|0)!=(j|0)){continue}break}}v[D+64>>2]=0;v[D+68>>2]=0;o=0;k=0;j=1;while(1){s=j<<2;j=j+1|0;s=v[s+D>>2];o=s+o<<1;v[(D- -64|0)+(j<<2)>>2]=o;k=k+s|0;if((j|0)!=16){continue}break};if(!((o|0)==65536|k>>>0<2)){j=C;break i}if(h){h=-1;E=0;J=B(H,3488)+a|0;while(1){q=w[(E+J|0)- -64|0];$a:{if(!q){break $a}k=(D- -64|0)+(q<<2)|0;j=v[k>>2];v[k>>2]=j+1;k=0;o=q;while(1){s=k;k=j&1|k<<1;j=j>>>1|0;o=o-1|0;if(o){continue}break}if(q>>>0<=10){if(k>>>0>1023){break $a}j=1<<q;o=q<<9|E;while(1){u[((k<<1)+J|0)+352>>1]=o;k=j+k|0;if(k>>>0<1024){continue}break}break $a}k=((k&1023)<<1)+J|0;j=u[k+352>>1];ab:{if(j){k=h;h=j;break ab}u[k+352>>1]=h;k=h-2|0}j=s>>>8&8388607;if(q>>>0>=12){while(1){j=j>>>1|0;o=(((j&1)+(h^-1)<<1)+J|0)+2400|0;h=u[o>>1];if(!h){u[o>>1]=k;h=k;k=h-2|0}q=q-1|0;if(q>>>0>11){continue}break}}u[(((j>>>1&1)+(h^-1)<<1)+J|0)+2400>>1]=E;h=k}E=E+1|0;q=v[a+24>>2];if(E>>>0<y[((q<<2)+a|0)+44>>2]){continue}break}}j=0;if((q|0)!=2){break Ta}break Xa;case 1:h=u[(((m&1023)<<1)+a|0)+7328>>1];bb:{if((h|0)>=0){if((h>>9)-1>>>0>=i>>>0){break bb}break Wa}if(i>>>0<11){break bb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break Wa}}h=11;continue P;case 2:k=u[(((m&1023)<<1)+a|0)+7328>>1];if((k|0)>=0){break Za}h=10;while(1){o=m>>>h|0;h=h+1|0;k=u[(((o&1)+(k^-1)<<1)+a|0)+9376>>1];if((k|0)<0){continue}break};break Ya;default:break _a}}h=t[O+42404|0]+((-1<<r^-1)&m)|0;i=i-r|0;m=m>>>r|0;k=a+j|0;Rb(k+10532|0,(A|0)==16?w[k+10531|0]:0,h);j=h+j|0;break Xa}h=k>>9;k=k&511}i=i-h|0;m=m>>>h|0;A=k;if(k>>>0>15){break Va}t[(a+j|0)+10532|0]=A;j=j+1|0}k=v[a+48>>2];h=v[a+44>>2];o=k+h|0;if(o>>>0<=j>>>0){break Ua}if(i>>>0>14){break Wa}if((z-l|0)<=1){h=1;continue}m=w[l|0]<<i|m|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=2;continue}if(!((A|0)!=16|j)){A=16;j=0;break j}O=A-16|0;r=t[O+42400|0];if(r>>>0<=i>>>0){break Sa}h=12;continue P}if((j|0)!=(o|0)){break k}C=a+10532|0;lc(a- -64|0,C,h);lc(a+3552|0,h+C|0,k);q=v[a+24>>2];C=j}H=q-1|0;v[a+24>>2]=H;h=0;continue}h=3;continue}}h=2}cb:while(1){db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{switch(h|0){case 0:h=u[(((m&1023)<<1)+a|0)+352>>1];sb:{if((h|0)>=0){if((h>>9)-1>>>0>=i>>>0){break sb}break db}if(i>>>0<11){break sb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break db}}h=13;continue P;case 1:k=u[(((m&1023)<<1)+a|0)+352>>1];if((k|0)>=0){break qb}h=10;while(1){j=m>>>h|0;h=h+1|0;k=u[(((j&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break};j=k;break pb;case 3:break gb;case 4:break hb;case 5:break lb;case 6:break mb;case 2:break rb;default:break nb}}while(1){h=z-l|0;if(!((F-p|0)>1?(h|0)>=4:0)){if(i>>>0>14){m=n;break db}if((h|0)<=1){m=n;h=0;continue cb}m=w[l|0]<<i|n|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0;break db}tb:{if(i>>>0>14){m=i;h=l;break tb}m=i+16|0;n=(w[l|0]|w[l+1|0]<<8)<<i|n;h=l+2|0}j=u[(((n&1023)<<1)+a|0)+352>>1];ub:{if((j|0)<0){l=10;while(1){i=n>>>l|0;l=l+1|0;j=u[(((i&1)+(j^-1)<<1)+a|0)+2400>>1];if((j|0)<0){continue}break}break ub}l=j>>9}i=m-l|0;m=n>>>l|0;if(j&256){l=h;break ob}if(i>>>0>14){k=i}else{m=(w[h|0]|w[h+1|0]<<8)<<i|m;h=h+2|0;k=i+16|0}l=h;h=u[(((m&1023)<<1)+a|0)+352>>1];vb:{if((h|0)<0){n=10;while(1){i=m>>>n|0;n=n+1|0;h=u[(((i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break vb}n=h>>9}t[p|0]=j;i=k-n|0;n=m>>>n|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;m=n;j=h;break ob}h=k>>9;j=k&511}i=i-h|0;m=m>>>h|0;if(j>>>0>255){break ob}h=14;continue P}C=256;k=j&511;h=256;if((k|0)==256){break U}r=0;h=m;o=(k<<2)-1028|0;j=v[o+41872>>2];s=j;if(k-265>>>0>19){break fb}r=v[o+42e3>>2];if(r>>>0>i>>>0){h=15;continue P}h=3;continue}if(!j){n=m;j=-1;break jb}j=j-1|0;h=18;continue P}i=i-r|0;n=m>>>r|0;A=((-1<<r^-1)&m)+A|0;break kb}r=u[(((m&1023)<<1)+a|0)+3840>>1];wb:{if((r|0)<0){h=10;while(1){k=m>>>h|0;h=h+1|0;r=u[(((k&1)+(r^-1)<<1)+a|0)+5888>>1];if((r|0)<0){continue}break}k=r;break wb}h=r>>9;k=r&511}o=k<<2;A=v[o+42128>>2];i=i-h|0;m=m>>>h|0;r=0;if(k-4>>>0>25){n=m;break kb}r=v[o+42256>>2];if(r>>>0<=i>>>0){break ib}h=17;continue P}G=p-d|0;if(!(!N|G>>>0>=A>>>0)){m=n;break l}h=(G-A&M)+d|0;if((h>>>0<p>>>0?p:h)+j>>>0>F>>>0){m=n;h=7;continue}if(j>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;j=j-3|0;if(j>>>0>2){continue}break}}if(!j){break jb}t[p|0]=w[h|0];if((j|0)!=1){t[p+1|0]=w[h+1|0]}p=j+p|0}h=2;continue}h=6;continue}h=u[(((m&1023)<<1)+a|0)+3840>>1];xb:{if((h|0)>=0){if((h>>9)-1>>>0>=i>>>0){break xb}break eb}if(i>>>0<11){break xb}k=10;while(1){h=u[(((m>>>k&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<=-1){o=k+2|0;k=k+1|0;if(i>>>0>=o>>>0){continue}}break}if((h|0)>-1){break eb}}h=16;continue P}i=i-r|0;h=m>>>r|0;s=((-1<<r^-1)&m)+j|0}j=s;m=h;if(i>>>0>14){break eb}if((z-l|0)<=1){h=4;continue}m=m|w[l|0]<<i|w[l+1|0]<<i+8;i=i+16|0;l=l+2|0}h=5;continue}h=1;continue}}if(h?j:0){break T}i=h}if(j){break Q}h=0}C=h;if(!(t[a+20|0]&1)){break R}break o}i=h;if(h>>>0>7){break S}h=5;continue}i=h-8|0;A=m&255;m=m>>>8|0;h=6;continue}h=0;continue}h=7;continue}}n=i&-8;if(!(!n|b>>>0>=l>>>0)){j=n-8|0;d=j>>>3|0;h=(b^-1)+l|0;d=d>>>0<h>>>0?d:h;n=j-(d<<3)|0;l=(d^-1)+l|0}if(!n){m=(((n&63)>>>0>=32?0:-1<<n)^-1)&m>>>(i&7);o=0;h=0;j=C;i=0;if(!(g&1)){break m}n=0;break n}ha(42408,41840,2787,42418);L()}while(1){yb:{zb:{Ab:{Bb:{Cb:{Db:{switch(n|0){case 0:if(o>>>0>3){j=o;i=h;break m}if(h){break Cb}i=0;j=o;n=1;continue;case 1:break Db;default:break Bb}}if(l>>>0<z>>>0){break zb}v[a>>2]=42;k=g&2?1:-4;break d}j=o;i=h;if(h>>>0>7){break Ab}n=2;continue}while(1){if(l>>>0>=z>>>0){v[a>>2]=41;k=g&2?1:-4;break d}m=w[l|0]<<i|m;n=i>>>0>4294967287;d=l+1|0;l=d;h=i+8|0;i=h;if(n){continue}break}l=d;o=j}n=m&255;m=m>>>8|0;h=h-8|0;break yb}n=w[l|0];l=l+1|0;o=j;h=i}v[a+16>>2]=v[a+16>>2]<<8|n;o=o+1|0;n=0;continue}}s=0;q=34;break f}q=37;s=-1;break f}q=21;s=-1;break f}q=17;s=-1;break f}q=35;s=-1;break f}q=10;s=-1;break f}q=39;s=-1}v[a>>2]=q;if(!(i>>>0<8|b>>>0>=l>>>0)){h=i-8|0;d=h>>>3|0;i=(b^-1)+l|0;d=d>>>0<i>>>0?d:i;l=(d^-1)+l|0;i=h-(d<<3)|0}k=s;break d}k=g&2?1:-4}v[a+4>>2]=i;v[a+60>>2]=G;v[a+40>>2]=r;v[a+36>>2]=j;v[a+32>>2]=A;v[a+56>>2]=(((i&63)>>>0>=32?0:-1<<i)^-1)&m;v[c>>2]=l-b;h=p-e|0;v[f>>2]=h;if(!(g&9)|(k|0)<0){break b}b=v[a+28>>2];l=b>>>16|0;i=b&65535;if(h){n=(h>>>0)%5552|0;while(1){j=0;if(n>>>0>=8){m=8;while(1){b=w[e|0]+i|0;c=b+w[e+1|0]|0;d=c+w[e+2|0]|0;f=d+w[e+3|0]|0;j=f+w[e+4|0]|0;C=j+w[e+5|0]|0;o=C+w[e+6|0]|0;i=o+w[e+7|0]|0;l=i+(o+(C+(j+(f+(d+(c+(b+l|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;if(n>>>0>(m|7)>>>0){m=m+8|0;continue}break}j=n&8184}if(j>>>0<n>>>0){b=n-j|0;m=e;while(1){i=w[m|0]+i|0;l=l+i|0;m=m+1|0;j=j+1|0;if((n|0)!=(j|0)){continue}break}e=b+e|0}h=h-n|0;l=(l>>>0)%65521|0;i=(i>>>0)%65521|0;n=5552;if(h){continue}break}}b=l<<16|i;v[a+28>>2]=b;if(k){break b}k=0;if(g&1){break a}}jb=K+144|0;return k}jb=K+144|0;return v[a+16>>2]==(b|0)?0:-2}function o1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=0,L=C(0),M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=C(0),W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=C(0);E=jb-17168|0;jb=E;v[E+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!Bo(a+6152|0,b)){break c}h=Dw(b,v[a+6148>>2])+Ao(b)|0;v[E+17164>>2]=h;if((c|0)==(h|0)){h=c;break b}d:{if((h+4|0)<=(c|0)){if(Bo(b,b+h|0)){break d}}v[E+17164>>2]=0;break c}if(h){break b}}j=b;s=Rb(a,0,6668)+6148|0;q=E+17164|0;i=c;e:{if((c|0)>=5){y=i-4|0;while(1){if(SG(j)){r=Dw(j,v[s>>2]);h=r+Ao(j)|0;f=0;f:{g:{if(r){break g}l=4;H=k+4|0;while(1){if((y|0)<=((l<<1)+k|0)){break f}r=0;f=j+l|0;h:{if(!Bo(j,f)){break h}g=l-Ao(j)|0;A=Ao(f)+g|0;if((i|0)<(A+(l+H|0)|0)){break h}if(!Bo(j,f+A|0)){break h}v[s>>2]=g;r=g;h=l}f=!r;if(l>>>0>2302){break g}l=l+1|0;if(!r){continue}break}}if((i|0)<(h+k|0)|f){break f}A=j;H=i-k|0;g=0;f=0;i:{while(1){o=g;g=g+A|0;g=(o+Dw(g,r)|0)+Ao(g)|0;o=(f|0)!=0;if((H|0)<(g+4|0)){break i}o=0;if(!Bo(A,g+A|0)){break i}f=f+1|0;if((f|0)!=10){continue}break}o=1}if(o){break e}}if(!((h|0)!=(i|0)|k)){k=0;h=i;break e}v[s>>2]=0}j=j+1|0;k=k+1|0;if((y|0)!=(k|0)){continue}break}}h=0;k=i}v[q>>2]=h;p=k;h=v[E+17164>>2];if((h+k|0)<=(c|0)?h:0){break b}v[e>>2]=p;p=0;break a}H=b+p|0;v[a+6152>>2]=w[H|0]|w[H+1|0]<<8|(w[H+2|0]<<16|w[H+3|0]<<24);v[e+4>>2]=p;v[e>>2]=h+p;v[e+8>>2]=w[H+3|0]>191?1:2;ba=e,ca=WG(H),v[ba+12>>2]=ca;v[e+16>>2]=4-(w[H+1|0]>>>1&3);ba=e,ca=Cw(H),v[ba+20>>2]=ca;if(!d){p=Bw(H);break a}UG(E+17152|0,H+4|0,h-4|0);if(!(t[H+1|0]&1)){Ud(E+17152|0,16)}j:{if(v[e+16>>2]==3){p=0;y=E+17152|0;h=E+3740|0;k=0;c=H;g=w[c+1|0];b=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[c+2|0]>>>2&3)|0;i=b-((b|0)!=0)|0;l=w[c+3|0]>191?1:2;k:{if(g&8){f=Ud(y,9);l=l<<1;k=Ud(y,l+7|0);break k}f=Ud(y,l|8)>>>l|0}b=B(i,40);q=b+42768|0;A=b+43088|0;j=B(i,23)+42576|0;l:{m:{while(1){g=w[c+3|0];i=Ud(y,12);u[h+4>>1]=i;b=Ud(y,9);u[h+6>>1]=b;if((b&65535)>>>0>288){break m}r=g>>>0>191?k<<4:k;ba=h,ca=Ud(y,8),t[ba+10|0]=ca;b=Ud(y,w[c+1|0]&8?4:9);t[h+13|0]=22;t[h+14|0]=0;v[h>>2]=j;u[h+8>>1]=b;n:{if(Ud(y,1)){b=Ud(y,2);t[h+11|0]=b;if(!(b&255)){break m}g=Ud(y,1);u[h+18>>1]=65287;t[h+12|0]=g;if(w[h+11|0]==2){b=h;o:{if(!(g&255)){v[h>>2]=q;t[h+18|0]=8;k=0;g=39;break o}v[h>>2]=A;k=w[c+1|0]&8?8:6;g=30}t[b+14|0]=g;t[h+13|0]=k;r=r&3855}b=Ud(y,10);ba=h,ca=Ud(y,3),t[ba+21|0]=ca;ba=h,ca=Ud(y,3),t[ba+22|0]=ca;ba=h,ca=Ud(y,3),t[ba+23|0]=ca;k=b<<5;break n}t[h+11|0]=0;t[h+12|0]=0;k=Ud(y,15);ba=h,ca=Ud(y,4),t[ba+18|0]=ca;b=Ud(y,3);t[h+20|0]=255;t[h+19|0]=b}t[h+17|0]=k&31;t[h+15|0]=k>>>10;t[h+16|0]=k>>>5&31;D=(i&65535)+D|0;b=h;p:{if(w[c+1|0]&8){i=Ud(y,1);break p}i=x[h+8>>1]>499}t[b+24|0]=i;ba=h,ca=Ud(y,1),t[ba+25|0]=ca;b=Ud(y,1);t[h+27|0]=r>>>12&15;t[h+26|0]=b;h=h+28|0;k=r<<4;l=l-1|0;if(l){continue}break}b=(v[y+4>>2]+D|0)>(v[y+8>>2]+(f<<3)|0)?-1:f;break l}b=-1}if(!((b|0)<0|v[E+17156>>2]>v[E+17160>>2])){r=E+17152|0;g=v[r+4>>2];i=v[r+8>>2];h=E+912|0;j=v[a+6144>>2];c=j-b|0;A=(b|0)<(j|0)?b:j;j=lc(h+12|0,(((c|0)>0?c:0)+a|0)+6156|0,A);c=(i-g|0)/8|0;lc(j+A|0,v[r>>2]+(v[r+4>>2]/8|0)|0,c);UG(h,j,c+A|0);h=(b|0)<=v[a+6144>>2];if(h){Y=a+2304|0;p=v[e+8>>2];Z=E+8620|0;_=E+3852|0;b=0;while(1){$=Rb(_,0,4608);A=E+912|0;r=(B(B(b,p),28)+E|0)+3740|0;l=0;y=a;S=y+6152|0;if((p|0)>=1){j=A+7548|0;while(1){s=B(l,28)+r|0;D=x[s+4>>1];M=v[A+4>>2];K=(A+B(l,39)|0)+16156|0;k=A;i=j;c=l;o=jb-48|0;jb=o;m=s;R=!w[m+13|0]+(w[m+14|0]!=0)|0;T=w[m+25|0];f=o;N=f+44|0;q=S;q:{if(w[q+1|0]&8){F=w[m+27|0];g=w[x[m+8>>1]+43504|0];c=g&3;t[o+47|0]=c;t[o+46|0]=c;c=g>>>2|0;t[o+45|0]=c;t[o+44|0]=c;c=B(R,28)+43408|0;break q}c=(w[q+3|0]&16)>>>4&(c|0)!=0;O=c?12:0;U=x[m+8>>1]>>>c|0;while(1){G=1;g=3;while(1){c=g;I=w[(c+O|0)+43520|0];t[c+(o+44|0)|0]=((U|0)/(G|0)|0)%(I|0);G=B(G,I);g=c-1|0;if(c){continue}break}O=O+4|0;U=U-G|0;if((U|0)>-1){continue}break}F=-16;c=(B(R,28)+43408|0)+O|0}G=0;while(1){P=w[c+G|0];if(P){r:{if(F&8){lc(f,K,P);break r}R=w[G+N|0];if(!R){Rb(f,0,P);Rb(K,0,P);break r}g=(F|0)>-1?-1:-1<<R^-1;O=0;while(1){I=Ud(k,R);t[K+O|0]=(g|0)==(I|0)?-1:I;t[f+O|0]=I;O=O+1|0;if((P|0)!=(O|0)){continue}break}}F=F<<1;f=f+P|0;K=K+P|0;G=G+1|0;if((G|0)!=4){continue}}break}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;I=w[m+14|0];s:{if(I){c=2-T|0;f=w[m+23|0]<<c;k=w[m+22|0]<<c;g=w[m+21|0]<<c;c=w[m+13|0];G=0;while(1){N=o+(c+G|0)|0;t[N|0]=g+w[N|0];t[N+1|0]=k+w[N+1|0];t[N+2|0]=f+w[N+2|0];G=G+3|0;if(I>>>0>G>>>0){continue}break}break s}if(!w[m+24|0]){break s}F=0;while(1){c=o+F|0;t[c+11|0]=w[c+11|0]+w[F+43544|0];F=F+1|0;if((F|0)!=10){continue}break}}L=Aw(C(2048),((((w[q+3|0]&224)==96)<<1)-w[m+10|0]|0)+258|0);F=0;if((I|0)!=(0-w[m+13|0]|0)){c=T+1|0;while(1){ba=i+(F<<2)|0,da=Aw(L,w[o+F|0]<<c),z[ba>>2]=da;F=F+1|0;if(F>>>0<w[m+14|0]+w[m+13|0]>>>0){continue}break}}jb=o+48|0;o=(A+B(l,2304)|0)+2940|0;c=j;D=D+M|0;J=C(0);P=0;k=A;i=v[k+4>>2];q=v[k>>2]+((i|0)/8|0)|0;g=w[q|0]|w[q+1|0]<<8|(w[q+2|0]<<16|w[q+3|0]<<24);f=(g<<24|g<<8&16711680|(g>>>8&65280|g>>>24))<<(i&7);n=i|-8;K=q+4|0;F=v[s>>2];G=x[s+6>>1];g=1;t:{if(!G){break t}while(1){i=s+P|0;g=w[i+15|0];X=(u[(g<<1)+47968>>1]<<1)+43584|0;O=w[i+18|0];u:{if(g>>>0>=16){M=w[g+48032|0];I=32-M|0;while(1){N=w[F|0]>>>1|0;q=(G|0)>(N|0)?N:G;J=z[c>>2];while(1){m=u[X+(f>>>26&62)>>1];if((m|0)<=-1){g=5;while(1){n=g+n|0;f=f<<g;g=m&7;m=u[X+((f>>>32-g|0)-(m<<16>>19)<<1)>>1];if((m|0)<0){continue}break}}U=m&65535;i=U>>>8|0;n=i+n|0;f=f<<i;W=1;while(1){aa=o;g=U&15;v:{if((g|0)==15){m=f<<M;g=(f>>>I|0)+15|0;n=n+M|0;if((n|0)>=0){while(1){m=w[K|0]<<n|m;f=(n|0)>7;n=n-8|0;K=K+1|0;if(f){continue}break}}V=C(J*C(((m|0)>-1?1:-1)|0));f=g;w:{if((f|0)<=128){Q=z[(f<<2)+48128>>2];break w}T=f<<3;i=f;f=(f|0)<1024;T=f?T:i;R=T<<1&64;L=C(C((T&63)-R|0)/C((T&-64)+R|0));Q=C(C(C(C(C(C(L*C(.2222222238779068))+C(1.3333333730697632))*L)+C(1))*(f?C(16):C(256)))*z[(R+T>>6<<2)+48128>>2])}V=C(V*Q);break v}m=f;V=C(z[(((f>>>27&16|g)^16)<<2)+48064>>2]*J)}z[aa>>2]=V;U=U>>>4|0;o=o+4|0;i=(g|0)!=0;n=i+n|0;f=m<<i;i=W&1;W=0;if(i){continue}break}if((n|0)>-1){while(1){f=w[K|0]<<n|f;i=(n|0)>7;n=n-8|0;K=K+1|0;if(i){continue}break}}q=q-1|0;if(q){continue}break}G=G-N|0;c=c+4|0;F=F+1|0;if((O|0)<1){break u}O=O-1|0;if((G|0)>0){continue}break}break u}while(1){q=w[F|0]>>>1|0;W=(q|0)<(G|0)?q:G;J=z[c>>2];while(1){m=u[X+(f>>>26&62)>>1];if((m|0)<=-1){g=5;while(1){n=g+n|0;f=f<<g;g=m&7;m=u[X+((f>>>32-g|0)-(m<<16>>19)<<1)>>1];if((m|0)<0){continue}break}}m=m&65535;i=m>>>8|0;n=i+n|0;f=f<<i;g=1;while(1){i=m&15;z[o>>2]=z[(((i|f>>>27&16)^16)<<2)+48064>>2]*J;m=m>>>4|0;o=o+4|0;i=(i|0)!=0;n=i+n|0;f=f<<i;i=g&1;g=0;if(i){continue}break}if((n|0)>-1){while(1){f=w[K|0]<<n|f;i=(n|0)>7;n=n-8|0;K=K+1|0;if(i){continue}break}}W=W-1|0;if(W){continue}break}G=G-q|0;c=c+4|0;F=F+1|0;if((O|0)<1){break u}O=O-1|0;if((G|0)>0){continue}break}}P=P+1|0;if((G|0)>0){continue}break}g=1-G|0}while(1){x:{i=w[s+26|0]?47952:47920;m=w[i+(f>>>28|0)|0];if(!(m&8)){m=w[i+((f<<4>>>32-(m&3))+(m>>>3)|0)|0]}q=m&7;n=q+n|0;if((D|0)<((n+(K-v[k>>2]<<3)|0)-24|0)){break x}g=g-1|0;i=c;y:{if(g){break y}g=w[F|0]>>>1|0;if(!g){break x}F=F+1|0;J=z[c>>2];i=c+4|0}f=f<<q;if(m&128){z[o>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}if(m&64){z[o+4>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}g=g-1|0;c=i;z:{if(g){break z}g=w[F|0]>>>1|0;if(!g){break x}F=F+1|0;J=z[i>>2];c=i+4|0}if(m&32){z[o+8>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}if(m&16){z[o+12>>2]=(f|0)<0?C(-J):J;n=n+1|0;f=f<<1}if((n|0)>=0){while(1){f=w[K|0]<<n|f;i=(n|0)>7;n=n-8|0;K=K+1|0;if(i){continue}break}}o=o+16|0;continue}break}v[k+4>>2]=D;l=l+1|0;if((p|0)!=(l|0)){continue}break}}c=w[y+6155|0];A:{if(c&16){l=0;M=jb-16|0;jb=M;q=A+2940|0;f=q+2304|0;j=r;m=v[j>>2];o=w[j+14|0];s=o+w[j+13|0]|0;I=s;N=M+4|0;v[N+8>>2]=-1;v[N>>2]=-1;v[N+4>>2]=-1;if(s>>>0>=1){while(1){D=0;k=l+m|0;i=w[k|0];c=0;B:{if(!i){break B}C:{while(1){g=D<<2;if(z[g+f>>2]!=C(0)|z[(g|4)+f>>2]!=C(0)){break C}D=D+2|0;if(i>>>0>D>>>0){continue}break}c=i;break B}v[N+((l>>>0)%3<<2)>>2]=l;c=w[k|0]}f=((c&255)<<2)+f|0;l=l+1|0;if((I|0)!=(l|0)){continue}break}}if(w[j+13|0]){g=v[M+12>>2];i=v[M+8>>2];c=v[M+4>>2];c=(c|0)<(i|0)?i:c;c=(c|0)<(g|0)?g:c;v[M+12>>2]=c;v[M+8>>2]=c;v[M+4>>2]=c}m=A+16195|0;k=o?3:1;g=s-k|0;l=0;while(1){i=g+l|0;c=i-k|0;f=w[S+1|0]<<28>>31&3;D:{if((c|0)<=v[(M+4|0)+(l<<2)>>2]){break D}f=w[c+m|0]}c=f;t[i+m|0]=c;l=l+1|0;if((k|0)!=(l|0)){continue}break}l=M+4|0;k=u[j+36>>1]&1;f=0;g=v[j>>2];D=w[g|0];if(D){j=w[S+1|0]&8?7:64;c=g;while(1){i=w[S+3|0]&32;E:{F:{if(v[l+((f>>>0)%3<<2)>>2]>=(f|0)){break F}s=w[f+m|0];if(s>>>0>=j>>>0){break F}Q=i?C(1.4142135381698608):C(1);G:{if(w[S+1|0]&8){i=s<<3;L=z[i+48656>>2];J=z[(i|4)+48656>>2];break G}L=Aw(C(1),s+1>>>1<<k);i=s&1;J=i?C(1):L;L=i?L:C(1)}i=q;V=C(L*Q);L=C(J*Q);o=0;if((D|0)>=1){while(1){s=i+(o<<2)|0;Q=z[s>>2];z[s+2304>>2]=Q*L;z[s>>2]=Q*V;o=o+1|0;if((o|0)!=(D|0)){continue}break}}break E}if(!i){break E}RG(q,D)}q=(w[c|0]<<2)+q|0;f=f+1|0;c=g+f|0;D=w[c|0];if(D){continue}break}}jb=M+16|0;break A}if((c&224)!=96){break A}RG(A+2940|0,576)}if((p|0)>=1){i=A+7708|0;l=0;while(1){c=w[y+6153|0];I=(w[r+12|0]!=0)<<1<<((B((c>>>3&1)+(c>>>4&1)|0,3)+(w[y+6154|0]>>>2&3)|0)==2);k=(A+B(l,2304)|0)+2940|0;D=k;if(w[r+14|0]){j=((A+B(l,2304)|0)+B(I,72)|0)+2940|0;g=i;f=g;q=v[r>>2]+w[r+13|0]|0;n=w[q|0];if(n){c=j;while(1){m=n&255;o=m>>>0>1?m:1;S=m<<1;n=1;while(1){z[f>>2]=z[c>>2];z[f+4>>2]=z[(m<<2)+c>>2];s=S<<2;z[f+8>>2]=z[s+c>>2];c=c+4|0;f=f+12|0;if((n|0)!=(o|0)){n=n+1|0;continue}break}c=c+s|0;n=w[q+3|0];q=q+3|0;if(n){continue}break}}lc(j,g,f-g|0);c=I-1|0}else{c=31}if((c|0)>=1){while(1){g=0;while(1){j=g<<2;f=j+D|0;j=j+48720|0;J=z[j>>2];Q=z[f+72>>2];V=z[j+32>>2];j=(17-g<<2)+D|0;L=z[j>>2];z[f+72>>2]=C(J*Q)-C(V*L);z[j>>2]=C(V*Q)+C(J*L);g=g+1|0;if((g|0)!=8){continue}break}D=D+72|0;g=(c|0)>1;c=c-1|0;if(g){continue}break}}c=k;f=y+B(l,1152)|0;g=w[r+11|0];if(I){QG(c,f,48784,I);f=B(I,36)+f|0;c=B(I,72)+c|0}H:{if((g|0)==2){o=jb-80|0;jb=o;g=32-I|0;if((g|0)>=1){S=o|8;s=o|4;while(1){q=lc(o,c,72);j=v[f+20>>2];v[c+16>>2]=v[f+16>>2];v[c+20>>2]=j;j=v[f+12>>2];v[c+8>>2]=v[f+8>>2];v[c+12>>2]=j;j=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=j;j=f+24|0;zw(q,c+24|0,j);zw(s,c+48|0,j);zw(S,f,j);c=c+72|0;f=f+36|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}jb=o+80|0;break H}QG(c,f,B((g|0)==3,72)+48784|0,32-I|0)}f=0;k=k+72|0;while(1){g=1;while(1){c=(g<<2)+k|0;z[c>>2]=-z[c>>2];c=g>>>0<16;g=g+2|0;if(c){continue}break}k=k+144|0;c=f>>>0<30;f=f+2|0;if(c){continue}break}r=r+28|0;l=l+1|0;if((p|0)!=(l|0)){continue}break}}TG(Y,$,18,v[e+8>>2],d,Z);p=v[e+8>>2];d=B(p,1152)+d|0;b=b+1|0;if(b>>>0<(w[H+1|0]&8?2:1)>>>0){continue}break}}b=a;j=E+912|0;d=v[j+8>>2]>>>3|0;c=v[j+4>>2]+7>>>3|0;g=d-c|0;i=(g|0)>511;e=i?511:g;if((g|0)>=1){$i(b+6156|0,(j+(i?d-511|0:c)|0)+12|0,e)}v[b+6144>>2]=e;break j}Ew(a);break a}i=E+17152|0;p=0;k=0;r=0;b=E;A=b;g=0;I:{J:{K:{c=H;h=w[c+3|0];j=h>>>6|0;switch(j-1|0){case 2:break I;case 0:break K;default:break J}}g=(h>>>2&12)+4|0;break I}g=32}h=w[c+1|0];L:{if((h&6)==6){h=32;c=50188;break L}if(!(h&8)){h=30;c=50191;break L}h=w[c+2|0]>>>2&3;c=Cw(c)>>>((j|0)!=3)|0;c=c?c:192;if(c>>>0<=55){h=(h|0)==2?12:8;c=50212;break L}h=(h|0)!=1?c>>>0>95?30:27:27;c=50200}t[A+768|0]=h;t[A+769|0]=(g|0)>(h|0)?h:g;h=c;M:{if(!w[b+768|0]){break M}f=50096;while(1){if((r|0)==(p|0)){f=w[h|0]+50096|0;r=w[h+2|0]+r|0;k=w[h+1|0];h=h+3|0}c=p<<1;j=w[Ud(i,k)+f|0];t[(c+b|0)+770|0]=j;D=w[b+769|0];if(p>>>0<D>>>0){j=w[Ud(i,k)+f|0];D=w[b+769|0]}t[(b+(c|1)|0)+770|0]=D?j:0;j=w[b+768|0];p=p+1|0;if(j>>>0>p>>>0){continue}break}if(!j){k=j<<1;break M}p=0;while(1){c=b+p|0;N:{if(!w[c+770|0]){h=6;break N}if((w[H+1|0]&6)==6){h=2;break N}h=Ud(i,2);j=w[b+768|0]}t[c+834|0]=h;k=j<<1&510;p=p+1|0;if(k>>>0>p>>>0){continue}break}}f=b+770|0;H=b+834|0;c=b;g=0;if((k|0)>=1){while(1){j=w[f|0];h=0;O:{if(!j){break O}h=19>>>w[g+H|0]&3|4}f=f+1|0;A=B(j,3)-6|0;l=4;L=C(0);while(1){if(h&l){j=Ud(i,6);r=(j|0)/3|0;L=C(z[(A+(j-B(r,3)|0)<<2)+50224>>2]*C(2097152>>>r|0))}z[c>>2]=L;c=c+4|0;l=l>>>1|0;if(l){continue}break}g=g+1|0;if((k|0)!=(g|0)){continue}break}}p=w[b+769|0];c=w[b+768|0];if(p>>>0<c>>>0){while(1){t[(b+(p<<1|1)|0)+770|0]=0;p=p+1|0;if(c>>>0>p>>>0){continue}break}}p=0;A=Rb(E+3852|0,0,4608);q=a+2304|0;r=E+8620|0;c=0;P:{while(1){H=((c<<2)+E|0)+3852|0;y=E+17152|0;s=v[e+16>>2]|1;D=0;i=E;l=w[i+768|0];b=576;while(1){Q:{if(!(l&255)){l=0;break Q}f=H+(B(D,s)<<2)|0;g=0;while(1){h=b;k=w[(g+i|0)+770|0];R:{if(!k){break R}if(k>>>0<=16){if((s|0)<1){break R}j=(-1<<k-1)+1|0;b=0;while(1){ba=(b<<2)+f|0,da=C(Ud(y,k)+j|0),z[ba>>2]=da;b=b+1|0;if((s|0)!=(b|0)){continue}break}break R}j=2<<k-17;k=j|1;b=Ud(y,(k-(j>>>3|0)|0)+2|0);if((s|0)<1){break R}j=j>>>1|0;l=0;while(1){o=b;b=(b>>>0)/(k>>>0)|0;z[(l<<2)+f>>2]=(o-B(k,b)|0)-j|0;l=l+1|0;if((s|0)!=(l|0)){continue}break}}b=18-h|0;f=(h<<2)+f|0;g=g+1|0;l=w[i+768|0];if(g>>>0<l<<1>>>0){continue}break}}D=D+1|0;if((D|0)!=4){continue}break}c=(s<<2)+c|0;if((c|0)==12){j=(p<<2)+E|0;b=A;c=E;i=w[c+769|0];h=b+B(i,72)|0;lc(h+2304|0,h,B(w[c+768|0]-i|0,72));if(w[c+768|0]){l=0;while(1){k=0;while(1){h=(k<<2)+b|0;z[h>>2]=z[h>>2]*z[j>>2];h=h+2304|0;z[h>>2]=z[h>>2]*z[j+12>>2];k=k+1|0;if((k|0)!=12){continue}break}j=j+24|0;b=b+72|0;l=l+1|0;if(l>>>0<w[c+768|0]){continue}break}}TG(q,A,12,v[e+8>>2],d,r);Rb(A,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[E+17156>>2]<=v[E+17160>>2]){p=p+1|0;if((p|0)==3){break P}continue}break}Ew(a);p=0;break a}h=1}p=B(Bw(a+6152|0),h)}jb=E+17168|0;return p|0}function fha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=jb-304|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!ht(b,d+208|0)){break h}if(!hP(d+208|0)){break h}if(!Qb(b,id(gP(d+208|0),mb))){break h}if(!c){s=1;break h}Hd(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;k=gd(d+192|0);i:{j:{k:{l:{m:{n:{o:{p:{switch(((w[d+248|0]|w[d+249|0]<<8)&61440)-4096>>>12|0){case 0:q:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|w[d+240|0]&15)){break q}if((w[d+246|0]|w[d+247|0]<<8)&65455){break q}v[a+1074304>>2]=18219008;v[114578]=0;e=Q(2,d+32|0,17034)|0;g=v[114578];v[114578]=0;i=1;if((g|0)==1){break o}Gb(k,e);yb(e);v[114578]=0;W(479,a+1074308|0,81,1)|0;g=v[114578];v[114578]=0;e=1;if((g|0)!=1){break i}break b}r:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|(w[d+246|0]|w[d+247|0]<<8))){break r}if(w[d+261|0]){break r}v[114578]=0;e=Q(2,d+32|0,17060)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break j}f=P()|0;O()|0;break a}v[114578]=0;h=Q(2,d+32|0,17074)|0;g=v[114578];v[114578]=0;f=1;if((g|0)!=1){Gb(k,h);yb(h);break k}f=P()|0;O()|0;break a;case 1:v[114578]=0;h=Q(2,d+32|0,17089)|0;g=v[114578];v[114578]=0;e=1;if((g|0)!=1){Gb(k,h);yb(h);break k}f=P()|0;O()|0;break a;case 2:s:{t:{u:{v:{w:{g=w[d+248|0]|w[d+249|0]<<8;x:{if(g>>>0<=12820){v[114578]=0;e=Q(2,d+32|0,17103)|0;h=v[114578];v[114578]=0;if((h|0)!=1){Gb(k,e);break x}f=P()|0;O()|0;break a}v[114578]=0;e=Q(2,d+160|0,17119)|0;h=v[114578];v[114578]=0;if((h|0)==1){break w}v[114578]=0;R(219,d+176|0,e|0);h=v[114578];v[114578]=0;if((h|0)==1){break v}h=w[d+248|0]|w[d+249|0]<<8;v[114578]=0;v[d+128>>2]=h-12820;U(245,d+32|0,d+176|0,d+128|0);h=v[114578];v[114578]=0;if((h|0)==1){break u}Gb(k,d+32|0);yb(d+32|0);Ib(d+176|0)}yb(e);if((w[d+248|0]|w[d+249|0]<<8)>>>0<12807){break l}if(w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24)){break s}break l}f=P()|0;O()|0;break a}f=P()|0;O()|0;break t}f=P()|0;O()|0;Ib(d+176|0)}yb(e);break a}e=w[d+248|0]|w[d+249|0]<<8;h=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);v[114578]=0;e=Q(661,e|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break n}h=Sp(d+32|0);v[h+44>>2]=e;v[114578]=0;R(662,a+1304500|0,h|0);e=v[114578];v[114578]=0;if((e|0)!=1){break l}f=P()|0;O()|0;break a;case 3:f=w[d+248|0]|w[d+249|0]<<8;y:{if((f|0)==16640){v[114578]=0;e=Q(2,d+32|0,17143)|0;h=v[114578];v[114578]=0;if((h|0)!=1){Gb(k,e);yb(e);v[114578]=0;W(479,a+1074308|0,81,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}break y}f=P()|0;O()|0;break a}e=w[d+248|0]|w[d+249|0]<<8;h=w[d+262|0]|w[d+263|0]<<8;v[114578]=0;U(663,d+32|0,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}Gb(k,d+32|0);yb(d+32|0);v[a+480260>>2]=1}h=(f|0)!=16640;e=1;f=0;break i;case 4:v[114578]=0;f=Q(2,d+32|0,17155)|0;h=v[114578];v[114578]=0;if((h|0)!=1){Gb(k,f);yb(f);v[a+1074304>>2]=((w[d+248|0]|w[d+249|0]<<8)&4095)<<16;f=0;break k}f=P()|0;O()|0;break a;case 5:v[114578]=0;e=Q(2,d+32|0,17143)|0;g=v[114578];v[114578]=0;if((g|0)!=1){Gb(k,e);yb(e);v[114578]=0;W(479,a+1074308|0,81,1)|0;g=v[114578];v[114578]=0;e=0;if((g|0)==1){break b}break i}f=P()|0;O()|0;break a;case 6:v[114578]=0;e=Q(2,d+32|0,17163)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break j}f=P()|0;O()|0;break a;default:break p}}if((w[d+248|0]|w[d+249|0]<<8)!=51712){break i}v[114578]=0;e=Q(2,d+32|0,17176)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break j}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}v[114578]=0;e=1;W(479,a+1074308|0,107,1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}v[a+480260>>2]=1;h=0;if(g>>>0>12820){break i}}v[114578]=0;h=Q(2,d+144|0,17183)|0;g=v[114578];v[114578]=0;z:{A:{B:{C:{D:{if((g|0)!=1){v[114578]=0;R(219,d+176|0,h|0);g=v[114578];v[114578]=0;if((g|0)==1){break D}v[d+16>>2]=w[d+249|0]&15;g=w[d+248|0];v[114578]=0;v[d>>2]=g;R(660,d+128|0,d|0);g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;fa(996,d+32|0,d+176|0,k|0,d+16|0,d+128|0);g=v[114578];v[114578]=0;if((g|0)==1){break B}Gb(k,d+32|0);yb(d+32|0);yb(d+128|0);Ib(d+176|0);yb(h);h=0;break i}f=P()|0;O()|0;break a}f=P()|0;O()|0;break z}f=P()|0;O()|0;break A}f=P()|0;O()|0;yb(d+128|0)}Ib(d+176|0)}yb(h);break a}Gb(k,e);yb(e);e=0}v[114578]=0;g=Q(2,d+32|0,17192)|0;j=v[114578];v[114578]=0;E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{if((j|0)!=1){Gb(a+1304436|0,g);yb(g);v[114578]=0;g=Q(2,d+32|0,17208)|0;j=v[114578];v[114578]=0;if((j|0)==1){break S}Gb(a+1304448|0,g);yb(g);Gb(a+1304460|0,k);v[a+1304496>>2]=v[a+1074304>>2]?7:4;if(e){v[114578]=0;e=a+1074308|0;Q(480,e|0,77)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}v[114578]=0;Q(480,e|0,78)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}v[114578]=0;Q(480,e|0,79)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}v[114578]=0;Q(480,e|0,80)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}v[114578]=0;Q(480,e|0,82)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}v[114578]=0;Q(480,e|0,96)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}}i=((w[d+248|0]|w[d+249|0]<<8)&61440)>>>0<4097|((w[d+248|0]|w[d+249|0]<<8)>>>0<12820?((w[d+248|0]|w[d+249|0]<<8)&61440)==12288:0)?i:1;v[114578]=0;e=a+901404|0;Z(997,e|0);g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!i){v[114578]=0;Z(634,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}}v[114578]=0;U(577,d+176|0,1,d+208|0);e=v[114578];v[114578]=0;if((e|0)==1){break R}v[114578]=0;R(417,d+32|0,d+176|0);e=v[114578];v[114578]=0;if((e|0)==1){break R}Gb(a+1304400|0,d+32|0);yb(d+32|0);if(w[d+246|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+246|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+246|0]&64?0:(w[d+248|0]|w[d+249|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}e=w[d+257|0];v[a+480196>>2]=e;T:{U:{if(e){if((e|0)!=255){break U}e=0;if(!f){break T}}v[a+480196>>2]=6}e=f}v[a+480204>>2]=B(w[d+258|0],1e4);if(w[d+258|0]<=32){v[a+480204>>2]=e?125e4:32e4}f=w[d+256|0];v[114578]=0;t[d+32|0]=f;t[d+176|0]=64;f=Q(393,d+32|0,d+176|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break N}f=w[f|0];v[a+480200>>2]=f<<2;if(!((w[d+248|0]|w[d+249|0]<<8)>>>0>4895|f)){v[a+480200>>2]=256}if((w[d+250|0]|w[d+251|0]<<8)!=1|w[d+259|0]>7){break P}f=w[d+259|0];v[114578]=0;v[d+32>>2]=(f<<4)+16;v[d+176>>2]=127;f=Q(464,d+32|0,d+176|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break Q}v[a+480228>>2]=v[f>>2];break O}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}if(!(w[d+259|0]!=18?w[d+259|0]!=2:0)){v[a+480228>>2]=32;break O}f=w[d+259|0];v[114578]=0;v[d+32>>2]=f&127;v[d+176>>2]=16;f=Q(552,d+32|0,d+176|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break M}v[a+480228>>2]=v[f>>2]}v[a+480232>>2]=36;if(!(!h|(w[d+248|0]|w[d+249|0]<<8)>>>0>=19763)){v[a+480232>>2]=64}u[a+480188>>1]=4;i=Gt(d+120|0);f=0;while(1){v[114578]=0;h=(f<<5)+a|0;o=h+480280|0;Z(434,o|0);g=v[114578];v[114578]=0;if((g|0)==1){break L}g=d+f|0;j=w[g+272|0];if(w[g+272|0]!=255){u[a+480188>>1]=f+1;u[h+480284>>1]=j&8?204:51}if(t[g+272|0]<=-1){v[o>>2]=1024}if(((j&127)-16&255)>>>0<=13){u[h+480284>>1]=128;Pj(d+32|0,i,f);ge(d+32|0,1)}f=f+1|0;if((f|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}f=Vb(a+484360|0);h=w[d+240|0]|w[d+241|0]<<8;v[114578]=0;ea(581,f|0,b|0,h|0,255,254)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}q=cq(d+176|0);f=w[d+242|0]|w[d+243|0]<<8;v[114578]=0;W(395,b|0,q|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}o=cq(d+128|0);f=w[d+244|0]|w[d+245|0]<<8;v[114578]=0;W(395,b|0,o|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){if(w[d+261|0]==252){f=0;v[114578]=0;Q(998,b|0,d+32|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}while(1){g=(d+32|0)+f|0;h=w[g|0];V:{if(!(h&32)){break V}j=((f<<5)+a|0)+480284|0;if(e){Pj(d+16|0,i,f);if(Cb(d+16|0)){break V}h=w[g|0]}u[j>>1]=(((h&15)<<8|8)>>>0)/15}f=f+1|0;if((f|0)!=32){continue}break}}h=w[d+242|0]|w[d+243|0]<<8;f=0;v[114578]=0;u[d+32>>1]=h;u[d+16>>1]=3999;h=Q(478,d+32|0,d+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break K}h=x[h>>1];u[a+480190>>1]=h;if(h){h=c&2;i=d+80|0;while(1){g=rc(q,f);g=w[g|0]|w[g+1|0]<<8;v[114578]=0;g=Q(256,b|0,g<<4)|0;j=v[114578];v[114578]=0;if((j|0)==1){break J}W:{if(!g){break W}v[114578]=0;g=Q(999,b|0,d+32|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break J}if(!g){break W}v[114578]=0;g=f+1|0;j=(B(g,104)+a|0)+484380|0;U(1e3,d+32|0,j|0,e|0);l=v[114578];v[114578]=0;if((l|0)==1){break J}v[114578]=0;U(577,d|0,1,i|0);l=v[114578];v[114578]=0;X:{Y:{Z:{if((l|0)==1){break Z}v[114578]=0;R(417,d+16|0,d|0);l=v[114578];v[114578]=0;if((l|0)==1){break Z}v[114578]=0;Q(371,((g<<5)+a|0)+946300|0,d+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Y}yb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))|(!h|w[d+32|0]>1)){break W}g=w[d+46|0];l=w[d+47|0];p=w[d+45|0];v[114578]=0;g=Q(256,b|0,l<<12|g<<4|p<<20)|0;l=v[114578];v[114578]=0;if((l|0)==1){break X}if(!g){break W}g=w[d+250|0]|w[d+251|0]<<8;v[114578]=0;U(1001,d+16|0,d+32|0,(g|0)==1|0);g=v[114578];v[114578]=0;if((g|0)!=1){v[114578]=0;W(402,d+16|0,j|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break W}}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;yb(d+16|0);break f}f=P()|0;O()|0;break f}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}s=1;if(!(c&1)){break E}c=w[d+248|0]|w[d+249|0]<<8;e=w[d+244|0]|w[d+245|0]<<8;v[114578]=0;u[d+32>>1]=e;u[d+16>>1]=255;e=Q(478,d+32|0,d+16|0)|0;f=v[114578];v[114578]=0;_:{$:{if((f|0)!=1){r=x[e>>1];v[114578]=0;i=a+484344|0;R(403,i|0,r|0);e=v[114578];v[114578]=0;if((e|0)==1){break $}y=c>>>0<4896;if(r){break _}l=0;p=0;break F}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}A=d+32|5;C=d+32|3;z=d+32|4;D=d+32|2;E=d+32|1;h=0;p=0;l=0;while(1){v[114578]=0;c=W(404,i|0,h&65535,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break I}aa:{if(!c){break aa}c=rc(o,h);if(!(w[c|0]|w[c+1|0]<<8)){break aa}c=rc(o,h);c=w[c|0]|w[c+1|0]<<8;v[114578]=0;c=Q(256,b|0,c<<4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break I}if(!c){break aa}v[114578]=0;Q(340,b|0,2)|0;c=v[114578];v[114578]=0;if((c|0)==1){break I}f=0;c=_b(i,h);v[114578]=0;c=Q(497,c|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break H}while(1){v[114578]=0;n=T(389,b|0)|0;e=v[114578];v[114578]=0;ba:{ca:{if((e|0)!=1){if(n){break ca}if(f>>>0>62){break aa}c=_b(i,h);v[114578]=0;f=f+1|0;c=Q(497,c|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break ba}}f=P()|0;O()|0;break f}F=Rh(d+32|0);e=n&31;g=e>>>0<x[a+480188>>1];j=B(e,6)+c|0;if(n&32){v[114578]=0;R(473,d+16|0,b|0);e=v[114578];v[114578]=0;da:{ea:{fa:{if((e|0)!=1){m=dd(d+16|0);e=w[d+16|0];if(e>>>0>239){break fa}e=(B(e>>>4|0,12)+(e&15)|0)+13|0;break ea}f=P()|0;O()|0;break f}ga:{switch(e-254|0){case 0:break ea;case 1:break ga;default:break da}}e=0}t[(g?j:d+32|0)|0]=e}t[(g?j+1|0:E)|0]=w[m|0]}ha:{if(!(n&64)){break ha}v[114578]=0;e=T(389,b|0)|0;m=v[114578];v[114578]=0;ia:{if((m|0)!=1){m=g?j+2|0:D;t[d+16|0]=e;if(e<<24>>24>-1|e>>>0>192){break ia}t[m|0]=2;t[(g?j+4|0:z)|0]=w[d+16|0]^128;break ha}f=P()|0;O()|0;break f}t[m|0]=1;v[114578]=0;t[d|0]=64;e=Q(393,d+16|0,d|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break G}t[(g?j+4|0:z)|0]=w[e|0]}if(!(n&128)){break ba}v[114578]=0;R(473,d+16|0,b|0);e=v[114578];v[114578]=0;ja:{if((e|0)!=1){e=dd(d+16|0);m=g?j+3|0:C;t[m|0]=w[d+16|0];n=g?j+5|0:A;t[n|0]=w[e|0];Ty(g?j:F,0);ka:{e=w[m|0];if((e|0)==20){if((w[n|0]&240)!=160){break ba}if((w[d+248|0]|w[d+249|0]<<8)>>>0<4896){break ka}e=w[m|0]}if((e|0)!=31){break ba}e=w[n|0];if(e>>>0<=15){break ja}y=0;break ba}t[n|0]=w[n|0]&15^136;break ba}f=P()|0;O()|0;break f}if(e>>>0<=7){p=p+1|0;break ba}l=((e|0)!=8)+l|0}if(f>>>0<64){continue}break}}h=h+1|0;if((r|0)!=(h|0)){continue}break}break F}f=P()|0;O()|0;break f}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}if(!y){break E}a=x[a+480188>>1];if((a|0)>(l+p|0)|(a|0)<=(l-p|0)){break E}e=Ce(i)-1&65535;a=0;c=0;if(Ce(i)>>>0>e>>>0){while(1){if(mh(Ge(i,a))){b=bc(Ge(i,a));f=cc(Ge(i,a));a=jb-16|0;jb=a;v[a>>2]=f;v[a+8>>2]=b;if(Jb(a+8|0,a)){while(1){b=v[a+8>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}Cj(a+8|0);if(Jb(a+8|0,a)){continue}break}}jb=a+16|0}c=c+1|0;a=c&65535;if(e>>>0>=a>>>0){continue}break}}}Bj(o);Bj(q);yb(k)}jb=d+304|0;return s|0}f=P()|0;O()|0}Bj(o);break d}f=P()|0;O()|0}Bj(q);break a}f=P()|0;O()|0;break a}f=P()|0;O()|0}yb(k);S(f|0);L()}function o4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;a:{b:{c:{d:{e:{f:{if(Vd(b,38235)){Wb(a);break f}if(Vd(b,38236)){b=jb-96|0;jb=b;d=Wb(a);v[114578]=0;Z(236,b- -64|0);a=v[114578];v[114578]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[114578]=0;v[b+32>>2]=0;R(2118,b+48|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}v[114578]=0;Q(1250,d|0,b+48|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break o}yb(b+48|0);v[114578]=0;Q(1995,d|0,38894)|0;a=v[114578];v[114578]=0;q:{if((a|0)==1){break q}v[114578]=0;v[b+32>>2]=5;R(2118,b+48|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[114578]=0;Q(1250,d|0,b+48|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}yb(b+48|0);v[114578]=0;Q(1995,d|0,38894)|0;a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;v[b+32>>2]=8;R(2118,b+48|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}v[114578]=0;Q(1250,d|0,b+48|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break k}yb(b+48|0);v[114578]=0;a=Q(85,b+48|0,38235)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}f=Fb(a);yb(a);if(!f){break i}v[114578]=0;Q(1995,d|0,38235)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}f=gh(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[114578]=0;v[b+12>>2]=a;R(2118,b+16|0,b+12|0);a=v[114578];v[114578]=0;if((a|0)==1){break D}v[114578]=0;U(2119,b+32|0,39478,b+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break C}v[114578]=0;R(1535,f|0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break B}yb(b+32|0);yb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[114578]=0;c=Q(85,b+32|0,39480)|0;a=v[114578];v[114578]=0;if((a|0)==1){break z}v[114578]=0;R(1535,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break y}yb(c);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(c);break r}if(!w[(b- -64|0)+17|0]){break w}v[114578]=0;c=Q(85,b+32|0,39489)|0;a=v[114578];v[114578]=0;if((a|0)==1){break v}v[114578]=0;R(1535,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break u}yb(c)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(c);break r}v[114578]=0;c=Q(85,b+32|0,39495)|0;a=v[114578];v[114578]=0;E:{if((a|0)!=1){v[114578]=0;R(1535,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break E}yb(c);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(c);break r}if(nd(f)){break g}v[114578]=0;Q(1995,d|0,39499)|0;a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;c=Q(85,b+16|0,38894)|0;a=v[114578];v[114578]=0;F:{G:{H:{if((a|0)!=1){v[114578]=0;U(2120,b+32|0,f|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break H}v[114578]=0;Q(1250,d|0,b+32|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break G}yb(b+32|0);yb(c);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;yb(b+32|0)}yb(c);break r}a=P()|0;O()|0}ld(f)}_e(b- -64|0);break c}ld(f);_e(b- -64|0);jb=b+96|0;break f}if(Vd(b,38252)){v[g>>2]=0;Wr(a,g);break f}if(Vd(b,38274)){v[g>>2]=5;Wr(a,g);break f}if(Vd(b,38296)){v[g>>2]=8;Wr(a,g);break f}if(Vd(b,38318)){f=jb-16|0;jb=f;b=jb-16|0;jb=b;v[b+12>>2]=38235;Ub(a,v[b+12>>2]);jb=b+16|0;jb=f+16|0;break f}if(Vd(b,38341)){b=Ub(g,38235);f=Fb(b);v[114578]=0;Q(85,a|0,(f?38370:38368)|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}yb(b);break f}if(Vd(b,38372)){b=jb-48|0;jb=b;cD(b+16|0);v[114578]=0;f=Q(2,b|0,39569)|0;c=v[114578];v[114578]=0;I:{J:{K:{L:{if((c|0)!=1){v[114578]=0;U(251,b+32|0,b+16|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break L}v[114578]=0;U(9,a|0,0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break K}yb(b+32|0);yb(f);yb(b+16|0);jb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;yb(b+32|0)}yb(f)}yb(b+16|0);break a}if(Vd(b,38389)){b=jb-16|0;jb=b;i=jb-16|0;jb=i;v[i+8>>2]=53;f=b;c=jb-176|0;jb=c;h=Hv(c+160|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[i+8>>2];if(d&1){v[114578]=0;v[c+144>>2]=19466496;R(242,c+96|0,c+144|0);d=v[114578];v[114578]=0;if((d|0)==1){break $}v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break _}yb(c+96|0);d=v[i+8>>2]}if(!(d&4)){break Y}v[114578]=0;d=da(243)|0;e=v[114578];v[114578]=0;if((e|0)==1){break X}if(!d){break Z}break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}v[114578]=0;Z(244,c+96|0);d=v[114578];v[114578]=0;aa:{if((d|0)!=1){v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break aa}yb(c+96|0);break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}ba:{d=v[i+8>>2];if(!(d&8)){break ba}v[114578]=0;d=Q(2,c+128|0,7142)|0;e=v[114578];v[114578]=0;ca:{da:{ea:{fa:{ga:{if((e|0)!=1){v[114578]=0;R(219,c+144|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break ga}v[114578]=0;U(245,c+96|0,c+144|0,7152);e=v[114578];v[114578]=0;if((e|0)==1){break fa}v[114578]=0;R(201,h|0,c+96|0);e=v[114578];v[114578]=0;if((e|0)==1){break ea}yb(c+96|0);Ib(c+144|0);yb(d);d=v[i+8>>2];break ba}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ca}a=P()|0;O()|0;break da}a=P()|0;O()|0;yb(c+96|0)}Ib(c+144|0)}yb(d);break N}ha:{if(!(d&16)){break ha}v[114578]=0;Z(236,c+96|0);d=v[114578];v[114578]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((d|0)!=1){v[114578]=0;R(246,c+144|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break ja}d=Wc(c+144|0);yb(c+144|0);if(!d){v[114578]=0;d=Q(2,c- -64|0,7156)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Ga}v[114578]=0;R(219,c+80|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break Fa}v[114578]=0;R(246,c+48|0,c+96|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ea}v[114578]=0;U(247,c+144|0,c+80|0,c+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break Da}v[114578]=0;R(201,h|0,c+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break Ca}yb(c+144|0);yb(c+48|0);Ib(c+80|0);yb(d)}if(!Wc(Ug(c+96|0))){v[114578]=0;d=Q(2,c+32|0,7160)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ya}v[114578]=0;R(219,c+80|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break xa}e=Ug(c+96|0);v[114578]=0;U(247,c+144|0,c+80|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break wa}v[114578]=0;R(201,h|0,c+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break va}yb(c+144|0);Ib(c+80|0);yb(d)}v[114578]=0;R(248,c+144|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break sa}d=Wc(c+144|0);yb(c+144|0);if(!d){v[114578]=0;d=Q(2,c+16|0,7156)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ra}v[114578]=0;R(219,c+80|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break qa}v[114578]=0;R(248,c+48|0,c+96|0);e=v[114578];v[114578]=0;if((e|0)==1){break pa}v[114578]=0;U(247,c+144|0,c+80|0,c+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break oa}v[114578]=0;R(201,h|0,c+144|0);e=v[114578];v[114578]=0;if((e|0)==1){break na}yb(c+144|0);yb(c+48|0);Ib(c+80|0);yb(d)}_e(c+96|0);d=v[i+8>>2];break ha}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;break Ba}a=P()|0;O()|0;yb(c+144|0)}yb(c+48|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ua}a=P()|0;O()|0;yb(c+144|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ka}a=P()|0;O()|0;break la}a=P()|0;O()|0;break ma}a=P()|0;O()|0;yb(c+144|0)}yb(c+48|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0}_e(c+96|0);break N}Ha:{if(!(d&32)){break Ha}v[114578]=0;d=da(243)|0;e=v[114578];v[114578]=0;if((e|0)==1){break X}if(d){break Ha}gd(c+96|0);v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break O}yb(c+96|0)}if(w[i+8|0]&64){v[114578]=0;Z(249,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break W}v[114578]=0;R(201,h|0,c+96|0);d=v[114578];v[114578]=0;if((d|0)==1){break V}yb(c+96|0)}v[114578]=0;d=Q(2,c+96|0,7166)|0;e=v[114578];v[114578]=0;if((e|0)==1){break U}v[114578]=0;U(250,c|0,h|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break T}v[114578]=0;e=Q(2,c+144|0,10991)|0;j=v[114578];v[114578]=0;if((j|0)==1){break S}v[114578]=0;U(251,f|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break R}yb(e);yb(c);yb(d);cl(h);jb=c+176|0;break M}a=P()|0;O()|0;break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;yb(e)}yb(c)}yb(d);break N}a=P()|0;O()|0;yb(c+96|0)}cl(h);S(a|0);L()}jb=i+16|0;v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38402)){b=jb-48|0;jb=b;Kq(b);v[114578]=0;R(246,b+32|0,b|0);f=v[114578];v[114578]=0;Ia:{Ja:{if((f|0)!=1){v[114578]=0;U(9,a|0,0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break Ja}yb(b+32|0);_e(b);jb=b+48|0;break f}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;yb(b+32|0)}_e(b);break a}if(Vd(b,38413)){b=jb-32|0;jb=b;Kq(b);f=Ug(b);v[114578]=0;U(9,a|0,0,f|0);a=v[114578];v[114578]=0;if((a|0)!=1){_e(b);jb=b+32|0;break f}a=P()|0;O()|0;_e(b);break a}if(Vd(b,38425)){b=jb-48|0;jb=b;Kq(b+16|0);Ka:{if(v[b+28>>2]){f=v[b+28>>2];v[114578]=0;v[b+12>>2]=f;R(2118,a|0,b+12|0);a=v[114578];v[114578]=0;if((a|0)!=1){break Ka}a=P()|0;O()|0;_e(b+16|0);break a}Wb(a)}_e(b+16|0);jb=b+48|0;break f}if(Vd(b,38441)){Kq(g);b=w[g+16|0];v[114578]=0;Q(85,a|0,(b?38368:38370)|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_e(g);break f}a=P()|0;O()|0;_e(g);break a}if(Vd(b,38460)){Kq(g);b=w[g+17|0];v[114578]=0;Q(85,a|0,(b?38368:38370)|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_e(g);break f}a=P()|0;O()|0;_e(g);break a}if(Vd(b,38486)){Kq(g);b=w[g+18|0];v[114578]=0;Q(85,a|0,(b?38368:38370)|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_e(g);break f}a=P()|0;O()|0;_e(g);break a}if(Vd(b,38504)){b=jb-16|0;jb=b;f=jb-32|0;jb=f;c=gd(b);v[114578]=0;Z(236,f|0);d=v[114578];v[114578]=0;La:{Ma:{Na:{if((d|0)!=1){d=Ug(f);v[114578]=0;Q(237,c|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Na}_e(f);jb=f+32|0;break La}a=P()|0;O()|0;break Ma}a=P()|0;O()|0;_e(f)}yb(c);break a}v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38510)){d=jb-16|0;jb=d;b=jb+-64|0;jb=b;c=gd(d);v[114578]=0;f=Q(2,b+16|0,7127)|0;h=v[114578];v[114578]=0;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((h|0)!=1){v[114578]=0;R(219,b+32|0,f|0);h=v[114578];v[114578]=0;if((h|0)==1){break Ua}v[114578]=0;v[b+12>>2]=13;v[b+8>>2]=0;v[b+4>>2]=0;fa(239,b+48|0,b+32|0,b+12|0,b+8|0,b+4|0);h=v[114578];v[114578]=0;if((h|0)==1){break Ta}v[114578]=0;Q(192,c|0,b+48|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Sa}yb(b+48|0);Ib(b+32|0);yb(f);jb=b- -64|0;break Oa}a=P()|0;O()|0;break Pa}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;break Ra}a=P()|0;O()|0;yb(b+48|0)}Ib(b+32|0)}yb(f)}yb(c);break a}v[114578]=0;U(9,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break f}a=P()|0;O()|0;break c}if(Vd(b,38525)){b=jb-16|0;jb=b;Cn(b,0,7349);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38533)){b=jb-48|0;jb=b;d=Ub(b+16|0,39574);v[114578]=0;R(2121,b|0,2);f=v[114578];v[114578]=0;Va:{Wa:{Xa:{Ya:{if((f|0)!=1){v[114578]=0;U(3,b+32|0,d|0,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break Ya}v[114578]=0;U(9,a|0,0,b+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break Xa}yb(b+32|0);yb(b);yb(d);jb=b+48|0;break f}a=P()|0;O()|0;break Va}a=P()|0;O()|0;break Wa}a=P()|0;O()|0;yb(b+32|0)}yb(b)}break c}if(Vd(b,38541)){b=jb-16|0;jb=b;Cn(b,0,9345);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38549)){b=jb-16|0;jb=b;Iq(b,0);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38553)){b=jb-16|0;jb=b;Iq(b,2);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Vd(b,38571)){b=jb-16|0;jb=b;Iq(b,3);v[114578]=0;U(9,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}Wb(a)}jb=g+32|0;break d}a=P()|0;O()|0;yb(b);break a}return}yb(d);break a}a=P()|0;O()|0;yb(b)}S(a|0);L()}function VT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-288|0;jb=e;Jc(b);a:{if(RA(b,12222)){o=Wb(e+272|0);v[114578]=0;f=W(432,b|0,o|0,-1)|0;i=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((i|0)!=1){if(!f){break b}v[114578]=0;f=Q(447,b|0,e+264|0)|0;i=v[114578];v[114578]=0;v:{if((i|0)==1){break v}if(!f){break b}if(!QA(e+264|0)){break b}d=PA(e+264|0);v[114578]=0;d=Gg(448,d,mb);f=v[114578];v[114578]=0;if((f|0)==1){break v}v[114578]=0;f=Q(258,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}d=0;if(!f){break b}if(!c){break c}v[114578]=0;R(449,a|0,4096);d=v[114578];v[114578]=0;if((d|0)==1){break v}v[114578]=0;Q(450,a+1304400|0,o|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[114578]=0;R(451,a|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break v}v[114578]=0;d=Q(2,e+96|0,12230)|0;f=v[114578];v[114578]=0;w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{if((f|0)!=1){Gb(a+1304436|0,d);yb(d);v[114578]=0;d=Q(2,e+96|0,12194)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}Gb(a+1304448|0,d);yb(d);v[114578]=0;d=Q(2,e+248|0,12244)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}v[114578]=0;R(219,e+48|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break E}t[e+216|0]=w[e+264|1];f=w[e+264|0];v[114578]=0;t[e+8|0]=f;R(452,e+232|0,e+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break D}v[114578]=0;X(453,e+96|0,e+48|0,e+216|0,e+232|0);f=v[114578];v[114578]=0;if((f|0)==1){break C}Gb(a+1304460|0,e+96|0);yb(e+96|0);yb(e+232|0);Ib(e+48|0);yb(d);v[a+1304496>>2]=4;if(w[e+264|0]<2){break x}v[114578]=0;u[e+96>>1]=8192;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break z}v[114578]=0;u[e+48>>1]=d;d=Q(454,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break z}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[114578]=0;t[e+96|0]=1;d=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break y}v[114578]=0;t[e+48|0]=d;d=Q(455,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break y}v[a+480196>>2]=w[d|0];v[114578]=0;Q(340,b|0,3)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break w}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break A}b=P()|0;O()|0;break B}b=P()|0;O()|0;yb(e+232|0)}Ib(e+48|0)}yb(d);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[114578]=0;t[e+96|0]=32;d=T(389,b|0)|0;f=v[114578];v[114578]=0;H:{I:{if((f|0)==1){break I}v[114578]=0;t[e+48|0]=d;d=Q(455,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}v[a+480204>>2]=B(w[d|0],1e4);v[114578]=0;t[e+96|0]=1;d=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break H}v[114578]=0;t[e+48|0]=d;d=Q(455,e+96|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break H}v[a+480196>>2]=w[d|0];v[114578]=0;d=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break w}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[a+480208>>2]=d>>>2&16|12;n=Ql(e+232|0);m=Ql(e+216|0);J:{K:{if(!x[a+480192>>1]){break K}j=1;i=e+80|1;p=e+96|12;while(1){v[114578]=0;f=W(456,a|0,j&65535,0)|0;d=v[114578];v[114578]=0;L:{M:{N:{if((d|0)==1){break N}if(!f){break K}v[114578]=0;d=W(433,b|0,f+492|0,-1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break N}if(!d){break K}v[114578]=0;h=T(389,b|0)|0;d=v[114578];v[114578]=0;O:{P:{Q:{R:{if((d|0)!=1){Rb(e+96|0,0,120);if(!h){break L}if(w[e+264|0]){v[114578]=0;d=Q(457,b|0,e+96|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break R}if(!d){break L}}if(!w[e+264|0]){v[114578]=0;d=W(261,b|0,p|0,96)|0;g=v[114578];v[114578]=0;if((g|0)==1){break R}if(!d){break L}}g=f+236|0;d=0;while(1){l=w[(e+96|0)+d|0];k=x[a+480190>>1];r=ed(g,d),s=(k+l|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[114578]=0;d=f+48|0;U(458,e+8|0,d|0,b|0);g=v[114578];v[114578]=0;if((g|0)==1){break Q}v[114578]=0;g=f+68|0;U(458,e+32|0,g|0,b|0);l=v[114578];v[114578]=0;if((l|0)==1){break Q}v[114578]=0;l=f+88|0;U(458,e+88|0,l|0,b|0);k=v[114578];v[114578]=0;if((k|0)==1){break Q}v[114578]=0;Q(459,b|0,e+80|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break P}v[f>>2]=(w[i|0]|w[i+1|0]<<8)&4095;f=w[i|0]|w[i+1|0]<<8;du(e+80|0,d,0);du(e+80|0,g,1);du(e+80|0,l,2);r=e,s=bc(d),v[r+48>>2]=s;r=e,s=cc(d),v[r+72>>2]=s;if(Jb(e+48|0,e+72|0)){break O}break M}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}while(1){S:{d=v[e+48>>2];t[e+68|0]=64;k=w[d+2|0];v[114578]=0;t[e+71|0]=((k<<6)- -64>>>0)/127;k=Q(393,e+68|0,e+71|0)|0;q=v[114578];v[114578]=0;if((q|0)==1){break S}t[d+2|0]=w[k|0];_d(e+48|0);if(Jb(e+48|0,e+72|0)){continue}break M}break}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}r=e,s=bc(g),v[r+48>>2]=s;r=e,s=cc(g),v[r+72>>2]=s;T:{if(!Jb(e+48|0,e+72|0)){break T}while(1){U:{d=v[e+48>>2];t[e+68|0]=64;g=w[d+2|0];v[114578]=0;t[e+71|0]=((g<<6)+128>>>0)/255;g=Q(393,e+68|0,e+71|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break U}t[d+2|0]=w[g|0];_d(e+48|0);if(Jb(e+48|0,e+72|0)){continue}break T}break}b=P()|0;O()|0;break e}r=e,s=bc(l),v[r+48>>2]=s;r=e,s=cc(l),v[r+72>>2]=s;if(Jb(e+48|0,e+72|0)){l=1<<(f>>>12&3);while(1){k=v[e+48>>2];d=t[k+2|0];f=Fma(d^-128,d>>31^-1,l,0);g=mb;d=g;V:{if((d|0)>-1?1:(d|0)>=-1?f>>>0>=4294967292:0){v[114578]=0;f=f+4|0;d=f>>>0<4?d+1|0:d;f=Gg(460,((d&7)<<29|f>>>3)&536870911,0);d=v[114578];v[114578]=0;if((d|0)!=1){break V}break f}v[114578]=0;d=(f-3|0)/8|0;f=Gg(460,d,d>>31);d=v[114578];v[114578]=0;if((d|0)==1){break f}}t[k+2|0]=f^128;_d(e+48|0);if(Jb(e+48|0,e+72|0)){continue}break}}d=x[a+480190>>1]+1|0;u[e+68>>1]=d;W:{X:{Y:{Z:{g=d&65535;if(g>>>0<=3999){f=0;d=0;while(1){v[114578]=0;W(433,b|0,((g<<5)+a|0)+946300|0,-1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Z}v[114578]=0;Q(461,b|0,e+48|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break Y}v[114578]=0;R(462,e+48|0,(B(x[e+68>>1]+d|0,104)+a|0)+484380|0);d=v[114578];v[114578]=0;if((d|0)==1){break Y}d=w[e+80|0];g=w[e+67|0];v[114578]=0;u[e+72>>1]=d|f<<8&32512|((g&3)!=0)<<15;R(463,m|0,e+72|0);d=v[114578];v[114578]=0;if((d|0)==1){break X}f=f+1|0;d=f&65535;if(h>>>0<=d>>>0){break W}g=x[e+68>>1]+d|0;if(g>>>0<=3999){continue}break}}v[114578]=0;Q(340,b|0,20)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break W}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}v[114578]=0;R(463,n|0,e+68|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}v[e+48>>2]=3999;d=x[a+480190>>1];v[114578]=0;v[e+72>>2]=d+h;d=Q(464,e+48|0,e+72|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break J}u[a+480190>>1]=v[d>>2]}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}d=Wb(e+96|0);v[114578]=0;f=W(432,b|0,d|0,-1)|0;i=v[114578];v[114578]=0;_:{$:{aa:{if((i|0)!=1){if(f){v[114578]=0;U(13,e+48|0,6,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break _}Gb(a+1304412|0,e+48|0);yb(e+48|0)}yb(d);f=0;while(1){v[114578]=0;d=(f<<5)+a|0;Z(434,d+480280|0);i=v[114578];v[114578]=0;if((i|0)==1){break aa}v[114578]=0;W(435,b|0,d+480289|0,-1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break aa}f=f+1|0;if((f|0)!=32){continue}break}v[114578]=0;d=Q(465,b|0,e+32|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}if(!d){break l}if((w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))>>>0<12){break p}d=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);v[114578]=0;d=Q(258,b|0,d-11|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}if(d){break $}break p}break q}b=P()|0;O()|0;break e}v[e+88>>2]=(w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))-11;j=rq(e+96|0);v[114578]=0;W(438,b|0,j|0,v[e+88>>2])|0;d=v[114578];v[114578]=0;if((d|0)==1){break s}v[114578]=0;v[e+48>>2]=50529027;d=Q(333,e+88|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break t}v[e+80>>2]=B(v[d>>2],85);i=Wb(e+48|0);d=e+32|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;v[e+8>>2]=d;d=Q(333,e+80|0,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break u}d=v[d>>2];v[114578]=0;R(111,i|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break u}if(v[e+88>>2]){f=0;while(1){ba:{h=w[xc(j,f)|0];d=f+1|0;if(!((h|0)!=255|v[e+88>>2]-d>>>0<2)){d=t[xc(j,d)|0];h=w[xc(j,f+2|0)|0];r=e,s=sf(i),v[r+8>>2]=s;Md(e+24|0,e+8|0);v[114578]=0;aa(439,i|0,v[e+24>>2],h|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=f+3|0;break ba}break u}v[114578]=0;R(110,i|0,h<<24>>24);f=v[114578];v[114578]=0;if((f|0)!=1){break ba}break u}f=d;if(y[e+88>>2]>d>>>0){continue}break}}v[114578]=0;X(440,e+8|0,4,6,i|0);d=v[114578];v[114578]=0;ca:{if((d|0)!=1){Gb(i,e+8|0);yb(e+8|0);d=Tb(i);v[114578]=0;d=T(441,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break ca}f=Fb(i);v[114578]=0;ea(442,a+1304424|0,d|0,f|0,74,0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ca}yb(i);fe(j);break p}break u}break u}break q}b=P()|0;O()|0;break e}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(i);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}fe(j);break e}b=P()|0;O()|0;yb(d);break e}d=Vb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[114578]=0;ea(443,d|0,b|0,f|0,65535,65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}j=c&1;if(j){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[114578]=0;R(403,a+484344|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break o}}d=e+264|3;da:{if(!(w[d|0]|w[d+1|0]<<8)){break da}i=a+484344|0;f=0;while(1){v[114578]=0;h=Q(258,b|0,4)|0;g=v[114578];v[114578]=0;ea:{if((g|0)!=1){if(h){break ea}break da}b=P()|0;O()|0;break e}v[114578]=0;h=T(392,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break i}v[114578]=0;U(343,e+96|0,b|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}fa:{if(!j){break fa}v[114578]=0;h=T(389,e+96|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}v[114578]=0;Q(340,e+96|0,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}v[114578]=0;h=W(404,i|0,f&65535,h+1|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break h}if(!h){break fa}v[114578]=0;W(436,e+96|0,e+48|0,-1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}h=_b(i,f);v[114578]=0;Q(437,h|0,e+48|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}h=_b(i,f);v[114578]=0;U(445,h|0,1,e+96|0);h=v[114578];v[114578]=0;if((h|0)==1){break h}}Bb(e+96|0);f=f+1|0;if(f>>>0<(w[d|0]|w[d+1|0]<<8)>>>0){continue}break}}if(!(c&2)){break l}if(!x[a+480190>>1]){break m}d=0;while(1){c=d+1|0;if(!w[rc(m,d)|0]){c=d+1|0;f=B(c,104)+a|0;d=ad(e+96|0,u[f+484414>>1]&1?16:8,1,0,u[rc(m,d)>>1]>-1?0:6);v[114578]=0;W(402,d|0,f+484380|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}}d=c;if(d>>>0<x[a+480190>>1]){continue}break}break m}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}if(!x[a+480190>>1]){break l}b=0;while(1){c=w[rc(m,b)|0];ga:{if(!c){break ga}c=c-1&65535;if(oc(n)>>>0<=c>>>0){break ga}c=(w[rc(m,b)+1|0]&127)+x[rc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break ga}f=B(c,104);i=f+a|0;d=i+484380|0;if(!De(d)){break ga}j=a+484380|0;h=B(b+1|0,104);c=j+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[(f+j|0)+34>>1]&1;v[c>>2]=v[d>>2];v[114578]=0;c=T(466,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}if(!c){break ga}c=v[(a+h|0)+484400>>2];v[114578]=0;c=T(467,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}f=v[i+484400>>2];v[114578]=0;f=T(467,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}lc(c,f,Aj(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}kf(m);kf(n);break c}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;Bb(e+96|0);break e}b=P()|0;O()|0;break e}b=P()|0;O()|0}kf(m);kf(n)}yb(o);S(b|0);L()}d=1}yb(o)}jb=e+288|0;return d|0}V(0)|0;O()|0;Ab();L()}function i3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-48|0;jb=e;d=Ub(e+32|0,38719);f=uf(c,d);yb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(f){ij(a,0,v[b+24>>2]+1304448|0);break k}d=Ub(e+32|0,38724);f=uf(c,d);yb(d);if(f){ij(a,0,v[b+24>>2]+1304436|0);break k}d=Ub(e+32|0,38734);f=uf(c,d);yb(d);if(f){ij(a,0,v[b+24>>2]+1304484|0);break k}d=Ub(e+32|0,38747);f=uf(c,d);yb(d);if(f){ij(a,0,v[b+24>>2]+1304472|0);break k}d=Ub(e+32|0,38765);f=uf(c,d);yb(d);if(f){c=e+32|0;d=v[v[b+24>>2]+480184>>2];b=78736;l:{while(1){if((d|0)==v[b>>2]){Cn(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=78784){continue}break}gd(c)}v[114578]=0;U(9,a|0,0,e+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break j}yb(e+32|0);break k}d=Ub(e+32|0,38775);f=uf(c,d);yb(d);if(f){l=e+32|0;h=v[v[b+24>>2]+480184>>2];c=jb-48|0;jb=c;b=78736;g=jb-16|0;jb=g;j=g+8|0;d=jb-16|0;jb=d;v[114578]=0;i=c+32|0;f=i;T(1522,f+4|0)|0;m=v[114578];v[114578]=0;m:{n:{o:{if((m|0)!=1){v[114578]=0;v[d+12>>2]=0;W(1523,f+8|0,d+12|0,j|0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break o}break n}break n}q=f,r=hc(f),v[q>>2]=r;jb=d+16|0;break m}V(0)|0;O()|0;Ab();L()}jb=g+16|0;d=gd(l);while(1){if((h|0)==v[b>>2]){f=v[b+4>>2];v[114578]=0;f=Q(2,c+16|0,f|0)|0;g=v[114578];v[114578]=0;p:{q:{r:{s:{t:{u:{if((g|0)!=1){v[114578]=0;U(1521,c|0,i|0,f|0);g=v[114578];v[114578]=0;if((g|0)==1){break s}if(!w[c+4|0]){break p}if(!Wc(d)){v[114578]=0;g=Q(2,c|0,20816)|0;l=v[114578];v[114578]=0;if((l|0)==1){break u}v[114578]=0;Q(192,d|0,g|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break t}yb(g)}v[114578]=0;Q(192,d|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break p}b=P()|0;O()|0;break r}b=P()|0;O()|0;break q}b=P()|0;O()|0;break r}b=P()|0;O()|0;yb(g);break r}b=P()|0;O()|0}yb(f)}yb(d);XK(i);S(b|0);L()}yb(f)}b=b+12|0;if((b|0)!=78784){continue}break}XK(i);jb=c+48|0;v[114578]=0;U(9,a|0,0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,38790);f=uf(c,d);yb(d);if(f){ij(a,0,v[b+24>>2]+1304460|0);break k}d=Ub(e+32|0,38798);f=uf(c,d);yb(d);if(f){ij(a,0,v[b+24>>2]+1304412|0);break k}d=Ub(e+32|0,38805);f=uf(c,d);yb(d);if(f){Af(e+32|0,v[b+24>>2]+1304400|0);v[114578]=0;U(2185,a|0,b|0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,38811);f=uf(c,d);yb(d);if(f){v:{if(!nd(Ow(v[b+24>>2]))){if(v[PH(Ow(v[b+24>>2]))+12>>2]){break v}}Wb(a);break k}b=PH(Ow(v[b+24>>2]));h=jb-192|0;jb=h;lc(h+144|0,b,44);i=v[b+44>>2];if(i){lc(h+44|0,b,44);c=jb-16|0;jb=c;b=Vv(v[h+64>>2]+1900|0,v[h+60>>2]+1|0,v[h+56>>2])-Vv(1970,1,1)|0;b=Fma(b,b>>31,86400,0);d=B(v[h+52>>2],3600);f=d;b=b+d|0;d=mb+(d>>31)|0;d=b>>>0<f>>>0?d+1|0:d;f=b;b=B(v[h+48>>2],60);g=b;f=f+b|0;b=(b>>31)+d|0;b=f>>>0<g>>>0?b+1|0:b;d=v[h+44>>2];g=d;f=d+f|0;d=(d>>31)+b|0;b=FF(c+8|0,f,f>>>0<g>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];jb=c+16|0;v[h+96>>2]=b;v[h+100>>2]=d;m=h+96|0;d=h+88|0;f=v[h+96>>2];g=v[h+100>>2];c=2147483647;n=Sd(+(i>>>0)*.054945054945054944);b=-1;w:{if(!(n<0x8000000000000000)){break w}c=-2147483648;b=0;if(!(n>-0x8000000000000000)){break w}if(D(n)<0x8000000000000000){c=D(n)>=1?n>0?~~F(H(n*2.3283064365386963e-10),4294967295)>>>0:~~I((n-+(~~n>>>0>>>0))*2.3283064365386963e-10)>>>0:0;b=~~n>>>0;break w}b=0}k=d;d=c+g|0;f=b+f|0;d=f>>>0<b>>>0?d+1|0:d;b=FF(k,f,d);j=jb-16|0;jb=j;i=v[b>>2];o=v[b+4>>2];v[j+12>>2]=0;v[j+8>>2]=0;v[j+4>>2]=0;b=Vv(1970,1,1)+Gma(i,o,86400,0)|0;l=b>>31;c=b;d=Fma(b,l,1e4,0)+14780|0;b=mb;g=d;b=d>>>0<14780?b+1|0:b;f=b;d=Gma(d,b,-14609700,-1);b=c;k=d+b|0;d=l+mb|0;d=b>>>0>k>>>0?d+1|0:d;b=k;k=Gma(g,f,365242500,0);b=b+k|0;d=mb+d|0;d=b>>>0<k>>>0?d+1|0:d;k=Gma(g,f,-146097e4,-1);b=k+b|0;d=mb+d|0;d=b>>>0<k>>>0?d+1|0:d;k=b;b=Gma(g,f,3652425,0);f=mb;p=f;g=k;k=Fma(b,f,-365,-1);g=g+k|0;f=mb+d|0;f=g>>>0<k>>>0?f+1|0:f;d=f;if(!((d|0)>0?1:(d|0)>=0)){d=p-(b>>>0<1)|0;b=b-1|0;f=Fma(b,d,-365,-1)+c|0;d=l+mb|0;d=c>>>0>f>>>0?d+1|0:d;c=f;f=(b|0)/-4|0;g=f;c=c+f|0;f=(f>>31)+d|0;f=c>>>0<g>>>0?f+1|0:f;d=c;c=(b|0)/100|0;g=c;d=d+c|0;c=(c>>31)+f|0;c=d>>>0<g>>>0?c+1|0:c;f=d;d=(b|0)/-400|0;g=d;f=f+d|0;d=(d>>31)+c|0;d=f>>>0<g>>>0?d+1|0:d;g=f}f=b;c=Fma(g,d,100,0)+52|0;b=mb;b=Gma(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[j+12>>2]=f+d;v[j+8>>2]=(c-B(d,12)|0)+1;b=Fma(b,mb,306,0)+5|0;d=mb;b=Gma(b,b>>>0<5?d+1|0:d,-10,-1)+g|0;v[j+4>>2]=b+1;vF(m);v[m+20>>2]=v[j+12>>2]-1900;v[m+16>>2]=v[j+8>>2]-1;b=v[j+4>>2];q=m,r=Hma(Gma(i,o,3600,0),mb,24),v[q+8>>2]=r;v[m+12>>2]=b;b=Gma(i,o,60,0);c=mb;q=m,r=Hma(b,c,60),v[q+4>>2]=r;q=m,r=i-Fma(b,c,60,0)|0,v[q>>2]=r;jb=j+16|0;lc(h+144|0,h+96|0,44)}f=e+32|0;l=lc(h,h+144|0,44);d=l;b=jb-112|0;jb=b;c=gd(b+96|0);v[114578]=0;i=Q(2,b+80|0,6848)|0;g=v[114578];v[114578]=0;x:{y:{z:{if((g|0)!=1){g=v[d+20>>2];if(g){break z}cd(f,c);break x}a=P()|0;O()|0;break y}v[114578]=0;v[b+48>>2]=g+1900;R(191,b- -64|0,b+48|0);g=v[114578];v[114578]=0;A:{B:{if((g|0)!=1){v[114578]=0;Q(192,c|0,b- -64|0)|0;g=v[114578];v[114578]=0;C:{if((g|0)!=1){yb(b- -64|0);if(y[d+16>>2]<12){break C}cd(f,c);break x}a=P()|0;O()|0;yb(b- -64|0);break A}v[114578]=0;g=Q(2,b+48|0,6850)|0;h=v[114578];v[114578]=0;D:{E:{F:{G:{H:{I:{if((h|0)!=1){h=v[d+16>>2];v[114578]=0;v[b+16>>2]=h+1;R(193,b+32|0,b+16|0);h=v[114578];v[114578]=0;if((h|0)==1){break I}v[114578]=0;U(3,b- -64|0,g|0,b+32|0);h=v[114578];v[114578]=0;if((h|0)==1){break H}v[114578]=0;Q(192,c|0,b- -64|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break G}yb(b- -64|0);yb(b+32|0);yb(g);if(v[d+12>>2]-1>>>0<31){break D}cd(f,c);break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break E}a=P()|0;O()|0;break F}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(g);break A}v[114578]=0;g=Q(2,b+48|0,6850)|0;h=v[114578];v[114578]=0;J:{K:{L:{M:{N:{O:{P:{if((h|0)!=1){v[114578]=0;R(193,b+32|0,d+12|0);h=v[114578];v[114578]=0;if((h|0)==1){break P}v[114578]=0;U(3,b- -64|0,g|0,b+32|0);h=v[114578];v[114578]=0;if((h|0)==1){break O}v[114578]=0;Q(192,c|0,b- -64|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break N}yb(b- -64|0);yb(b+32|0);yb(g);g=v[d+8>>2];if(g){break K}if(v[d+4>>2]|v[d>>2]){break J}cd(f,c);break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break L}a=P()|0;O()|0;break M}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(g);break A}if(g>>>0<24){break J}cd(f,c);break x}if(y[d+4>>2]>=60){cd(f,c);break x}v[114578]=0;g=Q(2,b- -64|0,6852)|0;h=v[114578];v[114578]=0;Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{if((h|0)!=1){v[114578]=0;Q(192,c|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break aa}yb(g);if(v[d+32>>2]>=1){v[114578]=0;g=Q(2,b- -64|0,6854)|0;h=v[114578];v[114578]=0;if((h|0)==1){break $}Gb(i,g);yb(g)}v[114578]=0;R(193,b+32|0,d+8|0);g=v[114578];v[114578]=0;if((g|0)==1){break _}v[114578]=0;g=Q(2,b+16|0,6861)|0;h=v[114578];v[114578]=0;if((h|0)==1){break Z}v[114578]=0;U(3,b+48|0,b+32|0,g|0);h=v[114578];v[114578]=0;if((h|0)==1){break Y}v[114578]=0;R(193,b|0,d+4|0);h=v[114578];v[114578]=0;if((h|0)==1){break X}v[114578]=0;U(3,b- -64|0,b+48|0,b|0);h=v[114578];v[114578]=0;if((h|0)==1){break W}v[114578]=0;Q(192,c|0,b- -64|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break V}yb(b- -64|0);yb(b);yb(b+48|0);yb(g);yb(b+32|0);if(y[d>>2]<62){break Q}v[114578]=0;U(194,f|0,c|0,i|0);d=v[114578];v[114578]=0;if((d|0)!=1){break x}break B}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(g);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break R}a=P()|0;O()|0;break S}a=P()|0;O()|0;break T}a=P()|0;O()|0;break U}a=P()|0;O()|0;yb(b- -64|0)}yb(b)}yb(b+48|0)}yb(g)}yb(b+32|0);break A}v[114578]=0;g=Q(2,b+48|0,6861)|0;h=v[114578];v[114578]=0;ba:{ca:{da:{ea:{fa:{if((h|0)!=1){v[114578]=0;R(193,b+32|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break fa}v[114578]=0;U(3,b- -64|0,g|0,b+32|0);d=v[114578];v[114578]=0;if((d|0)==1){break ea}v[114578]=0;Q(192,c|0,b- -64|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break da}yb(b- -64|0);yb(b+32|0);yb(g);v[114578]=0;Q(192,c|0,i|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break B}cd(f,c);break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break ba}a=P()|0;O()|0;break ca}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(g);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0}yb(i)}yb(c);S(a|0);L()}yb(i);yb(c);jb=b+112|0;jb=l+192|0;v[114578]=0;U(9,a|0,0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,38816);f=uf(c,d);yb(d);if(f){c=b;xO(e+32|0,v[b+24>>2]+1304424|0);ga:{ha:{ia:{if(!Wc(e+32|0)){break ia}c=v[c+24>>2];v[114578]=0;c=T(2186,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break ga}ja:{switch(c|0){case 0:v[114578]=0;R(2187,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ia}c=P()|0;O()|0;break b;case 1:v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ia}c=P()|0;O()|0;break b;case 2:if(Wc(e+32|0)){v[114578]=0;R(2187,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}Gb(e+32|0,e+16|0);yb(e+16|0)}if(!Wc(e+32|0)){break ia}v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ia}c=P()|0;O()|0;break b;case 3:if(Wc(e+32|0)){v[114578]=0;R(2188,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}Gb(e+32|0,e+16|0);yb(e+16|0)}if(!Wc(e+32|0)){break ia}v[114578]=0;R(2187,e+16|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){Gb(e+32|0,e+16|0);yb(e+16|0);break ia}c=P()|0;O()|0;break b;case 4:v[114578]=0;R(2187,e+16|0,b|0);c=v[114578];v[114578]=0;ka:{la:{if((c|0)!=1){v[114578]=0;R(2188,e|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break ka}if(Wc(e+16|0)){break la}v[114578]=0;Q(1250,e+32|0,e+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break la}break d}c=P()|0;O()|0;break b}if(!Wc(e)){v[114578]=0;Q(1250,e+32|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}}yb(e);yb(e+16|0);break ia}c=P()|0;O()|0;break c;case 5:break ja;default:break ia}}v[114578]=0;R(2187,e+16|0,b|0);c=v[114578];v[114578]=0;ma:{if((c|0)!=1){v[114578]=0;R(2188,e|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break ha}if(Wc(e)){break ma}v[114578]=0;Q(1250,e+32|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break ma}break f}c=P()|0;O()|0;break b}if(!Wc(e+16|0)){v[114578]=0;Q(1250,e+32|0,e+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}}yb(e);yb(e+16|0)}v[114578]=0;U(2185,a|0,b|0,e+32|0);a=v[114578];v[114578]=0;if((a|0)==1){break ga}yb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Ub(e+32|0,38824);f=uf(c,d);yb(d);if(f){xO(e+32|0,v[b+24>>2]+1304424|0);v[114578]=0;U(2185,a|0,b|0,e+32|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}f=c;c=Ub(e+32|0,38836);d=uf(f,c);yb(c);if(d){a=Wb(a);b=b+68|0;q=e,r=bc(b),v[q+32>>2]=r;q=e,r=cc(b),v[q+16>>2]=r;if(!Jb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[114578]=0;Q(1995,a|0,38845)|0;c=v[114578];v[114578]=0;if((c|0)==1){break g}}v[114578]=0;Q(1250,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}zn(e+32|0);c=0;if(Jb(e+32|0,e+16|0)){continue}break}break k}Ub(a,38235)}jb=e+48|0;return}c=P()|0;O()|0;yb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(a);break a}c=P()|0;O()|0;yb(e)}yb(e+16|0);break b}c=P()|0;O()|0;yb(e)}yb(e+16|0)}yb(e+32|0)}S(c|0);L()}function pd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;m=jb-16|0;jb=m;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(a>>>0<=244){f=v[115886];i=a>>>0<11?16:a+11&-8;c=i>>>3|0;b=f>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;e=v[b+463592>>2];a=e+8|0;c=v[e+8>>2];b=b+463584|0;m:{if((c|0)==(b|0)){n=463544,o=Jma(-2,d)&f,v[n>>2]=o;break m}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[e+4>>2]=b|3;b=b+e|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[115888];if(k>>>0>=i>>>0){break l}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+463592>>2];b=v[g+8>>2];a=a+463584|0;n:{if((b|0)==(a|0)){f=Jma(-2,c)&f;v[115886]=f;break n}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=i|3;d=g+i|0;b=c<<3;e=b-i|0;v[d+4>>2]=e|1;v[b+g>>2]=e;if(k){b=k>>>3|0;c=(b<<3)+463584|0;g=v[115891];b=1<<b;o:{if(!(b&f)){v[115886]=b|f;b=c;break o}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[115891]=d;v[115888]=e;break a}h=v[115887];if(!h){break l}b=(h&0-h)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+463848>>2];d=(v[b+4>>2]&-8)-i|0;c=b;while(1){p:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break p}}c=(v[a+4>>2]&-8)-i|0;e=c>>>0<d>>>0;d=e?c:d;b=e?a:b;c=a;continue}break}j=b+i|0;if(j>>>0<=b>>>0){break k}l=v[b+24>>2];e=v[b+12>>2];if((e|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=e;v[e+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;e=a;c=a+20|0;a=v[c>>2];if(a){continue}c=e+16|0;a=v[e+16>>2];if(a){continue}break}v[g>>2]=0;break b}i=-1;if(a>>>0>4294967231){break l}a=a+11|0;i=a&-8;j=v[115887];if(!j){break l}f=31;d=0-i|0;if(i>>>0<=16777215){a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|i>>>a+21&1)+28|0}c=v[(f<<2)+463848>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=i<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-i|0;if(g>>>0>=d>>>0){break t}e=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|e)){a=2<<f;a=(0-a|a)&j;if(!a){break l}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+463848>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-i|0;c=b>>>0<d>>>0;d=c?b:d;e=c?a:e;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!e|v[115888]-i>>>0<=d>>>0){break l}h=e+i|0;if(h>>>0<=e>>>0){break k}f=v[e+24>>2];b=v[e+12>>2];if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=e+20|0;a=v[c>>2];if(!a){a=v[e+16>>2];if(!a){break i}c=e+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[115888];if(c>>>0>=i>>>0){d=v[115891];b=c-i|0;u:{if(b>>>0>=16){v[115888]=b;a=d+i|0;v[115891]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=i|3;break u}v[115891]=0;v[115888]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}h=v[115889];if(h>>>0>i>>>0){b=h-i|0;v[115889]=b;c=v[115892];a=c+i|0;v[115892]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}a=0;j=i+47|0;b=j;if(v[116004]){c=v[116006]}else{v[116007]=-1;v[116008]=-1;v[116005]=4096;v[116006]=4096;v[116004]=m+12&-16^1431655768;v[116009]=0;v[115997]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=i>>>0){break a}d=v[115996];if(d){b=v[115994];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[463988]&4){break f}v:{w:{d=v[115892];if(d){a=463992;while(1){b=v[a>>2];if(d>>>0<b+v[a+4>>2]>>>0?b>>>0<=d>>>0:0){break w}a=v[a+8>>2];if(a){continue}break}}b=Yk(0);if((b|0)==-1){break g}f=c;d=v[116005];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=i>>>0|f>>>0>2147483646){break g}d=v[115996];if(d){a=v[115994];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=Yk(f);if((b|0)!=(a|0)){break v}break e}f=e&g-h;if(f>>>0>2147483646){break g}b=Yk(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|i+48>>>0<=f>>>0)){b=v[116006];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((Yk(b)|0)!=-1){f=b+f|0;b=a;break e}Yk(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}L()}e=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[115997]=v[115997]|4}if(c>>>0>2147483646){break d}b=Yk(c);a=Yk(0);if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=i+40>>>0){break d}}a=v[115994]+f|0;v[115994]=a;if(a>>>0>y[115995]){v[115995]=a}x:{y:{z:{g=v[115892];if(g){a=463992;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break z}a=v[a+8>>2];if(a){continue}break}break y}a=v[115890];if(!(a>>>0<=b>>>0?a:0)){v[115890]=b}a=0;v[115999]=f;v[115998]=b;v[115894]=-1;v[115895]=v[116004];v[116001]=0;while(1){d=a<<3;c=d+463584|0;v[d+463592>>2]=c;v[d+463596>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115889]=c;a=a+b|0;v[115892]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115893]=v[116008];break x}if(v[a+12>>2]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break y}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[115892]=c;b=v[115889]+f|0;a=b-a|0;v[115889]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[115893]=v[116008];break x}if(y[115890]>b>>>0){v[115890]=b}c=b+f|0;a=463992;A:{B:{C:{D:{E:{F:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break F}break}if(!(w[a+12|0]&8)){break E}}a=463992;while(1){c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break D}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=i|3;f=c+(c+8&7?-8-c&7:0)|0;h=i+j|0;c=f-h|0;if((f|0)==(g|0)){v[115892]=h;a=v[115889]+c|0;v[115889]=a;v[h+4>>2]=a|1;break B}if(v[115891]==(f|0)){v[115891]=h;a=v[115888]+c|0;v[115888]=a;v[h+4>>2]=a|1;v[a+h>>2]=a;break B}a=v[f+4>>2];if((a&3)==1){g=a&-8;G:{if(a>>>0<=255){d=v[f+8>>2];a=a>>>3|0;b=v[f+12>>2];if((b|0)==(d|0)){n=463544,o=v[115886]&Jma(-2,a),v[n>>2]=o;break G}v[d+12>>2]=b;v[b+8>>2]=d;break G}i=v[f+24>>2];b=v[f+12>>2];H:{if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break H}I:{a=f+20|0;d=v[a>>2];if(d){break I}a=f+16|0;d=v[a>>2];if(d){break I}b=0;break H}while(1){e=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[e>>2]=0}if(!i){break G}d=v[f+28>>2];a=(d<<2)+463848|0;J:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break J}n=463548,o=v[115887]&Jma(-2,d),v[n>>2]=o;break G}v[i+(v[i+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break G}}v[b+24>>2]=i;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break G}v[b+20>>2]=a;v[a+24>>2]=b}f=f+g|0;c=c+g|0}v[f+4>>2]=v[f+4>>2]&-2;v[h+4>>2]=c|1;v[c+h>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;K:{if(!(c&a)){v[115886]=a|c;a=b;break K}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break B}a=31;if(c>>>0<=16777215){a=c>>>8|0;e=a+1048320>>>16&8;a=a<<e;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|e))|0;a=(a<<1|c>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;e=(a<<2)+463848|0;d=v[115887];b=1<<a;L:{if(!(d&b)){v[115887]=b|d;v[e>>2]=h;v[h+24>>2]=e;break L}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[e>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break C}b=a>>>29|0;a=a<<1;e=d+(b&4)|0;b=v[e+16>>2];if(b){continue}break}v[e+16>>2]=h;v[h+24>>2]=d}v[h+12>>2]=h;v[h+8>>2]=h;break B}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115889]=c;a=a+b|0;v[115892]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115893]=v[116008];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[116001];v[c+16>>2]=v[116e3];v[c+20>>2]=a;a=v[115999];v[c+8>>2]=v[115998];v[c+12>>2]=a;v[116e3]=c+8;v[115999]=f;v[115998]=b;v[116001]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break x}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){a=e>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;M:{if(!(c&a)){v[115886]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break x}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+463848|0;c=v[115887];b=1<<a;N:{if(!(c&b)){v[115887]=b|c;v[d>>2]=g;v[g+24>>2]=d;break N}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((e|0)==(v[b+4>>2]&-8)){break A}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break x}a=v[d+8>>2];v[a+12>>2]=h;v[d+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=d;v[h+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[115889];if(a>>>0<=i>>>0){break d}b=a-i|0;v[115889]=b;c=v[115892];a=c+i|0;v[115892]=a;v[a+4>>2]=b|1;v[c+4>>2]=i|3;a=c+8|0;break a}v[114552]=48;a=0;break a}O:{if(!f){break O}c=v[e+28>>2];a=(c<<2)+463848|0;P:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break P}j=Jma(-2,c)&j;v[115887]=j;break O}v[f+(v[f+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break O}}v[b+24>>2]=f;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break O}v[b+20>>2]=a;v[a+24>>2]=b}Q:{if(d>>>0<=15){a=d+i|0;v[e+4>>2]=a|3;a=a+e|0;v[a+4>>2]=v[a+4>>2]|1;break Q}v[e+4>>2]=i|3;v[h+4>>2]=d|1;v[d+h>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;R:{if(!(c&a)){v[115886]=a|c;a=b;break R}a=v[b+8>>2]}v[b+8>>2]=h;v[a+12>>2]=h;v[h+12>>2]=b;v[h+8>>2]=a;break Q}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[h+28>>2]=a;v[h+16>>2]=0;v[h+20>>2]=0;c=(a<<2)+463848|0;S:{b=1<<a;T:{if(!(b&j)){v[115887]=b|j;v[c>>2]=h;v[h+24>>2]=c;break T}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);i=v[c>>2];while(1){b=i;if((v[b+4>>2]&-8)==(d|0)){break S}c=a>>>29|0;a=a<<1;c=b+(c&4)|0;i=v[c+16>>2];if(i){continue}break}v[c+16>>2]=h;v[h+24>>2]=b}v[h+12>>2]=h;v[h+8>>2]=h;break Q}a=v[b+8>>2];v[a+12>>2]=h;v[b+8>>2]=h;v[h+24>>2]=0;v[h+12>>2]=b;v[h+8>>2]=a}a=e+8|0;break a}U:{if(!l){break U}c=v[b+28>>2];a=(c<<2)+463848|0;V:{if(v[a>>2]==(b|0)){v[a>>2]=e;if(e){break V}n=463548,o=Jma(-2,c)&h,v[n>>2]=o;break U}v[(v[l+16>>2]==(b|0)?16:20)+l>>2]=e;if(!e){break U}}v[e+24>>2]=l;a=v[b+16>>2];if(a){v[e+16>>2]=a;v[a+24>>2]=e}a=v[b+20>>2];if(!a){break U}v[e+20>>2]=a;v[a+24>>2]=e}W:{if(d>>>0<=15){a=d+i|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break W}v[b+4>>2]=i|3;v[j+4>>2]=d|1;v[d+j>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+463584|0;e=v[115891];a=1<<a;X:{if(!(a&f)){v[115886]=a|f;a=c;break X}a=v[c+8>>2]}v[c+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=c;v[e+8>>2]=a}v[115891]=j;v[115888]=d}a=b+8|0}jb=m+16|0;return a|0}function Xla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=jb+-64|0;jb=f;Jc(a);a:{b:{if(b>>>0<=2){C=f,D=Gd(a),t[C+56|0]=D;$b(a,2);e=f+56|2;b=hg(a);t[e|0]=b;t[e+1|0]=b>>>8;e=f+56|4;b=Cf(a);t[e|0]=b;t[e+1|0]=b>>>8;t[e+2|0]=b>>>16;t[e+3|0]=b>>>24;break b}Ff(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{n=d+484344|0;b=f+56|2;r=Cd(w[b|0]|w[b+1|0]<<8,1,1024);m=mx(n,r,0);if((m|0)!=65535){e=Rn(_b(n,m),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];s=x[lf(f,f+40|0)>>1];g=s+1|0;if(x[d+480188>>1]>(g&65535)>>>0){b=g&65535;while(1){t[e+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Tt(f+40|0,g,f);if(r){b=(b|0)!=0;while(1){d:{e:{if(!w[xc(o,0)|0]){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}l=g<<24>>24;if((l|0)<=-1){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}C=xc(o,0),D=g,t[C|0]=D}y=0;t[f|0]=0;h=l&63;f:{g:{if(!h){break g}v[114578]=0;e=T(389,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}t[f|0]=e;l=0;h:{switch(h-1|0){case 0:t[c+12|0]=0;v[114578]=0;t[f+36|0]=1;e=Q(455,f+36|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){t[c+14|0]=w[e|0];t[c+15|0]=0;b=1;break f}break c;case 1:if(!e){break f}t[c+15|0]=e;b=1;t[c+12|0]=1;g=w[c+13|0];if(!g){break g}t[c+14|0]=B(B(e,g),15);break g;case 2:e=e>>>4|0;t[c+13|0]=e;if(e){b=w[c+12|0]!=0;break f}t[c+12|0]=0;break f;case 3:l=e;break f;case 5:if(!e){break f}b=(w[c+12|0]?15:14)+c|0;g=w[b|0];t[b|0]=g>>>0<256-e>>>0?e+g|0:-1;b=1;break g;case 6:break h;default:break f}}if(!e){break f}b=1;g=(w[c+12|0]?15:14)+c|0;l=w[g|0];t[g|0]=l>>>0>e+1>>>0?l-e|0:1}l=0}v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d}l=0;e=xc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;y=0;if(!(b&1)){break d}}b=w[c+12|0];e=w[c+13|0];if(e?0:b){break d}i:{if(b){v[f>>2]=1;b=w[c+15|0];v[114578]=0;v[f+28>>2]=B(b,e)<<1;e=Q(552,f|0,f+28|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}e=v[e>>2];break i}e=B(w[c+14|0],30)+30|0}b=255;j:{while(1){h=B(b,e);if(h-1536>>>0<10752){break j}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(h|0)/48;ce(f+32|0,32,255);v[114578]=0;v[f>>2]=1;e=Q(552,f|0,f+36|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}t[c+16|0]=v[e>>2];y=1}b=_b(n,m);v[114578]=0;b=W(472,b|0,k|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(s){z=k-1|0;i=1;p=1;while(1){k:{if(!w[xc(o,i)|0]){v[114578]=0;j=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(j&128){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}C=xc(o,i),D=g,t[C|0]=D}A=1;if(j&64){v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[b+1|0]=g;A=!g}l:{if(!(j&32)){break l}v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[b|0]=g;if((g-1&255)>>>0<=107){e=Rp(g+24|0);t[b|0]=e;C=Nc(c,i),D=e,t[C+1|0]=D;break l}if((g+127&255)>>>0<=107){e=Rp((g&127)+24|0);t[b|0]=e;C=Nc(c,i),D=e,t[C|0]=D;t[b|0]=0;break l}if((g|0)!=255){break l}t[b|0]=254}if(!(w[b|0]|!w[b+1|0])){e=w[Nc(c,i)+1|0];t[b+1|0]=0;t[b|0]=e}v[114578]=0;g=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(g){C=Nc(c,i),D=0,t[C+5|0]=D}t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;t[f+22|0]=0;if(j&16){t[b+2|0]=1;v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[b+4|0]=g+2>>>2}m:{if(!(j&8)){break m}v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;t[f+27|0]=g;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+24|0]=g;n:{o:{p:{q:{r:{s:{t:{u:{e=w[f+27|0];switch(e-1|0){case 0:break o;case 9:break p;case 5:case 6:case 7:case 8:break q;case 4:break r;case 3:break s;case 2:break t;case 1:break u;default:break n}}t[b|0]=255;break n}C=b,D=w[Nc(c,i)+1|0],t[C|0]=D;C=Nc(c,i),D=0,t[C+5|0]=D;break n}e=St(g,w[c+16|0]);t[f+24|0]=e;v:{if(e){t[f+27|0]=20;t[f+24|0]=e|208;break v}t[f+27|0]=0}if(w[b|0]){break m}C=b,D=w[Nc(c,i)+1|0],t[C|0]=D;C=Nc(c,i),D=0,t[C+5|0]=D;break m}t[f|0]=1;e=St(g,w[c+16|0]);v[114578]=0;t[f+28|0]=e;g=Q(455,f|0,f+28|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[f+24|0]=w[g|0];t[f+27|0]=15;C=Nc(c,i),D=0,t[C+5|0]=D;break m}break c}w:{if(!k){break w}if((e|0)==w[Nc(c,i)+4|0]){break w}h=_b(n,m);v[114578]=0;g=W(498,f|0,20,(w[f+27|0]+122|160)&255)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}e=Gn(Fn(Ne(g,z),p&65535));v[114578]=0;g=Q(499,h|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break w}e=w[f+27|0];C=Nc(c,i),D=e,t[C+4|0]=D}t[f+27|0]=10;if(!w[b|0]){C=b,D=w[Nc(c,i)+1|0],t[C|0]=D}C=Nc(c,i),D=0,t[C+5|0]=D;break m}t[f+27|0]=20;C=f,D=w[Nc(c,i)+5|0]?-98:-97,t[C+24|0]=D;e=w[Nc(c,i)+5|0];C=Nc(c,i),D=e^1,t[C+5|0]=D;break m}t[b|0]=254}t[f+27|0]=0}q=0;g=0;x:{if(!(j&4)){break x}v[114578]=0;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;t[f+26|0]=g;g=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}g=g<<24>>24;t[f+23|0]=g;e=f;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{h=w[f+26|0];switch(h-1|0){case 11:break A;case 10:break B;case 7:case 8:case 9:break C;case 6:break D;case 5:break E;case 3:case 4:break F;case 2:break G;case 1:break H;case 0:break I;default:break z}}e=(g|0)>-1;t[f+26|0]=e?2:3;if(!e){g=0-g|0;t[f+23|0]=g}J:{if((g&255)>>>0<16){break J}v[114578]=0;g=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break J}K:{if(w[f+26|0]==2){e=w[b|0];v[114578]=0;v[f>>2]=e+(w[f+23|0]>>>4|0);v[f+28>>2]=120;g=Q(464,f|0,f+28|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break K}break c}e=w[b|0];v[114578]=0;v[f>>2]=e-(w[f+23|0]>>>4|0);v[f+28>>2]=1;g=Q(552,f|0,f+28|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}}t[b|0]=v[g>>2];t[f+23|0]=w[f+23|0]&15}v[114578]=0;t[f|0]=15;g=Q(393,f|0,f+23|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[f+23|0]=w[g|0]|240;g=0;break x}break c}e=St(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|208;g=1;break x}t[f+26|0]=0;g=1;break x}g=1;break y}e=w[c+16|0];v[114578]=0;g=W(554,g&255,e|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+23|0]=g;t[f+26|0]=w[f+26|0]==4?2:3;g=1;break x}if(!w[b|0]){C=b,D=w[Nc(c,i)|0],t[C|0]=D;g=w[f+23|0]}e=w[c+16|0];v[114578]=0;g=W(554,g&255,e|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+26|0]=4;t[f+23|0]=g;g=1;break x}C=b,D=Rp((g&255)+25|0),t[C|0]=D;t[f+23|0]=255;t[f+26|0]=4;g=1;break x}L:{if(!k){break L}if((h|0)==w[Nc(c,i)+2|0]){break L}h=_b(n,m);v[114578]=0;g=W(498,f|0,20,(w[f+26|0]-8|48)&255)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}e=Gn(Fn(Ne(g,z),p&65535));v[114578]=0;g=Q(499,h|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break L}e=w[f+26|0];C=Nc(c,i),D=e,t[C+2|0]=D}t[f+26|0]=5;e=w[c+16|0];v[114578]=0;g=Q(555,w[f+23|0],e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+23|0]=g;g=1;break x}e=gT(g&255,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=e;g=1;break x}e=St(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|192;g=1;break x}t[f+26|0]=0;t[b|0]=254;g=1;break x}g=0}t[e+26|0]=g}M:{if(!(j&2)){break M}v[114578]=0;h=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;t[f+25|0]=h;j=T(389,a|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+22|0]=j;N:{O:{P:{Q:{R:{S:{T:{h=w[f+25|0];switch(h-1|0){case 9:break O;case 7:case 8:break P;case 6:break Q;case 3:case 4:case 5:break R;case 2:break S;case 0:case 1:break T;default:break N}}e=w[c+16|0];v[114578]=0;h=W(556,j|0,e|0,(h|0)==1|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+25|0]=11;t[f+22|0]=h;q=1;break M}e=gT(j,w[c+16|0]);t[f+25|0]=18;t[f+22|0]=e;q=1;break M}U:{if(!k){break U}if((h|0)==w[Nc(c,i)+3|0]){break U}j=_b(n,m);v[114578]=0;h=W(498,f|0,20,(w[f+25|0]-4|64)&255)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}e=Gn(Fn(Ne(h,z),p&65535));v[114578]=0;h=Q(499,j|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!h){break U}e=w[f+25|0];C=Nc(c,i),D=e,t[C+3|0]=D}t[f+25|0]=8;e=w[c+16|0];v[114578]=0;h=Q(555,w[f+22|0],e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+22|0]=h;q=1;break M}t[f+25|0]=9;break M}e=w[c+16|0];v[114578]=0;h=W(556,j|0,e|0,(h|0)==8|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+25|0]=29;t[f+22|0]=h;q=1;break M}t[f+25|0]=27;e=w[c+16|0];v[114578]=0;h=Q(555,j|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}t[f+22|0]=h;q=1;break M}t[f+25|0]=0}if(g){fT(b,k,x[d+480188>>1],w[f+26|0],f+23|0)}if(q){fT(b,k,x[d+480188>>1],w[f+25|0],f+22|0)}V:{if(!A){break V}v[114578]=0;g=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!g){break V}e=w[f+26|0];if(!e){t[f+23|0]=255;t[f+26|0]=4;break V}if(w[f+25|0]|(e|0)==4){break V}t[f+22|0]=255;t[f+25|0]=4}W:{if(w[b+2|0]!=1){break W}X:{if(!w[f+26|0]){t[f+26|0]=13;t[f+23|0]=w[b+4|0];break X}if(w[f+25|0]){break W}t[f+25|0]=13;t[f+22|0]=w[b+4|0]}t[b+2|0]=0}v[114578]=0;fa(500,f|0,f+26|0,f+23|0,f+25|0,f+22|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}Y:{if(w[b+2|0]){break Y}e=w[f+26|0];if(!e){break Y}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}e=b;Z:{if(w[f+27|0]){v[114578]=0;fa(500,f|0,f+25|0,f+22|0,f+27|0,f+24|0);g=v[114578];v[114578]=0;if((g|0)==1){break c}_:{if(w[b+2|0]){break _}g=w[f+25|0];if(!g){break _}t[b+2|0]=g;t[b+4|0]=w[f+22|0]}t[b+3|0]=w[f+27|0];g=f+24|0;break Z}g=w[f+25|0];if(!g){break k}t[b+3|0]=g;g=f+22|0}t[e+5|0]=w[g|0];break k}e=xc(o,i);t[e|0]=w[e|0]-1}b=b+6|0;p=p+1|0;i=p&65535;if(s>>>0>=i>>>0){continue}break}}$:{if(!y){break $}g=_b(n,m);v[114578]=0;e=W(498,f|0,17,w[f+32|0])|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Uh(Fn(Ne(e,k),0));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}g=_b(n,m);v[114578]=0;e=W(498,f|0,16,w[f+36|0])|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=Uh(Ne(e,k));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break $}}break c}aa:{if(!(l&240)){break aa}g=_b(n,m);v[114578]=0;e=W(498,f|0,20,l>>>4|224)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=eT(Ne(e,k));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break aa}}break c}ba:{e=l&15;if(!e){break ba}b=w[c+16|0];g=_b(n,m);b=Cd((B(b,e)>>>0)/15&255,1,15);v[114578]=0;e=W(498,f|0,20,b|96)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=eT(Ne(e,k));v[114578]=0;Q(499,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ba}}break c}b=0;k=k+1|0;if((r|0)!=(k|0)){continue}break}}fe(o)}jb=f- -64|0;return m|0}a=P()|0;O()|0;fe(o);S(a|0);L()}function GU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;o=ph(b,11882);a:{if(!o){break a}if(!Qb(b,6)){break a}while(1){b:{k=Cf(b);c:{if((k|0)==(Fj(11887)|0)){break c}i=w[11892]|w[11893]<<8|(w[11894]<<16|w[11895]<<24);if(!(k&1616928864)|k&-2139062144){break c}if((i|0)!=(k|0)){break b}}fg(b,4);break a}l=1;q=hg(b);if(x[a+480192>>1]){while(1){j=v[(((l&65535)<<2)+a|0)+900380>>2];if(j){d:{i=q;m=b;p=k;if((Fj(11872)|0)==(k|0)){$b(m,i);break d}e=p;c=i;d=m;g=0;h=jb-32|0;jb=h;e:{f:{g:{h:{i:{j:{k:{l:{m:{f=j;n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+23|0]=s;g=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+18|0]=s;g=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Qb(d,c)){break n}r=f,s=Ok(d,c),v[r>>2]=s;g=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+21|0]=s;g=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}e=f+236|0;ud(h+16|0,d,c);c=0;while(1){v[114578]=0;d=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}r=ed(e,c),s=d,u[r>>1]=s;c=c+1|0;if(c>>>0<128){continue}break}Bb(h+16|0);g=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+31|0]=s;g=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+34|0]=s;g=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+16|0]=s;g=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[h+16>>2]=240;r=h,s=Ok(d,c),v[r>>2]=s;gg(f+68|0,v[Lb(h+16|0,h)>>2]);g=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}if(Kb(d)){while(1){v[114578]=0;e=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}r=Pb(d,c),s=e,t[r+2|0]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+82|0]=s;g=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+27|0]=s;g=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}if(Kb(d)){while(1){v[114578]=0;e=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break h}r=Pb(d,c),s=e,u[r>>1]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+83|0]=s;g=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}r=f,s=B(jq(d,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[r+40>>2]=s;g=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+36|0]=s;g=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}if(Kb(d)){while(1){v[114578]=0;e=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}r=Pb(d,c),s=e,t[r+2|0]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}if(Kb(d)){while(1){v[114578]=0;e=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}r=Pb(d,c),s=e,u[r>>1]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+24|0]=s;g=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}if(Kb(d)){while(1){v[114578]=0;e=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}r=Pb(d,c),s=e,t[r+2|0]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+62|0]=s;g=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}ud(h+16|0,d,c);c=0;v[114578]=0;d=Q(376,f|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}if(Kb(d)){while(1){v[114578]=0;e=T(375,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}r=Pb(d,c),s=e,u[r>>1]=s;c=c+1|0;if(Kb(d)>>>0>c>>>0){continue}break}}Bb(h+16|0);g=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+63|0]=s;g=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+15|0]=s;g=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}ud(h+16|0,d,c);e=Wb(h);if(c){d=0;while(1){v[114578]=0;g=T(378,h+16|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break E}v[114578]=0;Q(379,e|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114578]=0;Q(371,f+492|0,e|0)|0;c=v[114578];v[114578]=0;g=1;if((c|0)==1){break E}yb(e);Bb(h+16|0);break n}if(c>>>0>4){break n}if(!Qb(d,c)){break n}r=f,s=Ok(d,c),v[r+4>>2]=s;g=1;break n}if(c>>>0>4){break n}if(!Qb(d,c)){break n}r=f,s=Ok(d,c),v[r+8>>2]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+61|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f- -64|0,s=kd(d,c),t[r|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+81|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+84|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+101|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+102|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+103|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+104|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+17|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+19|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+20|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+22|0]=s;g=1;break n}if(c>>>0>2){break n}if(!Qb(d,c)){break n}r=f,s=jq(d,c),u[r+28>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+30|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=PB(d,c),t[r+26|0]=s;g=1;break n}if(c>>>0>128){break n}e=f+108|0;ud(h+16|0,d,c);c=0;while(1){v[114578]=0;d=T(377,h+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}r=fc(e,c),s=d,t[r|0]=s;c=c+1|0;if(c>>>0<128){continue}break}Bb(h+16|0);g=1;break n}c=P()|0;O()|0;break f}c=P()|0;O()|0;yb(e);break f}if(c>>>0>32){break n}ud(h+16|0,d,c);e=Wb(h);if(c){d=0;while(1){v[114578]=0;g=T(378,h+16|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break m}v[114578]=0;Q(379,e|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114578]=0;Q(371,f+524|0,e|0)|0;c=v[114578];v[114578]=0;g=1;if((c|0)!=1){yb(e);Bb(h+16|0);break n}break m}if(c>>>0>2){break n}if(!Qb(d,c)){break n}r=f,s=jq(d,c),u[r+12>>1]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+25|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+35|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+105|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+85|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+65|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+100|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+80|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=kd(d,c),t[r+60|0]=s;g=1;break n}if(c>>>0>1){break n}if(!Qb(d,c)){break n}r=f,s=PB(d,c),t[r+33|0]=s;g=1;break n}g=1;c=Ok(d,c);if(!Sn(c)){break n}t[f+14|0]=c;break n}v[h+16>>2]=240;r=h,s=Ok(d,c),v[r>>2]=s;gg(f+48|0,v[Lb(h+16|0,h)>>2]);g=1;break n}v[h+16>>2]=240;r=h,s=Ok(d,c),v[r>>2]=s;gg(f+88|0,v[Lb(h+16|0,h)>>2]);g=1;break n}c=P()|0;O()|0;break f}c=jq(d,c);d=v[f+40>>2];v[f+40>>2]=d-((d>>>0)%1e4|0)+(c>>>0)%1e4;g=1}jb=h+32|0;break e}c=P()|0;O()|0;yb(e);break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0;break f}c=P()|0;O()|0}Bb(h+16|0);S(c|0);L()}if(!g){$b(m,i);break d}if((Fj(11877)|0)==(p|0)){i=w[j+15|0];t[j+15|0]=0;t[j+60|0]=i>>>1&2|i<<1&4|(w[j+60|0]&240|i&1);t[j+80|0]=i>>>4&2|i>>>2&4|(w[j+80|0]&240|i>>>3&1);t[j+100|0]=i>>>5&4|(w[j+100|0]&224|i>>>6&1)}}}l=l+1|0;if(x[a+480192>>1]>=(l&65535)>>>0){continue}break}}if(Qb(b,6)){continue}break}}return o|0}function xaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-720|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(!Ff(b,d+712|0)){break D}if(!MK(d+712|0)){break D}if(!Et(b,d+704|0)){break D}if(!LK(d+704|0)){break D}i=1313423693;g=w[d+704|0]|w[d+705|0]<<8|(w[d+706|0]<<16|w[d+707|0]<<24);if((g|0)!=1179012417){i=1414090313;if((g|0)!=538987841){break D}}l=Lk(d+688|0,b);j=wx(d+672|0);E:{F:{G:{H:{I:{J:{K:{L:{M:{if(!c){v[114578]=0;X(1536,d+112|0,l|0,((g|0)==1179012417?1:2)|0,i|0);b=v[114578];v[114578]=0;if((b|0)!=1){break M}a=P()|0;O()|0;break a}v[114578]=0;U(1537,d+112|0,l|0,((g|0)==1179012417?1:2)|0);b=v[114578];v[114578]=0;if((b|0)==1){break L}}b=j;if(v[b>>2]){Id(b);IK(b);up(b);Xf(zb(b),v[b>>2],We(b));m=zb(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0}b=d+112|0;El(j,b);v[j>>2]=v[b>>2];v[j+4>>2]=v[b+4>>2];f=v[zb(b)>>2];m=zb(j),n=f,v[m>>2]=n;m=zb(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0;tl(d+112|0);v[114578]=0;U(1538,d+656|0,j|0,i|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[114578]=0;b=T(339,d+656|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}f=0;if(!b){break E}v[114578]=0;b=Q(1539,d+656|0,d+576|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break G}if(!b|!w[d+641|0]){break E}b=w[d+641|0];v[114578]=0;f=Q(258,d+656|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break G}if(!c|f^1){break E}v[114578]=0;R(449,a|0,8388608);b=v[114578];v[114578]=0;if((b|0)==1){break G}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+640|0]<<4^-1)&16;b=w[d+641|0];v[114578]=0;u[d+112>>1]=b;u[d+480>>1]=127;b=Q(478,d+112|0,d+480|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break K}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+642|0];v[a+480204>>2]=B(w[d+643|0],1e4);v[a+480200>>2]=w[d+648|0]<<1;v[114578]=0;Q(238,a+1304436|0,((g|0)==1179012417?31715:31681)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break G}v[114578]=0;b=Q(2,d+112|0,31749)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}Gb(a+1304448|0,b);yb(b);v[a+1304496>>2]=4;v[114578]=0;U(1540,d+480|0,2,d+576|0);b=v[114578];v[114578]=0;if((b|0)==1){break J}v[114578]=0;R(417,d+112|0,d+480|0);b=v[114578];v[114578]=0;if((b|0)==1){break J}Gb(a+1304400|0,d+112|0);yb(d+112|0);if(!x[a+480188>>1]){break H}b=0;h=(g|0)==1179012417;while(1){v[114578]=0;i=(b<<5)+a|0;e=i+480280|0;Z(434,e|0);f=v[114578];v[114578]=0;N:{O:{P:{Q:{R:{if((f|0)!=1){v[114578]=0;f=T(389,d+656|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break R}if(h){break Q}if(f>>>0<129){break P}break O}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(f<<24>>24<=-1){break O}v[114578]=0;v[d+112>>2]=f<<2;v[d+480>>2]=256;f=Q(464,d+112|0,d+480|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){u[i+480284>>1]=v[f>>2];break N}a=P()|0;O()|0;break b}u[i+480284>>1]=f<<1;break N}v[e>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break H}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[114578]=0;b=Q(1541,j|0,1380209231)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break F}}a=P()|0;O()|0;break b}if(b){v[114578]=0;U(1538,d+112|0,j|0,1380209231);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=T(389,d+112|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}f=Vb(a+484360|0);v[114578]=0;ea(581,f|0,d+112|0,b+1&255,255,254)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}Bb(d+112|0)}if(c&1){v[114578]=0;u[d+40>>1]=0;U(1542,d+480|0,j|0,1414807888);b=v[114578];v[114578]=0;if((b|0)==1){break e}b=od(d+480|0);v[114578]=0;f=a+484344|0;R(403,f|0,b&65535);b=v[114578];v[114578]=0;if((b|0)==1){break k}m=d,n=bc(d+480|0),v[m+544>>2]=n;m=d,n=cc(d+480|0),v[m+64>>2]=n;if(Jb(d+544|0,d- -64|0)){i=(g|0)!=1179012417;while(1){b=Ze(d+112|0,v[d+544>>2]);v[114578]=0;h=T(389,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}v[114578]=0;u[d+464>>1]=h;h=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}v[114578]=0;U(343,d+560|0,b|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break i}v[114578]=0;X(1543,d+560|0,x[d+464>>1],i|0,a|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}Bb(d+560|0);v[114578]=0;h=Q(454,d+40|0,d+464|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}u[d+40>>1]=x[h>>1];Bb(b);Tf(d+544|0);if(Jb(d+544|0,d- -64|0)){continue}break}}if(x[d+40>>1]){b=0;while(1){v[114578]=0;i=b&65535;h=Q(444,f|0,i|0)|0;e=v[114578];v[114578]=0;S:{if((e|0)!=1){if(h){break S}v[114578]=0;W(404,f|0,i|0,64)|0;i=v[114578];v[114578]=0;if((i|0)!=1){break S}}a=P()|0;O()|0;break f}b=b+1|0;if(x[d+40>>1]>(b&65535)>>>0){continue}break}}hd(d+480|0)}T:{if((g|0)==1179012417){v[114578]=0;U(1542,d- -64|0,j|0,1414745673);b=v[114578];v[114578]=0;if((b|0)==1){break B}m=d,n=bc(d- -64|0),v[m+96>>2]=n;m=d,n=cc(d- -64|0),v[m+24>>2]=n;U:{if(Jb(d+96|0,d+24|0)){f=c&2;i=d+488|0;h=d+112|1;while(1){c=Ze(d+544|0,v[d+96>>2]);v[114578]=0;b=Q(1544,c|0,d+112|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break U}V:{if(!b){break V}b=w[h|0];if((b|0)==255){break V}v[114578]=0;b=W(456,a|0,b+1|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}if(!b){break V}g=x[a+480190>>1];v[114578]=0;U(1545,d+112|0,b|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break A}b=0;if(!w[d+142|0]){break V}while(1){W:{if(!En(a)){break W}v[114578]=0;g=Q(1546,c|0,d+480|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break z}if(!g){break W}g=x[a+480190>>1]+1|0;u[a+480190>>1]=g;if((w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))!=1347240275){break W}v[114578]=0;U(577,d+464|0,2,i|0);e=v[114578];v[114578]=0;X:{Y:{Z:{if((e|0)==1){break Z}v[114578]=0;R(417,d+40|0,d+464|0);e=v[114578];v[114578]=0;if((e|0)==1){break Z}v[114578]=0;g=g&65535;Q(371,((g<<5)+a|0)+946300|0,d+40|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break Y}yb(d+40|0);v[114578]=0;g=(B(g,104)+a|0)+484380|0;U(1547,d+480|0,d+112|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}if(!f){break X}v[114578]=0;R(1548,d+40|0,d+480|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+40|0,g|0,c|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break W}}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;yb(d+40|0);break l}g=Aj(g);v[114578]=0;Q(340,c|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break m}}b=b+1|0;if(b>>>0<w[d+142|0]){continue}break}}Bb(c);Tf(d+96|0);if(Jb(d+96|0,d+24|0)){continue}break}}hd(d- -64|0);break T}a=P()|0;O()|0;break l}v[114578]=0;U(1542,d+464|0,j|0,1179011410);b=v[114578];v[114578]=0;if((b|0)==1){break y}m=d,n=bc(d+464|0),v[m+456>>2]=n;m=d,n=cc(d+464|0),v[m+448>>2]=n;if(Jb(d+456|0,d+448|0)){g=c&2;f=d+480|4;c=d+56|4;i=d+112|5;while(1){h=Lk(d+544|0,v[d+456>>2]);v[114578]=0;b=T(392,d+544|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break x}_:{if((b|0)!=538986817){break _}v[114578]=0;b=Q(1549,d+544|0,d+440|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break w}if(!b|(w[d+440|0]|w[d+441|0]<<8|(w[d+442|0]<<16|w[d+443|0]<<24))!=1414745673){break _}v[114578]=0;b=Q(1550,d+544|0,d+112|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break v}if(!b){break _}b=w[i|0];if((b|0)==255){break _}v[114578]=0;b=W(456,a|0,b+1|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break u}if(!b){break _}e=x[a+480190>>1];v[114578]=0;U(1551,d+112|0,b|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break u}v[114578]=0;U(1537,d+480|0,h|0,2);b=v[114578];v[114578]=0;if((b|0)==1){break C}v[114578]=0;U(1542,d+96|0,d+480|0,1179011410);b=v[114578];v[114578]=0;if((b|0)==1){break t}tl(d+480|0);m=d,n=bc(d+96|0),v[m+88>>2]=n;m=d,n=cc(d+96|0),v[m+80>>2]=n;$:{if(!Jb(d+88|0,d+80|0)){break $}aa:{while(1){b=Ze(d- -64|0,v[d+88>>2]);v[114578]=0;h=T(392,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}ba:{ca:{if((h|0)!=538989377){break ca}if(!En(a)){break ca}h=w[d+436|0]|w[d+437|0]<<8;e=h-1|0;t[d+436|0]=e;t[d+437|0]=e>>>8;if(!h){Bb(b);break $}h=x[a+480190>>1]+1|0;u[a+480190>>1]=h;v[114578]=0;e=Q(1549,b|0,d+56|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break r}da:{if(!(!e|(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))!=1347240275)){e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;U(343,d+40|0,b|0,e|0);e=v[114578];v[114578]=0;ea:{if((e|0)!=1){v[114578]=0;e=Q(1552,d+40|0,d+480|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break ba}if(!e){break aa}v[114578]=0;U(746,d+8|0,2,f|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)!=1){break ea}}a=P()|0;O()|0;break p}a=P()|0;O()|0;break o}v[114578]=0;h=h&65535;Q(371,((h<<5)+a|0)+946300|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}yb(d+24|0);v[114578]=0;h=(B(h,104)+a|0)+484380|0;U(1553,d+480|0,d+112|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break ba}if(!g){break da}e=w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24);v[114578]=0;Q(256,d+40|0,e+4|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break ba}v[114578]=0;R(1554,d+24|0,d+480|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+24|0,h|0,d+40|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break da}}a=P()|0;O()|0;break p}Bb(b);break $}Bb(d+40|0)}Bb(b);Tf(d+88|0);if(Jb(d+88|0,d+80|0)){continue}break $}break}a=P()|0;O()|0;break p}Bb(d+40|0);Bb(b)}hd(d+96|0)}Bb(d+544|0);Tf(d+456|0);if(Jb(d+456|0,d+448|0)){continue}break}}hd(d+464|0)}f=1}Bb(d+656|0);tl(j);Bb(l)}jb=d+720|0;return f|0}a=P()|0;O()|0;break n}a=P()|0;O()|0;break b}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;break n}a=P()|0;O()|0;tl(d+480|0);break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break o}a=P()|0;O()|0;yb(d+24|0)}Bb(d+40|0)}Bb(b);hd(d+96|0)}Bb(d+544|0);hd(d+464|0);break b}a=P()|0;O()|0}Bb(c);hd(d- -64|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;Bb(d+560|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}Bb(b)}hd(d+480|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Bb(d+112|0);break b}a=P()|0;O()|0}Bb(d+656|0)}tl(j);Bb(l);S(a|0);L()}function Daa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0;g=jb-48|0;jb=g;f=a+1074304|0;if(!(v[f>>2]==18284544|y[a+1074304>>2]>=18285126)){wg(a+1074308|0,0)}h=a+1074308|0;Eb(g+32|0,h,0);if(Cb(g+32|0)){q=(v[a+480180>>2]&16777248)!=0}Eb(g+32|0,h,0);if(Cb(g+32|0)){D=v[a+480180>>2]==4}if(y[f>>2]<18874368){a:{if(!x[a+480192>>1]){break a}c=1;while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[g+32>>2]=B(w[b+20|0],100)>>>6;v[g+16>>2]=100;E=b,F=v[Lb(g+32|0,g+16|0)>>2],t[E+20|0]=F;c:{d:{if(q){if(y[f>>2]<18350080){e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2}if(y[f>>2]<18285314){break d}break c}e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2}oO(uu(b,2),4,v[a+480180>>2])}e:{if(!w[b+34|0]|(y[f>>2]<18284544|y[f>>2]>=18285136)){break e}if(!zi(b)){break e}Nb(h,2,1)}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))|y[f>>2]>=18285136){break b}Nb(h,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!x[a+480190>>1]|(!(v[a+480180>>2]&16777248)|y[f>>2]>=18285314&q))){b=1;while(1){c=B(b&65535,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;m=AO(b);if((m|0)!=(b|0)){while(1){b=c;d=b+32|0;while(1){e=w[b|0];f:{g:{if((e-97&255)>>>0<=5){i=e-32|0;break g}i=99;h:{if(e>>>0<=106){if(e-88>>>0<2){break h}if((e|0)==75){break g}break f}if(e-120>>>0<2){break h}if((e|0)==107){break g}break f}i=122}t[b|0]=i}b=b+1|0;if((d|0)!=(b|0)){continue}break}c=c+32|0;if((m|0)!=(c|0)){continue}break}}}i:{if(v[f>>2]==18874368|y[f>>2]>=18874896|(!(v[a+480180>>2]&16777252)|!x[a+480192>>1])){break i}b=1;c=0;while(1){j:{e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[e+31|0]?e:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break j}break i}t[e+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Nb(h,3,1)}k:{if(!(v[a+480180>>2]&16777248)|(v[f>>2]==19005440|y[f>>2]>=19006226)){break k}Eb(g+32|0,h,0);if(!Cb(g+32|0)){Eb(g+16|0,h,1);if(!Cb(g+16|0)){break k}}if(!x[a+480192>>1]){break k}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}l:{m:{n:{if(y[f>>2]<19007233){e=a+946300|0;b=a+906300|0;while(1){c=jb-16|0;jb=c;i=b+80|0;Xt(c,1,i);Ic(g+16|0,c);jb=c+16|0;v[114578]=0;X(440,g+32|0,0,7,g+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break m}yb(g+16|0);v[114578]=0;Q(507,i|0,g+32|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break n}yb(g+32|0);b=b+160|0;if((e|0)!=(b|0)){continue}break}}if(!(v[a+480180>>2]!=4|y[f>>2]<19007257|(v[a+1074368>>2]!=4|y[f>>2]>=19071236))){Tx(a,5)}if(!(!x[a+480192>>1]|(v[f>>2]==19202048|y[f>>2]>=19202055))){c=1;while(1){i=(((c&65535)<<2)+a|0)+900380|0;b=v[i>>2];o:{if(!b|!w[b+20|0]|!w[b+31|0]){break o}b=b+236|0;e=ct(b);if((b|0)!=(e|0)){while(1){if(x[b>>1]){break o}b=b+2|0;if((e|0)!=(b|0)){continue}break}}t[v[i>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!x[a+480192>>1]|y[f>>2]>=19267584)){c=1;while(1){b=v[(((c&65535)<<2)+a|0)+900380>>2];p:{if(!b){break p}e=t[b+26|0];t[b+26|0]=(((e|0)>-1?1:-1)+e|0)/2;if(y[f>>2]>=18350080?q:0){break p}t[b+19|0]=w[b+19|0]+3>>>2}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}q:{if(!x[a+480192>>1]|y[f>>2]>=19398674){break q}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Nb(h,94,1);break q}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}r:{if(!x[a+480192>>1]|y[f>>2]>=19399428){break r}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Nb(h,101,1);break r}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=jb-16|0;jb=b;u[g+12>>1]=0;v[g+8>>2]=a;Eb(b+8|0,a+1074308|0,0);E=g,F=Cb(b+8|0),t[E+14|0]=F;jb=b+16|0;b=v[g+12>>2];v[g>>2]=v[g+8>>2];v[g+4>>2]=b;e=jb-16|0;jb=e;n=a+484344|0;c=Ce(n);b=v[g+4>>2];i=v[g>>2];v[e>>2]=i;v[e+4>>2]=b;v[e+8>>2]=i;v[e+12>>2]=b;b=e;i=jb-32|0;jb=i;A=c-1&65535;s:{if(Ce(n)>>>0>A>>>0){r=v[b>>2];s=v[b+4>>2];while(1){b=z&65535;if(mh(Ge(n,b))){c=bc(Ge(n,b));d=cc(Ge(n,b));b=i;v[b+24>>2]=r;v[b+28>>2]=s;v[b+8>>2]=r;v[b+12>>2]=s;m=b+8|0;l=jb-16|0;jb=l;v[l>>2]=d;v[l+8>>2]=c;if(Jb(l+8|0,l)){while(1){d=v[l+8>>2];c=m;o=x[c+4>>1];b=o+1|0;u[c+4>>1]=b;if(x[v[c>>2]+480188>>1]<=(b&65535)>>>0){u[c+4>>1]=0}t:{if(en(d)){break t}b=v[c>>2];j=v[b+1074304>>2];p=v[b+480180>>2];u:{if((p|0)==2){if(w[d+3|0]!=23|j>>>0>=18415616){break u}Ue(d+5|0,64);break u}if(p&16777248){v:{if(w[c+6|0]|j>>>0>=18874368?j>>>0>=18285314:0){break v}w:{switch(w[d+3|0]-20|0){case 3:Ue(d+5|0,128);break v;case 0:break w;default:break v}}b=w[d+5|0];if((b|0)!=208){if((b|0)!=192){break v}t[d|0]=254;t[d+3|0]=0;break v}t[d+3|0]=0}x:{if(j>>>0>=18350080){b=0;if(w[c+6|0]|j>>>0>=18874368){break x}}k=w[d+3|0]-6&255;b=0;if(k>>>0>23){break x}b=8388643>>>k&1}if(j>>>0<18874368){k=w[d+3|0];b=b|((k|0)==24|(k|0)==22)}y:{if(!b){break y}k=w[d+5|0];b=k&15;if(!b|(b|0)==15){break y}k=k&240;if(!k|(k|0)==240){break y}if(w[d+3|0]==24){t[d+5|0]=k;break y}t[d+5|0]=b}if(!x[v[c>>2]+480192>>1]|((j|0)==19005440|j>>>0>=19005700)|(w[c+6|0]|x[v[c>>2]+480192>>1]>=w[d+1|0])){break u}t[d+4|0]=0;t[d+2|0]=1;break u}if((p|0)!=4){break u}z:{if(w[d+3|0]!=23|j>>>0>=19137026|(j>>>0<18874368?!(w[c+6|0]?j>>>0>=18285314:0):0)){break z}if(w[d+5|0]<65){break z}t[d+3|0]=0}if(!(w[d+3|0]!=10|(w[c+6|0]|j>>>0>=18874368?j>>>0>=18415616:0)|w[d+2|0]!=11)){t[d+3|0]=0}A:{if(w[d+2|0]!=11|j>>>0>=18874640|w[d+3|0]!=4){break A}b=w[d+4|0];if(w[c+6|0]?0:!b){break A}k=w[d+5|0];if(!k){break A}t[d+2|0]=0;E=d,F=eR(k+(b<<4)|0),t[E+5|0]=F}if(w[d+5|0]|(w[d+3|0]!=16|j>>>0>=19007241)){break u}t[d+3|0]=0}B:{if(j>>>0>=18874368){break B}C=(w[d+5|0]&240)==96;k=w[d+3|0];b=C&(k|0)==20;C:{D:{if(!(!C|(k|0)!=28)){if(!w[c+6|0]|(p|0)!=4){break D}b=b|j>>>0<18350080}if(!b){break C}}if(!o){break C}b=d+B(0-o|0,6)|0;while(1){if(!((w[b+3|0]|8)!=28|(w[b+5|0]&240)!=96)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}if(!o|(w[d+5|0]&240)!=224|w[d+3|0]!=20){break B}b=d+B(0-o|0,6)|0;while(1){if(!(w[b+3|0]!=20|(w[b+5|0]&240)!=224)){t[b+3|0]=0}b=b+6|0;if(d>>>0>b>>>0){continue}break}}E:{if(w[d+2|0]!=8|j>>>0>=19333175|(j|0)==19333120){break E}F:{G:{H:{I:{b=w[d+3|0];switch(b-5|0){case 1:break E;case 0:break G;case 2:break I;default:break H}}if(!w[d+4|0]){break F}t[d+3|0]=11;break E}if((b|0)!=26){break E}}c=w[d+5|0];if(!(c&15)){t[d+2|0]=0;t[d+3|0]=5;t[d+5|0]=c|w[d+4|0]&15;break E}J:{switch(b-5|0){case 1:break E;case 0:case 2:break F;default:break J}}if((b|0)!=26){break E}}t[d+2|0]=0}if(w[d+3|0]|((p|0)==16777216|w[d+2|0]!=15)){break t}t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3}Cj(l+8|0);if(Jb(l+8|0,l)){continue}break}}b=v[m+4>>2];v[i+16>>2]=v[m>>2];v[i+20>>2]=b;jb=l+16|0}z=z+1|0;if((z&65535)>>>0<=A>>>0){continue}break}v[g+32>>2]=r;v[g+36>>2]=s;break s}c=v[b+4>>2];v[g+32>>2]=v[b>>2];v[g+36>>2]=c}jb=i+32|0;jb=e+16|0;K:{L:{if(!q){break L}b=v[f>>2];if(b>>>0>=19267584){break L}Nb(h,8,(b|0)==18284544|b>>>0>18285313);b=30904;while(1){c=v[f>>2];e=v[b+4>>2];Nb(h,v[b>>2],c>>>0>=e>>>0|(c|0)==(e&-65536));b=b+8|0;if((b|0)!=31240){continue}break}break K}if(!D){break K}b=v[f>>2];if(b>>>0>=19267584){break K}Nb(h,8,b>>>0>18285313);b=31256;while(1){Nb(h,v[b>>2],y[f>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=31488){continue}break}}M:{if(v[a+480180>>2]&16777248){b=31488;while(1){c=v[f>>2];e=v[b+4>>2];i=e&-65536;if(!(c>>>0<=i>>>0|c>>>0>=e>>>0?c>>>0>=i>>>0:0)){wg(h,v[b>>2])}b=b+8|0;if((b|0)!=31536){continue}break}break M}if(v[a+480180>>2]==4){b=31536;while(1){if(y[f>>2]<y[b+4>>2]){wg(h,v[b>>2])}b=b+8|0;if((b|0)!=31592){continue}break}break M}if(v[a+480180>>2]!=2){break M}b=31600;while(1){if(y[f>>2]<y[b+4>>2]){wg(h,v[b>>2])}b=b+8|0;if((b|0)!=31680){continue}break}}if(!(v[a+480180>>2]!=4|y[f>>2]>=18415616)){Nb(h,98,1)}if(!(y[f>>2]<19333159|y[f>>2]>=19333193)){b=0;while(1){c=b+77|0;Eb(g+32|0,h,c);Nb(h,b+86|0,Cb(g+32|0));wg(h,c);b=b+1|0;if((b|0)!=5){continue}break}}N:{if(y[f>>2]<18284544){Nb(h,8,1);break N}if(y[f>>2]<18284544|y[f>>2]>18874627|v[f>>2]==18874368){break N}Nb(h,6,1)}O:{if(y[f>>2]<19136512){wg(h,7);break O}if(!(v[a+480180>>2]&16777248)|(y[f>>2]<19136512|y[f>>2]>=19267584)){break O}Nb(h,7,1)}Eb(g+32|0,h,31);P:{if(!Cb(g+32|0)|y[f>>2]<19071234|(!x[a+480192>>1]|y[f>>2]>=19398723)){break P}b=1;while(1){Q:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break Q}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break Q}Nb(h,97,1);break P}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}R:{if(!x[a+480192>>1]|v[a+480180>>2]!=16777216|(y[f>>2]<19398688|y[f>>2]>19485952)){break R}if(!x[a+480190>>1]){break R}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break R}break}Nb(h,109,1)}jb=g+48|0;return}a=P()|0;O()|0;yb(g+32|0);break l}a=P()|0;O()|0;yb(g+16|0)}S(a|0);L()}function kF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=C(0),L=0;d=jb-144|0;jb=d;D=Rb(d,0,144);v[D+76>>2]=-1;v[D+44>>2]=a;v[D+32>>2]=2422;v[D+84>>2]=a;E=c;i=jb-304|0;jb=i;e=D;d=b;a=w[b|0];a:{if(!a){break a}b:{c:{d:{e:{while(1){f:{g:{if(fl(a&255)){while(1){a=d;d=d+1|0;if(fl(w[a+1|0])){continue}break}Bh(e,0,0);while(1){b=v[e+4>>2];h:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break h}b=$c(e)}if(fl(b)){continue}break}d=v[e+4>>2];if(v[e+104>>2]){d=d-1|0;v[e+4>>2]=d}b=d-v[e+8>>2]|0;g=b>>31;l=b;d=o+v[e+124>>2]|0;b=r+v[e+120>>2]|0;d=b>>>0<r>>>0?d+1|0:d;c=b;b=l+b|0;d=d+g|0;r=b;o=b>>>0<c>>>0?d+1|0:d;break g}i:{j:{k:{b=w[d|0];if((b|0)==37){a=w[d+1|0];if((a|0)==42){break k}if((a|0)!=37){break j}}Bh(e,0,0);a=((b|0)==37)+d|0;b=v[e+4>>2];l:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break l}b=$c(e)}if((b|0)!=w[a|0]){if(v[e+104>>2]){v[e+4>>2]=v[e+4>>2]-1}if(F){break a}x=0;if((b|0)>-1){break a}break c}b=r+1|0;o=b>>>0<1?o+1|0:o;r=b;break g}m=0;a=d+2|0;break i}if(!(!bh(a)|w[d+2|0]!=36)){a=w[d+1|0]-48|0;b=jb-16|0;v[b+12>>2]=E;a=a>>>0>1?((a<<2)+E|0)-4|0:E;v[b+8>>2]=a+4;m=v[a>>2];a=d+3|0;break i}m=v[E>>2];E=E+4|0;a=d+1|0}x=0;m:{if(!bh(w[a|0])){d=0;break m}d=0;while(1){b=a+1|0;d=(w[a|0]+d|0)-48|0;if(bh(w[a+1|0])){d=B(d,10);a=b;continue}else{a=b}break}}b=a;c=w[b|0];n:{if((c|0)!=109){break n}p=0;x=(m|0)!=0;c=w[a+1|0];q=0;b=a+1|0}a=b+1|0;k=3;o:{p:{switch(c-65|0){case 39:c=b+2|0;b=w[b+1|0]==104;a=b?c:a;k=b?-2:-1;break o;case 43:c=b+2|0;b=w[b+1|0]==108;a=b?c:a;k=b?3:1;break o;case 51:case 57:k=1;break o;case 11:k=2;break o;case 41:break o;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break p;default:break d}}k=0;a=b}b=w[a|0];c=(b&47)==3;G=c?1:k;s=c?b|32:b;q:{if((s|0)==91){break q}r:{if((s|0)!=110){if((s|0)!=99){break r}d=(d|0)>1?d:1;break q}lF(m,G,r,o);break g}Bh(e,0,0);while(1){b=v[e+4>>2];s:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break s}b=$c(e)}if(fl(b)){continue}break}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}b=b-v[e+8>>2]|0;c=b;g=b>>31;j=o+v[e+124>>2]|0;b=r+v[e+120>>2]|0;j=b>>>0<r>>>0?j+1|0:j;o=b;b=b+c|0;c=g+j|0;r=b;o=b>>>0<o>>>0?c+1|0:c}h=d;l=d>>31;Bh(e,d,l);b=v[e+104>>2];c=v[e+4>>2];t:{if(b>>>0>c>>>0){v[e+4>>2]=c+1;break t}if(($c(e)|0)<0){break d}b=v[e+104>>2]}if(b){v[e+4>>2]=v[e+4>>2]-1}b=16;u:{v:{w:{x:{y:{z:{A:{switch(s-88|0){default:b=s-65|0;if(b>>>0>6|!(1<<b&113)){break u}case 9:case 13:case 14:case 15:oF(i,e,G,0);b=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-b|0)&v[e+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break b}if(!m){break u}b=v[i+8>>2];c=v[i+12>>2];d=v[i>>2];g=v[i+4>>2];switch(G|0){case 2:break w;case 1:break x;case 0:break y;default:break u};case 3:case 11:case 27:if((s&239)==99){Rb(i+32|0,-1,257);t[i+32|0]=0;if((s|0)!=115){break v}t[i+65|0]=0;t[i+46|0]=0;u[i+42>>1]=0;u[i+44>>1]=0;break v}c=w[a+1|0];g=(c|0)==94;Rb(i+32|0,g,257);t[i+32|0]=0;b=g?a+2|0:a+1|0;B:{C:{D:{a=w[(g?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break D}k=(c|0)!=94;a=b;break B}k=(c|0)!=94;t[i+78|0]=k;break C}k=(c|0)!=94;t[i+126|0]=k}a=b+1|0}while(1){b=w[a|0];E:{if((b|0)!=45){if(!b){break d}if((b|0)!=93){break E}break v}b=45;c=w[a+1|0];if(!c|(c|0)==93){break E}g=a+1|0;a=w[a-1|0];F:{if(c>>>0<=a>>>0){b=c;break F}while(1){a=a+1|0;t[a+(i+32|0)|0]=k;b=w[g|0];if(b>>>0>a>>>0){continue}break}}a=g}t[(b+i|0)+33|0]=k;a=a+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break u;case 0:case 24:case 32:break z;case 17:break A}}b=0}f=e;g=0;d=0;k=0;H=jb-16|0;jb=H;G:{H:{I:{J:{K:{L:{if(b>>>0<=36){while(1){c=v[f+4>>2];M:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break M}c=$c(f)}if(fl(c)){continue}break}N:{O:{switch(c-43|0){case 0:case 2:break O;default:break N}}k=(c|0)==45?-1:0;c=v[f+4>>2];if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break N}c=$c(f)}P:{if(!(b&-17|(c|0)!=48)){c=v[f+4>>2];Q:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break Q}c=$c(f)}if((c&-33)==88){b=16;c=v[f+4>>2];R:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break R}c=$c(f)}if(w[c+59841|0]<16){break K}if(!v[f+104>>2]){break H}v[f+4>>2]=v[f+4>>2]-1;break H}if(b){break P}b=8;break K}b=b?b:10;if(b>>>0>w[c+59841|0]){break P}if(v[f+104>>2]){v[f+4>>2]=v[f+4>>2]-1}Bh(f,0,0);v[114552]=28;b=0;c=0;break G}if((b|0)!=10){break K}h=c-48|0;if(h>>>0<=9){b=0;while(1){g=b+h|0;b=v[f+4>>2];S:{if(b>>>0<y[f+104>>2]){v[f+4>>2]=b+1;c=w[b|0];break S}c=$c(f)}h=c-48|0;if(!(h>>>0>9|g>>>0>429496728)){b=B(g,10);continue}break}}if(h>>>0>9){break L}j=Fma(g,0,10,0);l=mb;b=h;while(1){c=v[f+4>>2];T:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break T}c=$c(f)}h=c-48|0;n=h>>>0>9;d=l;g=b+j|0;d=g>>>0<b>>>0?d+1|0:d;if((d|0)==429496729&g>>>0>=2576980378|d>>>0>429496729|n){break L}j=Fma(g,d,10,0);l=mb;n=l;b=h;if((n|0)==-1&j>>>0<=(b^-1)>>>0|(n|0)!=-1){continue}break}b=10;break J}v[114552]=28;b=0;c=0;break G}b=10;if(h>>>0<=9){break J}break I}if(b-1&b){h=w[c+59841|0];if(h>>>0<b>>>0){c=0;while(1){g=c+h|0;l=g>>>0>119304646;c=v[f+4>>2];U:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break U}c=$c(f)}h=w[c+59841|0];if(!(l|h>>>0>=b>>>0)){c=B(b,g);continue}break}}if(b>>>0<=h>>>0){break J}l=b;while(1){n=Fma(g,d,l,0);j=mb;h=h&255;if((j|0)==-1&(h^-1)>>>0<n>>>0){break J}c=j;d=h+n|0;c=d>>>0<h>>>0?c+1|0:c;g=d;d=c;j=b;c=v[f+4>>2];V:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break V}c=$c(f)}h=w[c+59841|0];if(j>>>0<=h>>>0){break J}$g(H,l,0,g,d);if(!(v[H+8>>2]|v[H+12>>2])){continue}break}break J}l=t[(B(b,23)>>>5&7)+60097|0];h=w[c+59841|0];if(h>>>0<b>>>0){c=0;while(1){g=c|h;j=g>>>0>134217727;c=v[f+4>>2];W:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break W}c=$c(f)}h=w[c+59841|0];if(!(j|h>>>0>=b>>>0)){c=g<<l;continue}break}}if(b>>>0<=h>>>0){break J}j=l;n=j&31;if((j&63)>>>0>=32){j=0;n=-1>>>n|0}else{j=-1>>>n|0;n=(1<<n)-1<<32-n|-1>>>n}if(!j&g>>>0>n>>>0){break J}while(1){I=h&255;h=g;c=l;g=c&31;if((c&63)>>>0>=32){d=h<<g;c=0}else{d=(1<<g)-1&h>>>32-g|d<<g;c=h<<g}g=I|c;I=b;c=v[f+4>>2];X:{if(c>>>0<y[f+104>>2]){v[f+4>>2]=c+1;c=w[c|0];break X}c=$c(f)}h=w[c+59841|0];if(I>>>0<=h>>>0){break J}if((d|0)==(j|0)&g>>>0<=n>>>0|d>>>0<j>>>0){continue}break}}if(w[c+59841|0]>=b>>>0){break I}while(1){d=v[f+4>>2];Y:{if(d>>>0<y[f+104>>2]){v[f+4>>2]=d+1;c=w[d|0];break Y}c=$c(f)}if(w[c+59841|0]<b>>>0){continue}break}v[114552]=68;k=0;g=-1;d=-1}if(v[f+104>>2]){v[f+4>>2]=v[f+4>>2]-1}if((g|0)==-1&(d|0)==-1){if(!(k|1)){v[114552]=68;b=-2;c=-1;break G}}b=k;g=b^g;c=b;b=g-b|0;l=d;d=c>>31;c=(l^d)-((c>>>0>g>>>0)+d|0)|0;break G}Bh(f,0,0);b=0;c=0}jb=H+16|0;d=v[e+4>>2]-v[e+8>>2]|0;if(v[e+120>>2]==(0-d|0)&v[e+124>>2]==(0-((d>>31)+((d|0)!=0)|0)|0)){break b}if(!(!m|(s|0)!=112)){v[m>>2]=b;break u}lF(m,G,b,c);break u}J=m,K=mF(d,g,b,c),z[J>>2]=K;break u}J=m,L=iw(d,g,b,c),A[J>>3]=L;break u}v[m>>2]=d;v[m+4>>2]=g;v[m+8>>2]=b;v[m+12>>2]=c;break u}c=(s|0)==99;k=c?d+1|0:31;g=(G|0)!=1;Z:{if(!g){b=m;if(x){b=pd(k<<2);if(!b){break e}}v[i+296>>2]=0;v[i+300>>2]=0;d=0;while(1){q=b;_:{while(1){b=v[e+4>>2];$:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break $}b=$c(e)}if(!w[(b+i|0)+33|0]){break _}t[i+27|0]=b;b=so(i+28|0,i+27|0,1,i+296|0);if((b|0)==-2){continue}if((b|0)==-1){break f}if(q){v[(d<<2)+q>>2]=v[i+28>>2];d=d+1|0}if(!x|(d|0)!=(k|0)){continue}break}k=k<<1|1;b=Qq(q,k<<2);if(b){continue}break f}break}if(!((i|0)==-296?1:!v[i+296>>2])){break f}p=0;break Z}if(x){d=0;b=pd(k);if(!b){break e}while(1){p=b;while(1){b=v[e+4>>2];aa:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break aa}b=$c(e)}if(!w[(b+i|0)+33|0]){q=0;break Z}t[d+p|0]=b;d=d+1|0;if((k|0)!=(d|0)){continue}break}q=0;k=k<<1|1;b=Qq(p,k);if(b){continue}break}break d}d=0;if(m){while(1){b=v[e+4>>2];ba:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break ba}b=$c(e)}if(w[(b+i|0)+33|0]){t[d+m|0]=b;d=d+1|0;continue}else{q=0;p=m;break Z}}}while(1){b=v[e+4>>2];ca:{if(b>>>0<y[e+104>>2]){v[e+4>>2]=b+1;b=w[b|0];break ca}b=$c(e)}if(w[(b+i|0)+33|0]){continue}break}p=0;q=0}b=v[e+4>>2];if(v[e+104>>2]){b=b-1|0;v[e+4>>2]=b}f=b-v[e+8>>2]|0;b=f+v[e+120>>2]|0;j=v[e+124>>2]+(f>>31)|0;j=b>>>0<f>>>0?j+1|0:j;if(!(j|b)|((b|0)!=(h|0)|(j|0)!=(l|0)?(s|0)==99:0)){break b}da:{if(!x){break da}if(!g){v[m>>2]=q;break da}v[m>>2]=p}if(c){break u}if(q){v[(d<<2)+q>>2]=0}if(!p){p=0;break u}t[d+p|0]=0}b=v[e+4>>2]-v[e+8>>2]|0;d=b>>31;l=b;o=o+v[e+124>>2]|0;b=r+v[e+120>>2]|0;o=b>>>0<r>>>0?o+1|0:o;c=b;b=l+b|0;d=d+o|0;r=b;o=b>>>0<c>>>0?d+1|0:d;F=((m|0)!=0)+F|0}d=a+1|0;a=w[a+1|0];if(a){continue}break a}break}p=0;break d}p=0;q=0}if(F){break b}}F=-1}if(!x){break a}Xb(p);Xb(q)}jb=i+304|0;jb=D+144|0;return F}function pF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=jb-192|0;jb=m;y=h;G=i&65535;r=d;n=e&65535;F=(e^i)&-2147483648;l=i>>>16&32767;a:{t=e>>>16&32767;b:{c:{if(l-1>>>0<32766?t-1>>>0<=32765:0){break c}I=e&2147483647;k=I;j=d;if(!(!j&(k|0)==2147418112?!(b|c):k>>>0<2147418112)){L=d;F=e|32768;break b}I=i&2147483647;e=I;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){L=h;F=i|32768;b=f;c=g;break b}if(!(b|j|(k^2147418112|c))){if(!(d|f|(e^2147418112|g))){b=0;c=0;F=2147450880;break b}F=F|2147418112;b=0;c=0;break b}if(!(d|f|(e^2147418112|g))){b=0;c=0;break b}if(!(b|j|(c|k))){break a}if(!(d|f|(e|g))){F=F|2147418112;b=0;c=0;break b}if((k|0)==65535|k>>>0<65535){i=b;d=!(n|r);h=d<<6;j=E(d?b:r)+32|0;b=E(d?c:n);b=h+((b|0)==32?j:b)|0;qf(m+176|0,i,c,r,n,b-15|0);K=16-b|0;r=v[m+184>>2];n=v[m+188>>2];c=v[m+180>>2];b=v[m+176>>2]}if(e>>>0>65535){break c}d=!(y|G);e=d<<6;h=E(d?f:y)+32|0;d=E(d?g:G);d=e+((d|0)==32?h:d)|0;qf(m+160|0,f,g,y,G,d-15|0);K=(d+K|0)-16|0;y=v[m+168>>2];G=v[m+172>>2];f=v[m+160>>2];g=v[m+164>>2]}e=G|65536;I=e;M=y;d=y;j=e<<15|d>>>17;d=d<<15|g>>>17;h=-102865788-d|0;e=j;i=1963258675-(j+(d>>>0>4192101508)|0)|0;$g(m+144|0,d,j,h,i);j=v[m+152>>2];$g(m+128|0,0-j|0,0-(v[m+156>>2]+((j|0)!=0)|0)|0,h,i);h=v[m+136>>2];i=h<<1|v[m+132>>2]>>>31;h=v[m+140>>2]<<1|h>>>31;$g(m+112|0,i,h,d,e);j=h;h=v[m+120>>2];$g(m+96|0,i,j,0-h|0,0-(v[m+124>>2]+((h|0)!=0)|0)|0);h=v[m+104>>2];i=h<<1|v[m+100>>2]>>>31;h=v[m+108>>2]<<1|h>>>31;$g(m+80|0,i,h,d,e);j=h;h=v[m+88>>2];$g(m- -64|0,i,j,0-h|0,0-(v[m+92>>2]+((h|0)!=0)|0)|0);h=v[m+72>>2];i=h<<1|v[m+68>>2]>>>31;h=v[m+76>>2]<<1|h>>>31;$g(m+48|0,i,h,d,e);j=h;h=v[m+56>>2];$g(m+32|0,i,j,0-h|0,0-(v[m+60>>2]+((h|0)!=0)|0)|0);h=v[m+40>>2];i=h<<1|v[m+36>>2]>>>31;h=v[m+44>>2]<<1|h>>>31;$g(m+16|0,i,h,d,e);j=h;h=v[m+24>>2];$g(m,i,j,0-h|0,0-(v[m+28>>2]+((h|0)!=0)|0)|0);K=(t-l|0)+K|0;h=v[m+8>>2];j=v[m+12>>2]<<1|h>>>31;k=h<<1|v[m+4>>2]>>>31;h=k-1|0;k=j-(k>>>0<1)|0;j=0;D=j;i=h;p=e;t=0;q=Fma(h,j,e,t);e=mb;w=e;x=k;l=0;h=d;j=Fma(k,l,d,0);d=j+q|0;k=mb+e|0;e=d;k=d>>>0<j>>>0?k+1|0:k;d=k;k=0;j=(d|0)==(w|0)&e>>>0<q>>>0|d>>>0<w>>>0;q=Fma(x,l,p,t);t=q+d|0;j=mb+(j|k)|0;z=t;w=q>>>0>t>>>0?j+1|0:j;h=Fma(i,D,h,o);d=0+h|0;j=mb+e|0;j=d>>>0<h>>>0?j+1|0:j;A=(e|0)==(j|0)&d>>>0<k>>>0|e>>>0>j>>>0;p=d;h=j;d=g;B=(d&131071)<<15|f>>>17;o=Fma(i,D,B,0);d=mb;u=d;j=f;s=j<<15&-32768;j=Fma(x,l,s,0);e=j+o|0;k=mb+d|0;k=e>>>0<j>>>0?k+1|0:k;d=k;C=Fma(i,D,s,C);s=0+C|0;j=e;k=j+mb|0;k=s>>>0<C>>>0?k+1|0:k;k=(j|0)==(k|0)&s>>>0<J>>>0|j>>>0>k>>>0;j=(d|0)==(u|0)&j>>>0<o>>>0|d>>>0<u>>>0;e=d;d=Fma(x,l,B,H)+d|0;j=j+mb|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=k+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=d+p|0;j=j+h|0;j=d>>>0<e>>>0?j+1|0:j;t=d;q=j;e=(j|0)==(h|0)&d>>>0<p>>>0|h>>>0>j>>>0;d=e+A|0;k=0;k=d>>>0<e>>>0?1:k;e=d;d=d+z|0;j=k+w|0;j=d>>>0<e>>>0?j+1|0:j;e=(t|0)!=0|(q|0)!=0;d=e+d|0;j=d>>>0<e>>>0?j+1|0:j;h=d;o=0-d|0;s=0;w=Fma(o,s,i,D);d=mb;u=d;e=w;p=d;s=Fma(x,l,o,s);d=mb;z=d;A=0-(((h|0)!=0)+j|0)|0;o=0;k=Fma(i,D,A,o);h=k+s|0;j=mb+d|0;j=h>>>0<k>>>0?j+1|0:j;d=j;j=h+p|0;B=0;e=B+e|0;p=e;k=e;j=k>>>0<B>>>0?j+1|0:j;e=j;j=(u|0)==(j|0)&k>>>0<w>>>0|j>>>0<u>>>0;k=(d|0)==(z|0)&h>>>0<s>>>0|d>>>0<z>>>0;h=d;d=Fma(x,l,A,o)+d|0;k=k+mb|0;k=d>>>0<h>>>0?k+1|0:k;h=d;d=j+d|0;j=k;A=d;h=d>>>0<h>>>0?j+1|0:j;B=0-(((t|0)!=0)+q|0)|0;q=0;z=Fma(B,q,i,D);s=mb;u=0-t|0;k=Fma(u,0,x,l);d=k+z|0;j=mb+s|0;t=d;d=d>>>0<k>>>0?j+1|0:j;C=0;u=Fma(i,D,u,H);i=C+u|0;k=t;j=k+mb|0;j=i>>>0<u>>>0?j+1|0:j;j=(j|0)==(k|0)&i>>>0<C>>>0|j>>>0<k>>>0;k=(d|0)==(s|0)&k>>>0<z>>>0|d>>>0<s>>>0;i=d;d=Fma(x,l,B,q)+d|0;k=k+mb|0;k=d>>>0<i>>>0?k+1|0:k;i=d;d=j+d|0;j=k;j=d>>>0<i>>>0?j+1|0:j;i=d;d=d+p|0;k=j+e|0;k=d>>>0<i>>>0?k+1|0:k;i=d;j=d;d=k;k=(e|0)==(k|0)&j>>>0<p>>>0|e>>>0>k>>>0;e=k+A|0;j=h;j=e>>>0<k>>>0?j+1|0:j;k=e;e=i;w=e-2|0;h=w;q=d-(e>>>0<2)|0;e=q;e=(d|0)==(e|0)&h>>>0<i>>>0|d>>>0>e>>>0;d=k+e|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;h=k-(e>>>0<1)|0;e=0;x=e;l=d;i=r;z=i<<2|c>>>30;A=0;p=Fma(d,e,z,A);e=mb;o=e;j=e;e=c;B=(e&1073741823)<<2|b>>>30;t=0;H=h;i=0;e=Fma(B,t,h,i);d=e+p|0;j=mb+j|0;j=d>>>0<e>>>0?j+1|0:j;k=(j|0)==(o|0)&d>>>0<p>>>0|j>>>0<o>>>0;p=d;h=j;e=j;s=q;j=0;q=j;c=k;C=((n&1073741823)<<2|r>>>30)&-262145|262144;j=Fma(s,j,C,0);d=j+d|0;k=mb+e|0;k=d>>>0<j>>>0?k+1|0:k;n=d;e=k;h=(k|0)==(h|0)&d>>>0<p>>>0|h>>>0>k>>>0;d=c+h|0;j=0;j=d>>>0<h>>>0?1:j;h=Fma(H,i,C,J);d=h+d|0;j=mb+j|0;j=d>>>0<h>>>0?j+1|0:j;r=Fma(l,x,C,J);h=mb;c=d;o=Fma(z,A,H,i);d=o+r|0;k=mb+h|0;k=d>>>0<o>>>0?k+1|0:k;o=d;d=k;k=(h|0)==(d|0)&r>>>0>o>>>0|h>>>0>d>>>0;r=c+d|0;j=j+k|0;k=r;h=k>>>0<d>>>0?j+1|0:j;p=n;n=0;d=p+n|0;r=e;j=o+e|0;j=d>>>0<n>>>0?j+1|0:j;e=j;n=(j|0)==(r|0)&d>>>0<p>>>0|j>>>0<r>>>0;j=k+n|0;k=h;u=j;h=j>>>0<n>>>0?k+1|0:k;r=d;n=e;p=Fma(B,t,s,q);e=mb;o=Fma(w,0,z,A);d=o+p|0;j=mb+e|0;j=d>>>0<o>>>0?j+1|0:j;o=d;p=(e|0)==(j|0)&p>>>0>d>>>0|e>>>0>j>>>0;e=j;D=p;k=b;c=k<<2&-4;k=Fma(l,x,c,0);d=k+d|0;j=mb+j|0;j=d>>>0<k>>>0?j+1|0:j;p=d;k=d;d=j;j=(j|0)==(e|0)&k>>>0<o>>>0|e>>>0>j>>>0;e=D+j|0;k=0;k=e>>>0<j>>>0?1:k;o=e;e=r+e|0;j=k+n|0;j=e>>>0<o>>>0?j+1|0:j;o=e;k=e;e=j;n=(j|0)==(n|0)&k>>>0<r>>>0|j>>>0<n>>>0;k=n+u|0;j=h;u=k;n=k>>>0<n>>>0?j+1|0:j;N=Fma(H,i,c,O);H=mb;i=Fma(C,J,w,P);h=i+N|0;k=mb+H|0;k=h>>>0<i>>>0?k+1|0:k;C=h;r=Fma(z,A,s,q);h=h+r|0;i=k;j=k+mb|0;j=h>>>0<r>>>0?j+1|0:j;z=h;k=Fma(l,x,B,t);h=h+k|0;l=j;j=j+mb|0;r=h;j=h>>>0<k>>>0?j+1|0:j;h=j;x=0;D=(j|0)==(l|0)&r>>>0<z>>>0|j>>>0<l>>>0;j=(i|0)==(l|0)&z>>>0<C>>>0|i>>>0>l>>>0;i=j+((i|0)==(H|0)&C>>>0<N>>>0|i>>>0<H>>>0)|0;k=0;i=D+i|0;j=i;k=h|0;i=k+o|0;j=(j|x)+e|0;j=i>>>0<k>>>0?j+1|0:j;k=i;l=j;j=(e|0)==(j|0)&k>>>0<o>>>0|e>>>0>j>>>0;e=j+u|0;k=n;z=e;e=e>>>0<j>>>0?k+1|0:k;o=i;s=Fma(s,q,c,O);q=mb;k=Fma(B,t,w,P);i=k+s|0;j=mb+q|0;j=i>>>0<k>>>0?j+1|0:j;n=j;j=0;k=(n|0)==(q|0)&i>>>0<s>>>0|n>>>0<q>>>0;i=n+p|0;j=(j|k)+d|0;j=i>>>0<n>>>0?j+1|0:j;k=i;i=j;c=(d|0)==(j|0)&k>>>0<p>>>0|d>>>0>j>>>0;j=j+r|0;n=0;h=n+k|0;d=h;j=d>>>0<n>>>0?j+1|0:j;h=(i|0)==(j|0)&d>>>0<k>>>0|i>>>0>j>>>0;d=c+h|0;j=0;j=d>>>0<h>>>0?1:j;h=d;d=d+o|0;k=j+l|0;k=d>>>0<h>>>0?k+1|0:k;h=d;i=k;k=(k|0)==(l|0)&d>>>0<o>>>0|k>>>0<l>>>0;d=k+z|0;j=e;j=d>>>0<k>>>0?j+1|0:j;e=j;d:{if((j|0)==131071|j>>>0<131071){q=0;w=b<<17;l=f;x=0;s=Fma(i,0,l,x);b=mb;z=b;c=0;A=c;t=0;j=Fma(h,c,g,t);c=j+s|0;k=mb+b|0;k=c>>>0<j>>>0?k+1|0:k;b=k;p=q;u=0;o=Fma(l,x,h,A);q=u+o|0;j=c;k=j+mb|0;k=q>>>0<o>>>0?k+1|0:k;o=k;j=(j|0)==(k|0)&u>>>0>q>>>0|j>>>0>k>>>0;H=p-j|0;k=(q|0)!=0|(k|0)!=0;u=H-k|0;w=(w-(j>>>0>p>>>0)|0)-(k>>>0>H>>>0)|0;j=Fma(d,0,l,x);k=mb;l=Fma(h,A,y,0);j=l+j|0;k=mb+k|0;k=j>>>0<l>>>0?k+1|0:k;r=Fma(i,n,g,t);l=r+j|0;j=mb+k|0;j=l>>>0<r>>>0?j+1|0:j;j=((b|0)==(z|0)&c>>>0<s>>>0|b>>>0<z>>>0)+j|0;c=b;b=b+l|0;k=b;b=k>>>0<c>>>0?j+1|0:j;c=Fma(h,i,I,0);j=mb;p=k;l=Fma(f,g,e,0);c=l+c|0;k=mb+j|0;k=c>>>0<l>>>0?k+1|0:k;l=Fma(d,e,g,t);c=l+c|0;j=mb+k|0;k=Fma(i,n,y,G);c=k+c|0;k=c;y=0;c=p+y|0;j=b+k|0;j=c>>>0<y>>>0?j+1|0:j;b=c;y=u-b|0;G=w-((b>>>0>u>>>0)+j|0)|0;K=K-1|0;n=0-q|0;b=0-(((q|0)!=0)+o|0)|0;break d}q=i>>>1|0;w=0;p=b<<16;h=(i&1)<<31|h>>>1;i=d<<31|i>>>1;b=0;s=b;r=0;t=Fma(h,b,g,r);b=mb;A=b;j=n;k=e<<31|d>>>1;n=d<<31|q;H=j|k;o=n;C=0;B=0;k=Fma(n,C,f,B);c=k+t|0;j=mb+b|0;j=c>>>0<k>>>0?j+1|0:j;b=j;u=w;x=0;D=Fma(h,s,f,B);w=x+D|0;j=c;k=j+mb|0;k=w>>>0<D>>>0?k+1|0:k;D=k;j=(j|0)==(k|0)&x>>>0>w>>>0|j>>>0>k>>>0;J=u-j|0;k=(w|0)!=0|(k|0)!=0;x=J-k|0;u=(p-(j>>>0>u>>>0)|0)-(k>>>0>J>>>0)|0;j=Fma(h,i,I,0);p=mb;J=Fma(f,g,e>>>1|0,0);j=J+j|0;k=mb+p|0;k=j>>>0<J>>>0?k+1|0:k;d=(e&1)<<31|d>>>1;e=e>>>1|0;J=Fma(d,e,g,r);p=J+j|0;n=Fma(n,H,y,G);G=n+p|0;n=0;j=Fma(g,r,o,C);r=mb;q=Fma(d,0,f,B);k=q+j|0;j=mb+r|0;l=Fma(h,s,y,0);y=l+k|0;k=mb+(k>>>0<q>>>0?j+1|0:j)|0;j=y;y=l>>>0>j>>>0?k+1|0:k;k=(b|0)==(A|0)&c>>>0<t>>>0|b>>>0<A>>>0;c=b;b=b+j|0;k=k+y|0;k=b>>>0<c>>>0?k+1|0:k;c=b;b=b+n|0;j=k+G|0;j=b>>>0<c>>>0?j+1|0:j;y=x-b|0;G=u-((b>>>0>x>>>0)+j|0)|0;n=0-w|0;b=0-(((w|0)!=0)+D|0)|0}if((K|0)>=16384){F=F|2147418112;b=0;c=0;break b}l=K+16383|0;if((K|0)<=-16383){e:{if(l){break e}l=n;k=b<<1|l>>>31;l=l<<1;c=(g|0)==(k|0)&f>>>0<l>>>0|g>>>0<k>>>0;f=y;k=G<<1|f>>>31;f=f<<1|b>>>31;f=(f|0)==(M|0)&(k|0)==(I|0)?c:(I|0)==(k|0)&f>>>0>M>>>0|k>>>0>I>>>0;b=f+h|0;j=i;j=b>>>0<f>>>0?j+1|0:j;c=j;f=d+((i|0)==(j|0)&b>>>0<h>>>0|i>>>0>j>>>0)|0;k=e&65535;e=f;k=d>>>0>e>>>0?k+1|0:k;d=k;if(!(d&65536)){break e}L=e|L;F=d|F;break b}b=0;c=0;break b}j=i;k=b<<1|n>>>31;r=n<<1;g=(g|0)==(k|0)&f>>>0<=r>>>0|g>>>0<k>>>0;f=y;k=G<<1|f>>>31;c=f<<1|b>>>31;c=(c|0)==(M|0)&(k|0)==(I|0)?g:(I|0)==(k|0)&c>>>0>=M>>>0|k>>>0>I>>>0;b=c+h|0;j=b>>>0<c>>>0?j+1|0:j;c=j;f=d+((i|0)==(j|0)&b>>>0<h>>>0|i>>>0>j>>>0)|0;j=e&65535;e=f;k=(l<<16)+(d>>>0>e>>>0?j+1|0:j)|0;f=0;e=f+e|0;L=L|e;F=F|(e>>>0<f>>>0?k+1|0:k)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=L;v[a+12>>2]=F;jb=m+192|0;return}v[a>>2]=0;v[a+4>>2]=0;b=!(d|f|(e|g));v[a+8>>2]=b?0:L;v[a+12>>2]=b?2147450880:F;jb=m+192|0}function JH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=jb-128|0;jb=h;a:{b:{if(g){Hj(h+112|0,f,32);v[114578]=0;W(799,h+96|0,f|0,32)|0;i=v[114578];v[114578]=0;if((i|0)!=1){break b}c=P()|0;O()|0;break a}Wb(h+112|0);Wb(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(Pr(c)){i=b+24|0;b=v[i>>2];v[114578]=0;b=Q(444,b+484344|0,c&65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break r}if(b){break q}}v[114578]=0;U(2195,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)!=1){break p}}c=P()|0;O()|0;break c}b=_b(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){v[114578]=0;U(2195,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)!=1){break p}break d}if(!(x[v[i>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){v[114578]=0;U(2195,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}break p}v[114578]=0;c=W(2196,b|0,d|0,e&65535)|0;b=v[114578];v[114578]=0;if((b|0)==1){break o}Le(h+112|0);Le(h+96|0);v[114578]=0;b=T(553,c|0)|0;d=v[114578];v[114578]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){F:{G:{if(!b){if(!ls(c)){break G}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[114578]=0;X(2197,h- -64|0,b|0,e|0,d|0);d=v[114578];v[114578]=0;b=1;if((d|0)==1){break E}v[114578]=0;U(9,h+80|0,0,h- -64|0);d=v[114578];v[114578]=0;if((d|0)!=1){break F}c=P()|0;O()|0;break B}b=0;v[114578]=0;Q(85,h+80|0,38869)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}}v[114578]=0;Q(1250,h+112|0,h+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break C}yb(h+80|0);if(b){yb(h- -64|0)}v[114578]=0;b=T(553,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}H:{if(b){v[114578]=0;Q(85,h+80|0,38873)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}break H}if(ls(c)){v[114578]=0;Q(85,h+80|0,38877)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break H}break e}v[114578]=0;Q(85,h+80|0,38869)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}}v[114578]=0;Q(1250,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break A}yb(h+80|0);j=f-1|0;if(j>>>0<5){break t}v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break z}v[114578]=0;Q(1250,h+112|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break y}yb(b);v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break x}v[114578]=0;Q(1250,h+96|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break w}yb(b);b=c+1|0;I:{if(w[c+1|0]){v[114578]=0;R(837,h+80|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){break I}break f}v[114578]=0;Q(85,h+80|0,38881)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}}v[114578]=0;Q(1250,h+112|0,h+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}yb(h+80|0);J:{if(w[b|0]){v[114578]=0;Q(85,h+80|0,38884)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break J}break g}v[114578]=0;Q(85,h+80|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}}v[114578]=0;Q(1250,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break u}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(h+80|0);if(!b){break c}}yb(h- -64|0);break c}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;yb(h+80|0);break c}yb(h+80|0);if(j>>>0<8){break t}v[114578]=0;b=T(1341,c|0)|0;d=v[114578];v[114578]=0;K:{L:{M:{N:{O:{P:{Q:{if((d|0)!=1){R:{if(b){v[114578]=0;b=Q(85,h+48|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Q}v[114578]=0;e=T(1343,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break P}d=0;v[114578]=0;v[h+16>>2]=e&255;R(836,h+32|0,h+16|0);k=v[114578];v[114578]=0;e=1;if((k|0)==1){break P}v[114578]=0;U(138,h+80|0,b|0,h+32|0);b=v[114578];v[114578]=0;if((b|0)!=1){break R}c=P()|0;O()|0;break i}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[114578]=0;b=Q(2198,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break L}v[114578]=0;b=W(799,h+48|0,1,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break L}e=0;v[114578]=0;R(837,h+32|0,c+4|0);k=v[114578];v[114578]=0;d=1;if((k|0)==1){break O}v[114578]=0;U(138,h+80|0,b|0,h+32|0);b=v[114578];v[114578]=0;if((b|0)!=1){break R}c=P()|0;O()|0;yb(h+32|0);break k}e=0;v[114578]=0;Q(85,h+80|0,38901)|0;b=v[114578];v[114578]=0;d=0;if((b|0)==1){break M}}v[114578]=0;Q(1250,h+112|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break N}yb(h+80|0);if(d){yb(h+32|0);yb(h+48|0)}if(e){yb(h+32|0);yb(h+48|0)}v[114578]=0;b=T(1341,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break l}S:{if(b){v[114578]=0;Q(85,h+80|0,38905)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}break S}if(w[c+2|0]){v[114578]=0;Q(85,h+80|0,38909)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break S}break l}v[114578]=0;Q(85,h+80|0,38901)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}}v[114578]=0;Q(1250,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break K}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break h}c=P()|0;O()|0;break k}c=P()|0;O()|0;yb(h+80|0);if(!d){break j}yb(h+32|0);break k}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}yb(h+80|0);if(j>>>0<12){break t}v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;T:{U:{V:{W:{X:{Y:{Z:{_:{$:{if((d|0)!=1){v[114578]=0;Q(1250,h+112|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break $}yb(b);v[114578]=0;b=Q(85,h+80|0,38887)|0;d=v[114578];v[114578]=0;if((d|0)==1){break _}v[114578]=0;Q(1250,h+96|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Z}yb(b);v[114578]=0;b=T(1341,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break Y}aa:{if(b){b=0;v[114578]=0;d=T(1342,c|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;v[h+28>>2]=d&4095;R(1061,h+80|0,h+28|0);d=v[114578];v[114578]=0;if((d|0)!=1){break aa}}c=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[114578]=0;b=Q(2199,b|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break X}v[114578]=0;d=W(799,h+16|0,1,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break X}v[114578]=0;R(837,h|0,c+5|0);e=v[114578];v[114578]=0;b=1;if((e|0)==1){break W}v[114578]=0;U(138,h+80|0,d|0,h|0);d=v[114578];v[114578]=0;if((d|0)!=1){break aa}c=P()|0;O()|0;yb(h);break m}b=0;v[114578]=0;Q(85,h+80|0,38869)|0;d=v[114578];v[114578]=0;if((d|0)==1){break U}}v[114578]=0;Q(1250,h+112|0,h+80|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break V}yb(h+80|0);if(b){yb(h);yb(h+16|0)}v[114578]=0;b=T(1341,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}ba:{if(b){v[114578]=0;Q(85,h+80|0,38913)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}break ba}if(w[c+3|0]){v[114578]=0;Q(85,h+80|0,38913)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break ba}break n}v[114578]=0;Q(85,h+80|0,38869)|0;b=v[114578];v[114578]=0;if((b|0)==1){break n}}v[114578]=0;Q(1250,h+96|0,h+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break T}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break m}c=P()|0;O()|0;yb(h+80|0);if(!b){break c}yb(h);break m}c=P()|0;O()|0;break c}yb(h+80|0);if(!f){break s}}ca:{da:{ea:{fa:{if(Fb(h+112|0)>>>0>f>>>0){v[114578]=0;X(232,h+80|0,h+112|0,0,f|0);b=v[114578];v[114578]=0;if((b|0)!=1){break fa}c=P()|0;O()|0;break c}if(g){b=Fb(h+112|0);v[114578]=0;b=W(799,h+80|0,f-b|0,32)|0;c=v[114578];v[114578]=0;if((c|0)==1){break da}v[114578]=0;Q(1250,h+112|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=P()|0;O()|0;yb(b);break c}yb(b);if(Fb(h+96|0)>>>0>f>>>0){break ca}break ea}if(Fb(h+96|0)>>>0<=f>>>0){break s}break ca}Gb(h+112|0,h+80|0);yb(h+80|0);if(Fb(h+96|0)>>>0>f>>>0){break ca}if(!g){break s}}b=Fb(h+96|0);v[114578]=0;b=W(799,h+80|0,f-b|0,32)|0;c=v[114578];v[114578]=0;ga:{if((c|0)!=1){v[114578]=0;Q(1250,h+96|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break ga}yb(b);break s}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}v[114578]=0;X(232,h+80|0,h+96|0,0,f|0);b=v[114578];v[114578]=0;if((b|0)!=1){Gb(h+96|0,h+80|0);yb(h+80|0);break s}c=P()|0;O()|0;break c}v[114578]=0;U(2195,a|0,h+112|0,h+96|0);a=v[114578];v[114578]=0;if((a|0)==1){break o}}yb(h+96|0);yb(h+112|0);jb=h+128|0;return}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}yb(h+16|0);break c}c=P()|0;O()|0;break c}yb(h+48|0)}if(!e){break c}}yb(h+32|0)}yb(h+48|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0}yb(h+96|0)}yb(h+112|0);S(c|0);L()}
function Uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-304|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!ht(b,d+208|0)){break j}if(!QP(d+208|0)){break j}if(!Qb(b,id(PP(d+208|0),mb))){break j}if(!c){n=1;break j}if(!Pc(b,w[d+208|4])){break j}Hd(a,268435456);wi(a);v[a+480208>>2]=4;f=Ub(d+88|0,16651);Gb(a+1304436|0,f);yb(f);f=Ub(d+88|0,16670);Gb(a+1304448|0,f);yb(f);v[a+1304496>>2]=4;Ye(d+16|0,d+208|6,48,3);Ic(d+88|0,d+16|0);Gb(a+1304400|0,d+88|0);yb(d+88|0);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){f=0;while(1){u[((f<<5)+a|0)+480284>>1]=B(w[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];e=w[d+302|0]|w[d+303|0]<<8;h=jb-16|0;jb=h;k=d+192|0;f=k;v[f>>2]=0;v[f+4>>2]=0;v[114578]=0;v[h+12>>2]=0;W(947,f+8|0,h+12|0,h+8|0)|0;i=v[114578];v[114578]=0;k:{if((i|0)!=1){jb=h+16|0;break k}V(0)|0;O()|0;Ab();L()}l:{if(!e){break l}v[114578]=0;R(945,k|0,e|0);h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;R(946,k|0,e|0);h=v[114578];v[114578]=0;if((h|0)!=1){break l}}a=P()|0;O()|0;MP(f);S(a|0);L()}f=w[d+302|0]|w[d+303|0]<<8;v[114578]=0;W(938,b|0,k|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}r=Jp(d+176|0);o=Jp(d+160|0);f=w[d+301|0];v[114578]=0;W(628,b|0,r|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}h=w[d+300|0];f=0;v[114578]=0;W(628,b|0,o|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break f}if(w[d+300|0]){p=c&2;q=d+88|4;l=d+126|0;m=d+88|6;while(1){v[114578]=0;h=f;f=f+1|0;i=B(f,104)+a|0;j=i+484380|0;R(388,j|0,0);e=v[114578];v[114578]=0;m:{n:{if((e|0)!=1){e=Pb(o,h);if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break m}e=Pb(o,h);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114578]=0;e=Q(256,b|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}if(!e){break m}v[114578]=0;e=Q(939,b|0,d+88|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}if(!e){break m}v[114578]=0;U(746,d+72|0,2,m|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;R(417,d+16|0,d+72|0);e=v[114578];v[114578]=0;if((e|0)!=1){break n}}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}v[114578]=0;Q(371,((f<<5)+a|0)+946300|0,d+16|0)|0;e=v[114578];v[114578]=0;o:{p:{q:{r:{s:{if((e|0)!=1){yb(d+16|0);v[114578]=0;U(940,d+72|0,2,l|0);e=v[114578];v[114578]=0;if((e|0)==1){break s}v[114578]=0;R(417,d+16|0,d+72|0);e=v[114578];v[114578]=0;if((e|0)==1){break s}v[114578]=0;Q(372,i+484423|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break r}yb(d+16|0);if(w[d+138|0]<=15){e=i+484414|0;u[e>>1]=x[e>>1]|32;u[i+484408>>1]=B(w[d+138|0],17)}e=w[d+139|0];v[114578]=0;t[d+16|0]=e;t[d+72|0]=64;e=Q(393,d+16|0,d+72|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}u[i+484412>>1]=w[e|0];v[i+484404>>2]=w[d+141|0]|w[d+142|0]<<8;e=i+484384|0;v[e>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);g=i+484388|0;v[g>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[j>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break p}n=v[e>>2];e=v[g>>2];break o}f=P()|0;O()|0;yb(d+16|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;yb(d+16|0);break b}f=P()|0;O()|0;break b}n=v[e>>2]>>>1|0;v[e>>2]=n;e=v[g>>2]>>>1|0;v[g>>2]=e;v[j>>2]=v[j>>2]>>>1}t:{if(e>>>0<=n>>>0){break t}e=i+484414|0;u[e>>1]=x[e>>1]|2;if(!(w[d+140|0]&2)){break t}u[e>>1]=x[e>>1]|4}v[114578]=0;Z(941,j|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}if(!p){break m}h=Pb(o,h);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);e=w[q|0];v[114578]=0;Q(256,b|0,e+h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break c}h=ad(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[114578]=0;W(402,h|0,j|0,b|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break m}f=P()|0;O()|0;break b}if(w[d+300|0]>f>>>0){continue}break}}n=1;u:{if(!(c&1)){break u}v[d+68>>2]=0;i=a+484360|0;Xp(Vb(i));F=d,G=bc(k),v[F+64>>2]=G;F=d,G=cc(k),v[F+56>>2]=G;j=a+484344|0;if(Jb(d- -64|0,d+56|0)){z=d+88|5;p=d+88|4;while(1){h=v[d- -64>>2];c=h;v:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break v}c=Pb(r,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}if(!c){break v}v[114578]=0;Q(942,b|0,d+88|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}if(!w[p|0]){break v}c=w[h|0]|w[h+1|0]<<8;f=w[h|0]|w[h+1|0]<<8;t[d+16|0]=w[z|0];e=w[d+262|0];g=w[h+2|0];v[114578]=0;t[d+72|0]=e-g;e=Q(393,d+16|0,d+72|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}q=w[e|0];e=w[h|0]|w[h+1|0]<<8;g=w[p|0];v[114578]=0;v[d+52>>2]=e+g;e=Q(394,d+68|0,d+52|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}v[d+68>>2]=v[e>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break v}s=c>>>6|0;e=f&63;A=0;while(1){w:{x:{y:{z:{A:{B:{C:{f=e>>>0>63;s=f+s|0;c=s&65535;if(oc(Vb(i))>>>0<=c>>>0){g=Vb(i);v[114578]=0;R(929,g|0,s+1&65535);g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;g=W(811,j|0,64,0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break C}F=rc(Vb(i),c),G=g,u[F>>1]=G}l=x[rc(Vb(i),c)>>1];v[114578]=0;c=Q(444,j|0,l|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}if(!c){break v}c=_b(j,l);g=w[h+2|0];v[114578]=0;y=f?0:e;f=W(472,c|0,y|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break x}m=0;if(q){break B}break y}f=P()|0;O()|0;break b}while(1){v[114578]=0;R(943,d+72|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break z}g=dd(d+72|0);D=Bf(d+72|0);C=Sh(d+72|0);E=hc(d+72|0);e=0;c=w[d+72|0];if((c-1&255)>>>0<=142){e=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+m|0]=e}t[f|0]=e;c=w[g|0];t[f+2|0]=1;t[f+1|0]=c;c=w[D|0];D:{if((c|0)!=255){t[f+4|0]=c;break D}t[f+2|0]=0}c=w[C|0];E:{if(c>>>0>22){break E}t[f+3|0]=w[c+16688|0];g=w[E|0];t[f+5|0]=g;c=f+5|0;F:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break E;case 4:t[c|0]=g&3|48;break E;case 7:if(Kb(k)>>>0<=g>>>0){break E}g=c;c=Pb(k,w[c|0]);e=w[c|0]|w[c+1|0]<<8;t[g|0]=e>>>6;c=_b(j,l);g=x[a+480188>>1];v[114578]=0;c=W(472,c|0,y|0,g-1&65535)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=e&63;break E}f=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=_b(j,l);e=x[a+480188>>1];v[114578]=0;c=W(472,c|0,y|0,e-1&65535)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break E}f=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break E;case 12:v[114578]=0;t[d+15|0]=15;e=Q(393,c|0,d+15|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c|0]=w[e|0]|208;break E}f=P()|0;O()|0;break b;case 13:v[114578]=0;t[d+15|0]=15;e=Q(393,c|0,d+15|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c|0]=w[e|0]|192;break E}f=P()|0;O()|0;break b;case 14:v[114578]=0;t[d+15|0]=15;e=Q(393,c|0,d+15|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){t[c|0]=w[e|0]|224;break E}f=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break E}e=g&240;if(!e|(e|0)==240){break E}t[c|0]=g|15;break E;case 9:case 18:break F;default:break E}}if(e&255){break E}t[f|0]=w[(d+16|0)+m|0]}f=f+6|0;m=m+1|0;if((q|0)!=(m|0)){continue}break}break y}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(q>>>0>=w[z|0]){break w}c=w[z|0];v[114578]=0;Q(340,b|0,B(c-q|0,5)|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break w}}f=P()|0;O()|0;break b}e=y+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}_d(d- -64|0);if(Jb(d- -64|0,d+56|0)){continue}break}}G:{a=v[d+68>>2];b=a&63;if(!b){break G}c=Vb(i);v[114578]=0;a=a>>>6|0;c=Q(546,c|0,a&65535)|0;f=v[114578];v[114578]=0;if((f|0)!=1){if(!c){break G}a=_b(j,x[rc(Vb(i),a&65535)>>1]);v[114578]=0;aa(944,a|0,b|0,0,1)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break G}}f=P()|0;O()|0;break b}a=Vb(i);F=d,G=bc(a),v[F+88>>2]=G;F=d,G=cc(a),v[F+16>>2]=G;if(!Jb(d+88|0,d+16|0)){break u}e=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){H:{if((e&65535)!=65535){break H}v[114578]=0;e=W(811,j|0,64,0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break H}f=P()|0;O()|0;break b}u[a>>1]=e}te(d+88|0);if(Jb(d+88|0,d+16|0)){continue}break}}Ji(o);Ji(r);OP(k)}jb=d+304|0;return n|0}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0}Ji(o);Ji(r)}OP(k);S(f|0);L()}function bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-240|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!jA(b,d+168|0)){break j}if(!mT(d+168|0)){break j}if(!c){e=1;break j}Hd(a,131072);j=Ub(d+152|0,12688);v[114578]=0;R(219,d+32|0,j|0);e=v[114578];v[114578]=0;k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[114578]=0;U(537,d+104|0,d+32|0,d+168|4);e=v[114578];v[114578]=0;if((e|0)==1){break q}Gb(a+1304436|0,d+104|0);yb(d+104|0);Ib(d+32|0);yb(j);e=Ub(d+104|0,12702);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;GT(d+32|0,3,d+181|0);Ic(d+104|0,d+32|0);Gb(a+1304400|0,d+104|0);yb(d+104|0);Hn(d+72|0,3,d+211|0);Ic(d+32|0,d+72|0);v[114578]=0;U(13,d+104|0,4,d+32|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Gb(a+1304412|0,d+104|0);yb(d+104|0);yb(d+32|0);e=Sp(d+104|0);m=e,n=Cd(w[d+231|0],1,31),v[m+12>>2]=n;m=e,n=Cd(w[d+232|0],1,12)-1|0,v[m+16>>2]=n;v[e+20>>2]=w[d+233|0];j=a+1304500|0;iA(j);lT(j,e);i=d+72|4;e=jb-16|0;jb=e;j=d+88|0;f=j;v[f>>2]=0;v[f+4>>2]=0;v[114578]=0;v[e+12>>2]=0;W(567,f+8|0,e+12|0,e+8|0)|0;f=v[114578];v[114578]=0;r:{if((f|0)!=1){jb=e+16|0;break r}V(0)|0;O()|0;Ab();L()}while(1){v[114578]=0;e=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}if(!e){break k}v[114578]=0;Q(538,b|0,d+72|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break n}f=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);e=w[d+172|0];s:{if((e|0)==3){g=2;if((w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))==1431389523){break s}e=w[d+172|0]}if((e&255)==4){g=4;if((w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))==1431389523){break s}e=w[d+172|0]}g=0;if((e&255)>>>0>7){break s}f=(w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))==1146113363?-1:f}v[114578]=0;U(343,d+32|0,b|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}v[114578]=0;W(539,j|0,d+72|0,d+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}Bb(d+32|0);v[114578]=0;Q(340,b|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break p}e=P()|0;O()|0;Ib(d+32|0)}yb(j);break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Bb(d+32|0);break b}v[114578]=0;b=T(277,d+72|0)|0;e=v[114578];v[114578]=0;t:{u:{v:{if((e|0)!=1){v[114578]=0;U(540,d+32|0,j|0,1431389523);e=v[114578];v[114578]=0;if((e|0)==1){break v}Wd(b,d+32|0);Bb(d+32|0);u[d+70>>1]=0;u[d+68>>1]=65534;if(w[d+172|0]<3){break t}v[114578]=0;e=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break u}break d}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}u[d+70>>1]=e;if(w[d+172|0]<4){break t}v[114578]=0;e=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}u[d+68>>1]=w[d+172|0]==4?e?e:-2:e}e=a+484360|0;f=Vb(e);v[114578]=0;g=T(332,b|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;ea(443,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}f=Vb(e);v[114578]=0;f=T(541,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}jg(d+70|0,f);f=Vb(e);v[114578]=0;f=T(541,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}jg(d+68|0,f);v[114578]=0;U(540,d+32|0,j|0,1414807888);f=v[114578];v[114578]=0;w:{x:{y:{z:{A:{B:{C:{D:{if((f|0)!=1){Wd(b,d+32|0);Bb(d+32|0);v[114578]=0;f=T(339,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!(c&1)|f^1){break w}v[114578]=0;Q(542,b|0,d- -64|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}m=a,n=Cd(w[d- -64|2],1,32)+1|0,u[m+480188>>1]=n;f=d- -64|0;f=w[f|0]|w[f+1|0]<<8;v[114578]=0;f=Q(397,d|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}m=d,n=bc(f),v[m+16>>2]=n;m=d,n=cc(f),v[m+56>>2]=n;if(Jb(d+16|0,d+56|0)){while(1){i=v[d+16>>2];v[114578]=0;g=w[d+172|0]<3?9:8;Q(340,b|0,g-4|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break B}v[114578]=0;h=T(392,b|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break A}fg(b,g);v[114578]=0;U(343,d+32|0,b|0,g+h|0);g=v[114578];v[114578]=0;if((g|0)==1){break z}Wd(i,d+32|0);Bb(d+32|0);Tf(d+16|0);if(Jb(d+16|0,d+56|0)){continue}break}}g=x[a+480188>>1];v[114578]=0;g=Q(543,d+32|0,g|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break y}i=Vb(e);v[114578]=0;h=T(544,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break f}v[114578]=0;i=a+484344|0;R(403,i|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break f}h=Vb(e);m=d,n=bc(h),v[m+16>>2]=n;m=d,n=cc(h),v[m+56>>2]=n;if(Jb(d+16|0,d+56|0)){while(1){h=v[d+16>>2];k=x[h>>1];if(od(f)>>>0>k>>>0){k=tc(f,x[h>>1]);v[114578]=0;k=aa(545,k|0,w[d+172|0],g|0,a|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break f}u[h>>1]=k}te(d+16|0);if(Jb(d+16|0,d+56|0)){continue}break}}h=Vb(e);v[114578]=0;h=Q(546,h|0,x[d+68>>1])|0;k=v[114578];v[114578]=0;if((k|0)==1){break f}if(!h){break x}if(!x[d+70>>1]){h=x[d+68>>1];k=Vb(e);v[114578]=0;k=T(541,k|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break f}if(h>>>0>=k>>>0){break x}}e=x[rc(Vb(e),x[d+68>>1])>>1];h=_b(i,e);v[114578]=0;k=W(498,d+16|0,12,w[d+70|0])|0;l=v[114578];v[114578]=0;if((l|0)!=1){e=Gn(Ne(k,v[_b(i,e)+12>>2]-1|0));v[114578]=0;Q(499,h|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break x}}break f}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}e=P()|0;O()|0;break e}dT(g);hd(f)}v[114578]=0;U(540,d+32|0,j|0,1196641603);e=v[114578];v[114578]=0;if((e|0)==1){break h}Wd(b,d+32|0);Bb(d+32|0);v[114578]=0;e=T(339,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}if(e){v[114578]=0;Q(340,b|0,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;e=T(332,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;ea(547,a+1304424|0,b|0,e|0,40,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}}v[114578]=0;U(540,d+32|0,j|0,1146113363);e=v[114578];v[114578]=0;if((e|0)==1){break g}v[114578]=0;U(540,d+16|0,j|0,1229999443);e=v[114578];v[114578]=0;E:{F:{if((e|0)!=1){Wd(b,d+16|0);Bb(d+16|0);v[114578]=0;f=T(389,b|0)|0;g=v[114578];v[114578]=0;e=1;G:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){i=!(c&2);c=1;while(1){g=30;H:{I:{J:{if(w[d+172|0]>=2){v[114578]=0;g=T(389,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break J}}v[114578]=0;W(548,b|0,((e<<5)+a|0)+946300|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break J}v[114578]=0;Q(549,b|0,d+16|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}v[114578]=0;e=B(e,104)+a|0;g=e+484380|0;R(550,d+16|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break I}f=w[d+172|0];if(f>>>0>=8){v[114578]=0;W(551,b|0,e+484423|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}f=w[d+172|0]}v[114578]=0;Q(340,b|0,((f&255)>>>0>1?6:2)|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break I}v[114578]=0;f=T(392,d+32|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;U(343,d|0,d+32|0,f|0);f=v[114578];v[114578]=0;if((f|0)!=1){break H}}e=P()|0;O()|0;break F}e=P()|0;O()|0;break F}e=P()|0;O()|0;break F}v[114578]=0;f=T(339,d|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break G}K:{if(i|f^1){break K}e=ad(d+56|0,u[e+484414>>1]&1?16:8,1,0,(w[d+31|0]&12)==4?7:0);v[114578]=0;W(402,e|0,g|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break K}break G}Bb(d);c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}v[114578]=0;Z(477,a|0);c=v[114578];v[114578]=0;e=1;if((c|0)!=1){break E}}e=P()|0;O()|0;break F}e=P()|0;O()|0;Bb(d);break F}e=P()|0;O()|0}Bb(d+32|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;Bb(d+32|0);Bb(b);kT(j)}jb=d+240|0;return e|0}e=P()|0;O()|0;yb(d+32|0);break a}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;dT(g)}hd(f);break c}e=P()|0;O()|0}Bb(b)}kT(j)}S(e|0);L()}function kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=jb-272|0;jb=d;Jc(b);g=jb-16|0;jb=g;i=d+112|0;zS(g+8|0,i);h=Hb(g+8|0);e=b;j=nc(e,ac(g,g+8|0));if((h|0)==(j|0)){$b(e,Hb(g+8|0))}jb=g+16|0;e=(h|0)==(j|0);if(!e){AS(i)}a:{b:{c:{d:{e:{f:{g:{h:{i:{if(!e){break i}if(!CS(d+112|0)){break i}if(!c){f=1;break i}Hd(a,v[((w[d+228|0]|w[d+229|0]<<8)<<2)+12976>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;e=Ub(d+16|0,13016);Gb(a+1304436|0,e);yb(e);e=Ub(d+16|0,13038);Gb(a+1304448|0,e);yb(e);e=Ub(d+80|0,13042);v[114578]=0;R(219,d+96|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;X(429,d+16|0,d+96|0,d+191|0,d+188|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}Gb(a+1304460|0,d+16|0);yb(d+16|0);Ib(d+96|0);yb(e);Mc(a+1304484|0,((w[d+228|0]|w[d+229|0]<<8)<<2)+13072|0);Mc(a+1304472|0,v[((w[d+228|0]|w[d+229|0]<<8)<<2)+77264>>2]);v[a+1304496>>2]=4;yg(d+96|0,2,d+112|4);Ic(d+16|0,d+96|0);Gb(a+1304400|0,d+16|0);yb(d+16|0);yg(d+96|0,2,d+148|0);Ic(d+16|0,d+96|0);if(Ht(d+16|0,13112)){v[114578]=0;U(13,d+96|0,4,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}Gb(a+1304412|0,d+96|0);yb(d+96|0)}yb(d+16|0);u[a+480188>>1]=32;e=0;j:{while(1){g=(e<<5)+a|0;i=g+480280|0;zg(i);k:{f=d+e|0;if(w[f+193|0]<=15){v[d+16>>2]=w[f+193|0]<<4|8;v[d+96>>2]=256;q=g+480284|0,r=v[de(d+16|0,d+96|0)>>2],u[q>>1]=r;break k}if(w[f+193|0]==16){u[g+480284>>1]=128;v[i>>2]=256;break k}if(w[f+193|0]!=255){break k}u[a+480188>>1]=e;break j}e=e+1|0;if((e|0)!=32){continue}break}e=x[a+480188>>1]}f=0;if(!(e&65535)){break i}v[d+16>>2]=w[d+225|0]<<2;v[d+96>>2]=256;q=a,r=v[Lb(d+16|0,d+96|0)>>2],v[q+480200>>2]=r;v[a+480196>>2]=w[d+226|0];v[a+480204>>2]=B(w[d+227|0],1e4);if(Pc(b,w[d+230|0]|w[d+231|0]<<8|(w[d+232|0]<<16|w[d+233|0]<<24))){Np(Vb(a+484360|0),b,w[d+234|0]+1|0,255,254)}if(!Pc(b,w[d+240|0]|w[d+241|0]<<8|(w[d+242|0]<<16|w[d+243|0]<<24))){break i}u[a+480190>>1]=w[d+248|0]+1;h=d+48|0;e=1;i=1;while(1){g=jb-16|0;jb=g;f=jb-16|0;jb=f;j=d+16|0;gc(g+8|0,j,62);jb=f+16|0;l=Hb(g+8|0);f=b;k=nc(f,ac(g,g+8|0));if((l|0)==(k|0)){$b(f,Hb(g+8|0))}jb=g+16|0;f=(l|0)==(k|0);if(!f){g=jb-16|0;jb=g;Rb(j,0,62);jb=g+16|0}if(f){f=B(e,104)+a|0;g=f+484380|0;Fd(g,0);yg(d,2,d+16|0);Ic(d+96|0,d);v[114578]=0;Q(371,((e<<5)+a|0)+946300|0,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}yb(d+96|0);Hk(d,2,h);Ic(d+96|0,d);v[114578]=0;Q(372,f+484423|0,d+96|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}yb(d+96|0);e=f+484404|0;v[e>>2]=w[d+74|0]|w[d+75|0]<<8;l:{if(!Lp(a)){break l}j=v[e>>2];e=0;while(1){if((j|0)==x[(e<<1)+13120>>1]){t[f+484417|0]=e<<4;break l}e=e+1|0;if((e|0)!=16){continue}break}}u[f+484412>>1]=64;v[g>>2]=w[d+61|0]|w[d+62|0]<<8|(w[d+63|0]<<16|w[d+64|0]<<24);if(w[d+73|0]&2){e=f+484414|0;u[e>>1]=x[e>>1]|1;v[g>>2]=v[g>>2]>>>1}v[f+484384>>2]=w[d+65|0]|w[d+66|0]<<8|(w[d+67|0]<<16|w[d+68|0]<<24);v[f+484388>>2]=(w[d+69|0]|w[d+70|0]<<8|(w[d+71|0]<<16|w[d+72|0]<<24))-1;if(t[d+73|0]&1){e=f+484414|0;u[e>>1]=x[e>>1]|2}m:{if(w[d+73|0]&4){t[d+96|0]=w[d+76|0];t[d|0]=64;q=f+484410|0,r=w[pc(d+96|0,d)|0]<<2,u[q>>1]=r;break m}e=f+484414|0;u[e>>1]=x[e>>1]|32768}n:{if(!(w[d+73|0]&8)){u[f+484408>>1]=128;break n}e=f+484414|0;u[e>>1]=x[e>>1]|32;g=f+484408|0;if(w[d+77|0]>=16){f=128}else{f=w[d+77|0];v[d>>2]=256;v[d+96>>2]=f<<4|8;f=v[de(d+96|0,d)>>2]}u[g>>1]=f;u[e>>1]=x[e>>1]&65279|(w[d+77|0]==16)<<8}i=i+1|0;e=i&65535;if(e>>>0<=x[a+480190>>1]){continue}}break}o:{if(!(c&2)){break o}if(!Pc(b,w[d+244|0]|w[d+245|0]<<8|(w[d+246|0]<<16|w[d+247|0]<<24))|!x[a+480190>>1]){break o}e=1;while(1){f=B(e&65535,104)+a|0;tg(ad(d+16|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}}m=a+484344|0;_f(m,w[d+239|0]+1|0);f=Vo(a);e=jb-16|0;jb=e;v[e+12>>2]=0;qs(e+12|0,f);j=v[e+12>>2];jb=e+16|0;Pc(b,w[d+235|0]|w[d+236|0]<<8|(w[d+237|0]<<16|w[d+238|0]<<24));o=c&1;i=0;l=1;while(1){c=hg(b);if(c>>>0>=3){ud(d+16|0,b,c-2|0);p:{if(!o){break p}v[114578]=0;c=T(339,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}if(!c){break p}v[114578]=0;c=W(404,m|0,i&65535,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}k=0;if(!c){break p}while(1){c=_b(m,i);v[114578]=0;p=Q(497,c|0,k|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break g}q:while(1){v[114578]=0;c=T(389,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}r:{if(!c){break r}e=c&31;if(e>>>0>=x[a+480188>>1]){break r}f=B(e,6)+p|0;if(c&32){v[114578]=0;R(473,d+96|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break g}g=dd(d+96|0);e=w[d+96|0];if(e){e=(e&127)-1|0;t[d+96|0]=e;t[f|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+13;v[114578]=0;e=T(611,f|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}l=e&l}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[114578]=0;c=Q(258,d+16|0,2)|0;e=v[114578];v[114578]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((e|0)!=1){if(!c){continue q}n=w[g|0];c=w[f+3|0];v[114578]=0;R(473,d+96|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break g}h=w[dd(d+96|0)|0];t[g|0]=h;e=w[(w[d+96|0]&31)+13152|0];t[f+3|0]=e;switch(e-2|0){case 2:case 3:case 6:case 7:case 8:case 9:case 10:case 12:case 14:case 15:case 16:break u;case 18:break y;case 13:break z;case 17:break A;case 11:break B;case 5:break C;case 4:break D;case 1:break E;case 0:break F;default:break x}}break g}if(h>>>0<224){break s}break t}if(h>>>0>=224){break t}break s}e=h&240;if(!e){break s}t[g|0]=e;break v}e=h&240;if(!e){break s}t[g|0]=e;break v}v[114578]=0;t[d|0]=64;e=Q(393,g|0,d|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){t[g|0]=w[e|0];v[114578]=0;e=Q(612,j|0,1)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}if(!e){break v}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=n;e=c;break u}break g}v[114578]=0;e=Q(613,j|0,19)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}if(e){break v}v[114578]=0;Z(614,f|0);e=v[114578];v[114578]=0;if((e|0)!=1){break v}break g}v[114578]=0;e=Q(613,j|0,15)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}if(e){break v}v[114578]=0;e=Q(613,j|0,19)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}if(!e){break v}t[f+3|0]=19;t[g|0]=w[g|0]&15|144;break s}G:{e=h>>>4|0;if((e|0)!=8){if(e){break G}H:{switch(h&15){case 4:t[f+3|0]=20;t[g|0]=158;break s;case 0:case 1:break w;case 5:break H;default:break G}}t[f+3|0]=20;t[g|0]=159;break s}v[114578]=0;e=Q(613,j|0,20)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}if(e){break v}t[f+3|0]=19;break s}t[f+3|0]=0;break s}if((e|0)!=31){break u}t[f+3|0]=17;break s}t[g|0]=h-112}e=w[f+3|0]}if((e&255)!=20){break s}e=w[g|0];if(w[f+2|0]|(e&240)!=128){break s}t[f+2|0]=2;t[f+4|0]=(((e&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=n;break s}t[g|0]=223}if(w[d+96|0]&32){continue}break}continue}break}k=k+1|0;if((k|0)!=64){continue}break}}Bb(d+16|0)}c=w[d+239|0]>i>>>0;i=i+1|0;if(c){continue}break}c=a;if((l^-1|x[a+480188>>1]!=4)&1|v[a+480180>>2]!=1){e=v[a+480208>>2]&-8454145}else{e=v[a+480208>>2]|8454144}v[c+480208>>2]=e;f=1;if(!(w[d+253|0]|w[d+254|0]<<8|(w[d+255|0]<<16|w[d+256|0]<<24))){break i}if(!Pc(b,w[d+249|0]|w[d+250|0]<<8|(w[d+251|0]<<16|w[d+252|0]<<24))){break i}Ky(a+1304424|0,b,w[d+253|0]|w[d+254|0]<<8|(w[d+255|0]<<16|w[d+256|0]<<24),4)}jb=d+272|0;return f|0}f=P()|0;O()|0;yb(d+16|0);break a}f=P()|0;O()|0;Bb(d+16|0);break a}f=P()|0;O()|0;yb(d+96|0);break a}f=P()|0;O()|0;yb(d+96|0);break a}f=P()|0;O()|0;Ib(d+96|0);break b}f=P()|0;O()|0}yb(e)}S(f|0);L()}function Jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0;d=jb-336|0;jb=d;a:{if(!Pc(b,1080)){break a}if(!An(b,d+332|0)){break a}Hd(a,1);o=BQ(d+312|0);if(!AQ(d+332|0,o)){break a}e=x[o+8>>1];if((e-1&65535)>>>0>126){break a}if(!c){f=1;break a}u[a+480188>>1]=e;h=w[o+12|0];V=w[o+11|0];e=w[o+10|0];I=1;if(!$d(d+332|0,15619)){I=$d(d+332|0,15624)}if(w[o+13|0]){Nb(a+1074308|0,5,1)}y=a+480188|0;z=V?x[y>>1]==8:0;q=$d(d+332|0,15629);p=1;if(!$d(d+332|0,15634)){p=$d(d+332|0,15639)}Pc(b,0);Tz(b,a+1304400|0,20);u[a+480190>>1]=31;l=(e|0)!=0;f=1;e=q;while(1){j=B(f,104)+a|0;g=j+484380|0;n=mz(b,d+176|0,g,((f<<5)+a|0)+946300|0,x[a+480188>>1]==4);g=v[g>>2];b:{if(p){t[j+484417|0]=0-(w[d+200|0]<<3);break b}l=g>>>0<65536&l}J=w[d+198|0]|w[d+199|0]<<8?!(w[d+204|0]|w[d+205|0]<<8)|J:J;j=e&1;e=0;c:{if(!j){break c}j=w[d+198|0]|w[d+199|0]<<8;i=(((j<<8|j>>>8)&65535)<<1)+i|0;if(w[d+200|0]){break c}if(!(w[d+198|0]|w[d+199|0]<<8)){e=1;break c}e=w[d+201|0]==64}K=n+K|0;k=g+k|0;f=f+1|0;if((f|0)!=32){continue}break}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{X=v[o+4>>2];if(X>>>0>=K>>>0){lz(b,d+176|0);$b(b,4);r=d+176|1;j=w[r|0];g=128;f=a+484360|0;In(Vb(f),d+176|2,128,65535,65535);M=i;i=!j&e;n=i?M:0;e=w[d+176|0];o:{if(e>>>0>128){break o}g=e;if(e){break o}e=128;while(1){j=e-1|0;if(!x[rc(Vb(f),j)>>1]){g=1;e=j;if(e>>>0>1){continue}break o}break}g=e}F=(h|0)!=0;j=yQ(b,Vb(f),g&65535,k,y,n);if(!(!i|x[a+480188>>1]!=8)){v[o>>2]=15644;F=1}p:{if(!z){break p}e=Vb(f);da=d,ea=bc(e),v[da+160>>2]=ea;da=d,ea=cc(e),v[da+144>>2]=ea;if(!Jb(d+160|0,d+144|0)){break p}while(1){e=v[d+160>>2];u[e>>1]=x[e>>1]>>>1;te(d+160|0);if(Jb(d+160|0,d+144|0)){continue}break}}Oe(Vb(f),w[r|0]);Y=g-1&65535;if(!(w[r|0]!=120|x[y>>1]!=4?Y>>>0>=w[r|0]:0)){Oe(Vb(f),0)}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;i=0;e=Yb(256/x[a+480188>>1]|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=e;lj(a,0);t[d+175|0]=0;C=1;p=1;if(!l){q:{if(!j){k=q;break q}n=d+160|5;k=q;l=0;p=0;while(1){e=0;g=0;while(1){f=Rh(d+160|0);ot(b,f);h=BS(f);r:{s:{t:{f=w[d+163|0];if((f-7&255)>>>0<3){k=0;break t}k=h?k:0;u:{v:{w:{switch(f-13|0){case 2:if(w[d+165|0]>31){break v}break r;case 1:break u;case 0:break w;default:break t}}g=g+1|0;if((g&65535)>>>0<2){break r}}k=0;break r}f=w[d+165|0];k=f>>>0>1?0:k;break s}if((f|0)!=8){if((f|0)!=14){break r}f=w[d+165|0];break s}da=d,ea=w[qh(d+175|0,n)|0],t[da+175|0]=ea;f=t[d+165|0];if((f|0)>-1){p=1;break r}l=(f|0)!=-92&(f&255)>>>0>143|l;break r}if((f&240)!=128){break r}t[d+144|0]=f<<4;da=d,ea=w[qh(d+175|0,d+144|0)|0],t[da+175|0]=ea}C=h&C;e=e+1|0;if((e|0)!=256){continue}break}i=i+1|0;if(j>>>0>(i&65535)>>>0){continue}break}i=0;if((p^-1|l)&1){break q}i=w[d+175|0]>47}p=k&1}Pc(b,1084);k=4;k=z?k:x[y>>1];D=a+484344|0;G=j+z&65535;_f(D,G);n=a+1074308|0;if(G){aa=c&1;j=k;ba=i^1;while(1){x:{g=!aa;y:{if(z){e=(s&65534)>>>1|0;l=s&1;if(!l){if(!rg(D,e,64)){break x}}l=Xe(_b(D,e),0,l<<2);break y}if(!rg(D,s&65535,64)){break x}l=Xe(_b(D,s),0,0)}if(g|!l){break x}e=x[a+480188>>1];t[d+144|0]=0;E=Tt(d+160|0,e,d+144|0);e=x[a+480188>>1];v[114578]=0;t[d+64|0]=0;H=W(885,d+144|0,e|0,d- -64|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}N=0;while(1){M=m;z:{if(j){i=0;f=0;g=0;while(1){v[114578]=0;h=B(i,6)+l|0;R(886,b|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break f}e=w[h+3|0];A:{B:{C:{if(!e){if(w[h+5|0]){break C}break B}if(!V){break C}D:{switch(e-14|0){case 0:t[h+3|0]=0;t[h+5|0]=0;break C;case 1:break D;default:break C}}if(w[h+5|0]<32){break C}t[h+5|0]=31}vj(h);e=1;E:{F:{G:{m=w[h+3|0];switch(m-14|0){case 2:break A;case 0:break F;case 3:break G;default:break E}}Z=w[h+5|0]<100|Z;f=1;break B}if(!p){break B}t[h+5|0]=0;break B}if(!(ba|(m|0)!=9)){e=w[h+5|0];if((e|0)==164){t[h+3|0]=20;t[h+5|0]=145;break B}v[114578]=0;e=T(887,e<<1)|0;m=v[114578];v[114578]=0;if((m|0)==1){break f}t[h+5|0]=e;break B}if((m|0)!=19){break B}e=w[h+5|0];if(e>>>0>15){break B}m=e&1;e=!m;ca=!m;m=_&1;_=(m|0)==(e|0)?_:ca;Q=((e|0)!=(m|0))+Q|0}e=g}H:{if(!w[h|0]){if(!w[h+1|0]|z){break H}if(!w[xc(E,i)|0]){break H}if(w[xc(E,i)|0]==w[h+1|0]){break H}m=xc(H,i);g=w[m|0]+1|0;t[m|0]=g;if((g&255)>>>0<4){break H}v[114578]=0;W(479,n|0,85,1)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}break H}da=xc(H,i),ea=0,t[da|0]=ea}g=w[h+1|0];if(g){da=xc(E,i),ea=g,t[da|0]=ea}g=e;i=i+1|0;if((j|0)!=(i|0)){continue}break}e=e&f;break z}e=0}m=M|e;l=B(x[y>>1],6)+l|0;N=N+1|0;if((N|0)!=64){continue}break}fe(H);fe(E);s=s+1|0;if((G|0)!=(s|0)){continue}}break}e=G<<8}else{e=0}I:{J:{K:{if((C^-1|J)&1){break K}L:{if($d(d+332|0,15629)){break L}if($d(d+332|0,15656)){break L}if(!$d(d+332|0,15661)){break K}}v[a+480208>>2]=v[a+480208>>2]|2162688;Nb(n,85,1);Nb(n,91,1);Nb(n,92,1);M:{if(w[d+175|0]>47){break M}Nb(n,84,1);if(w[r|0]==127){break M}Nb(n,83,1)}if(!((Q|0)>6|F)){break J}break I}if(!C){if(q^1|w[r|0]!=127|w[r|0]+1>>>0<Y>>>0){break I}v[o>>2]=15666;break I}if((Q|0)>6|F){break I}}v[a+480208>>2]=v[a+480208>>2]|8388608}if((q|F)==1){Nb(n,89,1)}if(I){Nb(n,84,1)}if(c&2){Pc(b,B(e,k)+1084|0);g=q&C;f=1;while(1){k=B(f,104)+a|0;c=k+484380|0;if(v[c>>2]){j=d+160|0;if(I){e=2}else{e=xQ(b,15680)?11:0}e=ad(j,8,1,0,e);l=v[b+8>>2]+qS(e,v[c>>2])|0;if(g){da=c,ea=v[bd(c,k+484388|0)>>2],v[da>>2]=ea}tg(e,c,b);Pc(b,l)}f=f+1|0;if((f|0)!=32){continue}break}}N:{if((q&Z^-1|m)&1){break N}b=wQ(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;Es(d+160|0,a,0,d+24|0);$=A[v[d+160>>2]>>3];Hl(d+160|0);if($<600){break N}Nb(n,5,1);b=vQ(d+96|0,$);c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;Es(d+160|0,a,0,d);b=w[v[d+160>>2]+26|0];Hl(d+160|0);if(b){wg(n,5);break N}v[o>>2]=15686}e=d+332|0;c=d+332|0;b=hc(d+332|0);if((c|0)!=(b|0)){while(1){g=w[c|0];t[e|0]=g>>>0>32?g:32;e=e+1|0;c=c+1|0;if((b|0)!=(c|0)){continue}break}}b=Ub(d+80|0,15706);v[114578]=0;R(219,d+144|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break n}c=hc(d+332|0);v[114578]=0;c=W(888,d+48|0,d+332|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}v[114578]=0;U(13,d- -64|0,1,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break l}v[114578]=0;U(247,d+160|0,d+144|0,d- -64|0);e=v[114578];v[114578]=0;if((e|0)==1){break k}Gb(a+1304436|0,d+160|0);yb(d+160|0);yb(d- -64|0);yb(c);Ib(d+144|0);yb(b);b=Ub(d+160|0,15726);Gb(a+1304448|0,b);yb(b);b=v[o>>2];if(b){Mc(a+1304460|0,b)}v[a+1304496>>2]=2}f=K>>>0<=X>>>0;break a}f=P()|0;O()|0;break h}f=P()|0;O()|0;break i}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(d- -64|0)}yb(c)}Ib(d+144|0)}yb(b);break d}f=P()|0;O()|0;break e}f=P()|0;O()|0;fe(H)}fe(E)}S(f|0);L()}jb=d+336|0;return f|0}function yU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=jb-176|0;jb=e;Jc(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!zB(b,e+128|0)){break h}if(!AB(e+128|0)){break h}if(!c){m=1;break h}Hd(a,2048);wi(a);d=Ub(e+96|0,12026);v[114578]=0;R(219,e+112|0,d|0);i=v[114578];v[114578]=0;if((i|0)==1){break c}v[114578]=0;k=e+128|3;U(385,e+80|0,e+112|0,k|0);i=v[114578];v[114578]=0;if((i|0)==1){break d}Gb(a+1304436|0,e+80|0);yb(e+80|0);Ib(e+112|0);yb(d);d=Ub(e+80|0,12022);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;u[a+480188>>1]=w[e+168|0];u[a+480190>>1]=w[e+164|0];yg(e+112|0,2,e+128|4);Ic(e+80|0,e+112|0);Gb(a+1304400|0,e+80|0);yb(e+80|0);if(w[k|0]<=9){u[a+480188>>1]=4;fg(b,1);lj(a,1)}d=w[k|0];i:{if(w[k|0]>=11){i=d>>>0>11?32:16;d=0;while(1){g=((d<<5)+a|0)+480284|0;h=tu(b)<<1;h=(h|0)>-128?h:-128;j:{if((h|0)<129){d=h+128|0;break j}v[((d<<5)+a|0)+480280>>2]=256;d=128}u[g>>1]=d;f=f+1|0;d=f&65535;if(i>>>0>d>>>0){continue}break}break i}if((d|0)!=10){break i}yB(b,e+80|0);d=0;while(1){u[((d<<5)+a|0)+480284>>1]=t[(e+80|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}k:{if(w[k|0]>=13){dq(e+80|0,b);f=dd(e+80|0);i=a;j=e+80|0;d=w[j|0];if(d>>>0<32){t[j|0]=125;d=125}v[i+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break k}v[a+480196>>2]=6;v[a+480204>>2]=125e4}i=a+484360|0;eg(Vb(i),w[e+165|0]);n=Ql(e+112|0);g=v[b+8>>2];p=w[k|0];l:{if(w[k|0]<14){break l}d=w[e+165|0];v[114578]=0;R(386,n|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break l}b=P()|0;O()|0;break e}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(w[e+165|0]){d=0;while(1){s=rc(Vb(i),d),z=d,u[s>>1]=z;if(w[k|0]>=14){v[114578]=0;f=T(359,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break u}s=rc(n,d),z=f,u[s>>1]=z}f=x[a+480188>>1];v[114578]=0;Q(340,b|0,f<<1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break u}d=d+1|0;if(d>>>0<w[e+165|0]){continue}break}}d=x[a+480190>>1];v[114578]=0;v[e+80>>2]=0;o=W(387,e- -64|0,d|0,e+80|0)|0;d=v[114578];v[114578]=0;f=1;if((d|0)!=1){v[e+60>>2]=0;v:{if(x[a+480190>>1]){i=1;while(1){v[114578]=0;j=B(f,104)+a|0;h=j+484380|0;R(388,h|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break v}v[114578]=0;l=T(389,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;W(390,b|0,((f<<5)+a|0)+946300|0,32)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;W(391,b|0,j+484423|0,13)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;d=T(392,b|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break g}m=f-1|0;s=Pb(o,m),z=d,v[s>>2]=z;w:{if(w[k|0]<=9){v[114578]=0;f=T(359,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break w}break g}v[114578]=0;f=T(392,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}}v[h>>2]=f;v[114578]=0;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[j+484404>>2]=d;v[114578]=0;d=T(389,b|0)|0;f=v[114578];v[114578]=0;x:{y:{z:{if((f|0)!=1){v[114578]=0;t[e+80|0]=d;t[e+48|0]=64;d=Q(393,e+80|0,e+48|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break z}u[j+484410>>1]=w[d|0]<<2;if(w[k|0]>9){break y}v[114578]=0;d=T(359,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[j+484384>>2]=d;v[114578]=0;d=T(359,b|0)|0;break x}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}v[114578]=0;d=T(392,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[j+484384>>2]=d;v[114578]=0;d=T(392,b|0)|0}f=v[114578];v[114578]=0;if((f|0)==1){break g}f=j+484388|0;v[f>>2]=d;if(l){l=j+484384|0;A:{if(!(d>>>0<=v[l>>2]+2>>>0|d>>>0>y[h>>2])){d=j+484414|0;u[d>>1]=x[d>>1]|2;break A}v[f>>2]=0;v[l>>2]=0}d=Pb(o,m);v[114578]=0;d=Q(394,e+60|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[e+60>>2]=v[d>>2]}i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}j=cq(e+48|0);d=w[e+166|0]|w[e+167|0]<<8;v[114578]=0;m=W(395,b|0,j|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}if(!m){break m}i=0;B:{if(!nd(j)){d=bc(j);i=cc(j);v[114578]=0;d=Q(396,d|0,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break B}v[e+80>>2]=d;d=v[e+80>>2];i=w[d|0]|w[d+1|0]<<8}v[114578]=0;f=i;l=Q(397,e+32|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){C:{if(f){d=0;while(1){v[114578]=0;Q(398,b|0,e+24|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break s}v[114578]=0;U(343,e+80|0,b|0,B(w[e+24|0]|w[e+25|0]<<8|w[e+26|0]<<16,3)|0);h=v[114578];v[114578]=0;if((h|0)==1){break C}Wd(tc(l,d),e+80|0);Bb(e+80|0);d=d+1|0;if((f|0)!=(d|0)){continue}break}}if(c&2){q=ad(e+24|0,8,1,0,1);v[114578]=0;h=Q(399,e+80|0,o|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break q}d=bc(h);f=cc(h);v[114578]=0;R(400,d|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break r}d=bc(h);f=cc(h);v[114578]=0;d=Q(401,d|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[e+16>>2]=d;s=e,z=bc(h),v[s+8>>2]=z;D:{if(!Jb(e+8|0,e+16|0)){break D}while(1){v[114578]=0;d=Q(258,b|0,1)|0;f=v[114578];v[114578]=0;E:{if((f|0)!=1){if(!d){break D}d=0;if(!x[a+480190>>1]){break E}while(1){v[114578]=0;f=Q(258,b|0,1)|0;r=v[114578];v[114578]=0;if((r|0)==1){break r}if(!f){break E}f=d+1|0;if(v[v[e+8>>2]>>2]!=v[Pb(o,d)>>2]){d=f;if(d>>>0>=x[a+480190>>1]){break E}continue}break}v[114578]=0;W(402,q|0,(B(f,104)+a|0)+484380|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break E}break r}break r}sB(e+8|0);if(Jb(e+8|0,e+16|0)){continue}break}}oe(h)}if(!(c&1)){break n}d=w[e+165|0];c=0;v[114578]=0;h=a+484344|0;R(403,h|0,d|0);d=v[114578];v[114578]=0;F:{if((d|0)!=1){if(!w[e+165|0]){break n}p=g+((p>>>0>13)<<1)|0;while(1){G:{d=64;H:{if(oc(n)>>>0<=c>>>0){break H}d=x[rc(n,c)>>1]}v[114578]=0;d=W(404,h|0,c&65535,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break F}I:{if(d){d=x[a+480188>>1];f=w[k|0];v[114578]=0;Q(256,b|0,p+B(((f>>>0>13)<<1)+(d<<1)|0,c)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break F}f=cq(e+80|0);d=x[a+480188>>1];v[114578]=0;d=W(395,b|0,f|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break I}J:{if(!d){break J}d=0;if(!x[a+480188>>1]){break J}while(1){K:{g=rc(f,d);if(!(w[g|0]|w[g+1|0]<<8)){break K}g=rc(f,d);if((w[g|0]|w[g+1|0]<<8)>>>0>(w[e+166|0]|w[e+167|0]<<8)>>>0){break K}g=rc(f,d);g=rc(j,(w[g|0]|w[g+1|0]<<8)-1|0);g=w[g|0]|w[g+1|0]<<8;if(!g|i>>>0<g>>>0){break K}q=_b(h,c);g=tc(l,g-1&65535);v[114578]=0;U(405,q|0,d&65535,g|0);g=v[114578];v[114578]=0;if((g|0)!=1){break K}break G}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}Bj(f)}c=c+1|0;if(c>>>0>=w[e+165|0]){break n}continue}}break}b=P()|0;O()|0;Bj(f);break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;break f}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break o}b=P()|0;O()|0;break p}b=P()|0;O()|0;oe(h);break p}b=P()|0;O()|0}hd(l)}Bj(j);break f}hd(l)}Bj(j);oe(o);kf(n)}jb=e+176|0;return m|0}b=P()|0;O()|0}oe(o)}kf(n);break a}b=P()|0;O()|0;Ib(e+112|0);break b}b=P()|0;O()|0}yb(d)}S(b|0);L()}function vha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-272|0;jb=d;Jc(b);g=jb-16|0;jb=g;i=d+120|0;mP(g+8|0,i);h=Hb(g+8|0);e=b;f=nc(e,ac(g,g+8|0));if((h|0)==(f|0)){$b(e,Hb(g+8|0))}jb=g+16|0;e=(f|0)==(h|0);if(!e){nP(i)}a:{b:{c:{d:{e:{if(!e){break e}if(!xP(d+120|0)){break e}if(!c){k=1;break e}Hd(a,4194304);e=Ub(d+40|0,16870);Gb(a+1304436|0,e);yb(e);e=Ub(d+40|0,16866);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;m=a,n=Cd(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[m+480188>>1]=n;e=w[d+189|0];v[a+480228>>2]=(e|0)==255?48:e;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);Ye(d+104|0,d+120|4,59,3);Ic(d+40|0,d+104|0);Gb(a+1304400|0,d+40|0);yb(d+40|0);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Pc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!ph(b,16904)){break f}Np(Vb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Pc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!ph(b,16909)){break g}while(1){e=(k<<5)+a|0;zg(e+480280|0);m=e+480284|0,n=((((Gd(b)^-1)&15)<<8|8)>>>0)/15|0,u[m>>1]=n;k=k+1|0;if((k|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Pc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!ph(b,16914)){break h}ud(d+104|0,b,(w[d+196|0]|w[d+197|0]<<8)<<6);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}g=c&2;k=a+480190|0;i=d+53|0;while(1){v[114578]=0;e=Q(979,d+104|0,d+40|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!e){break i}e=w[d+85|0]|w[d+86|0]<<8;u[d+38>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(De((B(e,104)+a|0)+484380|0)){break j}v[114578]=0;e=Q(454,k|0,d+38|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break c}u[a+480190>>1]=x[e>>1];v[114578]=0;R(980,d+40|0,(B(x[d+38>>1],104)+a|0)+484380|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;U(981,d+8|0,1,i|0);e=v[114578];v[114578]=0;k:{l:{if((e|0)==1){break l}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break l}v[114578]=0;Q(371,((x[d+38>>1]<<5)+a|0)+946300|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}yb(d+24|0);if(!g){break j}e=w[d+77|0]|w[d+78|0]<<8|(w[d+79|0]<<16|w[d+80|0]<<24);v[114578]=0;Q(256,b|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;R(982,d+24|0,d+40|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+24|0,(B(x[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break j}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d+24|0);break b}j=j+1|0;if((j&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Bb(d+104|0)}k=1;if(!(c&1)){break e}m:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break m}if(!Pc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break m}if(!ph(b,16919)){break m}h=a+484344|0;_f(h,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break m}i=d+24|2;g=0;while(1){if(!Et(b,d+24|0)){break m}if((w[d+24|0]|w[d+25|0]<<8)>>>0>3){ud(d+40|0,b,((w[d+24|0]|w[d+25|0]<<8)+15&131056)-4|0);c=w[i|0];v[114578]=0;c=W(404,h|0,g&65535,c|0)|0;e=v[114578];v[114578]=0;n:{if((e|0)!=1){o:{j=0;if(!c){break n}while(1){v[114578]=0;c=Q(258,d+40|0,1)|0;e=v[114578];v[114578]=0;p:{q:{r:{if((e|0)!=1){if(!c|w[i|0]<=j>>>0){break q}v[114578]=0;e=T(389,d+40|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break o}if(e){break r}j=j+1|0;continue}break o}c=_b(h,g);u[d+104>>1]=e&31;f=x[a+480188>>1];v[114578]=0;u[d+8>>1]=f-1;f=Q(478,d+104|0,d+8|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break o}f=x[f>>1];v[114578]=0;c=W(472,c|0,j|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break o}if(e&128){v[114578]=0;R(473,d+104|0,d+40|0);f=v[114578];v[114578]=0;if((f|0)==1){break o}f=dd(d+104|0);t[c|0]=w[d+104|0]+36;t[c+1|0]=w[f|0]}if(!(e&64)){break p}t[c+2|0]=1;v[114578]=0;f=T(389,d+40|0)|0;l=v[114578];v[114578]=0;s:{if((l|0)!=1){v[114578]=0;t[d+104|0]=f;t[d+8|0]=64;f=Q(393,d+104|0,d+8|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break s}t[c+4|0]=w[f|0];break p}break o}break o}if(w[i|0]==64){break n}c=_b(h,g);v[114578]=0;e=W(498,d+104|0,14,0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){e=Uh(Ne(e,w[i|0]-1|0));v[114578]=0;Q(499,c|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}v[114578]=0;R(473,d+104|0,d+40|0);e=v[114578];v[114578]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){e=w[dd(d+104|0)|0];t[c+5|0]=e;switch(w[d+104|0]-1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[114578]=0;e=T(389,d+40|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){t[c+5|0]=e;v[114578]=0;Q(340,d+40|0,1)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break o}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;Bb(d+40|0);break a}Bb(d+40|0)}g=g+1|0;if(g>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Pc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));Ky(a+1304424|0,b,hg(b),4)}jb=d+272|0;return k|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}Bb(d+104|0)}S(b|0);L()}function QV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;g=jb-1424|0;jb=g;Jc(b);Gq(a);a:{if(!_C(b,g+1408|0)){break a}if(!aD(g+1408|0)){break a}if(!ZC(b,g+1392|0)){break a}if(!$C(g+1392|0)){break a}b:{if(!c){break b}C=g+1400|0;c=C;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>Lj(b)>>>0){break a}c=C;r=g+1392|2;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+((w[r|0]|w[r+1|0]<<8)<<2)>>>0>Lj(b)>>>0){break a}ev(a);dv(g+40|0);cv(Tg(a)+28|0,g+40|0);Fq(g+40|0);o=v[Tg(a)+28>>2];c=g+1392|4;io(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));Rb(g+1136|0,0,256);c:{d:{if(w[r|0]|w[r+1|0]<<8){k=g+1112|4;l=g+1128|0;z=g+1130|0;s=g+1126|0;h=g+1124|0;while(1){c=C;if(!Pc(b,(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+(D<<2)|0)){break a}if(!Qb(b,4)){break a}j=Cf(b);if(!Pc(b,j)){break a}if(!bv(b,g+1112|0)){break a}e=w[h|0]|w[h+1|0]<<8;f=jb-16|0;jb=f;q=g+1096|0;c=q;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[f+12>>2]=0;W(269,c+8|0,f+12|0,f+8|0)|0;d=v[114578];v[114578]=0;e:{if((d|0)!=1){jb=f+16|0;break e}V(0)|0;O()|0;Ab();L()}f:{if(!e){break f}v[114578]=0;R(262,q|0,e|0);f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;R(263,q|0,e|0);f=v[114578];v[114578]=0;if((f|0)!=1){break f}}a=P()|0;O()|0;VC(c);S(a|0);L()}d=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!(w[h|0]|w[h+1|0]<<8)){break x}y:{while(1){c=Uk(q,d);v[114578]=0;c=Q(254,b|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break y}if(c){d=d+1|0;if(d>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break x}continue}break}break w}c=P()|0;O()|0;break c}if(w[h|0]|w[h+1|0]<<8){c=v[q>>2]}else{c=0}f=w[h|0]|w[h+1|0]<<8;v[114578]=0;e=T(255,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}d=f<<3;f=j+20|0;if(e>>>0>d+f>>>0){e=f+((w[h|0]|w[h+1|0]<<8)<<3)|0;z:{if(!(t[s|0]&1)){j=0;if(!(w[h|0]|w[h+1|0]<<8)){break g}while(1){if(!c){break z}if(!go(o,c)){break z}v[114578]=0;f=Q(256,b|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}if(!f){break z}d=xc(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));f=c;n=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);v[114578]=0;d=W(257,b|0,d|0,n|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break u}if((d|0)!=(w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24))){break z}c=c+8|0;j=j+1|0;if(j>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}break g}A:{B:{C:{D:{if(w[s|0]&4){if(!c){break A}if(!go(o,c)){break A}f=xc(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));y=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);n=w[z|0]|w[z+1|0]<<8;d=w[l|0]|w[l+1|0]<<8;v[114578]=0;e=Q(256,b|0,d+e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}if(!e){break A}e=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);d=w[l|0]|w[l+1|0]<<8;v[114578]=0;e=Q(258,b|0,e-d|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}if(!e){break A}e=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);d=w[l|0]|w[l+1|0]<<8;v[114578]=0;U(259,g+24|0,b|0,e-d|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}e=hm(g+40|0,g+24|0);Bb(g+24|0);u=0;j=0;p=0;if(!(w[h|0]|w[h+1|0]<<8)){break j}while(1){E:{v[114578]=0;d=Q(260,e|0,n+1|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break E}i=n&15;A=x[(i<<1)+11024>>1];F:{G:{if(A>>>0<=d>>>0){v[114578]=0;i=w[i+11104|0];m=Q(260,e|0,i|0)|0;B=v[114578];v[114578]=0;if((B|0)==1){break l}d=m+(d-A<<i)|0;if((d|0)!=(n|0)){n=d&15;break F}v[114578]=0;d=Q(260,e|0,4)|0;i=v[114578];v[114578]=0;if((i|0)==1){break l}if((d|0)==15){v[114578]=0;i=Q(260,e|0,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break l}d=65535;if(!i){break G}Bb(g+40|0);break g}d=d+65520|0}if(d>>>0>65535){break F}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;i=f+j|0;m=i;H:{if(w[s|0]&2){u=d+u|0;d=u;break H}d=w[s+1|0]&2?d:d^32768}t[m|0]=d;t[i+1|0]=d>>>8;j=j+2|0}if(j>>>0>=y>>>0){p=p+1|0;if(p>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break B}f=(p<<3)+c|0;if(!go(o,f)){break D}y=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=0;f=xc(o,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))}if((w[h|0]|w[h+1|0]<<8)>>>0>p>>>0){continue}break j}break}c=V(76880)|0;break k}if(!c){break A}if(!go(o,c)){break A}u=xc(o,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));y=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);n=w[z|0]|w[z+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break A}v[114578]=0;f=Q(256,b|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}if(!f){break A}f=w[l|0]|w[l+1|0]<<8;v[114578]=0;f=W(261,b|0,g+1136|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}if(f>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break A}f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114578]=0;f=Q(258,b|0,f-e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break s}if(!f){break A}f=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114578]=0;U(259,g+24|0,b|0,f-e|0);f=v[114578];v[114578]=0;if((f|0)==1){break m}i=hm(g+40|0,g+24|0);Bb(g+24|0);f=0;j=0;p=0;if(!(w[h|0]|w[h+1|0]<<8)){break p}I:{J:{while(1){K:{v[114578]=0;d=Q(260,i|0,n+1|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break K}E=j+u|0;m=n&7;B=w[m+11056|0];L:{M:{if(B>>>0<=d>>>0){v[114578]=0;m=w[m+11064|0];e=Q(260,i|0,m|0)|0;A=v[114578];v[114578]=0;if((A|0)==1){break r}d=e+(d-B<<m)|0;if((d|0)!=(n|0)){n=d&7;break L}v[114578]=0;d=Q(260,i|0,3)|0;m=v[114578];v[114578]=0;if((m|0)==1){break r}if((d|0)==7){v[114578]=0;d=Q(260,i|0,1)|0;m=v[114578];v[114578]=0;if((m|0)==1){break r}if(d){break J}d=g+1391|0;break M}d=d+248|0}if(d>>>0>255){break L}d=(g+1136|0)+d|0}e=w[d|0];d=e+f|0;m=e;e=(w[s|0]|w[s+1|0]<<8)&2;t[E|0]=e?d:m;f=e?d:f;j=j+1|0}if(j>>>0>=y>>>0){p=p+1|0;if(p>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break I}e=(p<<3)+c|0;if(!go(o,e)){break C}y=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);u=xc(o,w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24));j=0}if((w[h|0]|w[h+1|0]<<8)>>>0>p>>>0){continue}break p}break}c=V(76880)|0;break q}Bb(g+40|0);break g}Bb(g+40|0);break g}Bb(g+40|0);break w}Bb(g+40|0);break w}Bb(g+40|0);break g}}}}av(q);break a}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break n}_(c|0)|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)==1){break o}}Bb(g+40|0);break g}c=P()|0;O()|0}Bb(g+40|0);break c}c=P()|0;O()|0;break c}c=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break h}_(c|0)|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)==1){break i}}Bb(g+40|0);break g}c=P()|0;O()|0}Bb(g+40|0);break c}av(q);D=D+1|0;if(D>>>0<(w[r|0]|w[r+1|0]<<8)>>>0){continue}break}}Vi(g+8|0,o);_u(g+16|0,g+8|0);b=fo(g+40|0,g+16|0,0);Wd(Tg(a)+12|0,b);Bb(b);break b}c=P()|0;O()|0}av(q);S(c|0);L()}F=1}jb=g+1424|0;return F|0}function XZ(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2489;p=Rd(l+136|0,l+144|0,l+96|0);b=v[p>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;r=Wb(l+96|0);o=tf(l+80|0);m=tf(l- -64|0);n=tf(l+48|0);q=tf(l+32|0);v[114578]=0;na(2501,c|0,d|0,l+120|0,l+116|0,l+112|0,r|0,o|0,m|0,n|0,l+28|0);b=v[114578];v[114578]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;k=0;e=0;while(1){b=e;b:{c:{d:{e:{if((k|0)==4){break e}v[114578]=0;c=Q(2461,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(t[(l+120|0)+k|0]){case 1:if((k|0)==3){break c}v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;c=W(2502,h|0,8192,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(c){v[114578]=0;U(2503,l+16|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[l+16>>2];v[114578]=0;R(112,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((k|0)==3){break c}}while(1){v[114578]=0;c=Q(2461,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break c}v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;c=W(2502,h|0,8192,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break c}v[114578]=0;U(2503,l+16|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[l+16>>2];v[114578]=0;R(112,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}if((Fb(m)|0)==(0-Fb(n)|0)){break c}k:{if(Fb(m)){if(Fb(n)){break k}}if(Fb(m)){v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[Tb(m)>>2]){v[114578]=0;T(2465,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:b;break b}t[g|0]=1;break c}v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)!=v[Tb(n)>>2]){break c}v[114578]=0;T(2465,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:b;break b}v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[Tb(m)>>2]){v[114578]=0;T(2465,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:b;break b}v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[Tb(n)>>2]){v[114578]=0;T(2465,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:b;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(b|k>>>0<2)){e=0;if(!((k|0)==2&w[l+123|0]!=0|u)){break b}}y=l,z=Ed(o),v[y+8>>2]=z;c=Md(l+16|0,l+8|0);l:{if(!k|w[(k+l|0)+119|0]>1){break l}m:{while(1){y=l,z=Vj(o),v[y+8>>2]=z;if(!Jb(c,l+8|0)){break m}d=v[v[c>>2]>>2];v[114578]=0;d=W(2502,h|0,8192,d|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if(!d){break m}_d(c);continue}break}break a}y=l,z=Ed(o),v[y+8>>2]=z;c=tt(c,l+8|0);if(Fb(q)>>>0>=c>>>0){y=l,z=Vj(q),v[y+8>>2]=z;c=mO(l+8|0,c);d=Vj(q);e=Ed(o);v[114578]=0;c=CE(c,d,e);d=v[114578];v[114578]=0;if((d|0)==1){break a}if(c){break l}}y=l,z=Ed(o),v[y>>2]=z;Md(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];n:{while(1){y=l,z=Vj(o),v[y>>2]=z;if(!Jb(l+8|0,l)){break n}v[114578]=0;c=Q(2461,a|0,l+552|0)|0;d=v[114578];v[114578]=0;o:{if((d|0)==1){break o}if(!c){break n}v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}if((c|0)!=v[v[l+8>>2]>>2]){break n}v[114578]=0;T(2465,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}_d(l+8|0);continue}break}break a}if(!s){break c}y=l,z=Vj(o),v[y>>2]=z;if(!Jb(l+8|0,l)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114578]=0;d=Q(2461,a|0,l+552|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}if(!d){break p}v[114578]=0;e=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;d=W(2502,h|0,2048,e|0)|0;x=v[114578];v[114578]=0;if((x|0)==1){break a}r:{if(d){d=v[j>>2];if((d|0)==v[l+548>>2]){v[114578]=0;U(2505,i|0,j|0,l+548|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[j>>2]}v[j>>2]=d+4;v[d>>2]=e;c=c+1|0;break r}if(!c|!Fb(r)|(e|0)!=v[l+112>>2]){break p}e=v[l+132>>2];if((e|0)==v[l+128>>2]){v[114578]=0;U(2496,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c;c=0}v[114578]=0;T(2465,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break a}d=v[p>>2];s:{if(!c){break s}e=v[l+132>>2];if((d|0)==(e|0)){break s}if(v[l+128>>2]==(e|0)){v[114578]=0;U(2496,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c}t:{if(v[l+28>>2]<1){break t}v[114578]=0;c=Q(2462,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}u:{if(!c){v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if((c|0)==v[l+116>>2]){break u}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2465,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}while(1){if(v[l+28>>2]<1){break t}v[114578]=0;c=Q(2462,a|0,l+552|0)|0;d=v[114578];v[114578]=0;v:{if((d|0)==1){break v}w:{if(!c){v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}v[114578]=0;c=W(2502,h|0,2048,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}if(c){break w}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114578]=0;U(2505,i|0,j|0,l+548|0);c=v[114578];v[114578]=0;if((c|0)==1){break v}}v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}d=v[j>>2];v[j>>2]=d+4;v[d>>2]=c;v[114578]=0;v[l+28>>2]=v[l+28>>2]-1;T(2465,a|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}e=b;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}x:{if(!b){break x}e=1;while(1){if(Fb(b)>>>0<=e>>>0){break x}v[114578]=0;c=Q(2462,a|0,l+552|0)|0;d=v[114578];v[114578]=0;y:{if((d|0)==1){break y}z:{if(!c){v[114578]=0;c=T(2463,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break y}if((c|0)==v[hj(b,e)>>2]){break z}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2465,a|0)|0;c=v[114578];v[114578]=0;e=e+1|0;if((c|0)!=1){continue}}break}break a}A:{if(v[p>>2]==v[l+132>>2]){break A}v[l+16>>2]=0;a=v[p>>2];v[114578]=0;Ee(r,a,v[l+132>>2],l+16|0);a=v[114578];v[114578]=0;if((a|0)!=1){if(!v[l+16>>2]){break A}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}Lc(q);Lc(n);Lc(m);Lc(o);yb(r);Gc(p);jb=l+560|0;return a|0}e=b}k=k+1|0;continue}}}a=P()|0;O()|0;Lc(q);Lc(n);Lc(m);Lc(o);yb(r);Gc(p);S(a|0);L()}function hla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=jb-1328|0;jb=d;Jc(b);e=jb-16|0;jb=e;g=d+752|0;tS(e+8|0,g);l=Hb(e+8|0);i=b;j=nc(i,ac(e,e+8|0));if((l|0)==(j|0)){$b(i,Hb(e+8|0))}jb=e+16|0;i=(l|0)==(j|0);if(!i){uS(g)}a:{b:{c:{d:{if(!i){break d}if(!yS(d+752|0)){break d}if(!Qb(b,id(xS(d+752|0),mb))){break d}if(!c){f=1;break d}o=Gt(d+744|0);q=1;e:{while(1){i=(f<<5)+a|0;e=i+480280|0;zg(e);g=(d+752|0)+(f<<4)|0;u[i+480284>>1]=((w[g+78|0]<<8&65280)>>>0)/255;Hk(d+480|0,1,g- -64|0);Ic(d+96|0,d+480|0);v[114578]=0;Q(380,i+480289|0,d+96|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}yb(d+96|0);f:{g:{switch(w[g+79|0]){case 0:k=f+1|0;break f;case 1:v[e>>2]=1024;k=h+1|0;break f;case 2:break g;default:break e}}v[e>>2]=1024;Pj(d+96|0,o,f);ge(d+96|0,1)}q=f>>>0<31;h=h+1|0;f=f+1|0;if((f|0)!=32){continue}break}Hd(a,33554432);u[a+480188>>1]=k&255;f=Ub(d+96|0,13326);Gb(a+1304436|0,f);yb(f);f=Ub(d+96|0,13340);Gb(a+1304448|0,f);yb(f);v[a+1304496>>2]=4;h:{if(w[d+831|0]){break h}i=1;while(1){if(w[((i<<4)+d|0)+831|0]!=1){break h}f=1;i=i+1|0;if((i|0)!=16){continue}break}while(1){h=((f<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-1025;f=f+1|0;if((f|0)!=16){continue}break}}yg(d+480|0,1,d+752|0);Ic(d+96|0,d+480|0);Gb(a+1304400|0,d+96|0);yb(d+96|0);v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+790|0]|w[d+791|0]<<8)<<4&16;v[a+480196>>2]=w[d+800|0];v[a+480204>>2]=B(w[d+801|0],1e4);k=0;A=a,C=Cd(w[d+802|0],0,64)<<2,v[A+480200>>2]=C;A=a,C=Cd(w[d+803|0],4,127),v[A+480228>>2]=C;f=w[d+788|0]|w[d+789|0]<<8;u[a+480190>>1]=0;u[a+480192>>1]=f;lu(b,d+480|0);eq(Vb(a+484360|0),d+480|0,w[d+784|0]|w[d+785|0]<<8,65535,255);r=c&1;if(r){_f(a+484344|0,w[d+786|0]|w[d+787|0]<<8)}if(w[d+786|0]|w[d+787|0]<<8){s=a+484344|0;while(1){f=hg(b);m=hg(b);ud(d+96|0,b,f-4|0);i:{if(!r){break i}v[114578]=0;f=W(404,s|0,k&65535,m|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){j:{if(!f){break i}n=0;l=Rh(d+16|0);if(!m){break i}while(1){k:{v[114578]=0;i=T(389,d+96|0)|0;f=v[114578];v[114578]=0;l:{m:{if((f|0)!=1){if(i){break m}n=n+1|0;break l}break j}f=l;p=i&31;if(p>>>0<x[a+480188>>1]){f=_b(s,k);v[114578]=0;f=W(472,f|0,n|0,p|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break j}}n:{if(!(i&32)){break n}v[114578]=0;R(473,d+32|0,d+96|0);e=v[114578];v[114578]=0;h=f;o:{p:{if((e|0)!=1){g=dd(d+32|0);e=w[d+32|0];t[f|0]=e;t[f+1|0]=w[g|0];if((e|0)!=160){break p}e=255;break o}break j}if((e|0)!=255){t[f|0]=(B(e>>>4|0,12)+(e&15)|0)+13;v[114578]=0;g=T(615,f|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){e=0;if(!g){break o}break n}break j}e=0}t[h|0]=e}h=i&192;q:{if(!h){break q}if((h|0)==192){v[114578]=0;R(595,d+32|0,d+96|0);h=v[114578];v[114578]=0;r:{s:{t:{if((h|0)!=1){g=dd(d+32|0);i=Bf(d+32|0);h=Sh(d+32|0);j=d+32|0;z=w[j|0];if((z|0)!=12){break t}v[114578]=0;t[d+8|0]=64;e=Q(393,g|0,d+8|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break j}t[f+4|0]=w[e|0];e=1;break s}break j}e=w[i|0];u:{if((e|0)==12){v[114578]=0;t[d+8|0]=64;h=Q(393,h|0,d+8|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){t[f+4|0]=w[h|0];e=1;break u}break j}if((z|0)==10){t[f+4|0]=(w[g|0]<<6>>>0)/255;e=2;break s}if((e|0)!=10){break r}t[f+4|0]=(w[h|0]<<6>>>0)/255;e=2}i=j;h=g}t[f+2|0]=e;e=w[i|0]}t[f+3|0]=e;t[f+5|0]=w[h|0];break q}v[114578]=0;R(473,d+32|0,d+96|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}h=dd(d+32|0);t[f+3|0]=w[d+32|0];t[f+5|0]=w[h|0]}if(w[f+3|0]){v[114578]=0;Z(616,f|0);h=v[114578];v[114578]=0;if((h|0)==1){break j}}Pj(d+32|0,o,p);if(!Cb(d+32|0)){break l}v[114578]=0;h=T(617,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break k}if(!h){break l}t[f+3|0]=0}if(n>>>0<m>>>0){continue}break i}break}}}f=P()|0;O()|0;Bb(d+96|0);break b}Bb(d+96|0);k=k+1|0;if(k>>>0<(w[d+786|0]|w[d+787|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break e}n=c&2;i=1;h=1;while(1){m=i&65535;f=uL(a,m,0);e=jb-16|0;jb=e;c=jb-16|0;jb=c;g=d+96|0;gc(e+8|0,g,384);jb=c+16|0;l=Hb(e+8|0);c=b;j=nc(c,ac(e,e+8|0));if((l|0)==(j|0)){$b(c,Hb(e+8|0))}jb=e+16|0;c=(l|0)==(j|0);if(!c){e=jb-16|0;jb=e;Rb(g,0,384);jb=e+16|0}if(!(!c|!f)){l=h&65535;c=jb-32|0;jb=c;e=d+96|0;yg(c,1,e);Ic(c+16|0,c);v[114578]=0;Q(371,f+492|0,c+16|0)|0;g=v[114578];v[114578]=0;v:{if((g|0)!=1){yb(c+16|0);w:{if(!(w[e+378|0]|w[e+379|0]<<8)){break w}v[c+16>>2]=120;v[c>>2]=116;if(!v[Lb(c+16|0,c)>>2]){break w}j=f+236|0;g=0;while(1){k=w[(e+g|0)+32|0];A=ed(j,g+12|0),C=k+l|0,u[A>>1]=C;v[c+16>>2]=120;v[c>>2]=116;g=g+1|0;if(g>>>0<y[Lb(c+16|0,c)>>2]){continue}break}}v[f>>2]=w[e+376|0]|w[e+377|0]<<8;Wz(e,f+48|0,0);Wz(e,f+68|0,1);Wz(e,f+88|0,2);e=w[f+100|0];if(e&1){t[f+100|0]=e|16}if(!(v[f>>2]|t[f+60|0]&1)){v[f>>2]=32767}jb=c+32|0;break v}break a}f=0;x:{if(!(w[d+474|0]|w[d+475|0]<<8)){break x}while(1){y:{Op(b,d+32|0);c=f+h|0;j=c&65535;z:{if((w[d+92|0]|w[d+93|0]<<8|(w[d+94|0]<<16|w[d+95|0]<<24))!=808538953|j>>>0>3999){break z}u[a+480190>>1]=c;c=jb-32|0;jb=c;k=B(j,104)+a|0;l=k+484380|0;g=l;Fd(g,0);e=d+32|0;Qi(c,1,e);Ic(c+16|0,c);v[114578]=0;Q(372,g+43|0,c+16|0)|0;o=v[114578];v[114578]=0;A:{if((o|0)!=1){yb(c+16|0);v[g>>2]=w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24);v[g+4>>2]=w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24);v[g+8>>2]=w[e+24|0]|w[e+25|0]<<8|(w[e+26|0]<<16|w[e+27|0]<<24);v[g+24>>2]=w[e+28|0]|w[e+29|0]<<8|(w[e+30|0]<<16|w[e+31|0]<<24);u[g+30>>1]=w[e+32|0]<<2;u[g+28>>1]=w[e+33|0];if(t[e+48|0]&1){u[g+34>>1]=x[g+34>>1]|2}if(w[e+48|0]&2){u[g+34>>1]=x[g+34>>1]|4}if(w[e+48|0]&4){u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}if(w[e+48|0]&8){u[g+34>>1]=x[g+34>>1]|32}jb=c+32|0;break A}break a}WB(d+16|0,k+484423|0);v[114578]=0;Q(371,((j<<5)+a|0)+946300|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break y}yb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break z}ud(d+16|0,b,w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24));B:{if(!n){break B}c=ad(d+8|0,u[k+484414>>1]&1?16:8,1,0,0);v[114578]=0;W(402,c|0,l|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break B}f=P()|0;O()|0;Bb(d+16|0);break b}Bb(d+16|0)}f=f+1|0;if(f>>>0<(w[d+474|0]|w[d+475|0]<<8)>>>0){continue}break x}break}f=P()|0;O()|0;yb(d+16|0);break b}h=(w[d+474|0]|w[d+475|0]<<8)+h|0}if(m>>>0>=x[a+480192>>1]){break e}i=i+1|0;continue}}f=!q}jb=d+1328|0;return f&1}f=P()|0;O()|0;yb(d+96|0)}S(f|0);L()}a=P()|0;O()|0;yb(c+16|0);S(a|0);L()}function lba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-208|0;jb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;ML(a+900380|0);LL(a+946300|0);f=OL(g+48|0);v[114578]=0;d=a+906300|0;U(1410,d|0,d+4e4|0,f|0);d=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((d|0)!=1){$m(f);f:{if(wq(b)){f=0;d=jb-16|0;jb=d;i=g+48|0;h=i;v[h>>2]=0;v[h+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1419,h+8|0,d+12|0,d+8|0)|0;h=v[114578];v[114578]=0;g:{if((h|0)!=1){jb=d+16|0;break g}break a}h:{i:{j:{if(c&16){break j}v[114578]=0;h=(c|0)!=0;e=W(1411,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=4;k:{if(e){break k}v[114578]=0;e=W(1412,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=5;if(e){break k}v[114578]=0;e=W(1413,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=6;if(e){break k}e=0;v[114578]=0;h=W(1414,i|0,b|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break i}d=3;if(!h){break j}}if(!c){f=1;break c}if(!nd(i)){pQ(b,pu(i,0)+12|0)}e=d}if(c&32){break c}d=77744;l:{m:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[114578]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){if(f){break l}d=d+12|0;if((d|0)==78200){break m}continue}break}d=V(71180)|0;break h}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break c}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}Rx(i);break f}d=V(71180)|0}a=O()|0;Rx(i);if((ga(71180)|0)!=(a|0)){break d}_(d|0)|0;v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)==1){d=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break d}V(0)|0;O()|0;Ab()}L()}Hd(a,0);v[a+1074300>>2]=19466496}d=0;while(1){b=(d<<5)+a|0;jg(b+480286|0,64);b=b+480284|0;if(x[b>>1]>=257){u[b>>1]=128}pn((B(d,896)+a|0)+1074984|0,a,d&65535);d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1304392|0;f=1;while(1){d=B(f&65535,104)+a|0;b=d+484380|0;n:{if(De(b)){Dy(b,a,0);break n}e=d+484414|0;h=x[e>>1];if(h&16384){break n}v[b>>2]=0;v[b+4>>2]=0;v[b+16>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;u[e>>1]=h&65505}b=d+484412|0;if(x[b>>1]>=65){u[b>>1]=64}o:{if(!(w[d+484415|0]&2)){break o}if(!qj(i)){break o}d=jb-16|0;jb=d;b=a;h=b+1304392|0;if(!rd(h)){j=d+8|0;e=Pe(532);b=v[b+24620>>2];v[114578]=0;k=Q(1420,e|0,b|0)|0;b=v[114578];v[114578]=0;p:{if((b|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=k;W(1424,j|0,b+12|0,b+8|0)|0;e=v[114578];v[114578]=0;q:{if((e|0)!=1){jb=b+16|0;break q}break a}break p}a=P()|0;O()|0;Xb(e);S(a|0);L()}HL(h,Nd(d+8|0));rs(d+8|0)}jb=d+16|0}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;b=0;while(1){e=v[(((d&65535)<<2)+a|0)+900380>>2];if(e){b=v[a+480180>>2];Cc(e,65536);Cc(e+4|0,64);Cc(e+8|0,256);jg(e+28|0,16384);Ue(e+30|0,128);Ue(e+31|0,17);if(w[e+16|0]>=4){t[e+16|0]=0}if(w[e+17|0]>=5){t[e+17|0]=0}if(w[e+18|0]>=3){t[e+18|0]=0}Ue(e+19|0,64);Ue(e+20|0,100);f=t[e+26|0];r:{if((f|0)<-32){t[e+26|0]=224;break r}if((f|0)<=32){break r}t[e+26|0]=32}Ue(e+23|0,64);Ue(e+24|0,64);Fy(e+48|0,64);Fy(e+68|0,64);Fy(e+88|0,(b|0)==4096?255:64);b=e+108|0;f=0;while(1){s:{if(w[fc(b,f)|0]){if(w[fc(b,f)|0]<121){break s}}l=fc(b,f),m=f+1|0,t[l|0]=m}f=f+1|0;if(f>>>0<128){continue}break}if(!Sn(w[e+14|0])){t[e+14|0]=5}b=d}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=b;b=a+480204|0;t:{if(y[a+480204>>2]<1e4){v[b>>2]=125e4;break t}Cc(b,65535e4)}b=v[a+480196>>2];if(!b){v[a+480196>>2]=6;b=6}f=v[a+480220>>2];d=v[a+480216>>2];if(f>>>0<d>>>0){v[a+480220>>2]=d;f=d}v[a+1074416>>2]=b;v[a+1074420>>2]=v[a+480204>>2];v[a+1074412>>2]=f;v[a+1074408>>2]=d;v[a+1074444>>2]=v[a+480200>>2];fy(a+1074376|0);v[a+1074440>>2]=-65536;v[a+1074392>>2]=-2;b=a+1074384|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074432|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;u[a+480276>>1]=0;To(a);pj(a+1304360|0,1);b=a+484360|0;l=g,m=bc(b),v[l+48>>2]=m;l=g,m=cc(b),v[l+32>>2]=m;if(!Jb(g+48|0,g+32|0)){break e}while(1){b=v[g+48>>2];eg(b,rj(b));d=x[b+28>>1];if(oc(b)>>>0<=d>>>0){Oe(b,0)}By(g+48|0);if(Jb(g+48|0,g+32|0)){continue}break}break e}d=P()|0;O()|0;$m(f);break d}b=jb-16|0;jb=b;f=g+48|0;d=f;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1421,d+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;u:{if((d|0)!=1){jb=b+16|0;break u}break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{if((c&12)==12){d=0;while(1){h=B(d,160)+a|0;e=h+906300|0;b=e;E:{if(!(w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24)|(w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24)))){break E}v[114578]=0;Q(1415,e|0,a|0)|0;b=v[114578];v[114578]=0;F:{if((b|0)!=1){b=v[e>>2];if(!b){break F}c=v[h+906448>>2];e=v[v[b>>2]+56>>2];v[114578]=0;R(e|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break E}}d=P()|0;O()|0;break v}c=bc(f);i=cc(f);b=jb-32|0;jb=b;v[b+16>>2]=i;v[b+24>>2]=c;v[b+8>>2]=e;G:{if(!Jb(b+24|0,b+16|0)){break G}while(1){c=v[v[b+24>>2]>>2];i=v[b+8>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[i+20|0]|w[i+21|0]<<8|(w[i+22|0]<<16|w[i+23|0]<<24))){i=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=v[b+8>>2];c=(i|0)==(w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24))}else{c=0}if(c){break G}_d(b+24|0);if(Jb(b+24|0,b+16|0)){continue}break}}jb=b+32|0;v[g+32>>2]=v[b+24>>2];l=g,m=cc(f),v[l+16>>2]=m;if(Jb(g+32|0,g+16|0)){break E}v[114578]=0;v[g+32>>2]=h+906316;R(1416,f|0,g+32|0);b=v[114578];v[114578]=0;if((b|0)==1){break w}v[114578]=0;b=Q(2,g+16|0,20526)|0;c=v[114578];v[114578]=0;if((c|0)==1){break D}c=EL(e);v[114578]=0;U(6,g|0,0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break C}v[114578]=0;U(3,g+32|0,b|0,g|0);c=v[114578];v[114578]=0;if((c|0)==1){break B}v[114578]=0;U(646,a|0,2,g+32|0);c=v[114578];v[114578]=0;if((c|0)==1){break A}yb(g+32|0);yb(g);yb(b)}d=d+1|0;if((d|0)!=250){continue}break}}b=v[a+1074368>>2];v[114578]=0;R(1417,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break x}b=v[a+480180>>2];H:{if(!b){break H}qs(a+8|0,Vo(a));if(!v[a+1074304>>2]){break H}v[114578]=0;Z(1418,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break x}}CL(f);f=(b|0)!=0;break b}d=P()|0;O()|0;break v}d=P()|0;O()|0;break y}d=P()|0;O()|0;break z}d=P()|0;O()|0;yb(g+32|0)}yb(g)}yb(b);break v}d=P()|0;O()|0;break v}d=P()|0;O()|0}CL(f)}S(d|0);L()}Rx(i)}jb=g+208|0;return f|0}V(0)|0;O()|0;Ab();L()}function Cs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;v[h+28>>2]=c;a:{if((c|0)<1){break a}k=v[b+104>>2];i=v[b+656>>2];if(!(!i|v[a+480180>>2]!=16777216)){n=v[i+44>>2]!=0}b:{if(!(!i|(c|0)>128)){j=x[ed(i+236|0,c-1|0)>>1];c:{if((j-1&65535)>>>0<=3998){k=(B(j,104)+a|0)+484380|0;break c}Eb(h+16|0,a+1074308|0,43);if(!Cb(h+16|0)){break c}if(!nj(b)){break a}}j=w[fc(i+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=j;break b}j=c}if((j|0)>=121){d:{if(!(v[a+480180>>2]&16777248?(j|0)!=255:0)){cn(a,b);if(d){break d}Eb(h+16|0,a+1074308|0,100);if(!Cb(h+16|0)|!(w[a+480208|0]&4)|!w[b+811|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}Eb(h+16|0,a+1074308|0,50);if(Cb(h+16|0)){break g}}v[b+688>>2]=0}Eb(h+16|0,a+1074308|0,50);if(Cb(h+16|0)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Eb(h+16|0,a+1074308|0,20);if(!Cb(h+16|0)){break a}t[b+819|0]=0;t[b+824|0]=0;break a}h:{i:{j:{if(n){if(d){l=w[b+819|0];if(l){break j}}v[b+708>>2]=0}if(d){break i}if(!(!k|!(v[a+480180>>2]&1048588))){v[b+772>>2]=t[k+36|0];v[b+768>>2]=t[k+37|0]}if(k){Eb(h+16|0,a+1074308|0,24);j=0;m=1;if(!Cb(h+16|0)){break h}v[b+704>>2]=v[k+24>>2];break h}j=0;break h}m=v[i+44>>2];u[h>>1]=l;u[h+14>>1]=j;v[h+16>>2]=0;j=(v[h+16>>2]+B(u[m+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+876>>2]|0;v[b+708>>2]=j;v[b+876>>2]=0-j}m=(k|0)!=0;j=1;if(Kh(b)){break h}j=a+1074308|0;Eb(h+16|0,j,54);if(Cb(h+16|0)){v[b+700>>2]=0;break a}Eb(h+16|0,j,39);j=(Cb(h+16|0)^-1)&d}k:{if(Lp(a)){v[h+28>>2]=v[h+28>>2]+v[b+772>>2];ce(h+28|0,12,131);break k}fQ(h+28|0)}l=a+1074308|0;Eb(h+16|0,l,34);d=b;l:{if(Cb(h+16|0)){c=Rp(c);break l}c=v[h+28>>2]}t[d+819|0]=c;t[b+872|0]=w[b+872|0]|8;if(!(v[a+480180>>2]&16777250?0:j)){t[b+825|0]=0}d=$f(a,v[h+28>>2],v[b+768>>2],v[b+704>>2]);t[b+851|0]=0;Eb(h+16|0,l,48);if(Cb(h+16|0)){AM(a,b,i,k)}m:{if(e^1|j){break m}v[b+788>>2]=0;v[b+792>>2]=0;if(!i){break m}Eb(h+16|0,l,29);if(Cb(h+16|0)){t[b+820|0]=w[i+16|0]}if(!(w[i+60|0]&8)){xi(b+724|0)}if(!(w[i+80|0]&8)){xi(b+736|0)}if(!(w[i+100|0]&8)){xi(b+748|0)}if(w[i+20|0]){c=zs(bn(a));o=w[i+20|0];Eb(h+16|0,l,28);p=((B(c,o)<<16>>16)/64<<16)+65536>>16;c=b;n:{if(Cb(h+16|0)){o=v[b+764>>2];break n}o=(v[b+688>>2]+1|0)/2|0}u[c+788>>1]=(B(o,p)|0)/199}o:{if(!w[i+19|0]){break o}q=b,r=(B(zs(bn(a)),w[i+19|0])<<16>>16)/32|0,u[q+790>>1]=r;Eb(h+16|0,l,28);if(Cb(h+16|0)|x[b+796>>1]){break o}u[b+796>>1]=x[b+692>>1]+1}c=w[i+23|0];if(c){o=zs(bn(a));p=w[b+857|0];t[b+818|0]=p+1;u[b+792>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[i+24|0];if(!c){break m}o=zs(bn(a));p=w[b+858|0];t[b+817|0]=p+1;u[b+794>>1]=(B(p,(B(c,o+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}m=0;p:{q:{if(!d){break q}r:{s:{t:{if(j){u:{if(!v[b+700>>2]){v[b+700>>2]=d;if(!n){break u}break t}if(n){break t}}v[b+708>>2]=d;break t}v[b+700>>2]=d;if(n){break s}Eb(h+16|0,l,69);if(Cb(h+16|0)){break s}Eb(h,l,46);if(Cb(h)|v[a+480180>>2]==1){break s}v[b+708>>2]=d;break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=k;c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;v:{w:{if(!(v[a+480208>>2]&2097152)){Eb(h+16|0,l,96);if(!Cb(h+16|0)){break w}}if(w[b+811|0]){break w}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Lb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break v}v[b+660>>2]=0}c=x[k+34>>1];d=c&1023;n=d|v[b+88>>2]&-525056;v[b+88>>2]=n;x:{if(c&8){v[b+80>>2]=v[k+12>>2];c=v[k+16>>2];v[b+88>>2]=(d&16?n|4:n&-524295)|2;v[b+84>>2]=c;if(c>>>0>=y[b+76>>2]){break x}v[b+76>>2]=c;break x}if(!(d&2)){break x}v[b+80>>2]=v[k+4>>2];c=v[k+8>>2];v[b+84>>2]=c;if(c>>>0>=y[b+76>>2]){break x}v[b+76>>2]=c}Eb(h+16|0,l,83);if(!(!Cb(h+16|0)|v[b+80>>2])){c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];if(c&128){v[b+88>>2]=c|128;v[b+4>>2]=v[b+76>>2]-1}y:{if(w[b+842|0]>3){break y}Eb(h+16|0,l,21);if(!(Cb(h+16|0)|!(v[a+480180>>2]&16777248)|v[a+480208>>2]&4)){t[b+839|0]=16;break y}if(v[a+480180>>2]==16){t[b+839|0]=32;break y}if(v[a+480180>>2]&67633152){break y}t[b+839|0]=0}Eb(h+16|0,l,21);if(Cb(h+16|0)|w[b+845|0]>3){break r}t[b+840|0]=0}d=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){c=d;d=v[b+80>>2];v[b>>2]=c;v[b+4>>2]=d}if(!j){break q}m=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}if(!(w[a+480208|0]&8)|!w[b+811|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){yl(b);Eb(h+16|0,l,21);if(!Cb(h+16|0)){t[b+838|0]=0;v[b+780>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(w[b+811|0]|(!m|!(w[a+480208|0]&8)))){m=1;break p}if(w[b+811|0]?0:v[a+480180>>2]&1048580){break p}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}Eb(h+16|0,l,40);z:{A:{B:{C:{if(Cb(h+16|0)){if(m){if(w[b+811|0]?w[a+480208|0]&8:0){break B}v[b+88>>2]=v[b+88>>2]&-4194305;break A}c=v[b+88>>2]&-4196353;break C}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;k=1;if(m){break z}}u[b+862>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Eb(h+16|0,l,23);D:{if(Cb(h+16|0)){break D}Eb(h,l,22);if(Cb(h)){break D}Eb(h+16|0,l,52);if(Cb(h+16|0)){break D}Eb(h,l,71);if(Cb(h)){break D}t[b+859|0]=0;u[b+798>>1]=0}if(e){t[b+838|0]=0;v[b+780>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;E:{if(i){F:{G:{if(!YB(i)){if(zu(i)){break G}c=!(c>>>13|0);if(c){break F}break E}q=b,r=ZB(i),t[q+858|0]=r;if(!zu(i)){break F}}q=b,r=_B(i),t[q+857|0]=r}c=1;d=w[i+25|0];if((d|0)==255){break E}t[b+865|0]=d;break E}v[b+788>>2]=0;v[b+792>>2]=0;c=!c}H:{if(w[b+857|0]>=127){Eb(h+16|0,l,36);if(!Cb(h+16|0)){break H}}k=0;if(!c){break z}if((fp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break z}c=a+1304392|0;if(!rd(c)|(g|0)==65535){break z}lp(v[c>>2],g,w[b+857|0]>>>1|0,1);break z}k=0;break z}v[b+88>>2]=v[b+88>>2]&-4196353}k=1}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}I:{J:{if(w[a+24618|0]&16?c&1024:0){break J}a=v[b+104>>2];if(f?0:!(!a|!(w[a+35|0]&4))){break J}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break I}}if(f){break I}v[b+700>>2]=0}if(k){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}jb=h+32|0}function c_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2489;p=Rd(l+136|0,l+144|0,l+104|0);b=v[p>>2];v[l+132>>2]=b;v[l+128>>2]=b+400;r=Wb(l+104|0);o=Wb(l+88|0);m=Wb(l+72|0);n=Wb(l+56|0);q=Wb(l+40|0);v[114578]=0;na(2492,c|0,d|0,l+120|0,l+119|0,l+118|0,r|0,o|0,m|0,n|0,l+36|0);b=v[114578];v[114578]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;b=0;e=0;while(1){k=e;b:{c:{d:{e:{if((b|0)==4){break e}v[114578]=0;c=Q(2429,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break e}c=0;f:{g:{h:{i:{j:{switch(t[(l+120|0)+b|0]){case 1:if((b|0)==3){break c}v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(Kg(h,8192,c)){v[114578]=0;U(2493,l+24|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=t[l+24|0];v[114578]=0;R(110,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((b|0)==3){break c}}while(1){v[114578]=0;c=Q(2429,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!c){break c}v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(!Kg(h,8192,c)){break c}v[114578]=0;U(2493,l+24|0,a|0,0);c=v[114578];v[114578]=0;if((c|0)!=1){c=t[l+24|0];v[114578]=0;R(110,q|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}if((Fb(m)|0)==(0-Fb(n)|0)){break c}k:{if(Fb(m)){if(Fb(n)){break k}}if(Fb(m)){v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(m,0)|0]==(c&255)){v[114578]=0;T(2433,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:k;break b}t[g|0]=1;break c}v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(n,0)|0]!=(c&255)){break c}v[114578]=0;T(2433,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:k;break b}v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(m,0)|0]==(c&255)){v[114578]=0;T(2433,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}e=Fb(m)>>>0>1?m:k;break b}v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[kc(n,0)|0]==(c&255)){v[114578]=0;T(2433,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[g|0]=1;e=Fb(n)>>>0>1?n:k;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(k|b>>>0<2)){e=0;if(!((b|0)==2&w[l+123|0]!=0|u)){break b}}x=l,y=Ed(o),v[x+16>>2]=y;c=Md(l+24|0,l+16|0);l:{if(!b|w[(b+l|0)+119|0]>1){break l}while(1){m:{x=l,y=sf(o),v[x+16>>2]=y;if(!Jb(c,l+16|0)){break m}if(!Kg(h,8192,t[v[c>>2]])){break m}qg(c);continue}break}x=l,y=Ed(o),v[x+16>>2]=y;c=$l(c,l+16|0);if(Fb(q)>>>0>=c>>>0){x=l,y=sf(q),v[x+16>>2]=y;c=qz(l+16|0,c);d=sf(q);e=Ed(o);v[114578]=0;c=IE(c,d,e);d=v[114578];v[114578]=0;if((d|0)==1){break a}if(c){break l}}x=l,y=Ed(o),v[x+8>>2]=y;Md(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];n:{while(1){x=l,y=sf(o),v[x+8>>2]=y;if(!Jb(l+16|0,l+8|0)){break n}v[114578]=0;c=Q(2429,a|0,l+552|0)|0;d=v[114578];v[114578]=0;o:{if((d|0)==1){break o}if(!c){break n}v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}if(w[v[l+16>>2]]!=(c&255)){break n}v[114578]=0;T(2433,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}qg(l+16|0);continue}break}break a}if(!s){break c}x=l,y=sf(o),v[x+8>>2]=y;if(!Jb(l+16|0,l+8|0)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114578]=0;d=Q(2429,a|0,l+552|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}if(!d){break p}v[114578]=0;e=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}r:{if(Kg(h,2048,e)){d=v[j>>2];if((d|0)==v[l+548>>2]){v[114578]=0;U(2495,i|0,j|0,l+548|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[j>>2]}v[j>>2]=d+1;t[d|0]=e;c=c+1|0;break r}if(!c|!Fb(r)|w[l+118|0]!=(e&255)){break p}e=v[l+132>>2];if((e|0)==v[l+128>>2]){v[114578]=0;U(2496,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c;c=0}v[114578]=0;T(2433,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break a}d=v[p>>2];s:{if(!c){break s}e=v[l+132>>2];if((d|0)==(e|0)){break s}if(v[l+128>>2]==(e|0)){v[114578]=0;U(2496,p|0,l+132|0,l+128|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}e=v[l+132>>2]}v[l+132>>2]=e+4;v[e>>2]=c}t:{if(v[l+36>>2]<1){break t}v[114578]=0;c=Q(2430,a|0,l+552|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}u:{if(!c){v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}if(w[l+119|0]==(c&255)){break u}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2433,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}while(1){if(v[l+36>>2]<1){break t}v[114578]=0;c=Q(2430,a|0,l+552|0)|0;d=v[114578];v[114578]=0;v:{if((d|0)==1){break v}w:{if(!c){v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}if(Kg(h,2048,c)){break w}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114578]=0;U(2495,i|0,j|0,l+548|0);c=v[114578];v[114578]=0;if((c|0)==1){break v}}v[114578]=0;c=T(2431,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break v}d=v[j>>2];v[j>>2]=d+1;t[d|0]=c;v[114578]=0;v[l+36>>2]=v[l+36>>2]-1;T(2433,a|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}e=k;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}x:{if(!k){break x}e=1;while(1){if(Fb(k)>>>0<=e>>>0){break x}v[114578]=0;b=Q(2430,a|0,l+552|0)|0;c=v[114578];v[114578]=0;y:{if((c|0)==1){break y}z:{if(!b){v[114578]=0;b=T(2431,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break y}if(w[kc(k,e)|0]==(b&255)){break z}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114578]=0;T(2433,a|0)|0;b=v[114578];v[114578]=0;e=e+1|0;if((b|0)!=1){continue}}break}break a}A:{if(v[p>>2]==v[l+132>>2]){break A}v[l+24>>2]=0;a=v[p>>2];v[114578]=0;Ee(r,a,v[l+132>>2],l+24|0);a=v[114578];v[114578]=0;if((a|0)!=1){if(!v[l+24>>2]){break A}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}yb(q);yb(n);yb(m);yb(o);yb(r);Gc(p);jb=l+560|0;return a|0}e=k}b=b+1|0;continue}}}a=P()|0;O()|0;yb(q);yb(n);yb(m);yb(o);yb(r);Gc(p);S(a|0);L()}function d7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=C(0),A=C(0),B=0,D=0,E=0,F=C(0),G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=C(0),S=0,T=0,U=0,V=0,W=0,X=C(0),Y=0,Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}j=z[a+4268>>2];OI(a);if(j==z[a+4268>>2]){break a}Zw(a)}b:{if(!w[a+5045|0]){break b}p=a+44|0;if(!rh(p)){break b}q=Pd(p,0);x=Pd(p,1);m=jd(p,0);n=jd(p,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[m>>2]=z[a+5036>>2];z[n>>2]=z[a+5040>>2];t[a+5044|0]=0;x=x+4|0;q=q+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}r=k;d:{if(!r){break d}W=a+4960|0;G=a+4648|0;H=a+4672|0;S=a+4936|0;I=a+4696|0;J=a+4720|0;K=a+4744|0;L=a+4768|0;T=a+4840|0;E=a+4504|0;M=a+4528|0;U=a+4912|0;N=a+4552|0;O=a+4576|0;P=a+4600|0;Q=a+4624|0;V=a+4816|0;s=a+4888|0;u=a+4864|0;while(1){j=z[q>>2];j=C(C(C(z[a+5008>>2]-j)*z[a+4276>>2])+j);z[a+5008>>2]=j;_=Dc(u,v[a+4880>>2]),$=j,z[_>>2]=$;j=z[x>>2];j=C(C(C(z[a+5012>>2]-j)*z[a+4276>>2])+j);z[a+5012>>2]=j;_=Dc(s,v[a+4904>>2]),$=j,z[_>>2]=$;j=eh(u,v[a+4356>>2]);f=eh(u,v[a+4360>>2]);e=eh(u,v[a+4364>>2]);g=eh(u,v[a+4368>>2]);j=C(C(C(j*C(.6800000071525574))+C(C(e+eh(u,v[a+4372>>2]))*C(-.6200000047683716)))+C(C(g+f)*C(-.5)));if(t[a+4264|0]&1){f=j;j=C(z[Dc(V,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));_=Dc(V,v[a+4832>>2]),$=C(f-C(j*C(.6180340051651001))),z[_>>2]=$}X=z[a+4280>>2];_=a,$=C(eh(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;f=C(eh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];g=z[a+4980>>2];i=z[Dc(Q,v[a+4644>>2])>>2];y=z[a+4444>>2];g=C(z[Dc(Q,v[a+4644>>2])>>2]+C(y*C(g-i)));z[a+4980>>2]=g;i=z[a+4272>>2];h=C(e*C(-.7070000171661377));l=C(f*C(.7070000171661377));e=C(h+l);f=C(C(i*e)+C(z[a+4440>>2]*g));_=Dc(Q,v[a+4640>>2]),$=C(e-C(i*f)),z[_>>2]=$;e=z[a+4976>>2];g=z[Dc(P,v[a+4620>>2])>>2];i=z[a+4436>>2];e=C(z[Dc(P,v[a+4620>>2])>>2]+C(i*C(e-g)));z[a+4976>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4432>>2]*e));_=Dc(P,v[a+4616>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=z[a+4972>>2];g=z[Dc(O,v[a+4596>>2])>>2];i=z[a+4428>>2];f=C(z[Dc(O,v[a+4596>>2])>>2]+C(i*C(f-g)));z[a+4972>>2]=f;g=z[a+4272>>2];f=C(C(g*e)+C(z[a+4424>>2]*f));_=Dc(O,v[a+4592>>2]),$=C(e-C(g*f)),z[_>>2]=$;e=z[a+4968>>2];g=z[Dc(N,v[a+4572>>2])>>2];i=z[a+4420>>2];e=C(z[Dc(N,v[a+4572>>2])>>2]+C(i*C(e-g)));z[a+4968>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4416>>2]*e));_=Dc(N,v[a+4568>>2]),$=C(f-C(g*e)),z[_>>2]=$;y=C(C(C(f*C(.3499999940395355))+y)+C(e*C(-.3799999952316284)))}_=Dc(U,v[a+4928>>2]),$=e,z[_>>2]=$;k=Dc(U,v[a+4932>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-f)*z[a+4500>>2])+f;f=z[a+4964>>2];e=z[Dc(M,v[a+4548>>2])>>2];g=z[a+4412>>2];f=C(z[Dc(M,v[a+4548>>2])>>2]+C(g*C(f-e)));z[a+4964>>2]=f;g=C(z[a+4408>>2]*f);f=z[a+4272>>2];e=z[a+5028>>2];g=C(g+C(f*e));_=Dc(M,v[a+4544>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4960>>2];e=z[Dc(E,v[a+4524>>2])>>2];i=z[a+4404>>2];f=C(z[Dc(E,v[a+4524>>2])>>2]+C(i*C(f-e)));z[a+4960>>2]=f;e=z[a+4272>>2];R=C(C(e*g)+C(z[a+4400>>2]*f));_=Dc(E,v[a+4520>>2]),$=C(g-C(e*R)),z[_>>2]=$;z[a+5020>>2]=R;f=eh(s,v[a+4380>>2]);e=eh(s,v[a+4384>>2]);i=eh(s,v[a+4388>>2]);A=eh(s,v[a+4392>>2]);f=C(C(C(f*C(.7070000171661377))+C(C(i+eh(s,v[a+4396>>2]))*C(-.5)))+C(C(A+e)*C(-.6000000238418579)));if(t[a+4264|0]&1){e=f;f=C(z[Dc(T,v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Dc(T,v[a+4856>>2]),$=C(e-C(f*C(.6180340051651001))),z[_>>2]=$}A=z[a+4280>>2];e=z[a+5004>>2];i=z[Dc(L,v[a+4788>>2])>>2];F=z[a+4492>>2];e=C(z[Dc(L,v[a+4788>>2])>>2]+C(F*C(e-i)));z[a+5004>>2]=e;F=z[a+4272>>2];h=C(h-l);i=C(C(F*h)+C(z[a+4488>>2]*e));_=Dc(L,v[a+4784>>2]),$=C(h-C(F*i)),z[_>>2]=$;e=z[a+5e3>>2];h=z[Dc(K,v[a+4764>>2])>>2];l=z[a+4484>>2];e=C(z[Dc(K,v[a+4764>>2])>>2]+C(l*C(e-h)));z[a+5e3>>2]=e;h=z[a+4272>>2];e=C(C(h*i)+C(z[a+4480>>2]*e));_=Dc(K,v[a+4760>>2]),$=C(i-C(h*e)),z[_>>2]=$;i=C(C(e*C(-.20000000298023224))+C(C(g*C(.3799999952316284))+C(i*C(-.15000000596046448))));if(t[a+4264|0]&1){g=z[a+4996>>2];h=z[Dc(J,v[a+4740>>2])>>2];l=z[a+4476>>2];g=C(z[Dc(J,v[a+4740>>2])>>2]+C(l*C(g-h)));z[a+4996>>2]=g;h=z[a+4272>>2];g=C(C(h*e)+C(z[a+4472>>2]*g));_=Dc(J,v[a+4736>>2]),$=C(e-C(h*g)),z[_>>2]=$;e=z[a+4992>>2];h=z[Dc(I,v[a+4716>>2])>>2];l=z[a+4468>>2];e=C(z[Dc(I,v[a+4716>>2])>>2]+C(l*C(e-h)));z[a+4992>>2]=e;h=z[a+4272>>2];e=C(C(h*g)+C(z[a+4464>>2]*e));_=Dc(I,v[a+4712>>2]),$=C(g-C(h*e)),z[_>>2]=$;i=C(C(C(g*C(.3499999940395355))+i)+C(e*C(-.3799999952316284)))}Y=x+4|0;Z=q+4|0;g=C(A*f);_=Dc(S,v[a+4952>>2]),$=e,z[_>>2]=$;k=Dc(S,v[a+4956>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-f)*z[a+4500>>2])+f;f=z[a+4988>>2];e=z[Dc(H,v[a+4692>>2])>>2];h=z[a+4460>>2];f=C(z[Dc(H,v[a+4692>>2])>>2]+C(h*C(f-e)));z[a+4988>>2]=f;e=z[a+4272>>2];h=z[a+5032>>2];f=C(C(z[a+4456>>2]*f)+C(e*h));_=Dc(H,v[a+4688>>2]),$=C(h-C(e*f)),z[_>>2]=$;h=z[a+4284>>2];e=z[a+4984>>2];l=z[Dc(G,v[a+4668>>2])>>2];A=z[a+4452>>2];e=C(z[Dc(G,v[a+4668>>2])>>2]+C(A*C(e-l)));z[a+4984>>2]=e;l=z[a+4272>>2];e=C(C(l*f)+C(z[a+4448>>2]*e));_=Dc(G,v[a+4664>>2]),$=C(f-C(l*e)),z[_>>2]=$;z[a+5024>>2]=e;e=C(e*C(.3799999952316284));j=C(C(h*C(C(C(f-R)*C(.3799999952316284))+y))+C(X*j));f=z[a+4288>>2];k=E;while(1){o=k;B=v[o+16>>2];D=B-1|0;v[o+16>>2]=D;if((B|0)<=0){v[o+16>>2]=D+v[o+12>>2]}D=v[o+20>>2];B=D-1|0;v[o+20>>2]=B;if((D|0)<=0){v[o+20>>2]=B+v[o+12>>2]}k=k+24|0;if((W|0)!=(k|0)){continue}break}f=C(C(f*C(i-e))+g);e:{f:{if(w[a+4264|0]&2){q=Z;k=Y;break f}z[m>>2]=C(z[a+5036>>2]+j)*C(.5);z[n>>2]=C(z[a+5040>>2]+f)*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=j;if((r|0)==1){break e}r=r-1|0;q=q+8|0;n=n+4|0;m=m+4|0;k=x+8|0}x=k;z[m>>2]=j;z[n>>2]=f;n=n+4|0;m=m+4|0;r=r-1|0;if(r){continue}break d}break}t[a+5044|0]=1}pi(a,b,c,jd(p,0),jd(p,1),d)}}function gV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-160|0;jb=d;Jc(b);Gq(a);a:{if(!Ju(b,d+120|0)){break a}if(!OK(d+120|0)){break a}e=b;f=d+120|0;m=$e(11555);if(m){p=v[e+8>>2];if(Pc(e,w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24))){b:{if(!(w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24))){break b}while(1){if(!Qb(e,4)){break b}c:{if((w[f+4|0]|w[f+5|0]<<8)>>>0>=64){if((Ih(e)|0)<1){break c}}h=Gd(e);d:{if(h){g=1;j=0;while(1){q=Io(h<<24>>24);n=j>>>0>=m>>>0;i=n&g;h=i;e:{if(n){break e}h=i;if(!(g&1)){break e}h=w[j+11555|0]==(q&255)}g=h;j=j+1|0;h=Gd(e);if(h){continue}break}h=(j|0)==(m|0)&g;break d}h=!m}$b(e,4);l=h?1:l}o=o+1|0;if(o>>>0<(w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24))>>>0){continue}break}}j=l&1}Pc(e,p)}if(!j){break a}if(!c){k=1;break a}h=jb-16|0;jb=h;e=gh(d+104|0);i=d+120|0;c=i+16|0;g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114578]=0;c=b;g=Q(256,c|0,g|0)|0;f=v[114578];v[114578]=0;f:{g:{h:{i:{if((f|0)!=1){if(!g){break f}g=i+12|0;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[114578]=0;v[h>>2]=g;g=T(332,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break h}v[114578]=0;v[h+12>>2]=(g>>>0)/5;g=Q(333,h|0,h+12|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break h}g=v[g>>2];l=0;v[114578]=0;R(1533,e|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break i}if(!g){break f}i=i+4|0;j:{while(1){v[114578]=0;f=Q(258,c|0,5)|0;j=v[114578];v[114578]=0;k:{if((j|0)!=1){if(f){break k}break f}a=P()|0;O()|0;break g}f=w[i|0]|w[i+1|0]<<8;v[114578]=0;U(1534,h|0,c|0,f|0);f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;R(1535,e|0,h|0);f=v[114578];v[114578]=0;if((f|0)==1){break j}yb(h);l=l+1|0;if((g|0)!=(l|0)){continue}break f}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(h);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}ld(e);S(a|0);L()}jb=h+16|0;c=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);v[114578]=0;c=Q(256,b|0,c|0)|0;h=v[114578];v[114578]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((h|0)!=1){if(!c){break l}c=jb-16|0;jb=c;h=d+88|0;e=h;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(347,e+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;t:{if((e|0)!=1){jb=c+16|0;break t}V(0)|0;O()|0;Ab();L()}c=w[d+148|0]|w[d+149|0]<<8|(w[d+150|0]<<16|w[d+151|0]<<24);v[114578]=0;v[d+24>>2]=c;c=T(332,b|0)|0;e=v[114578];v[114578]=0;u:{if((e|0)==1){break u}v[114578]=0;v[d+56>>2]=c>>>2;c=Q(333,d+24|0,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break u}e=v[c>>2];v[114578]=0;R(334,h|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break r}c=d+120|4;if(!e){break s}while(1){v[114578]=0;g=Q(258,b|0,4)|0;i=v[114578];v[114578]=0;v:{if((i|0)!=1){if(g){break v}break s}b=P()|0;O()|0;break p}g=w[c|0]|w[c+1|0]<<8;v[114578]=0;g=Q(335,b|0,g|0)|0;i=v[114578];v[114578]=0;w:{if((i|0)!=1){v[d+24>>2]=g;if(wc(d+104|0)>>>0<=g>>>0){break w}v[114578]=0;R(336,h|0,d+24|0);g=v[114578];v[114578]=0;if((g|0)!=1){break w}}b=P()|0;O()|0;break p}k=k+1|0;if((e|0)!=(k|0)){continue}break}break s}b=P()|0;O()|0;break p}b=P()|0;O()|0;break o}e=w[d+144|0]|w[d+145|0]<<8|(w[d+146|0]<<16|w[d+147|0]<<24);k=0;v[114578]=0;e=Q(256,b|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break q}}b=P()|0;O()|0;break p}if(!e){break m}if(!(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))){break n}g=d+36|0;x:{y:{z:{A:{B:{C:{while(1){v[114578]=0;e=Q(258,b|0,4)|0;i=v[114578];v[114578]=0;D:{if((i|0)!=1){if(e){break D}break n}b=P()|0;O()|0;break p}e=w[c|0]|w[c+1|0]<<8;v[114578]=0;ma(337,b|0,d+84|0,d+80|0,d+76|0,d+72|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break A}E:{F:{if(v[d+76>>2]<1){break F}e=v[d+84>>2];if((e|0)>-1){break F}e=e^-1;v[d+84>>2]=e;if(Kb(h)>>>0<=e>>>0){break F}if(!Vd(sd(d+104|0,v[Pb(h,v[d+84>>2])>>2]),11555)){break F}v[114578]=0;X(338,d+56|0,b|0,v[d+80>>2],v[d+76>>2]);e=v[114578];v[114578]=0;if((e|0)==1){break z}v[114578]=0;e=T(339,d+56|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break y}if(e){if((w[c|0]|w[c+1|0]<<8)>>>0<=39){v[114578]=0;Q(340,d+56|0,8)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}}if((w[c|0]|w[c+1|0]<<8)>>>0<=59){v[114578]=0;Q(340,d+56|0,16)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}}v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}G:{if((w[c|0]|w[c+1|0]<<8)>>>0>=120){v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;Q(340,d+56|0,8)|0;break G}if((w[c|0]|w[c+1|0]<<8)>>>0>=100){v[114578]=0;Q(340,d+56|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;Q(340,d+56|0,4)|0;break G}if((w[c|0]|w[c+1|0]<<8)>>>0>=62){v[114578]=0;T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;Q(340,d+56|0,4)|0;break G}v[114578]=0;T(341,d+56|0)|0}e=v[114578];v[114578]=0;if((e|0)==1){break y}v[114578]=0;i=T(341,d+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break B}v[114578]=0;e=T(342,d+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break E}f=v[d+72>>2];H:{if((f|0)<0){break H}if(wc(d+104|0)>>>0<=f>>>0){break H}f=sd(d+104|0,v[d+72>>2]);v[114578]=0;U(13,d+8|0,2,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break C}Gb(d+24|0,d+8|0);yb(d+8|0)}v[114578]=0;U(343,d+8|0,d+56|0,i|0);i=v[114578];v[114578]=0;if((i|0)==1){break C}Wd(g,d+8|0);Bb(d+8|0);v[114578]=0;R(344,a|0,e|0);i=v[114578];v[114578]=0;if((i|0)==1){break C}Uu(e)}Bb(d+56|0)}k=k+1|0;if(k>>>0<(w[d+140|0]|w[d+141|0]<<8|(w[d+142|0]<<16|w[d+143|0]<<24))>>>0){continue}break n}break}b=P()|0;O()|0;break x}b=P()|0;O()|0;Uu(e);break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break p}b=P()|0;O()|0;break p}b=P()|0;O()|0}Bb(d+56|0)}qC(h)}ld(d+104|0);S(b|0);L()}k=nd(a)^1}qC(h)}ld(d+104|0)}jb=d+160|0;return k|0}function dp(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;h=jb-16|0;jb=h;i=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:i;r=v[b+764>>2];g=w[b+824|0];a:{if(!g){Eb(h+8|0,a+1074308|0,11);if(Cb(h+8|0)){break a}}b:{c:{if(!i){break c}if(!be(g)){break c}d:{j=i+236|0;g=g-1|0;if(x[ed(j,g)>>1]){break d}Eb(h+8|0,a+1074308|0,43);if(!Cb(h+8|0)){break d}if(zi(i)){break d}v[b+656>>2]=i;break a}if(w[fc(i+108|0,g)|0]>120){break a}g=x[ed(j,g)>>1];k=(g-1&65535)>>>0<3999?(B(g,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(g>>>0>250){break a}Eb(h+8|0,a+1074308|0,43);if(Cb(h+8|0)){if(i){k=0;if(zi(i)){break b}}t[b+825|0]=0;v[b+656>>2]=0;break a}k=0}g=v[b+656>>2];j=v[b+104>>2];m=(j|0)!=(k|0)&(j|0)!=0;p=!i|v[a+480180>>2]!=16777216?p:v[i+44>>2]!=0;if(m?!(!p|!d|v[b+656>>2]!=(i|0)):0){break a}e:{if(!(d&m)){break e}j=a+1074308|0;Eb(h+8|0,j,32);if(!(!Cb(h+8|0)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(v[a+480180>>2]==268435456|(v[a+480180>>2]&1048580?!(!i|(g|0)!=(i|0)):0)){break f}if(v[a+480180>>2]==1){if(Kh(b)){break f}}Eb(h+8|0,j,79);if(!Cb(h+8|0)){break e}if(!Kh(b)){break e}}l=1}g:{if(!v[b+16>>2]|(!m|(!x[a+480192>>1]|(g|0)!=(i|0)))){break g}Eb(h+8|0,a+1074308|0,87);if(!Cb(h+8|0)){break g}l=cg(b+810|0)^1|l}h:{i:{j:{k:{if(!(Kh(b)|!(v[a+480180>>2]&16777248))){if(!i){break k}if(!zi(i)){break k}}if((g|0)==(i|0)){break j}}l:{m:{if(!d){break m}Eb(h+8|0,a+1074308|0,61);if(!Cb(h+8|0)){break m}j=v[b+656>>2];if(j){break l}j=0;g=v[b+104>>2];if(g){break h}}n=1;break i}g=v[b+104>>2];break h}n=0}v[b+656>>2]=i;g=k;j=i}n:{o:{p:{if(!e){break p}q:{if(v[a+480180>>2]&3){if(g){if(De(g)){break q}}if(!nj(b)){break p}}if(!g){break o}}if(u[g+34>>1]<0){break p}v[b+688>>2]=x[g+30>>1]}i=(g|0)!=0;if(!(m&i&l)){break n}Eb(h+8|0,a+1074308|0,85);if(Cb(h+8|0)){v[b+768>>2]=t[g+37|0]}i=1;if(v[a+480180>>2]!=2){break n}if(!De(g)){break n}v[b+704>>2]=v[g+24>>2];break n}if(!(!j|!w[j+34|0])){i=b;k=b;o=v[b+656>>2];r:{if(o){k=v[o+4>>2]<<2;break r}k=v[k+688>>2]}v[i+688>>2]=k;i=0;break n}i=0;v[b+688>>2]=0}if(l){break a}t[b+825|0]=0;s:{if(!j){break s}Eb(h+8|0,a+1074308|0,29);if(s=0,z=!(Cb(h+8|0)?0:g),A=w[j+34|0]!=0|n,A?s:z){break s}t[b+820|0]=w[j+16|0]}k=j;q=64;l=b;v[b+764>>2]=64;o=g;if(g){q=x[o+32>>1];v[l+764>>2]=q}if(k){v[l+764>>2]=B(v[k+4>>2],q)>>>6}t:{if(v[a+480180>>2]&1048580?!e:0){break t}Eb(h+8|0,a+1074308|0,48);if(Cb(h+8|0)){break t}AM(a,b,j,g)}l=d^1;u:{v:{w:{if(!f){break w}e=a+1074308|0;Eb(h+8|0,e,19);x:{y:{z:{A:{B:{C:{D:{E:{if(Cb(h+8|0)){if(!v[b+76>>2]){k=1;break D}if(!(l|!c)){k=(w[a+480208|0]&8)>>>3|0;if(k){break D}break E}k=0;if(c){break E}break D}k=1;F:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break F}k=0;if(!(w[b+89|0]&16)){break F}k=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!j|n)){break B}if(!k){break A}c=v[b+88>>2];f=c&6144;break C}if(d){break D}if(!(w[b+89|0]&24)){k=0;break D}k=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|n){break B}if(!k){break A}c=v[b+88>>2];f=c&2048}v[b+88>>2]=c|2097152;if(!j){break x}if(f){break y}if(!(w[j+60|0]&8)){xi(b+724|0)}if(!(w[j+80|0]&8)){xi(b+736|0)}if(w[j+100|0]&8){break x}xi(b+748|0);break x}if(k){break z}}if(j){if(t[j+60|0]&1){break w}Eb(h+8|0,e,32);if(Cb(h+8|0)){xi(b+724|0);break w}yl(b);break w}c=0;if(!g){break v}break u}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break x}}yl(b)}Eb(h+8|0,e,21);if(Cb(h+8|0)){break w}t[b+838|0]=0;v[b+780>>2]=0}c=0;if(g){break u}if(!j){break v}c=1;if(zi(j)){break u}}v[b+764>>2]=0;v[b+104>>2]=0;break a}e=b;G:{H:{I:{J:{K:{if(!(!d|(i^1|v[b+104>>2]!=(g|0)))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break K}Eb(h+8|0,a+1074308|0,40);if(!Cb(h+8|0)|w[b+811|0]){break K}d=v[b+88>>2];break J}v[b+88>>2]=v[b+88>>2]&-6145;i=a+1074308|0;Eb(h+8|0,i,18);e=b;L:{if(!(s=!Cb(h+8|0),z=0,A=v[a+480180>>2]&16777248,A?s:z)){f=-640;if(!(v[b+104>>2]!=(g|0)|n)){break L}}f=-768}v[e+88>>2]=f&v[b+88>>2];M:{if(!j){break M}t[b+724|0]=w[j+60|0];t[b+736|0]=w[j+80|0];t[b+748|0]=w[j+100|0];N:{if((w[j+100|0]&17)!=17){break N}Eb(h+8|0,i,36);if(Cb(h+8|0)|w[b+857|0]){break N}t[b+857|0]=127}if(zu(j)){s=b,z=_B(j),t[s+857|0]=z}if(!YB(j)){break M}s=b,z=ZB(j),t[s+858|0]=z}if(c){break I}if(!d){break G}break H}d=v[b+88>>2]&-6145}v[e+88>>2]=d&-640;if(!c){break H}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break G}c=a+1074308|0;Eb(h+8|0,c,54);if(!Cb(h+8|0)){Eb(h,c,39);if(!Cb(h)){break G}}v[b+8>>2]=0;v[b+12>>2]=0}O:{if(w[b+810|0]!=255){break O}Eb(h+8|0,a+1074308|0,100);if(!Cb(h+8|0)|(!(v[a+480208>>2]&4)|!m)){break O}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+764>>2]=r;v[b+688>>2]=x[g+30>>1];if(!(w[g+34|0]&32)){break a}$s(b,x[g+28>>1],a);break a}v[b+104>>2]=g;v[b+76>>2]=v[g>>2];v[b+80>>2]=v[g+4>>2];v[b+84>>2]=v[g+8>>2];d=a+1074308|0;Eb(h+8|0,d,83);if(!(!Cb(h+8|0)|v[b+80>>2])){v[b+84>>2]=v[g>>2]}v[b+88>>2]=v[b+88>>2]|x[g+34>>1]&1023;Eb(h+8|0,d,21);if(Cb(h+8|0)){t[b+838|0]=0;v[b+780>>2]=0}c=b;P:{Q:{if(p){v[b+704>>2]=v[g+24>>2];t[b+872|0]=w[b+872|0]|8;e=0;break Q}if(v[a+480180>>2]&5?!(l|m):0){break P}v[b+704>>2]=v[g+24>>2];e=t[g+37|0]}v[c+768>>2]=e}c=b;if(Lp(a)){e=t[g+36|0]}else{e=0}v[c+772>>2]=e;Eb(h+8|0,d,69);if(!(Cb(h+8|0)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+876>>2]=0;i=v[b+88>>2];if(i&8){v[b+80>>2]=v[g+12>>2];v[b+84>>2]=v[g+16>>2];i=i>>>2&4|i|2;v[b+88>>2]=i}R:{if(!(i&2)){i=v[b+76>>2];break R}i=v[b+76>>2];c=v[b+84>>2];if(i>>>0<=c>>>0){break R}v[b+76>>2]=c;i=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<i>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}jb=h+16|0}function Jka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;e=jb-176|0;jb=e;a:{b:{c:{d:{e:{f:{g:{h:{if(!ph(b,14021)){break h}if(d){t[d|0]=1}k=a+1074308|0;Ft(k);o=a+480216|0;p=a+480224|0;l=a+1074368|0;q=a+480200|0;m=a+480248|0;i:{if(!Qb(b,7)){break i}r=a+480220|0;s=a+480228|0;z=a+480232|0;A=a+484360|0;n=a+480268|0;C=a+1304412|0;while(1){f=Cf(b);d=hg(b);if((f|0)==(w[14475]|w[14476]<<8|(w[14477]<<16|w[14478]<<24))){fg(b,6);break i}if(!(f&1616928864)|f&-2139062144){break i}if(!Qb(b,d)){break i}ud(e+160|0,b,d);j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)<=1347243309){if((f|0)<=1146367533){if((f|0)<=1130917458){if((f|0)==1127099950){break y}if((f|0)!=1129797166){break j}v[114578]=0;v[e>>2]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break v}v[a+1074300>>2]=v[e>>2];break j}if((f|0)==1130917459){break q}if((f|0)!=1145525806){break j}v[114578]=0;U(671,e+160|0,d|0,q|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}if((f|0)<=1213486400){if((f|0)==1146367534){break A}if((f|0)!=1196316499|d>>>0<3){break j}v[114578]=0;R(672,e+144|0,e+160|0);d=v[114578];v[114578]=0;if((d|0)==1){break o}v[114578]=0;g=W(673,e|0,e+144|0,8)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}yb(e+144|0);v[114578]=0;f=T(255,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}v[114578]=0;U(674,e|0,m|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break m}If(g);break j}if((f|0)==1213486401){break r}if((f|0)==1280530262){break u}if((f|0)!=1297303086){break j}Ft(k);h=0;break l}if((f|0)<=1380994349){if((f|0)<=1380340803){if((f|0)==1347243310){break w}if((f|0)!=1347244882){break j}v[114578]=0;U(675,e+160|0,d|0,n|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}if(Sn(w[n|0])){break j}t[n|0]=5;break j}if((f|0)==1380340804){break z}if((f|0)==1380986414){break s}if((f|0)!=1380991534){break j}v[114578]=0;U(671,e+160|0,d|0,o|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}if((f|0)<=1397768493){if((f|0)==1380994350){break k}if((f|0)!=1397052739|d>>>0<3){break j}v[114578]=0;f=T(359,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}if(!f|f>>>0>x[a+480190>>1]){break j}f=B(f,104)+a|0;d=f+484448|0;j=f+484484|0;while(1){v[114578]=0;g=T(392,e+160|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}v[d>>2]=g;d=d+4|0;if((j|0)!=(d|0)){continue}break}break j}if((f|0)==1397768494){break t}if((f|0)==1414344238){break x}if((f|0)!=1448301654){break j}v[114578]=0;U(671,e+160|0,d|0,z|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}v[114578]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[e>>2],1e4)+(y[a+480204>>2]%1e4|0);break j}v[114578]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[e>>2]%1e4;break j}d=P()|0;O()|0;break a}if(c){break j}v[114578]=0;u[e>>1]=0;U(676,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){D=a,E=Cd(x[e>>1],x[a+480188>>1],127),u[D+480188>>1]=E;break j}d=P()|0;O()|0;break a}v[114578]=0;U(677,e+160|0,d|0,p|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}v[114578]=0;U(678,e+160|0,d|0,l|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}break j}d=P()|0;O()|0;break a}v[114578]=0;v[e>>2]=0;U(671,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break f}d=v[e>>2];if(!d){break j}v[a+1074304>>2]=d;break j}v[114578]=0;U(671,e+160|0,d|0,s|0);d=v[114578];v[114578]=0;if((d|0)!=1){break j}break b}if(v[a+480180>>2]==4){break j}v[114578]=0;U(676,e+160|0,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){Oe(Vb(A),x[e>>1]);break j}d=P()|0;O()|0;break a}g=Wb(e);v[114578]=0;f=T(255,e+160|0)|0;d=v[114578];v[114578]=0;B:{if((d|0)==1){break B}v[114578]=0;W(679,e+160|0,g|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break B}v[114578]=0;U(13,e+144|0,0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break B}Gb(C,e+144|0);yb(e+144|0);yb(g);break j}d=P()|0;O()|0;yb(g);break a}if(d&1|d>>>0>126){break j}u[e>>1]=(d>>>1|0)- -64;v[114578]=0;u[e+144>>1]=127;f=Q(478,e|0,e+144|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}j=x[f>>1];if(j>>>0<65){break j}h=64;while(1){v[114578]=0;R(473,e|0,e+160|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}d=dd(e);f=e;C:{if(w[e|0]==255){break C}d=w[d|0];i=(h<<5)+a|0;g=i+480284|0;u[g>>1]=128;u[i+480286>>1]=d;i=i+480280|0;v[i>>2]=0;v[i>>2]=(w[f|0]&128)<<3;d=w[f|0]&127;t[f|0]=d;if(d>>>0<65){u[g>>1]=d<<2;d=w[f|0]}if((d|0)!=100){break C}v[i>>2]=v[i>>2]|256}h=h+1|0;if((j|0)!=(h|0)){continue}break}break j}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;yb(e+144|0);break a}d=P()|0;O()|0;If(g);break a}D:{E:{F:while(1){v[114578]=0;f=Q(258,e+160|0,1)|0;d=v[114578];v[114578]=0;if((d|0)==1){break E}if(!f|h>>>0>=110){break j}v[114578]=0;g=T(389,e+160|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break D}d=0;while(1){G:{if(!(!(g>>>d&1)|h>>>0>=110)){v[114578]=0;W(479,k|0,h|0,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break G}}h=h+1|0;d=d+1|0;if((d|0)!=8){continue}continue F}break}break}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[114578]=0;U(671,e+160|0,d|0,r|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}}Bb(e+160|0);if(Qb(b,7)){continue}break}}Yn(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(v[a+480224>>2]>=3){v[p>>2]=0}if(v[l>>2]>=6){v[l>>2]=0}Cc(q,256);if(nd(m)){break h}Sz(m,v[o>>2],16777216)}jb=e+176|0;return}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0}Bb(e+160|0);S(d|0);L()}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=jb-352|0;jb=d;Pc(b,60);i=15;a:{if(!ph(b,17212)){Pc(b,124);i=31;if(!ph(b,17217)){break a}}Hd(a,536870912);u[a+480190>>1]=i;Jc(b);b:{if(x[a+480190>>1]){while(1){f=rA(b);v[(d+224|0)+(e<<2)>>2]=f;if(f>>>0>131072){break b}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;e=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;lj(a,1);$b(b,4);f=Wp(b);if(f>>>0<178){break a}e=a;o=177693e5/+(f>>>0);c:{if(o<4294967296&o>=0){f=~~o>>>0;break c}f=0}v[e+480204>>2]=f;$b(b,14);d:{e:{f:{if(x[a+480190>>1]){p=d+78|0;j=1;i=0;m=1;while(1){uQ(b,d+56|0);e=v[((j<<2)+d|0)+220>>2];l=jb-16|0;jb=l;h=(B(j,104)+a|0)+484380|0;Fd(h,1);v[h>>2]=e;e=d+56|0;t[h+37|0]=w[e+24|0]<<4;t[l+15|0]=w[e+25|0];t[l+14|0]=64;q=h,r=w[pc(l+15|0,l+14|0)|0]<<2,u[q+30>>1]=r;f=e+26|0;g=w[f|0]|w[f+1|0]<<8;e=e+28|0;f=v[h>>2];g:{if(!f){break g}e=w[e|0]|w[e+1|0]<<8;g=(g<<8|g>>>8)&65535;v[h+4>>2]=g;e=(((e<<8|e>>>8)&65535)<<1)+g|0;v[h+8>>2]=e;if(f>>>0<=g>>>0){g=f-1|0;v[h+4>>2]=g}if(e>>>0>f>>>0){v[h+8>>2]=f;e=f}if(!(e-g>>>0>3?!(e>>>0<4|e>>>0<g>>>0):0)){v[h+4>>2]=0;v[h+8>>2]=0;break g}if(e>>>0<=g>>>0){break g}u[h+34>>1]=x[h+34>>1]|2}jb=l+16|0;e=d+56|0;while(1){if((w[e|0]-1&255)>>>0<=30){t[e|0]=32;i=i+1|0}e=e+1|0;if((p|0)!=(e|0)){continue}break}if(i>>>0>127){break b}Tl(d+192|0,3,d+56|0);Ic(d+208|0,d+192|0);v[114578]=0;Q(371,((j<<5)+a|0)+946300|0,d+208|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}yb(d+208|0);m=m+1|0;j=m&65535;if(j>>>0<=x[a+480190>>1]){continue}break}}f=Ub(d+56|0,17222);v[114578]=0;e=a+946332|0;h=Q(1002,e|0,f|0)|0;j=v[114578];v[114578]=0;i=1;h:{i:{j:{k:{if((j|0)!=1){if(!h){v[114578]=0;h=Q(85,d+208|0,17233)|0;i=v[114578];v[114578]=0;if((i|0)==1){break k}v[114578]=0;i=Q(1002,e|0,h|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}yb(h)}yb(f);e=0;if(!lz(b,d+56|0)){break a}if(!eP(d+56|0)){break a}if(c){break h}break d}e=P()|0;O()|0;break i}e=P()|0;O()|0;break i}e=P()|0;O()|0;yb(h)}yb(f);break e}u[d+54>>1]=0;if(w[d+56|0]){while(1){u[d+208>>1]=w[(d+e|0)+58|0]+1;q=d,r=x[Si(d+54|0,d+208|0)>>1],u[q+54>>1]=r;e=e+1|0;if(e>>>0<w[d+56|0]){continue}break}}e=d+56|1;f=w[e|0];h=w[d+56|0];j=a+484360|0;Oe(Vb(j),f>>>0<h>>>0?w[e|0]:0);In(Vb(j),d+56|2,w[d+56|0],65535,65535);if(x[a+480190>>1]==31){$b(b,4)}j=0;v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;l=c&1;if(l){_f(a+484344|0,x[d+54>>1])}if(x[d+54>>1]){h=a+484344|0;while(1){l:{m:{if(l){m=0;if(rg(h,j&65535,64)){break m}}$b(b,1024);break l}while(1){p=Xe(_b(h,j),m,0);e=0;while(1){Sl(d+208|0,b);f=p+B(e,6)|0;n:{o:{if(w[fc(d+208|0,0)|0]!=255){break o}t[(d+48|0)+e|0]=0;t[(d+40|0)+e|0]=0;p:{if(!i){break p}if(w[fc(d+208|0,1)|0]!=252){break p}q=fc(d+208|0,1),r=254,t[q|0]=r}q:{switch(w[fc(d+208|0,1)|0]-252|0){case 2:t[f+3|0]=13;break n;case 1:break n;case 0:break q;default:break o}}t[f+3|0]=14;t[d+39|0]=9;break n}g=v[d+208>>2];v[d+32>>2]=g;v[d+12>>2]=g;nt(d+12|0,f);g=w[f|0];r:{if(!g){break r}t[(d+40|0)+e|0]=0;t[(d+48|0)+e|0]=g;if(g>>>0>48){break r}t[d+192|0]=8;q=d,r=w[qh(d+39|0,d+192|0)|0],t[q+39|0]=r}s:{t:{u:{v:{w:{switch(w[f+3|0]){case 0:if(w[f+5|0]){break t}break s;case 1:t[f+3|0]=1;break n;case 2:g=w[f+5|0];if(g&240){t[f+3|0]=3;t[f+5|0]=g>>>4;break n}g=g&15;if(g){t[f+3|0]=2;t[f+5|0]=g;break n}t[f+5|0]=0;break t;case 3:if(w[(d+40|0)+e|0]){break u}t[f+3|0]=19;t[f+5|0]=0;break n;case 4:if(w[(d+40|0)+e|0]){break u}t[f+3|0]=19;t[f+5|0]=1;break n;case 5:if(!w[f+1|0]){break u}t[f+3|0]=13;t[d+192|0]=63;t[d+31|0]=w[f+5|0]+(x[(B(w[f+1|0],104)+a|0)+484410>>1]>>>2|0);q=f,r=w[pc(d+192|0,d+31|0)|0],t[q+5|0]=r;if(!w[(d+40|0)+e|0]){break v}t[f+2|0]=1;t[f+4|0]=w[f+5|0];t[f+5|0]=0;break t;case 6:g=w[f+1|0];if(!g){break u}t[f+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;k=w[f+5|0];g=g>>>0<k>>>0?0:g-k|0;t[f+5|0]=g;if(!w[(d+40|0)+e|0]){break v}t[f+4|0]=g;t[f+2|0]=1;t[f+5|0]=0;break t;case 8:k=w[(d+48|0)+e|0];g=w[f+5|0];n=k+(g>>>4|0)|0;t[(d+44|0)+e|0]=n;t[f+3|0]=2;g=g&15;t[(d+40|0)+e|0]=g;q=f,r=dP(g,k,n&255),t[q+5|0]=r;break v;case 9:t[d+192|0]=8;q=d,r=w[qh(d+39|0,d+192|0)|0],t[q+39|0]=r;break t;case 7:break w;default:break t}}g=w[(d+48|0)+e|0];k=w[f+5|0];n=g-(k>>>4|0)|0;t[(d+44|0)+e|0]=n;t[f+3|0]=3;k=k&15;t[(d+40|0)+e|0]=k;q=f,r=dP(k,n&255,g),t[q+5|0]=r}if(w[f+3|0]){break n}break s}t[f+5|0]=0}t[f+3|0]=0}k=w[(d+40|0)+e|0];if(!k){break n}n=(d+44|0)+e|0;g=w[n|0];if(g){t[(d+48|0)+e|0]=g;t[f|0]=g;t[f+5|0]=k;t[n|0]=0}t[f+3|0]=4}e=e+1|0;if((e|0)!=4){continue}break}m=m+1|0;if((m|0)!=64){continue}break}}j=j+1|0;if(j>>>0<x[d+54>>1]){continue}break}}x:{y:{z:{A:{B:{C:{if(c&2){i=x[a+480190>>1];if(!i){break B}e=1;while(1){c=(B(e&65535,104)+a|0)+484380|0;if(v[c>>2]){tg(ad(d+208|0,8,1,0,0),c,b);i=x[a+480190>>1]}e=e+1|0;if((e&65535)>>>0<=(i&65535)>>>0){continue}break}break C}i=x[a+480190>>1]}if((i&65535)!=15){break B}b=Ub(d+16|0,17242);v[114578]=0;R(219,d+192|0,b|0);c=v[114578];v[114578]=0;e=1;if((c|0)==1){break y}v[114578]=0;U(537,d+208|0,d+192|0,d+39|0);c=v[114578];v[114578]=0;if((c|0)!=1){break A}e=P()|0;O()|0;Ib(d+192|0);break x}e=0;v[114578]=0;Q(2,d+208|0,17255)|0;b=v[114578];v[114578]=0;if((b|0)==1){break z}}Gb(a+1304436|0,d+208|0);yb(d+208|0);if(e){Ib(d+192|0);yb(d+16|0)}Mc(a+1304448|0,x[a+480190>>1]==15?17286:17290);v[a+1304496>>2]=2;break d}e=P()|0;O()|0;break e}e=P()|0;O()|0}yb(b);break e}e=P()|0;O()|0;yb(d+208|0)}S(e|0);L()}e=1;break a}e=0}jb=d+352|0;return e|0}function c1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0,G=0,H=0;m=jb-560|0;jb=m;v[m+44>>2]=0;o(+b);p=j(1)|0;j(0)|0;a:{if((p|0)<-1?1:(p|0)<=-1){A=1;b=-b;o(+b);p=j(1)|0;j(0)|0;g=55648;break a}A=1;g=55651;if(e&2048){break a}g=55654;if(e&1){break a}A=0;z=1;g=55649}E=g;b:{if((p&2146435072)==2146435072){l=A+3|0;Jf(a,32,c,l,e&-65537);Qe(a,E,A);d=f&32;Qe(a,b!=b?d?55675:55679:d?55667:55671,3);break b}s=m+16|0;c:{d:{e:{b=sG(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;C=f|32;if((C|0)!=97){break e}break c}C=f|32;if((C|0)==97){break c}q=v[m+44>>2];n=(d|0)<0?6:d;break d}q=g-29|0;v[m+44>>2]=q;b=b*268435456;n=(d|0)<0?6:d}r=(q|0)<0?m+48|0:m+336|0;h=r;while(1){d=h;if(b<4294967296&b>=0){g=~~b>>>0}else{g=0}v[d>>2]=g;h=h+4|0;b=(b-+(g>>>0))*1e9;if(b!=0){continue}break}f:{if((q|0)<1){d=q;g=h;i=r;break f}i=r;d=q;while(1){G=(d|0)<29?d:29;g=h-4|0;g:{if(i>>>0>g>>>0){break g}k=G;d=0;p=0;while(1){y=g;H=v[g>>2];l=k&31;if((k&63)>>>0>=32){F=H<<l;l=0}else{F=(1<<l)-1&H>>>32-l;l=H<<l}l=l+d|0;F=p+F|0;p=l;d=Ima(l,d>>>0>l>>>0?F+1|0:F,1e9,0);l=Fma(d,mb,1e9,0);v[y>>2]=p-l;g=g-4|0;if(i>>>0<=g>>>0){p=0;continue}break}if(!d){break g}i=i-4|0;v[i>>2]=d}while(1){g=h;if(i>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-G|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25|0)/9|0;if((d|0)<=-1){u=h+1|0;l=(C|0)==102;while(1){y=(d|0)<-9?9:0-d|0;h:{if(g>>>0>i>>>0){p=1e9>>>y|0;k=-1<<y^-1;d=0;h=i;while(1){G=d;d=v[h>>2];v[h>>2]=G+(d>>>y|0);d=B(p,d&k);h=h+4|0;if(h>>>0<g>>>0){continue}break}i=v[i>>2]?i:i+4|0;if(!d){break h}v[g>>2]=d;g=g+4|0;break h}i=v[i>>2]?i:i+4|0}d=v[m+44>>2]+y|0;v[m+44>>2]=d;h=l?r:i;g=g-h>>2>(u|0)?h+(u<<2)|0:g;if((d|0)<0){continue}break}}h=0;i:{if(g>>>0<=i>>>0){break i}h=B(r-i>>2,9);k=v[i>>2];if(k>>>0<10){break i}d=100;while(1){h=h+1|0;if(d>>>0>k>>>0){break i}d=B(d,10);continue}}d=(n-((C|0)==102?0:h)|0)-((C|0)==103&(n|0)!=0)|0;if((d|0)<(B(g-r>>2,9)-9|0)){p=d+9216|0;k=(p|0)/9|0;l=((k<<2)+((q|0)<0?m+48|4:m+340|0)|0)-4096|0;d=10;j:{k=p-B(k,9)|0;if((k|0)>7){break j}d=100;while(1){k=k+1|0;if((k|0)==8){break j}d=B(d,10);continue}}q=v[l>>2];u=(q>>>0)/(d>>>0)|0;k:{p=q-B(d,u)|0;k=l+4|0;if((k|0)==(g|0)?!p:0){break k}b=(g|0)==(k|0)?1:1.5;k=d>>>1|0;x=k>>>0>p>>>0?.5:(k|0)==(p|0)?b:1.5;b=u&1?9007199254740994:9007199254740992;if(!(w[E|0]!=45|z)){x=-x;b=-b}k=q-p|0;v[l>>2]=k;if(b+x==b){break k}d=d+k|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<i>>>0){i=i-4|0;v[i>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}h=B(r-i>>2,9);k=v[i>>2];if(k>>>0<10){break k}d=100;while(1){h=h+1|0;if(d>>>0>k>>>0){break k}d=B(d,10);continue}}d=l+4|0;g=d>>>0<g>>>0?d:g}while(1){q=g;k=g>>>0<=i>>>0;if(!k){g=q-4|0;if(!v[g>>2]){continue}}break}l:{if((C|0)!=103){z=e&8;break l}g=n?n:1;d=(g|0)>(h|0)&(h|0)>-5;n=(d?h^-1:-1)+g|0;f=(d?-1:-2)+f|0;z=e&8;if(z){break l}g=-9;m:{if(k){break m}d=v[q-4>>2];if(!d){break m}g=0;if((d>>>0)%10|0){break m}k=0;g=100;while(1){if(!((d>>>0)%(g>>>0)|0)){k=k+1|0;g=B(g,10);continue}break}g=k^-1}d=B(q-r>>2,9);if((f&-33)==70){z=0;d=(d+g|0)-9|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d;break l}z=0;d=((d+h|0)+g|0)-9|0;d=(d|0)>0?d:0;n=(d|0)>(n|0)?n:d}y=n|z;l=(y|0)!=0;d=a;k=c;p=f&-33;g=(h|0)>0?h:0;n:{if((p|0)==70){break n}g=h>>31;g=Gm(g+h^g,0,s);if((s-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((s-g|0)<2){continue}break}}u=g-2|0;t[u|0]=f;t[g-1|0]=(h|0)<0?45:43;g=s-u|0}l=(g+(l+(n+A|0)|0)|0)+1|0;Jf(d,32,k,l,e);Qe(a,E,A);Jf(a,48,c,l,e^65536);o:{p:{q:{if((p|0)==70){d=m+16|8;h=m+16|9;f=i>>>0>r>>>0?r:i;i=f;while(1){g=Gm(v[i>>2],0,h);r:{if((f|0)!=(i|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(h|0)){break r}t[m+24|0]=48;g=d}Qe(a,g,h-g|0);i=i+4|0;if(r>>>0>=i>>>0){continue}break}if(y){Qe(a,55683,1)}if((n|0)<1|i>>>0>=q>>>0){break q}while(1){g=Gm(v[i>>2],0,h);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}Qe(a,g,(n|0)<9?n:9);g=n-9|0;i=i+4|0;if(q>>>0<=i>>>0){break p}d=(n|0)>9;n=g;if(d){continue}break}break p}s:{if((n|0)<0){break s}f=i>>>0<q>>>0?q:i+4|0;k=m+16|9;d=m+16|8;h=i;while(1){g=Gm(v[h>>2],0,k);if((k|0)==(g|0)){t[m+24|0]=48;g=d}t:{if((h|0)!=(i|0)){if(m+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break t}Qe(a,g,1);g=g+1|0;if((n|0)<1?!z:0){break t}Qe(a,55683,1)}q=g;g=k-g|0;Qe(a,q,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(f>>>0<=h>>>0){break s}if((n|0)>-1){continue}break}}Jf(a,48,n+18|0,18,0);Qe(a,u,s-u|0);break o}g=n}Jf(a,48,g+9|0,9,0)}break b}n=f&32;q=n?E+9|0:E;u:{if(d>>>0>11){break u}g=12-d|0;if(!g){break u}x=8;while(1){x=x*16;g=g-1|0;if(g){continue}break}if(w[q|0]==45){b=-(x+(-b-x));break u}b=b+x-x}g=v[m+44>>2];h=g>>31;g=Gm(h^g+h,0,s);if((s|0)==(g|0)){t[m+15|0]=48;g=m+15|0}k=A|2;h=v[m+44>>2];p=g-2|0;t[p|0]=f+15;t[g-1|0]=(h|0)<0?45:43;g=e&8;i=m+16|0;while(1){f=i;r=n;if(D(b)<2147483648){h=~~b}else{h=-2147483648}t[i|0]=r|w[h+55632|0];i=f+1|0;b=(b-+(h|0))*16;if(!((i-(m+16|0)|0)!=1|(b==0?!(g|(d|0)>0):0))){t[f+1|0]=46;i=f+2|0}if(b!=0){continue}break}f=!d|((i-m|0)-18|0)>=(d|0)?(s-(p+(m+16|0)|0)|0)+i|0:((d+s|0)-p|0)+2|0;l=f+k|0;Jf(a,32,c,l,e);Qe(a,q,k);Jf(a,48,c,l,e^65536);d=i-(m+16|0)|0;Qe(a,m+16|0,d);g=d;d=s-p|0;Jf(a,48,f-(g+d|0)|0,0,0);Qe(a,p,d)}Jf(a,32,c,l,e^8192);jb=m+560|0;return((c|0)>(l|0)?c:l)|0}function cM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0),s=0,y=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=C(0),M=0,N=0,O=C(0),P=0;i=jb-48|0;jb=i;n=x[a+480192>>1]?v[(B(b,896)+a|0)+1075640>>2]:n;E=a+1074308|0;g=B(b,896)+a|0;F=g+1075805|0;I=g+1075672|0;J=g+1075772|0;G=g+1075748|0;H=g+1075744|0;K=g+1075704|0;p=g+1075676|0;q=g+1075668|0;s=g+1075648|0;y=g+1075792|0;A=g+1075072|0;k=e&127;L=C(k>>>0);j=g+1075855|0;r=C(w[j|0]);g=1;while(1){e=w[d+o|0];if(e){l=e-48|0;a:{b:{if((l&255)>>>0<10){break b}if((e-65&255)>>>0<=5){l=e-55|0;break b}c:{d:{e:{switch(e-97|0){case 2:f:{e=xl(a,b,3,0);if(!e|e-251>>>0<5){break f}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break f}e=qv(e,79864,79872);if(!e){break f}e=nb[v[v[e>>2]+184>>2]](e,b)|0;h=(e|0)!=255;l=h?e:0;if(h|!n){break b}break c}if(n){break c}l=0;break b;case 13:e=0;if(!be(w[F|0])){break d}e=w[F|0]-1|0;break d;case 21:Eb(i+8|0,E,28);g:{if(!Cb(i+8|0)){Eb(i,E,1);h=0;if(!Cb(i)){break g}}h=u[J>>1]}e=B(v[G>>2],v[H>>2]);m=e;l=e>>31;e=B(v[a+1074444>>2],h+v[I>>2]|0);e=Yb((yc(Gma(Fma(m,l,e,e>>31),mb,1048576,0),mb)|0)/2|0,1,127);break d;case 23:v[i+8>>2]=v[p>>2]/2;v[i>>2]=127;e=v[de(i+8|0,i)>>2];break d;case 24:v[i+8>>2]=v[q>>2]/2;v[i>>2]=127;e=v[de(i+8|0,i)>>2];break d;case 0:e=0;if(!n){break d}h=x[n+28>>1];if(!h){break d}e=h-1>>>7&127;break d;case 1:e=0;if(!n){break d}h=x[n+28>>1];if(!h){break d}e=h-1&127;break d;case 14:e=v[s>>2]>>>8|0;break d;case 7:e=b;if(e>>>0>=x[a+480188>>1]){e=w[y|0]-1|0}e=e&127;break d;case 12:e=v[A>>2]>>>7&1;break d;case 15:e=0;if(!n){break d}h=w[n+30|0];if(!h){break d}e=h-1&127;break d;case 25:h=j;e=k;h:{if(!c){break h}e=k;if(t[j|0]<0){break h}i:{if(f>>>0<3){break i}m=(i+16|0)+f|0;if(w[m-3|0]!=240){break i}e=k;if(w[m-2|0]>239){break h}}D=Yo(a,r,L);if(D<C(4294967296)&D>=C(0)){e=~~D>>>0;break h}e=0}t[h|0]=e;break d;case 18:e=f;j:{if(!e){e=0;break j}while(1){e=e-1|0;if(w[e+(i+16|0)|0]==240){break j}if(e){continue}break}}if(w[(i+16|0)+e|0]!=240|f-e>>>0<5){break a}l=0;e=e+5|0;h=0;k:{if((f|0)==(e|0)){break k}while(1){l=w[(i+16|0)+e|0]+l|0;e=e+1|0;if((f|0)!=(e|0)){continue}break}h=0-l|0}e=h&127;break d;case 20:break e;default:break a}}e=B(v[G>>2],v[H>>2]);h=e;m=e>>31;e=B(v[a+1074444>>2],v[K>>2]);e=Yb((yc(Gma(Fma(h,m,e,e>>31),mb,67108864,0),mb)|0)/2|0,1,127)}h=g^-1;g=1;f=(h&1)+f|0;t[f+(i+16|0)|0]=e;f=f+1|0;break a}l=n;e=a;m=0;h=b;l:{m:{if(h>>>0>=256){break m}if(w[l+31|0]==17){e=x[(e+B(h,896)|0)+1075792>>1];e=(e?e-1|0:h)&15;break l}if(!zi(l)){break m}m=w[l+31|0]-1&15}e=m}l=e}e=(i+16|0)+f|0;n:{if(g&1){t[e|0]=l;break n}t[e|0]=w[e|0]<<4|l;f=f+1|0}g=(g^-1)&1}o=o+1|0;if((o|0)!=31){continue}}break}e=((g^-1)&1)+f|0;o:{if(!e){break o}l=0;g=0;while(1){q=(i+16|0)+g|0;d=t[q|0];p:{q:{r:{if((d|0)==-16){if(e-g>>>0>=4){o=4;if((w[(g+i|0)+17|0]&254)==240){break q}}o=g;s:{while(1){o=o+1|0;if(o>>>0>=e>>>0){break s}if(w[(i+16|0)+o|0]!=247){continue}break}d=o-g|0;o=d+1|0;if(o>>>0>=d>>>0){break q}}t[(i+16|0)+e|0]=247;e=e+1|0;o=e-g|0;break r}if((d|0)>=0){if(l&255){g=g-1|0;t[g+(i+16|0)|0]=l;break p}g=g+1|0;l=0;break p}M=i,N=DO(d&255),v[M+8>>2]=N;v[i>>2]=e-g;o=v[Lb(i+8|0,i)>>2]}if(!o){break o}d=w[q|0];l=d>>>0<240?d:l}j=a;m=b;h=c;s=0;p=jb-32|0;jb=p;k=o;v[p+28>>2]=k;t:{if(!k){break t}d=w[q|0];f=d-250|0;if(!(f>>>0>5|!(1<<f&37))){if(x[j+480188>>1]){f=0;while(1){d=(j+B(f,896)|0)+1075841|0;t[d|0]=127;t[d+1|0]=0;f=f+1|0;if(f>>>0<x[j+480188>>1]){continue}break}}d=w[q|0]}u:{if((d&255)!=240){break u}n=w[q+1|0];if((n&254)!=240){break u}if(k>>>0<4){break t}A=(j+B(m,896)|0)+1074984|0;y=w[q+2|0];d=(n|0)==241;f=t[q+3|0];if(!(y|d|(f|0)<0)){n=j+B(m,896)|0;k=n+1075841|0;d=k;if(h){f=bM(Yo(j,C(w[k|0]),C((f&255)>>>0)))}t[d|0]=f;t[n+1075802|0]=0;s=4;d=n+1075072|0;k=fp(j,A,!(v[d>>2]&32768),256);if((k|0)<0|!(w[d+1|0]&2)){break t}d=j+1304392|0;if(!rd(d)){break t}lp(v[d>>2],m,k>>>2&255,1);break t}if(!(d|(y|0)!=1|(f|0)<0)){k=j+B(m,896)|0;d=k+1075842|0;v:{if(!h){break v}r=Yo(j,C(w[d|0]),C((f&255)>>>0));if(r<C(4294967296)&r>=C(0)){f=~~r>>>0;break v}f=0}t[d|0]=f;t[k+1075801|0]=0;fp(j,A,!(v[k+1075072>>2]&32768),256);s=4;break t}d=(n|0)==241;if(!(d|(y|0)!=2)){s=4;if((f&255)>>>0>31){break t}d=j+B(m,896)|0;t[d+1075849|0]=(f&240)>>>4;fp(j,A,!(v[d+1075072>>2]&32768),256);break t}if(!(d|(y|0)!=3)){s=4;d=xl(j,m,3,0);if((f|0)<0|(d+5&255)>>>0<6){break t}d=(j+B(d,160)|0)+906284|0;r=C(C(((f^127)&255)>>>0)*C(.007874015718698502));if(!h){z[d>>2]=r;break t}M=d,O=Yo(j,z[d>>2],r),z[M>>2]=O;break t}if(y&128?0:(n|0)!=241){break t}s=4;d=xl(j,m,3,0);if((d+5&255)>>>0<6){break t}k=v[(j+B(d,160)|0)+906140>>2];if(!k|(f|0)<0){break t}d=(n|0)==241?y+128|0:y&127;r=C(C((f&255)>>>0)*C(.007874015718698502));if(!h){nb[v[v[k>>2]+44>>2]](k,d,r);break t}N=k,P=d,O=Yo(j,C(nb[v[v[k>>2]+48>>2]](k,d)),r),M=v[v[k>>2]+44>>2],nb[M](N|0,P|0,C(O));break t}w:{x:{if(m>>>0<x[j+480188>>1]){f=m+1|0;break x}f=x[(j+B(m,896)|0)+1075792>>1];if(!f){break w}}if(w[(j+B(m,896)|0)+1075075|0]&4|x[j+480188>>1]<(f&65535)>>>0){break w}d=xl(j,m,3,0);if(!d|d-251>>>0<5){break w}f=v[(j+B(d,160)|0)+906140>>2];if(!f){break w}d=w[q|0];if((d|0)==240){gc(p+16|0,Db(q),k);nb[v[v[f>>2]+72>>2]](f,p+16|0)|0;break w}M=p,P=DO(d),v[M+12>>2]=P;d=v[Lb(p+12|0,p+28|0)>>2];v[p+12>>2]=0;lc(p+12|0,q,d);nb[v[v[f>>2]+68>>2]](f,v[p+12>>2])|0}s=v[p+28>>2]}jb=p+32|0;g=(s?s:o)+g|0}if(e>>>0>g>>>0){continue}break}}jb=i+48|0}function Hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;d=jb-1824|0;jb=d;Jc(b);i=jb-16|0;jb=i;h=d+1224|0;jQ(i+8|0,h);j=Hb(i+8|0);e=b;l=nc(e,ac(i,i+8|0));if((j|0)==(l|0)){$b(e,Hb(i+8|0))}jb=i+16|0;e=(j|0)==(l|0);if(!e){kQ(h)}a:{if(!e){break a}if(!tQ(d+1224|0)){break a}if(!kz(b,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];e=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=e;e=d+1232|0;g=v[e+4>>2];v[d+1208>>2]=v[e>>2];v[d+1212>>2]=g;Hd(a,1);e=a+1074308|0;wg(e,83);Nb(e,84,1);Nb(e,85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;Pc(b,20);l=a+480188|0;g=1;i=1;while(1){h=B(g,104)+a|0;j=h+484380|0;e=((g<<5)+a|0)+946300|0;mz(b,d+16|0,j,e,1);n=v[j>>2];b:{if(!w[fc(e,0)|0]){break b}c:{if(qd(e,15730,3)){if(qd(e,15734,3)){break c}}if(w[fc(e,5)|0]==58){break b}}i=0}e=w[d+44|0]|w[d+45|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>=2){e=w[d+42|0]|w[d+43|0]<<8;v[h+484384>>2]=(e<<8|e>>>8)&65535;e=w[d+42|0]|w[d+43|0]<<8;k=(e<<8|e>>>8)&65535;e=w[d+44|0]|w[d+45|0]<<8;v[h+484388>>2]=k+(((e<<8|e>>>8)&65535)<<1);nn(j)}e=w[d+38|0]|w[d+39|0]<<8;d:{if(((e<<8|e>>>8)&65535)>>>0<=4999){e=w[d+42|0]|w[d+43|0]<<8;if(((e<<8|e>>>8)&65535)>>>0<1e4){break d}}v[d+1064>>2]=5;y=d,z=v[zf(d+1196|0,d+1064|0)>>2],v[y+1196>>2]=z}f=f+n|0;g=g+1|0;if((g|0)!=16){continue}break}lz(b,d+1064|0);o=a+484360|0;In(Vb(o),d+1064|2,128,65535,65535);g=0;n=yQ(b,Vb(o),w[d+1064|0],f,l,0);e=d+1064|1;if(n>>>0<2?!(w[e|0]|w[d+1064|0]):0){break a}if(nf(b)+65536>>>0<(n<<10)+f>>>0){break a}if(!c){g=1;break a}if(!w[e|0]){t[e|0]=120}if(!qd(d+1200|0,15738,6)){t[e|0]=120}v[a+480204>>2]=125e4;e:{if(w[e|0]==120){break e}f=a;q=145364549.18032786/+(240-w[e|0]|0);f:{if(q<4294967296&q>=0){e=~~q>>>0;break f}e=0}v[f+480204>>2]=e;if(v[d+1196>>2]>=2){v[d+16>>2]=i&1?4:5;y=d,z=v[zf(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z;break e}v[d+16>>2]=i&1?1:2;y=d,z=v[zf(d+1196|0,d+16|0)>>2],v[y+1196>>2]=z}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;Hn(d+1048|0,3,d+1200|0);Ic(d+16|0,d+1048|0);Gb(a+1304400|0,d+16|0);yb(d+16|0);h=0;lj(a,0);r=v[b+8>>2];u[d+1046>>1]=0;g:{h:{if(!n){i=0;break h}s=i&1;i=0;while(1){y=d,z=iz(bc(Vb(o)),cc(Vb(o)),d+1046|0),v[y+16>>2]=z;y=d,z=cc(Vb(o)),v[y+1048>>2]=z;f=Jb(d+16|0,d+1048|0);sQ(b,d+16|0);if(f){h=hz(d+16|0,0)+h|0;if(h>>>0>512){break g}}j=0;f=0;l=0;while(1){g=0;while(1){e=f;m=Ve(rQ(d+16|0,j),g);p=w[fc(m,2)|0]&15;k=w[fc(m,3)|0];f=0;i:{if(!(e&255)|(w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))){break i}f=e+1|0;if((f&255)>>>0<33){break i}v[d+1196>>2]=6}j:{k:{l:{switch(p-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1?k>>>0>=32:0){break k}m=(p|0)!=1;if(!(m|!k|k>>>0>2)){v[d+1048>>2]=2;y=d,z=v[zf(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break j}if(m){break j}if((k|0)!=55){if((k|0)!=71){break j}if((e|0)<3){break k}break j}if((e|0)<=2){break k}break j;case 10:v[d+1196>>2]=6;break j;case 11:case 12:case 13:v[d+1048>>2]=2;y=d,z=v[zf(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;if((p|0)!=13){break j}l=((j|k)!=0)+l|0;f=1;break j;case 14:break l;default:break j}}v[d+1048>>2]=3;y=d,z=v[zf(d+1196|0,d+1048|0)>>2],v[y+1196>>2]=z;break j}v[d+1196>>2]=s}g=g+1|0;if((g|0)!=4){continue}break}j=j+1|0;if((j|0)!=64){continue}break}if((l-1&255)>>>0<2){v[d+1196>>2]=6}i=(l&255)+i|0;f=x[d+1046>>1]+1|0;u[d+1046>>1]=f;if(n>>>0>(f&65535)>>>0){continue}break}}if(!(v[d+1196>>2]!=6|n+32>>>0>=i>>>0)){v[d+1196>>2]=5}Pc(b,r);o=c&1;if(o){_f(a+484344|0,n)}if(n){m=a+484344|0;i=0;while(1){sQ(b,d+16|0);m:{if(!o){break m}if(!rg(m,i&65535,64)){break m}v[d+1048>>2]=0;l=0;while(1){p=Xe(_b(m,i),l,0);h=0;while(1){f=Ve(rQ(d+16|0,l),h);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[d+8>>2]=f;v[d+12>>2]=f;e=p+B(h,6)|0;nt(d+8|0,e);n:{o:{p:{q:{f=w[e+5|0];if(f){j=e+3|0;k=(d+1048|0)+h|0;g=w[e+3|0];if((g|0)!=14){break q}t[k|0]=0;g=14;break p}j=(d+1048|0)+h|0;t[j|0]=0;g=w[e+3|0];if(!g){break o}j=e+3|0;break p}k=w[k|0];if(!k){break p}if(k>>>0>=16){t[e+2|0]=3;t[e+4|0]=k>>>4;break p}t[e+2|0]=4;t[e+4|0]=k}r:{s:{t:{u:{v:{switch(g-12|0){case 1:k=v[d+1196>>2];if((k|0)==6){break s}g=10;t[j|0]=10;break t;case 0:f=f&127;t[e+5|0]=f;g=12;break u;case 2:if(v[d+1196>>2]>3?f>>>0<=1:0){break r}g=10;t[j|0]=10;t[(d+1048|0)+h|0]=f;break u;case 3:break v;default:break u}}g=15;f=f&15;t[e+5|0]=f}k=v[d+1196>>2]}if((k|0)>1){break r}w:{x:{y:{switch(g|0){case 0:if(f>>>0>2){break x}break;case 2:break w;case 1:break x;default:break y}}t[j|0]=0;break n}t[j|0]=1;break n}g=f&15;if(g){t[j|0]=2;t[e+5|0]=g;break n}if(!(f&240)){break n}t[j|0]=3;t[e+5|0]=f>>>4;break n}t[e+5|0]=0}vj(e);break n}t[j|0]=0}h=h+1|0;if((h|0)!=4){continue}break}l=l+1|0;if((l|0)!=64){continue}break}}i=i+1|0;if((n|0)!=(i|0)){continue}break}}e=v[d+1196>>2];f=15744;z:{if(e>>>0>=7){break z}f=v[(e<<2)+77304>>2]}e=Ub(d+16|0,16009);Gb(a+1304436|0,e);yb(e);e=Ub(d+16|0,16022);Gb(a+1304448|0,e);yb(e);Mc(a+1304460|0,f);v[a+1304496>>2]=2;g=1;if(!(c&2)){break a}h=1;while(1){c=B(h,104)+a|0;f=c+484384|0;$b(b,v[f>>2]);e=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-e;c=c+484388|0;v[c>>2]=v[c>>2]-e;ad(d+16|0,8,1,1,0);tg(d+16|0,f,b);h=h+1|0;if((h|0)!=16){continue}break}break a}g=0}jb=d+1824|0;return g|0}function Cia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-224|0;jb=d;Jc(b);a:{b:{c:{d:{e:{f:{if(!Mt(b,d+208|0)){break f}if(!qQ(d+208|0)){break f}h=Yh(d+192|0);i=gd(d+176|0);Rb(d+112|0,0,64);v[114578]=0;f=Q(889,b|0,d+104|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+104|4;g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))-4|0;g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=0;h:{i:{j:{while(1){e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-8|0;e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);t[f|0]=e;t[f+1|0]=e>>>8;t[f+2|0]=e>>>16;t[f+3|0]=e>>>24;k:{if(c){break k}e=d+104|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=1413764176){break k}g=1;break g}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114578]=0;U(343,d+24|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=v[114578];v[114578]=0;l:{m:{n:{o:{p:{if((e|0)!=1){v[114578]=0;e=T(339,d+24|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}if(e){break p}Bb(d+24|0);break l}a=P()|0;O()|0;break a}e=d+104|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}v[114578]=0;k=Q(890,d+24|0,d+112|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}v[114578]=0;Q(340,d+24|0,4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break o}v[114578]=0;e=Q(891,d+24|0,16119)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}if(!e){break m}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0<7){break m}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114578]=0;aa(892,d+24|0,i|0,2,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-6|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break o}break m}v[114578]=0;g=W(893,a|0,d+24|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break m}}a=P()|0;O()|0;Bb(d+24|0);break a}pQ(h,d+24|0)}Bb(d+24|0);v[114578]=0;e=Q(889,b|0,d+104|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break j}if(e){continue}}break}if(Wc(i)){v[114578]=0;b=Q(2,d+24|0,16122)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}Gb(i,b);yb(b)}if(!(g&k&1)){break h}b=d+154|0;b=w[b|0]|w[b+1|0]<<8;v[114578]=0;f=b&1;W(479,a+1074308|0,5,!f|0)|0;b=v[114578];v[114578]=0;q:{r:{s:{if((b|0)!=1){b=d+150|0;if(w[b|0]|w[b+1|0]<<8){u[d+24>>1]=64;b=w[b|0]|w[b+1|0]<<8;v[114578]=0;u[d+88>>1]=b<<8|b>>>8;b=Q(478,d+24|0,d+88|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break s}v[a+480228>>2]=x[b>>1]}b=d+152|0;if(!(!f|!(w[b|0]|w[b+1|0]<<8))){b=w[b|0]|w[b+1|0]<<8;v[a+480204>>2]=B((b<<8|b>>>8)&65535,1e4)}if(w[d+112|0]){v[114578]=0;U(746,d+88|0,2,d+112|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;R(417,d+24|0,d+88|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}Gb(a+1304400|0,d+24|0);yb(d+24|0)}b=x[d+158>>1];u[d+86>>1]=b;u[d+22>>1]=b;if(!wp(d+22|0,1,12)){break h}b=x[d+156>>1];u[d+84>>1]=b;u[d+20>>1]=b;if(!wp(d+20|0,1,31)){break h}b=x[d+162>>1];u[d+82>>1]=b;u[d+18>>1]=b;if(!wp(d+18|0,0,23)){break h}b=x[d+164>>1];u[d+80>>1]=b;u[d+16>>1]=b;if(!wp(d+16|0,0,59)){break h}b=x[d+166>>1];u[d+78>>1]=b;u[d+14>>1]=b;if(wp(d+14|0,0,59)){break q}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}b=Sp(d+24|0);c=d+160|0;c=w[c|0]|w[c+1|0]<<8;v[b+20>>2]=(c<<8|c>>>8)&65535;c=d+158|0;c=w[c|0]|w[c+1|0]<<8;v[b+16>>2]=((c<<8|c>>>8)&65535)-1;c=d+156|0;c=w[c|0]|w[c+1|0]<<8;v[b+12>>2]=(c<<8|c>>>8)&65535;c=d+162|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=(c<<8|c>>>8)&65535;c=d+164|0;c=w[c|0]|w[c+1|0]<<8;v[b+4>>2]=(c<<8|c>>>8)&65535;c=d+166|0;c=w[c|0]|w[c+1|0]<<8;v[b>>2]=(c<<8|c>>>8)&65535;v[114578]=0;R(662,a+1304500|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(g&1){v[114578]=0;b=T(339,h|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}if(b){b=Wb(d+24|0);v[114578]=0;W(482,h|0,b|0,32)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}if(Ht(b,16126)){v[114578]=0;U(13,d+88|0,2,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}Gb(a+1304412|0,d+88|0);yb(d+88|0)}v[114578]=0;c=T(894,h|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!c){v[114578]=0;c=T(332,h|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;ea(547,a+1304424|0,h|0,c|0,40,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}}yb(b)}v[114578]=0;b=Q(2,d+88|0,16141)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}v[114578]=0;U(721,d+24|0,b|0,i|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}Gb(a+1304460|0,d+24|0);yb(d+24|0);yb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[114578]=0;a=a+1074308|0;W(479,a|0,84,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;W(479,a|0,83,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;W(479,a|0,85,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}}yb(i);Bb(h)}jb=d+224|0;return g&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b)}yb(i);Bb(h);S(a|0);L()}function $H(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-448|0;jb=e;a:{if(mj(b)){break a}g=w[fk(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;sk(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}Dd(e+184|0);f=v[e+184>>2];Dd(e+416|0);h=ek(f,v[e+420>>2],b);Dd(e+184|0);f=v[b>>2];g=v[b+4>>2];c:{d:{e:{f:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=qc(e+432|0,38235);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Hc(e+16|0,e+8|0)){a=ba(8)|0;v[114578]=0;d=Q(2142,e+416|0,c|0)|0;b=v[114578];v[114578]=0;g:{h:{i:{if((b|0)!=1){v[114578]=0;U(2119,e+184|0,39300,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}mc(a,e+184|0);c=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(e+184|0);break h}b=P()|0;O()|0;break g}b=P()|0;c=1;O()|0}yb(d);if(!c){break d}}ca(a|0);break d}if(!d){break f}d=ba(8)|0;v[114578]=0;f=Q(2142,e+384|0,b|0)|0;b=v[114578];v[114578]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[114578]=0;U(2119,e+400|0,39179,f|0);a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;U(2137,e+416|0,e+400|0,39315);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break q}v[114578]=0;c=Q(2142,e+368|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break p}v[114578]=0;U(138,e+184|0,e+416|0,c|0);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break o}mc(d,e+184|0);v[114578]=0;U(2009,d|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(e+184|0);a=0;break n}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;a=1;O()|0;break m}b=P()|0;O()|0}yb(c)}yb(e+416|0)}yb(e+400|0)}yb(f)}if(!a){break d}ca(d|0);break d}v[e+360>>2]=f;v[e+364>>2]=g;d=qc(e+352|0,38235);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Hc(e+176|0,e+168|0)){a=ba(8)|0;v[114578]=0;d=Q(2142,e+416|0,c|0)|0;b=v[114578];v[114578]=0;s:{t:{u:{if((b|0)!=1){v[114578]=0;U(2119,e+184|0,39300,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break u}mc(a,e+184|0);c=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(e+184|0);break t}b=P()|0;O()|0;break s}b=P()|0;c=1;O()|0}yb(d);if(!c){break d}}ca(a|0);break d}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=qc(e+336|0,39058);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Hc(e+160|0,e+152|0)){b=v[c+4>>2];v[e+328>>2]=v[c>>2];v[e+332>>2]=b;b=qc(e+320|0,39251);d=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=d;d=v[b+4>>2];v[e+56>>2]=v[b>>2];v[e+60>>2]=d;if(Hc(e- -64|0,e+56|0)){v[a+52>>2]=0;break f}b=v[c+4>>2];v[e+312>>2]=v[c>>2];v[e+316>>2]=b;b=qc(e+304|0,39259);d=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=d;d=v[b+4>>2];v[e+40>>2]=v[b>>2];v[e+44>>2]=d;if(Hc(e+48|0,e+40|0)){v[a+52>>2]=1;break f}b=v[c+4>>2];v[e+296>>2]=v[c>>2];v[e+300>>2]=b;b=qc(e+288|0,39268);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Hc(e+32|0,e+24|0)){v[a+52>>2]=2;break f}a=ba(8)|0;v[114578]=0;d=Q(2142,e+416|0,c|0)|0;b=v[114578];v[114578]=0;v:{w:{x:{if((b|0)!=1){v[114578]=0;U(2119,e+184|0,39362,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break x}mc(a,e+184|0);c=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(e+184|0);break w}b=P()|0;O()|0;break v}b=P()|0;c=1;O()|0}yb(d);if(!c){break d}}ca(a|0);break d}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=qc(e+272|0,39101);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Hc(e+144|0,e+136|0)){break f}b=v[c+4>>2];v[e+264>>2]=v[c>>2];v[e+268>>2]=b;b=qc(e+256|0,39273);d=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=d;d=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=d;b=0;y:{if(Hc(e+128|0,e+120|0)){break y}b=v[c+4>>2];v[e+248>>2]=v[c>>2];v[e+252>>2]=b;b=qc(e+240|0,39278);d=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=d;d=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=d;b=1;if(Hc(e+112|0,e+104|0)){break y}b=v[c+4>>2];v[e+232>>2]=v[c>>2];v[e+236>>2]=b;b=qc(e+224|0,39284);d=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=d;d=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=d;b=2;if(Hc(e+96|0,e+88|0)){break y}b=v[c+4>>2];v[e+216>>2]=v[c>>2];v[e+220>>2]=b;b=qc(e+208|0,39295);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Hc(e+80|0,e+72|0)){break y}a=ba(8)|0;v[114578]=0;c=Q(85,e+184|0,39387)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break f}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=IH(v[a+56>>2]),v[i+204>>2]=j;if(!Tw(e+184|0,v[b>>2]+24648|0)){break f}Jx(v[b>>2],e+184|0)}jb=e+448|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function nw(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0;h=jb-80|0;jb=h;v[h+76>>2]=b;z=h+55|0;s=h+56|0;b=0;a:{b:while(1){c:{if((q|0)<0){break c}if((2147483647-q|0)<(b|0)){v[114552]=61;q=-1;break c}q=b+q|0}d:{e:{f:{n=v[h+76>>2];b=n;i=w[b|0];if(i){while(1){g:{i=i&255;h:{if(!i){i=b;break h}if((i|0)!=37){break g}i=b;while(1){if(w[b+1|0]!=37){break h}j=b+2|0;v[h+76>>2]=j;i=i+1|0;m=w[b+2|0];b=j;if((m|0)==37){continue}break}}b=i-n|0;if(a){Qe(a,n,b)}if(b){continue b}j=h;i=!bh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];i:{if(!(i|w[b+2|0]!=36)){r=t[b+1|0]-48|0;y=1;b=b+3|0;break i}r=-1;b=b+1|0}v[j+76>>2]=b;m=0;k=t[b|0];i=k-32|0;j:{if(i>>>0>31){break j}i=1<<i;if(!(i&75913)){break j}while(1){k:{j=b+1|0;v[h+76>>2]=j;k=t[b+1|0];b=k-32|0;if(b>>>0>=32){break k}b=1<<b;if(!(b&75913)){break k}i=b|i;b=j;continue}break}b=j;m=i}l:{if((k|0)==42){j=h;m:{n:{if(!bh(t[b+1|0])){break n}b=v[h+76>>2];if(w[b+2|0]!=36){break n}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;o=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break m}if(y){break f}y=0;o=0;if(a){b=v[c>>2];v[c>>2]=b+4;o=v[b>>2]}b=v[h+76>>2]+1|0}v[j+76>>2]=b;if((o|0)>-1){break l}o=0-o|0;m=m|8192;break l}o=qG(h+76|0);if((o|0)<0){break f}b=v[h+76>>2]}l=-1;o:{if(w[b|0]!=46){break o}if(w[b+1|0]==42){p:{if(!bh(t[b+2|0])){break p}b=v[h+76>>2];if(w[b+3|0]!=36){break p}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;l=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;v[h+76>>2]=b;break o}if(y){break f}if(a){b=v[c>>2];v[c>>2]=b+4;l=v[b>>2]}else{l=0}b=v[h+76>>2]+2|0;v[h+76>>2]=b;break o}v[h+76>>2]=b+1;l=qG(h+76|0);b=v[h+76>>2]}i=0;while(1){x=i;p=-1;if(t[b|0]-65>>>0>57){break a}k=b+1|0;v[h+76>>2]=k;i=t[b|0];b=k;i=w[(i+B(x,58)|0)+55103|0];if(i-1>>>0<8){continue}break}q:{r:{if((i|0)!=19){if(!i){break a}if((r|0)>=0){v[(r<<2)+e>>2]=i;b=(r<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break r}if(!a){break d}pG(h- -64|0,i,c,g);k=v[h+76>>2];break q}if((r|0)>-1){break a}}b=0;if(!a){continue b}}j=m&-65537;i=m&8192?j:m;p=0;r=55136;m=s;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{b=t[k-1|0];b=x?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break s;case 9:case 13:case 14:case 15:break t;case 27:break y;case 12:case 17:break B;case 23:break C;case 0:case 32:break D;case 24:break E;case 22:break F;case 29:break G;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break e;default:break H}}I:{switch(b-65|0){case 0:case 4:case 5:case 6:break t;case 2:break w;case 1:case 3:break e;default:break I}}if((b|0)==83){break x}break e}k=v[h+64>>2];j=v[h+68>>2];r=55136;break A}b=0;J:{switch(x&255){case 0:v[v[h+64>>2]>>2]=q;continue b;case 1:v[v[h+64>>2]>>2]=q;continue b;case 2:i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue b;case 3:u[v[h+64>>2]>>1]=q;continue b;case 4:t[v[h+64>>2]]=q;continue b;case 6:v[v[h+64>>2]>>2]=q;continue b;case 7:break J;default:continue b}}i=v[h+64>>2];v[i>>2]=q;v[i+4>>2]=q>>31;continue b}l=l>>>0>8?l:8;i=i|8;b=120}n=s;C=b&32;x=v[h+68>>2];j=x;k=v[h+64>>2];if(j|k){while(1){n=n-1|0;t[n|0]=C|w[(k&15)+55632|0];x=j;j=j>>>4|0;k=(x&15)<<28|k>>>4;if(k|j){continue}break}}if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break z}r=(b>>>4|0)+55136|0;p=2;break z}b=s;n=v[h+68>>2];j=n;k=v[h+64>>2];if(j|k){while(1){b=b-1|0;t[b|0]=k&7|48;n=j;j=j>>>3|0;k=(n&7)<<29|k>>>3;if(k|j){continue}break}}n=b;if(!(i&8)){break z}b=s-n|0;l=(b|0)<(l|0)?l:b+1|0;break z}b=v[h+68>>2];j=b;k=v[h+64>>2];if((b|0)<-1?1:(b|0)<=-1){j=0-(j+((k|0)!=0)|0)|0;k=0-k|0;v[h+64>>2]=k;v[h+68>>2]=j;p=1;r=55136;break A}if(i&2048){p=1;r=55137;break A}p=i&1;r=p?55138:55136}n=Gm(k,j,s)}i=(l|0)>-1?i&-65537:i;b=v[h+68>>2];j=b;k=v[h+64>>2];if(!(!!(b|k)|l)){l=0;n=s;break e}b=!(j|k)+(s-n|0)|0;l=(b|0)<(l|0)?l:b;break e}b=v[h+64>>2];n=b?b:55146;b=Cr(n,0,l);m=b?b:l+n|0;i=j;l=b?b-n|0:l;break e}m=v[h+64>>2];if(l){break v}b=0;Jf(a,32,o,0,i);break u}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];v[h+64>>2]=h+8;l=-1;m=h+8|0}b=0;K:{while(1){j=v[m>>2];if(!j){break K}j=tG(h+4|0,j);n=(j|0)<0;if(!(n|j>>>0>l-b>>>0)){m=m+4|0;b=b+j|0;if(l>>>0>b>>>0){continue}break K}break}p=-1;if(n){break a}}Jf(a,32,o,b,i);if(!b){b=0;break u}m=0;k=v[h+64>>2];while(1){j=v[k>>2];if(!j){break u}j=tG(h+4|0,j);m=j+m|0;if((m|0)>(b|0)){break u}Qe(a,h+4|0,j);k=k+4|0;if(b>>>0>m>>>0){continue}break}}Jf(a,32,o,b,i^8192);b=(b|0)<(o|0)?o:b;continue b}b=nb[f|0](a,A[h+64>>3],o,l,i,b)|0;continue b}t[h+55|0]=v[h+64>>2];l=1;n=z;i=j;break e}j=b+1|0;v[h+76>>2]=j;i=w[b+1|0];b=j;continue}}p=q;if(a){break a}if(!y){break d}b=1;while(1){a=v[(b<<2)+e>>2];if(a){pG((b<<3)+d|0,a,c,g);p=1;b=b+1|0;if((b|0)!=10){continue}break a}break}p=1;if(b>>>0>=10){break a}while(1){if(v[(b<<2)+e>>2]){break f}b=b+1|0;if((b|0)!=10){continue}break}break a}p=-1;break a}m=m-n|0;k=(l|0)<(m|0)?m:l;j=k+p|0;b=(j|0)>(o|0)?j:o;Jf(a,32,b,j,i);Qe(a,r,p);Jf(a,48,b,j,i^65536);Jf(a,48,k,m,0);Qe(a,n,m);Jf(a,32,b,j,i^8192);continue}break}p=0}jb=h+80|0;return p}function TG(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=C(0),l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=C(0),A=0,D=0,E=C(0),F=C(0),G=C(0),H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0,R=0;if((d|0)>=1){while(1){x=B(v,2304)+b|0;l=0;s=jb-128|0;q=c;if((q|0)>=1){while(1){n=x+(l<<2)|0;j=s;o=0;while(1){i=z[B(31-o|0,72)+n>>2];w=B(o,72)+n|0;h=z[w>>2];m=C(i+h);k=z[w+1152>>2];y=z[B(15-o|0,72)+n>>2];E=C(k+y);z[j>>2]=m+E;w=B(o,12)+49040|0;i=C(z[w+4>>2]*C(h-i));h=C(z[w>>2]*C(y-k));z[j+64>>2]=i+h;k=z[w+8>>2];z[j+32>>2]=k*C(m-E);z[j+96>>2]=C(i-h)*k;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=1;j=s;while(1){m=z[j+28>>2];k=z[j>>2];i=C(m+k);y=z[j+16>>2];E=z[j+12>>2];h=C(y+E);F=C(i+h);G=z[j+24>>2];J=z[j+4>>2];K=C(G+J);L=z[j+20>>2];M=z[j+8>>2];N=C(L+M);O=C(K+N);z[j>>2]=F+O;z[j+16>>2]=C(F-O)*C(.7071067690849304);i=C(i-h);h=C(C(i+C(K-N))*C(.7071067690849304));z[j+24>>2]=C(i-h)*C(1.3065630197525024);z[j+8>>2]=C(h+i)*C(.5411961078643799);h=C(J-G);F=C(M-L);G=C(C(h+F)*C(.7071067690849304));i=C(k-m);m=C(G+i);h=C(i+h);k=C(C(C(E-y)+F)+C(h*C(-.1989123672246933)));h=C(C(k*C(.3826834261417389))+h);z[j+28>>2]=C(m-h)*C(2.562915563583374);z[j+4>>2]=C(h+m)*C(.509795606136322);h=C(k+C(h*C(-.1989123672246933)));i=C(i-G);z[j+20>>2]=C(h+i)*C(.8999761939048767);z[j+12>>2]=C(i-h)*C(.601344883441925);if((o|0)!=4){j=j+32|0;o=o+1|0;continue}break}o=0;i=z[s+32>>2];h=z[s+96>>2];k=z[s+64>>2];while(1){j=n;z[j>>2]=z[s+(o<<2)>>2];o=o+1|0;n=s+(o<<2)|0;m=z[n+96>>2];y=C(m+h);z[j+72>>2]=y+k;h=z[n+32>>2];z[j+144>>2]=h+i;k=z[n- -64>>2];z[j+216>>2]=y+k;n=j+288|0;i=h;h=m;if((o|0)!=7){continue}break}z[j+288>>2]=z[s+28>>2];i=z[s+124>>2];z[j+360>>2]=i+z[s+92>>2];h=z[s+60>>2];z[j+504>>2]=i;z[j+432>>2]=h;l=l+1|0;if((q|0)!=(l|0)){continue}break}}v=v+1|0;if((v|0)!=(d|0)){continue}break}}I=lc(f,a,3840);if((c|0)>=1){P=d<<5;v=0;while(1){n=jb-32|0;jb=n;o=(v<<8)+I|0;w=(v<<2)+b|0;z[o+4080>>2]=z[w+1152>>2];j=d;f=j-1|0;x=w+B(f,2304)|0;z[o+4084>>2]=z[x+1152>>2];z[o+4088>>2]=z[w>>2];z[o+4092>>2]=z[x>>2];z[o+4336>>2]=z[w+1156>>2];z[o+4340>>2]=z[x+1156>>2];z[o+4344>>2]=z[w+4>>2];z[o+4348>>2]=z[x+4>>2];A=(B(v,P)<<1)+e|0;D=A+(f<<1)|0;Fr(D,j,o+244|0);f=j<<6;Fr(f+D|0,j,o+500|0);Fr(A,j,o+240|0);Fr(f+A|0,j,o+496|0);q=49136;H=o+3840|0;f=14;while(1){s=f;g=f<<4;l=g+H|0;p=B(31-f|0,72);m=z[p+w>>2];z[l>>2]=m;z[(g|4)+H>>2]=z[p+x>>2];p=p|4;z[(g|8)+H>>2]=z[p+w>>2];z[(g|12)+H>>2]=z[p+x>>2];p=B(f,72);r=p+76|0;z[l+256>>2]=z[r+w>>2];z[l+260>>2]=z[r+x>>2];p=p+72|0;z[l-248>>2]=z[p+w>>2];z[l-244>>2]=z[p+x>>2];i=z[q>>2];p=g+o|0;k=z[p>>2];h=z[q+4>>2];z[n+16>>2]=C(m*i)-C(k*h);z[n>>2]=C(k*i)+C(m*h);r=f<<2;f=1;while(1){g=f<<2;m=z[g+l>>2];k=z[g+p>>2];z[g+(n+16|0)>>2]=C(m*i)-C(k*h);z[g+n>>2]=C(k*i)+C(m*h);f=f+1|0;if((f|0)!=4){continue}break}l=(r<<2)+H|0;p=l-3584|0;r=l-256|0;i=z[q+12>>2];h=z[q+8>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(m*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-3328|0;r=l-512|0;i=z[q+20>>2];h=z[q+16>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(k*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-3072|0;r=l-768|0;i=z[q+28>>2];h=z[q+24>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(m*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-2816|0;r=l-1024|0;i=z[q+36>>2];h=z[q+32>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(k*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-2560|0;r=l-1280|0;i=z[q+44>>2];h=z[q+40>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(m*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}p=l-2304|0;r=l-1536|0;i=z[q+52>>2];h=z[q+48>>2];f=0;while(1){g=f<<2;t=g+n|0;m=z[g+p>>2];k=z[g+r>>2];z[t>>2]=C(C(m*h)+C(k*i))+z[t>>2];g=g+(n+16|0)|0;z[g>>2]=C(C(k*h)-C(m*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=l-2048|0;p=l-1792|0;i=z[q+60>>2];h=z[q+56>>2];f=0;while(1){l=f<<2;r=l+n|0;m=z[g+l>>2];k=z[l+p>>2];z[r>>2]=C(C(m*h)+C(k*i))+z[r>>2];l=l+(n+16|0)|0;z[l>>2]=C(C(m*i)-C(k*h))+z[l>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(j,15-s|0)<<1;Q=f+D|0,R=mi(z[n+20>>2]),u[Q>>1]=R;l=B(j,s+17|0)<<1;Q=l+D|0,R=mi(z[n+4>>2]),u[Q>>1]=R;Q=f+A|0,R=mi(z[n+16>>2]),u[Q>>1]=R;Q=l+A|0,R=mi(z[n>>2]),u[Q>>1]=R;f=B(j,47-s|0)<<1;Q=f+D|0,R=mi(z[n+28>>2]),u[Q>>1]=R;l=B(j,s+49|0)<<1;Q=l+D|0,R=mi(z[n+12>>2]),u[Q>>1]=R;Q=f+A|0,R=mi(z[n+24>>2]),u[Q>>1]=R;Q=l+A|0,R=mi(z[n+8>>2]),u[Q>>1]=R;f=s-1|0;q=q- -64|0;if(s){continue}break}jb=n+32|0;v=v+2|0;if((v|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){v=0;while(1){z[(v<<2)+a>>2]=z[(b+v<<2)+I>>2];c=v>>>0<958;v=v+2|0;if(c){continue}break}break a}lc(a,(b<<2)+I|0,3840)}}function kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=jb-768|0;jb=d;Jc(b);f=jb-16|0;jb=f;g=d+160|0;iP(f+8|0,g);i=Hb(f+8|0);e=b;h=nc(e,ac(f,f+8|0));if((i|0)==(h|0)){$b(e,Hb(f+8|0))}jb=f+16|0;e=(h|0)==(i|0);if(!e){jP(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!lP(d+160|0)){break n}if(!Qb(b,id(kP(d+160|0),mb))){break n}if(!c){o=1;break n}Hd(a,262144);Kt(d+104|0,2,d+160|0);Ic(d+24|0,d+104|0);Gb(a+1304400|0,d+24|0);yb(d+24|0);e=Ub(d+24|0,16992);Gb(a+1304436|0,e);yb(e);e=Ub(d+24|0,17004);Gb(a+1304448|0,e);yb(e);f=Ub(d+144|0,17008);v[114578]=0;R(219,d+104|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}t[d+8|0]=w[d+190|0];e=w[d+189|0];v[114578]=0;t[d+127|0]=e;R(993,d+128|0,d+127|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=0;v[114578]=0;X(453,d+24|0,d+104|0,d+8|0,d+128|0);g=v[114578];v[114578]=0;if((g|0)==1){break f}Gb(a+1304460|0,d+24|0);yb(d+24|0);yb(d+128|0);Ib(d+104|0);yb(f);v[a+480208>>2]=12;v[a+1304496>>2]=4;u[a+480188>>1]=w[d+198|0]|w[d+199|0]<<8;u[d+24>>1]=w[d+194|0]|w[d+195|0]<<8;u[d+104>>1]=3999;A=a,C=x[lf(d+24|0,d+104|0)>>1],u[A+480190>>1]=C;Yz(Vb(a+484360|0),d+256|0,w[d+192|0]|w[d+193|0]<<8,255,254);if(x[a+480188>>1]){while(1){f=(e<<5)+a|0;zg(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}ud(d+104|0,b,B(w[d+194|0]|w[d+195|0]<<8,80));if(x[a+480190>>1]){g=c&2;i=d+72|0;e=0;while(1){v[114578]=0;Q(994,d+104|0,d+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}v[114578]=0;U(577,d+8|0,2,i|0);f=v[114578];v[114578]=0;o:{p:{q:{if((f|0)==1){break q}v[114578]=0;R(417,d+128|0,d+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break q}v[114578]=0;e=e+1|0;Q(371,((e<<5)+a|0)+946300|0,d+128|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}yb(d+128|0);v[114578]=0;f=(B(e,104)+a|0)+484380|0;U(995,d+128|0,d+24|0,f|0);h=v[114578];v[114578]=0;r:{if((h|0)==1){break r}if(!g|!v[f>>2]){break o}h=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[114578]=0;h=Q(256,b|0,h|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break r}if(!h){break o}v[114578]=0;W(402,d+128|0,f|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){break o}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(d+128|0);break g}if(x[a+480190>>1]>e>>>0){continue}break}}o=1;s:{if(!(c&1)){break s}c=w[d+196|0]|w[d+197|0]<<8;i=0;v[114578]=0;k=a+484344|0;R(403,k|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break l}if(!(w[d+196|0]|w[d+197|0]<<8)){break s}p=d+24|4;q=d+24|2;r=d+24|5;s=d+24|3;y=d+24|1;while(1){v[114578]=0;c=W(404,k|0,i&65535,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(i<<1)+d|0;e=c+512|0;if(!(w[e|0]|w[e+1|0]<<8)){break t}c=w[c+512|0]|w[c+513|0]<<8;v[114578]=0;c=Q(256,b|0,c<<4)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}if(!c){break t}l=0;c=_b(k,i);v[114578]=0;m=W(472,c|0,0,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}while(1){v[114578]=0;c=Q(258,b|0,1)|0;e=v[114578];v[114578]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}v[114578]=0;h=T(389,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break w}if(h){break v}l=l+1|0;m=B(x[a+480188>>1],6)+m|0;break u}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}u[d+28>>1]=0;v[d+24>>2]=0;c=h&31;f=B(c,6)+m|0;n=Rh(d+24|0);g=c>>>0<x[a+480188>>1];x:{y:{z:{A:{B:{C:{D:{if(!(h&32)){break D}v[114578]=0;R(473,d+128|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break C}e=dd(d+128|0);j=g?f:d+24|0;c=w[d+128|0];t[j|0]=c;t[(g?f+1|0:y)|0]=w[e|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}t[j|0]=c}if(!(h&64)){break x}v[114578]=0;R(473,d+128|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break j}z=dd(d+128|0);c=g?f+3|0:s;e=w[d+128|0];t[c|0]=e;j=g?f+5|0:r;t[j|0]=w[z|0];if(e>>>0>15){break B}v[114578]=0;Z(574,(g?f:n)|0);e=v[114578];v[114578]=0;if((e|0)!=1){break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}if(e>>>0>23){break y}n=c;c=w[e+17010|0];t[n|0]=c;break z}c=w[c|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}c=w[j|0];F:{G:{if(c>>>0>=136){e=c&127;break G}e=128;if(c>>>0<129){break F}}t[j|0]=e;c=e}t[j|0]=(B(c&127,255)>>>0)/127;break x}v[114578]=0;t[d+8|0]=64;c=Q(393,j|0,d+8|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){t[j|0]=w[c|0]<<1;break x}a=P()|0;O()|0;break g}t[c|0]=0}if(!(h&128)){break u}t[(g?f+2|0:q)|0]=1;v[114578]=0;c=T(389,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}t[(g?f+4|0:p)|0]=c}if(l>>>0<64){continue}break}}i=i+1|0;if(i>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Bb(d+104|0)}jb=d+768|0;return o|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}Bb(d+104|0);break a}a=P()|0;O()|0;yb(d+128|0);break d}a=P()|0;O()|0}Ib(d+104|0);break b}a=P()|0;O()|0}yb(f)}S(a|0);L()}function gU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-128|0;jb=e;Jc(b);a:{if(!RA(b,12168)){break a}if(!hu(b,e+112|0)){break a}if(!TA(e+112|0)){break a}if(!Qb(b,id(SA(e+112|0),mb))){break a}if(!$b(b,w[e+121|0]|w[e+122|0]<<8)){break a}b:{if(!c){break b}Hd(a,4096);v[a+480208>>2]=12;u[a+480188>>1]=(w[e+112|2]&31)+1;f=e+112|3;u[a+480190>>1]=w[f|0];lj(a,1);d=Ub(e+56|0,12176);Gb(a+1304436|0,d);yb(d);d=Ub(e+56|0,12194);Gb(a+1304448|0,d);yb(d);d=Ub(e+80|0,12198);v[114578]=0;R(219,e+96|0,d|0);i=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((i|0)!=1){v[114578]=0;X(429,e+56|0,e+96|0,e+112|1,e+112|0);i=v[114578];v[114578]=0;if((i|0)==1){break o}Gb(a+1304460|0,e+56|0);yb(e+56|0);Ib(e+96|0);yb(d);v[a+1304496>>2]=4;f=w[f|0];d=jb-16|0;jb=d;i=e+96|0;v[i>>2]=0;v[i+4>>2]=0;v[d+12>>2]=0;Zc(i+8|0,d+12|0,d+8|0);if(f){lq(i,f);XB(i,f,0)}jb=d+16|0;if(x[a+480190>>1]){f=1;d=1;while(1){v[114578]=0;Q(430,b|0,e+56|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break k}v[114578]=0;R(431,e+56|0,(B(f,104)+a|0)+484380|0);h=v[114578];v[114578]=0;if((h|0)==1){break k}h=w[e+72|0];ee(e+40|0,i,f-1|0);ge(e+40|0,(h&3)!=0);d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}v[114578]=0;W(432,b|0,a+1304400|0,-1)|0;f=v[114578];v[114578]=0;d=1;if((f|0)!=1){if(x[a+480190>>1]){while(1){v[114578]=0;W(433,b|0,(((d&65535)<<5)+a|0)+946300|0,-1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[114578]=0;f=(d<<5)+a|0;Z(434,f+480280|0);h=v[114578];v[114578]=0;if((h|0)==1){break e}v[114578]=0;W(435,b|0,f+480289|0,-1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+112|4;h=w[f|0]|w[f+1|0]<<8;d=0;v[114578]=0;k=a+484344|0;R(403,k|0,h|0);h=v[114578];v[114578]=0;if((h|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break n}b=P()|0;O()|0;Ib(e+96|0)}yb(d);break c}b=P()|0;O()|0;break d}if(w[f|0]|w[f+1|0]<<8){while(1){v[114578]=0;W(436,b|0,e+56|0,-1)|0;h=v[114578];v[114578]=0;p:{q:{if((h|0)==1){break q}v[114578]=0;h=W(404,k|0,d&65535,64)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}if(!h){break p}h=_b(k,d);v[114578]=0;Q(437,h|0,e+56|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break p}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}v[114578]=0;g=T(359,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}r:{if(!g){break r}v[114578]=0;d=Q(258,b|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break f}if(!d){break r}h=rq(e+56|0);v[114578]=0;W(438,b|0,h|0,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}d=Wb(e+40|0);v[114578]=0;R(111,d|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}l=e,m=bc(h),v[l>>2]=m;l=e,m=cc(h),v[l+32>>2]=m;if(Jb(e,e+32|0)){while(1){s:{g=w[v[e>>2]];if(g&128){l=e,m=sf(d),v[l+16>>2]=m;Md(e+24|0,e+16|0);v[114578]=0;aa(439,d|0,v[e+24>>2],g&127,32)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break s}break i}v[114578]=0;R(110,d|0,g<<24>>24);g=v[114578];v[114578]=0;if((g|0)!=1){break s}break i}qg(e);if(Jb(e,e+32|0)){continue}break}}v[114578]=0;X(440,e|0,4,5,d|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}Gb(d,e);yb(e);g=Tb(d);v[114578]=0;g=T(441,g|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break i}j=Fb(d);v[114578]=0;ea(442,a+1304424|0,g|0,j|0,76,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break i}yb(d);fe(h)}h=Vb(a+484360|0);d=e+112|6;g=w[d|0]|w[d+1|0]<<8;d=0;v[114578]=0;ea(443,h|0,b|0,g|0,65535,65535)|0;h=v[114578];v[114578]=0;if((h|0)==1){break f}t:{u:{v:{w:{if(!(w[f|0]|w[f+1|0]<<8)){break w}h=c&1;while(1){v[114578]=0;g=Q(258,b|0,4)|0;j=v[114578];v[114578]=0;x:{if((j|0)!=1){if(g){break x}break w}b=P()|0;O()|0;break d}v[114578]=0;g=T(392,b|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break u}v[114578]=0;U(343,e+56|0,b|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break t}y:{if(!h){break y}v[114578]=0;g=Q(444,k|0,d&65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break v}if(!g){break y}g=_b(k,d);v[114578]=0;U(445,g|0,0,e+56|0);g=v[114578];v[114578]=0;if((g|0)==1){break v}}Bb(e+56|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){f=1;d=1;while(1){c=B(f,104)+a|0;h=x[c+484414>>1];ee(e+56|0,i,f-1|0);f=ad(e+40|0,h&1?16:8,1,0,Cb(e+56|0)?6:0);v[114578]=0;W(402,f|0,c+484380|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break j}d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}ke(i);break b}b=P()|0;O()|0;Bb(e+56|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d);break g}b=P()|0;O()|0}fe(h);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}ke(i)}S(b|0);L()}f=1}jb=e+128|0;return f|0}function td(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;l=jb-96|0;jb=l;p=c;u=(g&131071)<<15|f>>>17;j=i&65535;s=j;k=h;C=k<<15|g>>>17;n=(e^i)&-2147483648;o=e&65535;x=o;m=d;y=o;o=0;D=(j&131071)<<15|k>>>17;F=i>>>16&32767;M=e>>>16&32767;a:{b:{if(M-1>>>0<=32765){j=0;if(F-1>>>0<32766){break b}}q=e&2147483647;w=q;j=d;if(!(!j&(q|0)==2147418112?!(b|c):q>>>0<2147418112)){z=d;n=e|32768;break a}e=i&2147483647;q=e;d=h;if(!(!d&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;n=i|32768;b=f;c=g;break a}if(!(b|j|(w^2147418112|c))){if(!(d|f|(g|q))){n=2147450880;b=0;c=0;break a}n=n|2147418112;b=0;c=0;break a}if(!(d|f|(q^2147418112|g))){d=b|j;e=c|w;b=0;c=0;if(!(d|e)){n=2147450880;break a}n=n|2147418112;break a}if(!(b|j|(c|w))){b=0;c=0;break a}if(!(d|f|(g|q))){b=0;c=0;break a}if((w|0)==65535|w>>>0<65535){h=b;i=c;d=!(m|x);e=d<<6;j=E(d?b:m)+32|0;b=E(d?c:x);b=e+((b|0)==32?j:b)|0;qf(l+80|0,h,i,m,x,b-15|0);m=v[l+88>>2];p=v[l+84>>2];y=v[l+92>>2];t=16-b|0;b=v[l+80>>2]}j=t;if(q>>>0>65535){break b}c=!(k|s);d=c<<6;e=E(c?f:k)+32|0;c=E(c?g:s);c=d+((c|0)==32?e:c)|0;i=c;qf(l- -64|0,f,g,k,s,c-15|0);e=v[l+76>>2];c=e;h=v[l+72>>2];d=h;d=d<<15;e=v[l+68>>2];C=e>>>17|d;d=0;f=v[l+64>>2];u=d|((e&131071)<<15|f>>>17);D=(c&131071)<<15|h>>>17;j=(t-i|0)+16|0}t=j;d=u;c=b;s=0;q=Fma(d,0,b,s);b=mb;G=b;e=f;A=e<<15&-32768;k=p;g=Fma(A,0,k,0);f=g+q|0;e=mb+b|0;e=f>>>0<g>>>0?e+1|0:e;h=f;j=f;i=0;g=Fma(c,s,A,B);f=i+g|0;b=j;j=j+mb|0;j=f>>>0<g>>>0?j+1|0:j;u=f;g=j;J=(b|0)==(j|0)&f>>>0<i>>>0|b>>>0>j>>>0;N=Fma(d,r,k,H);K=mb;p=m;f=Fma(A,B,m,0);b=f+N|0;j=mb+K|0;O=b;m=Fma(C,0,c,s);i=b+m|0;b=b>>>0<f>>>0?j+1|0:j;f=b+mb|0;w=i;f=i>>>0<m>>>0?f+1|0:f;x=f;j=f;f=(e|0)==(G|0)&h>>>0<q>>>0|e>>>0<G>>>0;h=e+w|0;j=f+j|0;q=h;j=h>>>0<e>>>0?j+1|0:j;m=j;e=h;h=j;Q=Fma(d,r,p,P);G=mb;f=A;I=y|65536;A=o;i=Fma(f,B,I,o);f=i+Q|0;j=mb+G|0;j=f>>>0<i>>>0?j+1|0:j;R=f;B=Fma(C,S,k,H);i=f+B|0;o=j;f=j+mb|0;f=i>>>0<B>>>0?f+1|0:f;L=i;D=D&2147483647|-2147483648;i=Fma(c,s,D,0);c=L+i|0;s=f;j=f+mb|0;B=c;c=c>>>0<i>>>0?j+1|0:j;y=J;i=0;f=i+e|0;j=h+B|0;J=f;h=f;e=y+f|0;y=f>>>0<i>>>0?j+1|0:j;f=y;f=e>>>0<h>>>0?f+1|0:f;h=e;i=f;t=(t+(F+M|0)|0)-16383|0;f=Fma(p,P,C,S);e=mb;r=Fma(d,r,I,A);d=r+f|0;j=mb+e|0;j=d>>>0<r>>>0?j+1|0:j;r=d;f=(e|0)==(j|0)&f>>>0>d>>>0|e>>>0>j>>>0;e=j;F=f;f=Fma(D,T,k,H);d=f+d|0;j=mb+j|0;j=d>>>0<f>>>0?j+1|0:j;f=d;d=j;k=(j|0)==(e|0)&f>>>0<r>>>0|e>>>0>j>>>0;j=F+k|0;e=0;e=j>>>0<k>>>0?1:e;r=f;k=d;F=j;f=(b|0)==(x|0)&w>>>0<O>>>0|b>>>0>x>>>0;b=f+((b|0)==(K|0)&N>>>0>O>>>0|b>>>0<K>>>0)|0;j=0;j=b>>>0<f>>>0?1:j;f=b;b=r+f|0;j=d+j|0;j=b>>>0<f>>>0?j+1|0:j;H=b;d=j;j=(j|0)==(k|0)&b>>>0<r>>>0|j>>>0<k>>>0;b=F+j|0;f=e;f=b>>>0<j>>>0?f+1|0:f;e=Fma(D,T,I,A);b=e+b|0;j=mb+f|0;r=b;e=b>>>0<e>>>0?j+1|0:j;k=Fma(D,T,p,P);f=mb;p=Fma(C,S,I,A);b=p+k|0;j=mb+f|0;j=b>>>0<p>>>0?j+1|0:j;p=b;b=j;j=(f|0)==(j|0)&k>>>0>p>>>0|f>>>0>j>>>0;k=b+r|0;e=e+j|0;e=k>>>0<b>>>0?e+1|0:e;r=k;k=0;b=k+H|0;j=d+p|0;j=b>>>0<k>>>0?j+1|0:j;f=j;k=(d|0)==(j|0)&b>>>0<H>>>0|d>>>0>j>>>0;d=r+k|0;j=e;C=d;d=d>>>0<k>>>0?j+1|0:j;p=b;k=f;f=(o|0)==(s|0)&R>>>0>L>>>0|o>>>0>s>>>0;e=f+((o|0)==(G|0)&Q>>>0>R>>>0|o>>>0<G>>>0)|0;f=e;e=f+((c|0)==(s|0)&B>>>0<L>>>0|c>>>0<s>>>0)|0;f=e;b=c+b|0;e=f+k|0;e=b>>>0<c>>>0?e+1|0:e;o=b;c=b;b=e;e=(e|0)==(k|0)&c>>>0<p>>>0|e>>>0<k>>>0;c=e+C|0;j=d;j=c>>>0<e>>>0?j+1|0:j;d=c;k=d;e=(m|0)==(y|0)&q>>>0>J>>>0|m>>>0>y>>>0;d=e+((m|0)==(x|0)&q>>>0<w>>>0|m>>>0<x>>>0)|0;f=0;f=d>>>0<e>>>0?1:f;m=d;d=d+o|0;e=b+f|0;e=d>>>0<m>>>0?e+1|0:e;c=(b|0)==(e|0)&d>>>0<o>>>0|b>>>0>e>>>0;b=k+c|0;j=b>>>0<c>>>0?j+1|0:j;c=j;c:{if(j&65536){t=t+1|0;break c}m=g>>>31|0;j=c<<1|b>>>31;b=b<<1|e>>>31;c=j;j=e<<1|d>>>31;d=d<<1|i>>>31;e=j;o=u;j=g<<1|o>>>31;u=o<<1;g=j;j=i<<1|h>>>31;h=h<<1|m;i=j}if((t|0)>=32767){n=n|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){f=1-t|0;if(f>>>0>=128){b=0;c=0;break a}j=t+127|0;qf(l+48|0,u,g,h,i,j);qf(l+32|0,d,e,b,c,j);Fm(l+16|0,u,g,h,i,f);Fm(l,d,e,b,c,f);u=(v[l+48>>2]|v[l+56>>2])!=0|(v[l+52>>2]|v[l+60>>2])!=0|(v[l+32>>2]|v[l+16>>2]);g=v[l+36>>2]|v[l+20>>2];h=v[l+40>>2]|v[l+24>>2];i=v[l+44>>2]|v[l+28>>2];d=v[l>>2];e=v[l+4>>2];c=v[l+12>>2];b=v[l+8>>2];break d}c=c&65535|t<<16}z=b|z;n=c|n;if(!(!h&(i|0)==-2147483648?!(g|u):(i|0)>-1)){j=e;b=d+1|0;j=b>>>0<1?j+1|0:j;f=b;c=j;f=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=f+z|0;e=n;z=d;n=d>>>0<f>>>0?e+1|0:e;break a}if(h|u|(i^-2147483648|g)){b=d;c=e;break a}c=d&1;b=c+d|0;j=e;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;e=(e|0)==(j|0)&d>>>0>f>>>0|e>>>0>j>>>0;d=e+z|0;j=n;z=d;n=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=n;jb=l+96|0}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;g=jb-208|0;jb=g;Jc(b);a:{b:{c:{d:{e:{if(!Xz(b,g+160|0)){break e}if(!RO(g+160|0)){break e}if(!c){h=1;break e}if(!Qb(b,id(QO(g+160|0),mb))){break e}Hd(a,128);yg(g+144|0,2,g+175|0);Ic(g+72|0,g+144|0);Gb(a+1304400|0,g+72|0);yb(g+72|0);d=Ub(g+72|0,17473);Gb(a+1304436|0,d);yb(d);d=Ub(g+72|0,17486);Gb(a+1304448|0,d);yb(d);d=Ub(g+144|0,17490);v[114578]=0;U(1027,g+72|0,d|0,v[(w[g+174|0]<<2)+77148>>2]);e=v[114578];v[114578]=0;h=1;if((e|0)==1){break b}Gb(a+1304460|0,g+72|0);yb(g+72|0);yb(d);v[a+480208>>2]=12;v[a+1304496>>2]=4;Jy(a+1304424|0,b,w[g+207|0]<<5,32,0);y=a,z=Gd(b),u[y+480190>>1]=z;if(x[a+480190>>1]){j=1;while(1){f:{if(w[g+174|0]>=52){jA(b,g+72|0);break f}e=jb-16|0;jb=e;v[e+12>>2]=64;v[e>>2]=66;d=b;i=v[Lb(e+12|0,e)>>2];if(!Qb(d,i)){i=nf(d)}f=g+72|0;Ot(e,f);xg(d,v[e>>2],i);Ot(e,f);Rb(v[e>>2]+i|0,0,66-i|0);$b(d,v[e+12>>2]);jb=e+16|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=jb-32|0;jb=i;e=(B(h,104)+a|0)+484380|0;Fd(e,0);d=g+72|0;Hk(i,2,d+32|0);Ic(i+16|0,i);v[114578]=0;Q(372,e+43|0,i+16|0)|0;f=v[114578];v[114578]=0;g:{if((f|0)!=1){yb(i+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);y=e,z=v[Lb(i+16|0,e)>>2],v[y+16>>2]=z;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;f=d- -64|0;if(w[f|0]|w[f+1|0]<<8){Ys(e,+((w[f|0]|w[f+1|0]<<8)<<16>>16)*25431315104166665e-22)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}jb=i+32|0;break g}a=P()|0;O()|0;yb(i+16|0);S(a|0);L()}yg(g+56|0,2,g+72|0);Ic(g+144|0,g+56|0);v[114578]=0;Q(371,((h<<5)+a|0)+946300|0,g+144|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}yb(g+144|0);j=j+1|0;h=j&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}Np(Vb(a+484360|0),b,256,255,254);h=0;d=Gd(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=Gd(b);r=d+1|0;if(x[a+480188>>1]){while(1){e=(h<<5)+a|0;zg(e+480280|0);i=e+480284|0;i:{if(w[g+174|0]>=51){e=(Gd(b)<<4|8)&248;break i}e=h&1?192:64}u[i>>1]=e;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}m=a+484344|0;_f(m,r);h=0;j=0;while(1){e=j&65535;if(!rg(m,e,64)){break e}j=j+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){i=Rh(g+72|0);n=0;while(1){if(Qb(b,5)){j=0;h=Xe(_b(m,n),0,o&65535);while(1){s=64-j|0;l=w[g+174|0];f=jb-16|0;jb=f;p=1;d=i;q=d;e=b;k=Gd(e);if((k|0)==252){p=Gd(e);k=Gd(e)}t[q|0]=(k-1&255)>>>0<60?k+36|0:0;Sl(f+8|0,e);e=dd(f+8|0);k=Bf(f+8|0);q=Sh(f+8|0);t[d+1|0]=w[f+8|0];t[f+7|0]=w[e|0]&15;t[f+6|0]=w[e|0]>>>4;t[f+5|0]=w[k|0];t[f+4|0]=w[q|0];PO(f+7|0,f+5|0,l);PO(f+6|0,f+4|0,l);j:{k:{l:{m:{k=w[f+7|0];l=(k|0)!=10;e=w[f+6|0];if(!(l|(e|0)!=10)){t[f+7|0]=0;y=f,z=un((w[f+4|0]|w[f+5|0]<<8)>>>6|0),t[y+5|0]=z;break m}if(!l){y=f,z=un(w[f+5|0]<<2),t[y+5|0]=z;break m}if((e|0)==10){y=f,z=un(w[f+4|0]<<2),t[y+4|0]=z;break m}if((e|0)!=(k|0)){break m}t[f+6|0]=0;break l}e=w[f+6|0];if((e|0)==13){break k}if(e){break j}k=w[f+7|0]}if((k&255)==13){break j}}lh(f+7|0,f+6|0);lh(f+5|0,f+4|0)}sx(f+6|0,f+4|0,f+7|0,f+5|0);rx(f,f+7|0,f+5|0,f+6|0,f+4|0);t[d+2|0]=w[f+7|0];t[d+4|0]=w[f+5|0];t[d+3|0]=w[f+6|0];t[d+5|0]=w[f+4|0];jb=f+16|0;e=j+p|0;j=e>>>0>64?s:p;if(j){while(1){d=v[g+72>>2];t[h|0]=d;t[h+1|0]=d>>>8;t[h+2|0]=d>>>16;t[h+3|0]=d>>>24;d=x[g+76>>1];t[h+4|0]=d;t[h+5|0]=d>>>8;h=B(x[a+480188>>1],6)+h|0;j=j-1|0;if(j){continue}break}j=e>>>0<64?e:64;if(j>>>0<64){continue}}break}n=n+1|0;if((r|0)!=(n|0)){continue}}break}o=o+1|0;if(x[a+480188>>1]>(o&65535)>>>0){continue}break}}e=x[a+480188>>1];d=g+8|0;i=kt(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[114578]=0;U(1029,i|0,e|0,0);e=v[114578];v[114578]=0;if((e|0)==1){a=P()|0;O()|0;ke(i);S(a|0);L()}v[114578]=0;U(1028,g+32|0,m|0,d|0);e=v[114578];v[114578]=0;h=1;if((e|0)==1){break d}ke(g+32|0);ke(d);if(!(c&2)|!x[a+480190>>1]){break e}j=1;while(1){c=B(j&65535,104)+a|0;tg(ad(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);j=j+1|0;if(x[a+480190>>1]>=(j&65535)>>>0){continue}break}}jb=g+208|0;return h|0}h=P()|0;O()|0;ke(d);break a}h=P()|0;O()|0;yb(g+144|0);break a}h=P()|0;O()|0;yb(d)}S(h|0);L()}function qga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb+-64|0;jb=e;a:{if(!Qb(c,8)){break a}$b(c,4);while(1){m=yt(c);if(m){break a}o=jb-288|0;jb=o;i=uN(o);h=jb-368|0;jb=h;uN(h+80|0);j=lc(i,h+80|0,282);f=0;i=c;if(ph(c,20108)){fg(i,4);l=Ze(h- -64|0,i);v[114578]=0;g=Q(1201,l|0,j|0)|0;k=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{if((k|0)==1){break g}if(!g){break b}g=w[j+26|0];v[114578]=0;g=Q(258,l|0,g|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break g}if(!g){break b}h:{i:{j:{if(w[j+26|0]){g=0;while(1){v[114578]=0;k=T(377,l|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break i}t[(f+j|0)+27|0]=k;g=g+k|0;f=f+1|0;if(f>>>0<w[j+26|0]){continue}break}g=g&65535;break j}g=0}f=0;v[114578]=0;k=Q(258,l|0,g|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break d}if(k){break h}break b}f=P()|0;O()|0;break c}v[114578]=0;Q(340,l|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}fg(l,vN(j));v[114578]=0;k=T(1202,h+56|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}tN(h+80|0);v[114578]=0;Q(1203,l|0,h+80|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;u[h+102>>1]=0;u[h+104>>1]=0;W(1204,k|0,h+80|0,h+107|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}f=w[j+26|0];v[114578]=0;Q(340,l|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}f=w[j+26|0];v[114578]=0;n=j+27|0;W(1204,k|0,n|0,f+n|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;U(343,h+40|0,l|0,g|0);g=v[114578];v[114578]=0;k:{l:{m:{if((g|0)!=1){v[114578]=0;R(859,h+16|0,h+40|0);g=v[114578];v[114578]=0;if((g|0)==1){break m}v[114578]=0;R(1206,h+8|0,h+16|0);g=v[114578];v[114578]=0;if((g|0)==1){break l}v[114578]=0;Q(1207,k|0,h+8|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break l}Ec(h+16|0);Bb(h+40|0);f=0;v[114578]=0;g=T(1208,k|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break e}if((g|0)!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break b}g=vN(j);v[114578]=0;Q(340,i|0,g|0)|0;i=v[114578];v[114578]=0;f=1;if((i|0)!=1){break b}break d}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;Ec(h+16|0)}Bb(h+40|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}Bb(l);S(f|0);L()}Bb(l)}jb=h+368|0;jb=o+288|0;if(f){continue}break}}t[d|0]=w[d|0]!=0|m;Jc(c);n:{o:{p:{q:{r:{s:{if(m){d=Cf(c);ud(e+48|0,c,nf(c));u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=d>>>(b&1)>>>(b>>>6&1);v[114578]=0;v[e+44>>2]=0;v[e+40>>2]=0;R(859,e+16|0,e+48|0);b=v[114578];v[114578]=0;if((b|0)==1){break s}v[114578]=0;c=T(414,e+16|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){d=v[e+16>>2];v[114578]=0;b=T(856,c|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}v[114578]=0;i=T(857,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;b=ea(858,b|0,i|0,e+44|0,e+40|0,0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}v[114578]=0;Q(340,e+48|0,v[e+44>>2])|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}if(!b){break q}i=v[e+44>>2];v[114578]=0;T(466,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}m=d-i|0;i=c+i|0;c=v[e+40>>2];d=0;while(1){t:{if(c){if(!m|(c|0)!=1){break r}if(y[a>>2]>d>>>0){break t}break r}if(y[a>>2]<=d>>>0){break r}}if(!De(a)){break r}v[114578]=0;v[e+12>>2]=0;v[e+8>>2]=0;c=T(856,i|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;g=T(857,m|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break p}v[114578]=0;c=ka(860,b|0,c|0,g|0,e+12|0,e+4|0,e+8|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;v[e+44>>2]=c;Q(340,e+48|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break p}c=v[a>>2];v[114578]=0;g=v[e+44>>2];c=T(861,c-d|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break p}Ak(e+8|0,c);u:{if(v[e+8>>2]<1){break u}if(v[e+12>>2]!=(ue(a)|0)){break u}c=0;if(v[e+12>>2]<=0){break u}while(1){v:{if(t[a+34|0]&1){h=v[a+20>>2];f=ue(a);j=v[v[e+4>>2]+(c<<2)>>2];v[114578]=0;fa(862,h+(B(d,f)<<1)|0,j|0,v[e+12>>2],v[e+8>>2],c|0);h=v[114578];v[114578]=0;if((h|0)!=1){break v}break p}h=v[a+20>>2];f=ue(a);j=v[v[e+4>>2]+(c<<2)>>2];v[114578]=0;fa(863,h+B(d,f)|0,j|0,v[e+12>>2],v[e+8>>2],c|0);h=v[114578];v[114578]=0;if((h|0)==1){break p}}c=c+1|0;if((c|0)<v[e+12>>2]){continue}break}}v[114578]=0;h=v[e+8>>2];c=T(864,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break p}m=m-g|0;i=g+i|0;v[e+40>>2]=c;d=d+h|0;continue}}break p}tg(b,a,c);c=1;break n}c=P()|0;O()|0;break o}v[114578]=0;Z(865,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){break q}break p}c=(b|0)!=0;Ec(e+16|0);Bb(e+48|0);break n}c=P()|0;O()|0;Ec(e+16|0)}Bb(e+48|0);S(c|0);L()}jb=e- -64|0;return c|0}function _ga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-192|0;jb=d;Jc(b);a:{if(!Xz(b,d+144|0)){break a}if(!aP(d+144|0)){break a}if(!Qb(b,id($O(d+144|0),mb))){break a}b:{if(!c){break b}Hd(a,256);Hn(d+16|0,2,d+144|0);Ic(d+48|0,d+16|0);Gb(a+1304400|0,d+48|0);yb(d+48|0);e=Ub(d+48|0,17295);Gb(a+1304436|0,e);yb(e);e=Ub(d+48|0,17312);Gb(a+1304448|0,e);yb(e);g=Ub(d+128|0,17316);v[114578]=0;R(219,d+16|0,g|0);e=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){v[114578]=0;R(452,d+112|0,d+175|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}v[114578]=0;X(453,d+48|0,d+16|0,d+174|0,d+112|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}Gb(a+1304460|0,d+48|0);yb(d+48|0);yb(d+112|0);Ib(d+16|0);yb(g);v[a+1304496>>2]=4;v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+176|0];if(w[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}g=(f&255?f:96)&255;e=BM(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=e;if(w[d+175|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;yb(d+112|0)}Ib(d+16|0)}yb(g);break c}t[d+48|0]=64;p=a,q=w[pc(d+178|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;zg(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){lt(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break k}i=jb-32|0;jb=i;h=(B(f,104)+a|0)+484380|0;Fd(h,0);g=d+16|0;Hk(i,2,g);Ic(i+16|0,i);v[114578]=0;Q(372,h+43|0,i+16|0)|0;e=v[114578];v[114578]=0;l:{m:{if((e|0)!=1){yb(i+16|0);e=g+24|0;v[h+24>>2]=w[e|0]|w[e+1|0]<<8;t[i+16|0]=w[g+22|0];t[i|0]=64;p=h,q=w[pc(i+16|0,i)|0]<<2,u[p+30>>1]=q;e=g+16|0;v[h>>2]=w[e|0]|w[e+1|0]<<8;e=g+18|0;v[h+4>>2]=w[e|0]|w[e+1|0]<<8;e=g+20|0;j=w[e|0]|w[e+1|0]<<8;v[h+8>>2]=j;g=v[h>>2];if(g>>>0>1){break m}v[h>>2]=0;break l}a=P()|0;O()|0;yb(i+16|0);S(a|0);L()}e=v[h+4>>2];if(g>>>0<=e>>>0|e>>>0>=j>>>0|(j|0)==65535){break l}u[h+34>>1]=2;p=h,q=v[Lb(h+8|0,h)>>2],v[p+8>>2]=q}jb=i+32|0;Hk(d,2,d+16|0);Ic(d+112|0,d);v[114578]=0;Q(371,((f<<5)+a|0)+946300|0,d+112|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}yb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;Np(Vb(e),b,w[d+175|0]?128:64,65535,65535);e=Vb(e);p=d,q=bc(e),v[p+16>>2]=q;p=d,q=cc(e),v[p+112>>2]=q;if(Jb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];g=x[e>>1];n:{if(!((g|0)!=99?(g|0)!=255:0)){u[e>>1]=65535;break n}if(g>>>0>63){break k}}te(d+16|0);if(Jb(d+16|0,d+112|0)){continue}break}}i=c&1;if(i){_f(a+484344|0,w[d+177|0])}if(w[d+177|0]){n=a+484344|0;while(1){o:{p:{if(i){if(rg(n,l&65535,64)){break p}}f=0;while(1){if((Gd(b)+5&255)>>>0>=3){$b(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break o}p=d,q=bc(_b(n,l)),v[p+112>>2]=q;v[d>>2]=63;k=65535;m=0;while(1){f=0;while(1){g=f;j=0;f=0;o=0;h=0;q:{r:{s:{t:{u:{v:{e=Gd(b);switch(e-251|0){case 1:break q;case 0:break t;case 2:break v;default:break u}}t[v[d+112>>2]]=254;break q}hq(d+16|0,b);f=w[fc(d+16|0,0)|0];o=w[fc(d+16|0,1)|0];h=w[fc(d+16|0,2)|0];j=254;if((e|0)==254){break s}j=e;if(e>>>0>95){break r}}j=(B(j>>>4|0,12)+(j&15)|0)+37|0}e=j;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=o>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(o&15)+17344|0];t[v[d+112>>2]+5|0]=h;w:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:j=v[d+112>>2];e=w[j+5|0];if(w[v[d+112>>2]+5|0]&15){t[j+5|0]=e&15;break q}t[j+5|0]=e&240;break q;case 3:t[v[d+112>>2]+5|0]=B(w[v[d+112>>2]+5|0]&240,10)|w[v[d+112>>2]+5|0]&15;x:{if((k|0)!=65535){if(w[v[d+112>>2]+5|0]){break x}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=k}k=65535}Cc(d,m);break q;case 1:k=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break q;case 5:if(w[d+175|0]<=20){t[v[d+112>>2]+5|0]=w[v[d+112>>2]+5|0]%10|w[v[d+112>>2]+5|0]/10<<4}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0;break q;case 7:break q;default:break w}}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0}Cj(d+112|0);f=g+1|0;if((g&65535)>>>0<3){continue}break}m=m+1|0;if((m|0)!=64){continue}break}if((k|0)==65535){break o}sl(_b(n,l),Gn(Ne(Qn(d+16|0,12,k&255),v[d>>2])))}l=l+1|0;if(l>>>0<w[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}g=ad(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;y:{if(!v[e>>2]|!x[c+484410>>1]){break y}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break y}if(!Pc(b,c<<4)){break y}tg(g,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;yb(d+112|0)}S(f|0);L()}f=1}jb=d+192|0;return f|0}function MT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-3040|0;jb=e;Jc(b);g=jb-16|0;jb=g;i=e+1080|0;vA(g+8|0,i);k=Hb(g+8|0);f=b;j=nc(f,ac(g,g+8|0));if((k|0)==(j|0)){$b(f,Hb(g+8|0))}jb=g+16|0;f=(j|0)==(k|0);if(!f){wA(i)}a:{if(!f){break a}if(!AA(e+1080|0)){break a}if(!c){d=1;break a}if(!Qb(b,id(1024,0))){break a}zA(b,e+560|0);zA(b,e+48|0);while(1){f=h<<2;g=f+(e+560|0)|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))>>>0>16777215){break a}f=f+(e+48|0)|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<3|(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0>4096){break a}if(!yA(b,((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))|0)+2978|0)){break a}h=h+1|0;if((h|0)!=128){continue}break}Hd(a,2);wi(a);d=Ub(e+16|0,12301);Gb(a+1304436|0,d);yb(d);d=Ub(e+16|0,12306);Gb(a+1304448|0,d);yb(d);d=Ub(e+16|0,12310);Gb(a+1304460|0,d);yb(d);v[a+1304496>>2]=4;d=w[e+1080|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;i=a+484360|0;Oe(Vb(i),w[e+1081|0]);v[a+480188>>2]=4194317;Nb(a+1074308|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){f=d+1|0;h=B(f,104)+a|0;g=h+484380|0;Fd(g,2);Qi(e+32|0,1,(B(d,13)+e|0)+1082|0);Ic(e+16|0,e+32|0);v[114578]=0;Q(371,((f<<5)+a|0)+946300|0,e+16|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break e}yb(e+16|0);j=g;d=(e+1080|0)+(d<<4)|0;g=d+422|0;v[j>>2]=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[h+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[h+484414>>1]=2;v[h+484388>>2]=d}v[h+484404>>2]=8287;d=f;if((d|0)!=32){continue}break}h=0;while(1){d=h+33|0;f=(B(d,104)+a|0)+484380|0;Fd(f,2);Qi(e+32|0,1,(B(h,13)+e|0)+2010|0);Ic(e+16|0,e+32|0);v[114578]=0;Q(371,((d<<5)+a|0)+946300|0,e+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}yb(e+16|0);v[e+24>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;d=(e+1080|0)+B(h,11)|0;g=w[d+1347|0];o=fc(e+16|0,0),p=g,t[o|0]=p;g=w[d+1352|0];o=fc(e+16|0,1),p=g,t[o|0]=p;g=w[d+1348|0];o=fc(e+16|0,2),p=g,t[o|0]=p;g=w[d+1353|0];o=fc(e+16|0,3),p=g,t[o|0]=p;g=w[d+1349|0];o=fc(e+16|0,4),p=g,t[o|0]=p;g=w[d+1354|0];o=fc(e+16|0,5),p=g,t[o|0]=p;g=w[d+1350|0];o=fc(e+16|0,6),p=g,t[o|0]=p;g=w[d+1355|0];o=fc(e+16|0,7),p=g,t[o|0]=p;g=w[d+1351|0];o=fc(e+16|0,8),p=g,t[o|0]=p;g=w[d+1356|0];o=fc(e+16|0,9),p=g,t[o|0]=p;d=w[d+1346|0];o=fc(e+16|0,10),p=d,t[o|0]=p;v[e+8>>2]=v[e+24>>2];d=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=d;op(f,1,e);h=h+1|0;if((h|0)!=32){continue}break}eq(Vb(i),e+2778|0,256,255,65535);k=a+484344|0;_f(k,128);n=c&1;h=0;f:{while(1){f=h<<2;d=f+(e+560|0)|0;Pc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);d=f+(e+48|0)|0;ud(e+16|0,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));g:{if(!n){break g}v[114578]=0;d=W(404,k|0,h&65535,64)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!d){break g}d=0;g=_b(k,h);while(1){v[114578]=0;f=Q(258,e+16|0,1)|0;i=v[114578];v[114578]=0;h:{i:{if((i|0)!=1){if(!f){break g}v[114578]=0;f=T(389,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}if(f>>>0>12){break i}v[114578]=0;i=W(472,g|0,d|0,f|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[114578]=0;R(473,e+32|0,e+16|0);j=v[114578];v[114578]=0;if((j|0)==1){break c}j=dd(e+32|0);l=e+32|0;m=w[l|0];f=f>>>0>3;t[i|0]=((m&15)+(f?13:37)|0)+B(m>>>4&7,12);t[i+1|0]=((w[j|0]>>>4|0)+(f?33:1)|0)+(w[l|0]>>>3&16);xA(i,w[j|0],f);break h}break c}i=f-32|0;if((i&255)>>>0<=12){v[114578]=0;i=W(472,g|0,d|0,i&65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[114578]=0;j=T(389,e+16|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break c}xA(i,j,f>>>0>35);break h}if((f|0)!=64){if((f|0)!=96){break f}if(!d){break g}v[114578]=0;d=W(472,g|0,d-1|0,0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}t[d+3|0]=14;break g}v[114578]=0;f=T(389,e+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}d=d+f|0}if(d>>>0<64){continue}break}}Bb(e+16|0);h=h+1|0;if((h|0)!=128){continue}break}d=1;if(!(c&2)){break a}h=1;while(1){tg(ad(e+16|0,8,1,0,1),(B(h,104)+a|0)+484380|0,b);h=h+1|0;if((h|0)!=33){continue}break}break a}Bb(e+16|0);d=0;break a}d=P()|0;O()|0;yb(e+16|0);break b}d=P()|0;O()|0;yb(e+16|0);break b}d=P()|0;O()|0;Bb(e+16|0)}S(d|0);L()}jb=e+3040|0;return d|0}function bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-80|0;jb=e;Jc(b);a:{b:{c:{d:{e:{if(UP(b,16628)){g=Mp(e- -64|0);h=Mp(e+48|0);l=kt(e+32|0);v[114578]=0;R(449,a|0,32768);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;d=Q(2,e+8|0,16637)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}Gb(a+1304436|0,d);yb(d);v[114578]=0;d=Q(2,e+8|0,16647)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=2;j=a+484360|0;i=e+24|4;f:{g:{h:{i:{j:{while(1){v[114578]=0;d=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}k:{l:{m:{n:{if(!d){break n}v[114578]=0;d=Q(927,b|0,e+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break m}if(!d){break n}d=i;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114578]=0;U(343,e+8|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=v[114578];v[114578]=0;if((d|0)==1){break l}v[114578]=0;d=T(339,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(d){break k}Bb(e+8|0)}if(x[a+480188>>1]){break j}d=0;break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{d=e+24|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)<=1347175757){if((d|0)==1129140036){break t}if((d|0)==1346458708){break r}if((d|0)!=1346522948){break p}if(od(g)>>>0>255){break p}v[114578]=0;R(601,g|0,e+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}break p}if((d|0)<=1396854595){if((d|0)==1347175758){break s}if(x[a+480190>>1]|(d|0)!=1396788560){break p}v[114578]=0;U(928,e+8|0,l|0,a|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}break p}if((d|0)==1396854596){break q}if((d|0)!=1397769541){break p}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(d>>>0<2){break p}v[114578]=0;d=T(485,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}o=a,p=Cd(d,1,255),v[o+480196>>2]=p;break p}if(x[a+480188>>1]){break p}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}f=0;if(d>>>0<8){break p}while(1){v[114578]=0;k=T(389,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}v[114578]=0;m=T(389,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}d=x[a+480188>>1];if(k|m){v[114578]=0;Z(434,((d<<5)+a|0)+480280|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}k=x[a+480188>>1];d=k+1|0;u[a+480188>>1]=d;u[((k<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64}v[114578]=0;Z(434,(((d&65535)<<5)+a|0)+480280|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}d=x[a+480188>>1];u[a+480188>>1]=d+1;u[((d<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break p}Bb(e+8|0);break g}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(d>>>0<2){break p}v[114578]=0;n=T(485,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}break p}d=Vb(j);v[114578]=0;f=T(255,e+8|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break e}v[114578]=0;ea(581,d|0,e+8|0,f|0,255,254)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break p}break e}if(od(h)>>>0>3998){break p}v[114578]=0;d=T(255,e+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}if(!d){break p}v[114578]=0;R(601,h|0,e+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}}Bb(e+8|0);continue}break}break e}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Vb(j);v[114578]=0;R(929,b|0,n&65535);b=v[114578];v[114578]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=od(g);v[114578]=0;R(403,a+484344|0,b&65535);b=v[114578];v[114578]=0;if((b|0)==1){break b}if(!od(g)){break u}b=0;while(1){d=tc(g,d);v[114578]=0;U(930,d|0,b&65535,a|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}b=b+1|0;d=b&65535;if(od(g)>>>0>d>>>0){continue}break}}f=1;if(x[a+480190>>1]<2){break g}i=c&2;b=0;v:{while(1){if(!i|od(h)>>>0<=b>>>0){break g}w:{c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){d=tc(h,b);v[114578]=0;d=T(255,d|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break w}Cc(c,d);ee(e+8|0,l,f-1|0);d=ad(e+24|0,8,1,1,Cb(e+8|0)?10:0);j=tc(h,b);v[114578]=0;W(402,d|0,c|0,j|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break f}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=1}ke(l);hd(h);hd(g)}jb=e+80|0;return d|0}a=P()|0;O()|0;Bb(e+8|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}ke(l);hd(h);hd(g);S(a|0);L()}function cI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-416|0;jb=e;t[e+415|0]=c;a:{if(mj(b)){break a}f=w[fk(b)|0];c=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}c=0}d=c;sk(e+160|0,b,v[b+4>>2]-1|0);c=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=c}Dd(e+160|0);c=v[e+160>>2];Dd(e+376|0);g=ek(c,v[e+380>>2],b);Dd(e+160|0);c=v[b>>2];f=v[b+4>>2];c:{d:{e:{f:{if((g|0)==v[e+164>>2]){v[e+400>>2]=c;v[e+404>>2]=f;a=qc(e+392|0,38235);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Hc(e+8|0,e)){a=ba(8)|0;v[114578]=0;R(2141,e+376|0,e+415|0);b=v[114578];v[114578]=0;g:{h:{i:{if((b|0)!=1){v[114578]=0;U(2119,e+160|0,39300,e+376|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}mc(a,e+160|0);d=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break e}b=P()|0;O()|0;yb(e+160|0);break h}b=P()|0;O()|0;break g}b=P()|0;d=1;O()|0}yb(e+376|0);if(!d){break f}}ca(a|0);break f}if(!d){break c}a=ba(8)|0;v[114578]=0;d=Q(2142,e+344|0,b|0)|0;b=v[114578];v[114578]=0;c=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[114578]=0;U(2119,e+360|0,39179,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;U(2137,e+376|0,e+360|0,39315);b=v[114578];v[114578]=0;if((b|0)==1){break q}v[114578]=0;R(2141,e+328|0,e+415|0);b=v[114578];v[114578]=0;if((b|0)==1){break p}v[114578]=0;U(138,e+160|0,e+376|0,e+328|0);b=v[114578];v[114578]=0;if((b|0)==1){break o}mc(a,e+160|0);v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break e}b=P()|0;O()|0;yb(e+160|0);c=0;break n}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break m}b=P()|0;O()|0}yb(e+328|0)}yb(e+376|0)}yb(e+360|0)}yb(d)}if(!c){break f}ca(a|0);break f}v[e+320>>2]=c;v[e+324>>2]=f;c=qc(e+312|0,38235);d=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=d;d=v[c+4>>2];v[e+144>>2]=v[c>>2];v[e+148>>2]=d;if(!Hc(e+152|0,e+144|0)){break d}a=ba(8)|0;v[114578]=0;R(2141,e+376|0,e+415|0);b=v[114578];v[114578]=0;s:{t:{u:{if((b|0)!=1){v[114578]=0;U(2119,e+160|0,39300,e+376|0);b=v[114578];v[114578]=0;if((b|0)==1){break u}mc(a,e+160|0);d=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break e}b=P()|0;O()|0;yb(e+160|0);break t}b=P()|0;O()|0;break s}b=P()|0;d=1;O()|0}yb(e+376|0);if(!d){break f}}ca(a|0)}S(b|0)}L()}c=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=c;c=qc(e+296|0,38917);d=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=d;d=v[c+4>>2];v[e+128>>2]=v[c>>2];v[e+132>>2]=d;v:{if(!Hc(e+136|0,e+128|0)){c=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=c;c=qc(e+280|0,39214);d=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=d;d=v[c+4>>2];v[e+112>>2]=v[c>>2];v[e+116>>2]=d;if(!Hc(e+120|0,e+112|0)){break v}}t[a+60|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=c;c=qc(e+264|0,38935);d=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=d;d=v[c+4>>2];v[e+96>>2]=v[c>>2];v[e+100>>2]=d;w:{if(!Hc(e+104|0,e+96|0)){c=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=c;c=qc(e+248|0,39232);d=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=d;d=v[c+4>>2];v[e+80>>2]=v[c>>2];v[e+84>>2]=d;if(!Hc(e+88|0,e+80|0)){break w}}t[a+61|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=c;c=qc(e+232|0,38954);d=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=d;d=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=d;if(Hc(e+72|0,e- -64|0)){t[a+62|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=c;c=qc(e+216|0,38972);d=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=d;d=v[c+4>>2];v[e+48>>2]=v[c>>2];v[e+52>>2]=d;if(Hc(e+56|0,e+48|0)){t[a+63|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=c;c=qc(e+200|0,38996);d=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=d;d=v[c+4>>2];v[e+32>>2]=v[c>>2];v[e+36>>2]=d;if(Hc(e+40|0,e+32|0)){t[a+64|0]=w[e+415|0];break c}c=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=c;b=qc(e+184|0,39070);c=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=c;c=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=c;if(!Hc(e+24|0,e+16|0)){break c}c=a+24|0;b=v[c>>2];d=b+24664|0;f=v[d+4>>2];v[e+176>>2]=v[d>>2];v[e+180>>2]=f;d=b+24656|0;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;d=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=d;b=e;if(w[e+415|0]){a=IH(v[a+56>>2])}else{a=0}v[b+180>>2]=a;if(!Tw(e+160|0,v[c>>2]+24648|0)){break c}Jx(v[c>>2],e+160|0)}jb=e+416|0}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-256|0;jb=f;Jc(b);a:{if(!jA(b,f+184|0)){break a}if(!XP(f+184|0)){break a}if(!Qb(b,id(WP(f+184|0),mb))){break a}b:{if(!c){break b}Hd(a,16);Hn(f,2,f+184|4);Ic(f+16|0,f);Gb(a+1304400|0,f+16|0);yb(f+16|0);u[a+480190>>1]=w[f+214|0];u[a+480188>>1]=w[f+217|0];e=Ub(f+16|0,16588);Gb(a+1304436|0,e);yb(e);e=Ub(f+16|0,16601);Gb(a+1304448|0,e);yb(e);d=Ub(f+168|0,16605);v[114578]=0;R(219,f|0,d|0);e=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=f+184|3;v[f+152>>2]=w[e|0]>>>4;e=w[e|0];v[114578]=0;v[f+164>>2]=e&15;X(534,f+16|0,f|0,f+152|0,f+164|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Gb(a+1304460|0,f+16|0);yb(f+16|0);Ib(f);yb(d);v[a+1304496>>2]=4;if(x[a+480190>>1]){e=1;i=1;while(1){BB(b,f+16|0);h=jb-16|0;jb=h;d=(B(e,104)+a|0)+484380|0;Fd(d,0);g=f+16|0;u[h+14>>1]=w[g+35|0]<<2;u[h+12>>1]=256;p=d,q=x[lf(h+14|0,h+12|0)>>1],u[p+30>>1]=q;j:{if((w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24))>>>0<3){break j}v[d>>2]=w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24);v[d+4>>2]=w[g+26|0]|w[g+27|0]<<8|(w[g+28|0]<<16|w[g+29|0]<<24);v[h+8>>2]=w[g+30|0]|w[g+31|0]<<8|(w[g+32|0]<<16|w[g+33|0]<<24);v[h+4>>2]=1;p=d,q=v[bd(h+8|0,h+4|0)>>2]-1|0,v[p+8>>2]=q;Cc(d+8|0,v[d>>2]);k:{if(y[d+8>>2]<=v[d+4>>2]+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;break k}u[d+34>>1]=x[d+34>>1]|2}t[d+37|0]=w[g+34|0];p=d,q=_s(0,t[g+34|0]<<4),v[p+24>>2]=q;if(!(t[g+36|0]&1)){break j}u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}jb=h+16|0;Tl(f+152|0,2,f+16|0);Ic(f,f+152|0);v[114578]=0;Q(371,((e<<5)+a|0)+946300|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}yb(f);i=i+1|0;e=i&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){e=0;while(1){d=(e<<5)+a|0;zg(d+480280|0);u[d+480284>>1]=(w[(f+e|0)+218|0]<<4|8)&248;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}d=f+16|0;g=jb-16|0;jb=g;e=b;l:{if(Qb(e,128)){FR(g+8|0,d);Bd(e,g+8|0);break l}e=jb-16|0;jb=e;h=jb-16|0;jb=h;i=d+128|0;while(1){ff(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}jb=h+16|0;jb=e+16|0}jb=g+16|0;JB(Vb(a+484360|0),f+16|0,w[f+211|0]+1|0);if(w[f+216|0]){break g}j=64;break f}e=P()|0;O()|0;break h}e=P()|0;O()|0;Ib(f)}yb(d);break c}j=w[f+216|0]}ud(f,b,B(w[f+208|0]|w[f+209|0]<<8,192));e=c&1;if(e){d=w[f+210|0];v[114578]=0;R(403,a+484344|0,d+1|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}}m:{n:{if(!e){break n}n=a+484344|0;while(1){v[114578]=0;d=W(404,n|0,k&65535,j|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break m}e=0;if(!d){break n}while(1){v[114578]=0;d=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}l=e;o:{if(!d|d>>>0>(w[f+208|0]|w[f+209|0]<<8)>>>0){break o}e=l&65535;if(e>>>0>=x[a+480188>>1]){break o}v[114578]=0;Q(256,f|0,B(d,192)-192|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}d=_b(n,k);v[114578]=0;e=W(472,d|0,0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}m=0;if(!j){break o}while(1){v[114578]=0;R(806,f+152|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}i=dd(f+152|0);h=Bf(f+152|0);g=e;d=w[f+152|0];if(d>>>0>=4){t[e|0]=(d>>>2|0)+37;d=w[f+152|0]}t[g+1|0]=d<<4&48|w[i|0]>>>4;d=w[h|0];g=0;h=0;p:{q:{r:{s:{t:{u:{i=w[i|0]&15;switch(i-8|0){case 0:break r;case 6:break t;case 2:break u;default:break s}}d=d&240?d&-16:d&15;i=10;break q}i=14;o=(d+16&240)>>>4|0;if(o>>>0>8){break q}if(1<<o&435){break r}break q}g=i;h=d}d=h;i=g;if(!((d|g)&255)){break p}}t[e+5|0]=d;t[e+3|0]=i;v[114578]=0;Z(574,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){break p}break d}e=B(x[a+480188>>1],6)+e|0;m=m+1|0;if((m|0)!=(j|0)){continue}break}}e=l+1|0;if((l&65535)>>>0<31){continue}break}e=w[f+210|0]>k>>>0;k=k+1|0;if(e){continue}break}}if(w[f+212|0]|w[f+213|0]<<8){e=w[f+212|0]|w[f+213|0]<<8;v[114578]=0;ea(547,a+1304424|0,b|0,e|0,39,1)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){d=1;while(1){c=B(d&65535,104)+a|0;e=ad(f+152|0,u[c+484414>>1]&1?16:8,1,0,1);v[114578]=0;W(402,e|0,c+484380|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;Bb(f);break b}break d}e=P()|0;O()|0;yb(f);break c}e=P()|0;O()|0;Bb(f)}S(e|0);L()}e=1}jb=f+256|0;return e|0}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-336|0;jb=d;Jc(b);a:{if(!Mt(b,d+320|0)){break a}if(!TS(d+320|0)){break a}if(v[d+320>>2]==1179472708){$b(b,4)}if(!Ff(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}i=d+312|4;g=i;LA(b,d+120|0,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Hd(a,8192);e=Ub(d+40|0,12774);Gb(a+1304436|0,e);yb(e);e=Ub(d+40|0,12786);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;Kt(d+104|0,2,d+120|0);Ic(d+40|0,d+104|0);Gb(a+1304400|0,d+40|0);yb(d+40|0);u[d+40>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+104>>1]=1;p=a,q=x[Si(d+40|0,d+104|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+40|0]=w[d+164|0];t[d+104|0]=64;e=w[pc(d+40|0,d+104|0)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=a;b:{if(w[d+165|0]==128){v[d+40>>2]=256/x[a+480188>>1];v[d+104>>2]=128;g=v[Lb(d+40|0,d+104|0)>>2];break b}g=w[d+165|0]&127}v[e+480228>>2]=g;e=0;while(1){g=(e<<5)+a|0;zg(g+480280|0);f=d+e|0;if(w[f+168|0]<=128){u[g+480284>>1]=w[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}e=a+484360|0;In(Vb(e),d+184|0,w[d+156|0]|w[d+157|0]<<8,255,254);if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){Oe(Vb(e),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Ff(b,d+312|0)){break a}m=c&2;j=a+484344|0;n=c&1;o=d+76|0;while(1){c=i;ud(d+104|0,b,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));c:{d:{e:{if(!(!n|v[d+312>>2]!=1414807888)){v[114578]=0;l=k&65535;c=W(404,j|0,l|0,64)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}if(!c){break c}v[114578]=0;Q(340,d+104|0,2)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}Qh(d+40|0);g=0;f:{while(1){v[114578]=0;c=Q(258,d+104|0,1)|0;e=v[114578];v[114578]=0;g:{h:{if((e|0)!=1){if(c^1|g>>>0>63){break f}v[114578]=0;e=T(389,d+104|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}if(e){break g}g=g+1|0;continue}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}c=d+40|0;i:{j:{k:{f=e&15;l:{if(f>>>0<x[a+480188>>1]){c=_b(j,l);v[114578]=0;c=W(472,c|0,g|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}}m:{if(!(e&128)){break m}v[114578]=0;f=T(389,d+104|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break k}if(!f){break m}t[c|0]=f>>>0<109?f+12|0:f}if(!(e&64)){break i}v[114578]=0;f=T(389,d+104|0)|0;h=v[114578];v[114578]=0;if((h|0)!=1){break j}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}t[c+1|0]=f}n:{o:{p:{q:{r:{s:{t:{u:{if(e&32){t[c+2|0]=1;v[114578]=0;f=T(389,d+104|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break u}v[114578]=0;t[d+24|0]=f;t[d+8|0]=64;f=Q(393,d+24|0,d+8|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break t}t[c+4|0]=w[f|0]}if(!(e&16)){continue}v[114578]=0;R(473,d+24|0,d+104|0);e=v[114578];v[114578]=0;if((e|0)==1){break s}h=dd(d+24|0);f=d+24|0;e=w[f|0];switch(e-17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}e=e&15;break o}t[f|0]=33;t[h|0]=145;e=w[f|0];break n}if(e>>>0<17){break n}e=(e&240)==32?9:-1}t[f|0]=e}t[c+3|0]=e;t[c+5|0]=w[h|0];v[114578]=0;Z(574,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break d}k=k+1|0;break c}if(v[d+312>>2]!=1414745673){break c}if(!En(a)){break c}c=x[a+480190>>1]+1|0;u[a+480190>>1]=c;v[114578]=0;Q(575,d+104|0,d+40|0)|0;e=v[114578];v[114578]=0;v:{w:{x:{if((e|0)==1){break x}v[114578]=0;c=(B(c&65535,104)+a|0)+484380|0;R(576,d+40|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break x}v[114578]=0;U(577,d+8|0,2,o|0);e=v[114578];v[114578]=0;if((e|0)==1){break w}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break w}e=x[a+480190>>1];v[114578]=0;Q(371,((e<<5)+a|0)+946300|0,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break v}yb(d+24|0);if(!m){break c}v[114578]=0;R(578,d+24|0,d+40|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;W(402,d+24|0,c|0,d+104|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break c}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d+24|0);break d}b=P()|0;O()|0}Bb(d+104|0);S(b|0);L()}Bb(d+104|0);e=1;if(Ff(b,d+312|0)){continue}break}}jb=d+336|0;return e|0}function wL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-16|0;jb=h;a:{b:{if(!be(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break b}d=v[((d<<2)+b|0)+900380>>2];if(!d){break b}d=v[d+44>>2];if(!d){break b}u[h+14>>1]=c-61;b=jb-80|0;jb=b;e=u[d+28>>1];f=h+14|0;c=u[f>>1];g=d+4|0;Kb(g);c:{d:{if((c|0)>=(e|0)){if((c|0)<=(x[d+28>>1]+Kb(g)<<16)-65536>>16){break d}}gd(a);break c}e:{e=u[d+30>>1];if(!e){c=d+52|0;m=b,n=jx(c,f),v[m+56>>2]=n;m=b,n=Hi(c),v[m+40>>2]=n;if(!Gi(b+56|0,b+40|0)){break e}Af(a,jh(b+56|0)+4|0);break c}c=b;g=u[f>>1];f:{if((g|0)>=0){e=(g|0)%(e|0)|0;break f}e=e+((g^-1)%(e|0)^-1)|0}u[c+78>>1]=e;c=gd(a);v[114578]=0;a=d+52|0;e=Q(1600,a|0,b+78|0)|0;g=v[114578];v[114578]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((g|0)==1){break w}v[b+72>>2]=e;a=Hi(a);v[114578]=0;v[b+56>>2]=a;a=Q(1601,b+72|0,b+56|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}if(a){v[114578]=0;a=T(1602,b+72|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break w}v[114578]=0;Q(237,c|0,a+4|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break w}a=u[d+30>>1];d=u[f>>1];x:{if((d|0)>=0){a=(d|0)/(a|0)|0;break x}a=((d+1|0)/(a|0)|0)-1|0}v[114578]=0;v[b+40>>2]=a+5;R(234,b+56|0,b+40|0);a=v[114578];v[114578]=0;y:{if((a|0)!=1){v[114578]=0;Q(192,c|0,b+56|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break y}yb(b+56|0);break c}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(b+56|0);break g}if(u[d+30>>1]>26){break t}v[114578]=0;e=W(799,b+40|0,1,(w[b+78|0]<<24)+1090519040>>24)|0;a=v[114578];v[114578]=0;if((a|0)==1){break v}v[114578]=0;U(13,b+56|0,0,e|0);a=v[114578];v[114578]=0;if((a|0)==1){break u}Gb(c,b+56|0);yb(b+56|0);yb(e);v[114578]=0;Q(235,c|0,32403)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break s}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(e);break g}v[114578]=0;v[b+36>>2]=u[b+78>>1]%16;R(1603,b+40|0,b+36|0);a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;v[b+20>>2]=(u[b+78>>1]/16<<16>>16)%16;R(1603,b+24|0,b+20|0);a=v[114578];v[114578]=0;if((a|0)==1){break q}v[114578]=0;U(3,b+56|0,b+40|0,b+24|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}Gb(c,b+56|0);yb(b+56|0);yb(b+24|0);yb(b+40|0);if(u[b+78>>1]<256){break s}v[114578]=0;U(9,b+8|0,0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}v[114578]=0;R(1604,b+40|0,b+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;U(13,b+56|0,0,b+40|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}Gb(c,b+56|0);yb(b+56|0);yb(b+40|0);yb(b+8|0)}a=u[d+30>>1];d=u[f>>1];if((d|0)<0){break j}a=(d|0)/(a|0)|0;break i}a=P()|0;O()|0;break g}a=P()|0;O()|0;break o}a=P()|0;O()|0;yb(b+24|0)}yb(b+40|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break k}a=P()|0;O()|0;yb(b+40|0)}yb(b+8|0);break g}a=((d+1|0)/(a|0)|0)-1|0}v[114578]=0;v[b+40>>2]=a+5;R(234,b+56|0,b+40|0);a=v[114578];v[114578]=0;z:{if((a|0)!=1){v[114578]=0;Q(192,c|0,b+56|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break z}yb(b+56|0);break c}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(b+56|0);break g}a=P()|0;O()|0}yb(c);S(a|0);L()}j=jb-16|0;jb=j;c=a;a=jb-16|0;jb=a;d=a;e=jb-144|0;jb=e;g=dh(e+8|0);i=v[v[g>>2]-12>>2];v[114578]=0;k=da(122)|0;l=v[114578];v[114578]=0;A:{B:{if((l|0)==1){break B}v[114578]=0;U(123,e|0,i+(e+8|0)|0,k|0);i=v[114578];v[114578]=0;if((i|0)==1){break B}Ob(e);v[114578]=0;R(131,g|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break B}v[114578]=0;R(125,d|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break B}Yd(g);jb=e+144|0;break A}a=P()|0;O()|0;Yd(g);S(a|0);L()}v[114578]=0;U(13,c|0,0,a|0);c=v[114578];v[114578]=0;C:{if((c|0)!=1){yb(a);jb=a+16|0;break C}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=j+16|0}jb=b+80|0;break a}f=v[b>>2];b=jb-32|0;jb=b;D:{if(xL(c)){v[b+16>>2]=v[5144];d=v[5141];v[b>>2]=v[5140];v[b+4>>2]=d;d=v[5143];v[b+8>>2]=v[5142];v[b+12>>2]=d;Ub(a,(b+(c<<2)|0)-1004|0);break D}if(be(c)){d=gd(b);v[114578]=0;e=c-1|0;c=(e<<16>>16)/12|0;f=Q(1434,d|0,f+(e-B(c,12)<<16>>16<<2)|0)|0;e=v[114578];v[114578]=0;E:{if((e|0)==1){break E}v[114578]=0;c=W(1435,f|0,1,(c<<16)+3145728>>16)|0;f=v[114578];v[114578]=0;if((f|0)==1){break E}v[114578]=0;Q(4,a|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break E}yb(d);break D}a=P()|0;O()|0;yb(d);S(a|0);L()}if(!c){Ub(a,20580);break D}Ub(a,20584)}jb=b+32|0}jb=h+16|0}function ela(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-704|0;jb=k;a:{b:{if(d>>>0<=511){d=0;a=jb-16|0;jb=a;h=jb-16|0;jb=h;g=k+24|0;gc(a+8|0,g,554);jb=h+16|0;h=Hb(a+8|0);i=nc(b,ac(a,a+8|0));if((h|0)==(i|0)){$b(b,Hb(a+8|0))}jb=a+16|0;a=(h|0)==(i|0);if(!a){b=jb-16|0;jb=b;Rb(g,0,554);jb=b+16|0}if(!a){break b}d=jb-32|0;jb=d;c:{d:{a=k+24|0;e:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1229999433){break e}Bu(d,3,a+32|0);Ic(d+16|0,d);v[114578]=0;Q(371,c+492|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}yb(d+16|0);Qi(d,1,a+4|0);Ic(d+16|0,d);v[114578]=0;Q(371,c+524|0,d+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}yb(d+16|0);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];i=c+108|0;e=c+236|0;b=0;h=a- -64|0;while(1){f=b<<1;g=w[f+h|0];f=w[h+(f|1)|0];o=ed(e,b),p=f,u[o>>1]=p;o=fc(i,b),p=(g>>>0<120?g:b)+1|0,t[o|0]=p;b=b+1|0;if((b|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[a+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[a+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[a+17|0]&4;i=c+61|0;t[i|0]=w[a+18|0];e=c+62|0;t[e|0]=w[a+19|0];f=c+63|0;t[f|0]=w[a+20|0];j=c- -64|0;t[j|0]=w[a+21|0];h=c+48|0;gg(h,25);b=0;while(1){f:{l=b<<1;g=w[(l+a|0)+504|0];o=Pb(h,b),p=g,u[o>>1]=p;if((g|0)==255){gg(h,b);break f}g=w[(a+(l|1)|0)+504|0];o=Pb(h,b),p=g,t[o+2|0]=p;b=b+1|0;if((b|0)!=25){continue}}break}a=w[qh(i,e)|0];if(Kb(h)>>>0<=a>>>0){t[c+60|0]=w[c+60|0]&253}a=w[qh(f,j)|0];if(Kb(h)>>>0>a>>>0){break e}t[c+60|0]=w[c+60|0]&251}jb=d+32|0;break c}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}d=554;break b}h=v[b+8>>2];g=jb-16|0;jb=g;v[g+12>>2]=674;v[g>>2]=674;d=b;i=v[Lb(g+12|0,g)>>2];if(!Qb(d,i)){i=nf(d)}e=k+24|0;SR(g,e);xg(d,v[g>>2],i);SR(g,e);Rb(v[g>>2]+i|0,0,674-i|0);$b(d,v[g+12>>2]);jb=g+16|0;m=b;i=c;d=c;l=v[a+480180>>2];a=0;f=jb-32|0;jb=f;g:{h:{j=k+24|0;e=j;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))==1229999433){Bu(f,3,e+32|0);Ic(f+16|0,f);v[114578]=0;Q(371,d+492|0,f+16|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break h}yb(f+16|0);Qi(f,1,e+4|0);Ic(f+16|0,f);v[114578]=0;Q(371,d+524|0,f+16|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break h}yb(f+16|0);v[d>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[d+4>>2]=w[e+24|0]>>>1;Cc(d+4|0,64);a=w[e+25|0]&127;v[d+8>>2]=a>>>0>64?128:a<<2;t[d+15|0]=w[d+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[f+16|0]=w[e+26|0];t[f|0]=100;o=d,p=w[pc(f+16|0,f)|0],t[o+20|0]=p;t[f+16|0]=w[e+27|0];t[f|0]=64;o=d,p=w[pc(f+16|0,f)|0],t[o+19|0]=p;t[d+16|0]=w[e+17|0];t[d+17|0]=w[e+18|0];t[d+18|0]=w[e+19|0];t[d+26|0]=w[e+22|0];t[d+27|0]=w[e+23|0];xu(d,w[e+58|0]&127,w[e+58|0]>>>7|0);wu(d,w[e+59|0]&127,w[e+59|0]>>>7|0);i:{j:{k:{if(!((w[e+28|0]|w[e+29|0]<<8)==514|(w[e+28|0]|w[e+29|0]<<8)==529|(w[e+28|0]|w[e+29|0]<<8)==544)){if((w[e+28|0]|w[e+29|0]<<8)!=532){break k}}if(w[e+61|0]==255){break k}if(w[e+61|0]<=128){t[d+30|0]=w[e+61|0]}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break j}break i}a=0;if(t[e+61|0]>=0){t[d+30|0]=w[e+61|0]+1}a=t[e+62|0]>=0?w[e+62|0]+1|0:a;if(t[e+63|0]<0){break j}a=(w[e+63|0]<<7)+a|0}u[d+28>>1]=a}a=t[e+60|0];t[d+31|0]=a;if((a|0)<=-1){t[d+31|0]=0;t[d+34|0]=a^128}a=0;l=l&16777216?240:25;Du(e+304|0,d+48|0,0,l);Du(e+386|0,d+68|0,32,l);Du(e+468|0,d+88|0,32,l);t[d+100|0]=w[d+100|0]&239|w[e+468|0]>>>3&16;l=d+108|0;n=d+236|0;d=e- -64|0;while(1){g=a<<1;e=w[g+d|0];g=w[d+(g|1)|0];o=ed(n,a),p=g,u[o>>1]=p;o=fc(l,a),p=(e>>>0<120?e:a)+1|0,t[o|0]=p;a=a+1|0;if((a|0)!=120){continue}break}a=554}jb=f+32|0;break g}a=P()|0;O()|0;yb(f+16|0);S(a|0);L()}d=0;l:{if(!a){break l}if(!((w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1297110104?(w[j+550|0]|w[j+551|0]<<8|(w[j+552|0]<<16|w[j+553|0]<<24))!=1481920589:0)){d=i+236|0;a=0;while(1){i=w[(a+j|0)+554|0];e=ed(d,a);u[e>>1]=x[e>>1]|i<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}d=a}Pc(m,h+d|0);if(!ph(b,13380)){break b}ud(k+8|0,b,Cf(b));v[114578]=0;b=T(255,k+8|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}v[114578]=0;a=Q(618,k+8|0,13385)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}if(a){v[114578]=0;a=T(389,k+8|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}t[c+34|0]=a>>>0>250?0:a}d=(b+d|0)+8|0;Bb(k+8|0)}jb=k+704|0;return d|0}a=P()|0;O()|0;Bb(k+8|0);S(a|0);L()}function KH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=jb-48|0;jb=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Pr(c)){h=b+24|0;if(dg(v[h>>2]+484344|0,c&65535)){break j}}c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}b=_b(v[h>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)?(d|0)>=0:0)){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}if(!(x[v[h>>2]+480188>>1]>(e|0)?(e|0)>=0:0)){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}if(f>>>0>=6){c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a);break i}b=Xe(b,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!cg(b)){if(!ls(b)){break n}}wL(g+16|0,v[h>>2],w[b|0],w[b+1|0]);v[114578]=0;U(9,g+32|0,0,g+16|0);c=v[114578];v[114578]=0;d=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}d=0;v[114578]=0;Q(85,g+32|0,38869)|0;c=v[114578];v[114578]=0;if((c|0)==1){break l}}v[114578]=0;c=T(553,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}o:{if(c){v[114578]=0;Q(85,g|0,38873)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}break o}if(ls(b)){v[114578]=0;Q(85,g|0,38877)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break o}break c}v[114578]=0;Q(85,g|0,38869)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}}Fh(a,g+32|0,g);yb(g);yb(g+32|0);if(!d){break i}yb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:c=b+1|0;p:{if(w[b+1|0]){qt(g+32|0,c);break p}Ub(g+32|0,38881)}q:{if(w[c|0]){v[114578]=0;Q(85,g+16|0,38884)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break q}break d}v[114578]=0;Q(85,g+16|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 2:r:{if(en(b)){Ub(g+32|0,38887);break r}if(w[b+2|0]){Hj(g+32|0,1,BK(v[v[h>>2]+8>>2],w[b+2|0]));break r}Ub(g+32|0,38887)}v[114578]=0;c=T(1341,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}s:{if(c){v[114578]=0;Q(85,g+16|0,38887)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}break s}if(w[b+2|0]){v[114578]=0;Q(85,g+16|0,38889)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break s}break e}v[114578]=0;Q(85,g+16|0,38887)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 4:t:{if(en(b)){i=g,j=hy(b)&255,v[i>>2]=j;tz(g+32|0,g);break t}if(w[b+2|0]){qt(g+32|0,b+4|0);break t}Ub(g+32|0,38881)}v[114578]=0;c=T(1341,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}u:{if(c){v[114578]=0;Q(85,g+16|0,38891)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}break u}if(w[b+2|0]){v[114578]=0;Q(85,g+16|0,38891)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break u}break f}v[114578]=0;Q(85,g+16|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 3:v:{if(en(b)){i=g,j=(Ds(b)&3840)!=0,t[i|0]=j;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;d=jb-16|0;jb=d;v[d+12>>2]=w[g|0];Ww(g+32|0,d+12|0,c);jb=d+16|0;jb=c+32|0;break v}if(w[b+3|0]){Hj(g+32|0,1,AK(v[v[h>>2]+8>>2],w[b+3|0]));break v}Ub(g+32|0,38894)}v[114578]=0;c=T(1341,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}w:{if(c){v[114578]=0;Q(85,g+16|0,38896)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}break w}if(w[b+3|0]){v[114578]=0;Q(85,g+16|0,38896)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break w}break g}v[114578]=0;Q(85,g+16|0,38894)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;case 5:x:{if(en(b)){i=g,j=Ds(b)&255,v[i>>2]=j;tz(g+32|0,g);break x}if(w[b+3|0]){qt(g+32|0,b+5|0);break x}Ub(g+32|0,38881)}v[114578]=0;c=T(1341,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break h}y:{if(c){v[114578]=0;Q(85,g+16|0,38898)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}break y}if(w[b+3|0]){v[114578]=0;Q(85,g+16|0,38898)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break y}break h}v[114578]=0;Q(85,g+16|0,38881)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}}Fh(a,g+32|0,g+16|0);yb(g+16|0);yb(g+32|0);break i;default:break k}}c=a;a=Wb(g+32|0);b=Wb(g+16|0);Fh(c,a,b);yb(b);yb(a)}jb=g+48|0;return}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);if(!d){break a}}yb(g+16|0)}S(c|0);L()}function B9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-144|0;jb=e;d=-1;a:{b:{c:{if(!Lt(v[v[b>>2]-12>>2]+b|0)){b=al(e+40|0,b);v[114578]=0;d=Q(683,e+24|0,32412)|0;f=v[114578];v[114578]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((f|0)!=1){v[114578]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(684,b|0,d|0,e+16|0);f=v[114578];v[114578]=0;if((f|0)==1){break F}Ib(d);v[114578]=0;t[e+15|0]=0;d=Q(683,e+24|0,32422)|0;f=v[114578];v[114578]=0;if((f|0)==1){break E}v[114578]=0;W(685,b|0,e+15|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break D}Ib(d);v[114578]=0;f=w[e+15|0];d=Q(683,e+24|0,32427)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}v[114578]=0;f=f?0:c;X(1606,b|0,a+40|0,d|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break B}Ib(d);v[114578]=0;u[e+12>>1]=65535;c=Q(683,e+24|0,32429)|0;d=v[114578];v[114578]=0;if((d|0)==1){break A}v[114578]=0;W(1183,b|0,e+12|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break z}Ib(c);v[114578]=0;u[e+10>>1]=0;c=Q(683,e+24|0,32431)|0;d=v[114578];v[114578]=0;if((d|0)==1){break y}v[114578]=0;W(1183,b|0,e+10|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break x}Ib(c);u[a>>1]=x[e+10>>1];v[114578]=0;c=Q(683,e+24|0,32433)|0;d=v[114578];v[114578]=0;if((d|0)==1){break w}v[114578]=0;X(1607,b|0,a+52|0,c|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break v}Ib(c);v[114578]=0;c=Q(683,e+24|0,32435)|0;d=v[114578];v[114578]=0;if((d|0)==1){break u}v[114578]=0;W(1572,b|0,a+36|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}Ib(c);v[114578]=0;c=Q(683,e+24|0,32437)|0;d=v[114578];v[114578]=0;if((d|0)==1){break s}v[114578]=0;f=a+4|0;aa(1608,b|0,f|0,c|0,1609)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}Ib(c);v[114578]=0;c=Q(683,e+24|0,32442)|0;d=v[114578];v[114578]=0;if((d|0)==1){break q}v[114578]=0;g=a+28|0;W(1610,b|0,g|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break p}Ib(c);v[114578]=0;c=Q(683,e+24|0,32447)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}v[114578]=0;W(1610,b|0,a+30|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break n}Ib(c);v[114578]=0;c=Q(683,e+24|0,32452)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}v[114578]=0;W(1611,b|0,a+32|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break l}Ib(c);v[114578]=0;u[e+8>>1]=0;c=Q(683,e+24|0,32457)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;W(1183,b|0,e+8|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break k}Ib(c);d=-1;if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>=601){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break d}c=v[a+36>>2];v[114578]=0;c=T(861,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break j}v[114578]=0;v[e+24>>2]=c;v[e+16>>2]=0;c=W(1240,e+24|0,e+16|0,32408)|0;h=v[114578];v[114578]=0;if((h|0)==1){break i}v[a+36>>2]=v[c>>2];if(Kb(f)>>>0>32767){break d}switch(x[a>>1]-1|0){case 0:break g;case 2:break h;default:break f}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(u[e+8>>1]<1){break d}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];c=x[a+28>>1];v[114578]=0;u[e+16>>1]=c;u[e+18>>1]=(c+x[e+8>>1]|0)-1;a=aa(1612,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}if(u[e+8>>1]<1){break d}z[e+24>>2]=z[a+32>>2];c=x[a+28>>1];v[114578]=0;u[e+16>>1]=c;u[e+18>>1]=(c+x[e+8>>1]|0)-1;a=ea(1613,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}v[114578]=0;Z(1614,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}}d=1}vg(b)}jb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}vg(b);S(a|0);L()}function zI(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;l=jb-48|0;jb=l;v[l+44>>2]=0;if(!(i?0:!(d|g|h))){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Xb(k);v[j>>2]=0}v[114578]=0;Y(81);k=v[114578];v[114578]=0;b:{c:{if((k|0)==1){m=ab(71204,83324,83336,83440,71360,71464,71412,71304,71292,71608,71576,71544,71532,71180,0)|0;d:{e:{n=O()|0;if((n|0)==(ga(71204)|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=277;if((j|0)==1){break e}break b}if((ga(83324)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(83336)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(83440)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71360)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71464)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71412)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71304)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71292)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71608)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71576)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71544)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}if((ga(71532)|0)==(n|0)){k=_(m|0)|0;v[114578]=0;R(2108,j|0,k|0);j=v[114578];v[114578]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break d}o=ga(71180)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[114578]=0;R(2108,j|0,m|0);j=v[114578];v[114578]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}$()}o=!g;if(d){j=nb[d|0](k,e)|0}else{j=3}if(!(o|!(j&2))){v[g+16>>2]=k;m=v[l+44>>2];f:{if(m){o=Zd(m);break f}o=Zd(34181)}v[g+20>>2]=o}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];g:{if(g){g=Zd(g);break g}g=Zd(34181)}v[i>>2]=g}g=v[l+44>>2];if(g){Xb(g);v[l+44>>2]=0}h:{if(!(j&1)){break h}v[114578]=0;R(1990,l+32|0,a|0);g=v[114578];v[114578]=0;i:{j:{if((g|0)!=1){k:{if(f){v[114578]=0;R(1991,f|0,l+32|0);g=v[114578];v[114578]=0;if((g|0)!=1){break k}break j}g=Tb(l+32|0);if(b){v[114578]=0;R(b|0,g|0,c|0);g=v[114578];v[114578]=0;if((g|0)==1){break j}break k}Yr(g,l)}yb(l+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;yb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+4>>2]=248;v[l>>2]=37537;v[l+8>>2]=a?a:34181;a=v[13922];oG(a,37407,l);Br(a);$()}jb=l+48|0}function xG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=jb-560|0;jb=h;g=c;c=(c-3|0)/24|0;r=(c|0)>0?c:0;l=g+B(r,-24)|0;n=v[(e<<2)+52288>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=r-j|0;while(1){A[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+v[(c<<2)+52304>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}p=l-24|0;i=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){k=g+j|0;c=0;while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(k-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-l|0;t=48-l|0;z=l-25|0;g=n;a:{while(1){f=A[(g<<3)+h>>3];c=0;i=g;q=(g|0)<1;if(!q){while(1){k=(h+480|0)+(c<<2)|0;m=f;f=f*5.960464477539063e-8;b:{if(D(f)<2147483648){j=~~f;break b}j=-2147483648}f=+(j|0);m=m+f*-16777216;c:{if(D(m)<2147483648){j=~~m;break c}j=-2147483648}v[k>>2]=j;i=i-1|0;f=A[(i<<3)+h>>3]+f;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=$h(f,p);f=f+H(f*.125)*-8;d:{if(D(f)<2147483648){k=~~f;break d}k=-2147483648}f=f-+(k|0);e:{f:{g:{u=(p|0)<1;h:{if(!u){i=(g<<2)+h|0;j=v[i+476>>2];c=j>>t;s=i;i=j-(c<<t)|0;v[s+476>>2]=i;k=c+k|0;j=i>>y;break h}if(p){break g}j=v[((g<<2)+h|0)+476>>2]>>23}if((j|0)<1){break e}break f}j=2;if(f>=.5){break f}j=0;break e}i:{if(q){i=0;break i}c=0;w=1;while(1){i=(h+480|0)+(c<<2)|0;q=v[i>>2];s=i;j:{if(w){i=0;if(!q){break j}i=16777216-q|0}else{i=16777215-q|0}v[s>>2]=i;i=1}c=c+1|0;if((g|0)==(c|0)){break i}w=!i;continue}}k:{if(u){break k}l:{switch(z|0){case 0:c=(g<<2)+h|0;v[c+476>>2]=v[c+476>>2]&8388607;break k;case 1:break l;default:break k}}c=(g<<2)+h|0;v[c+476>>2]=v[c+476>>2]&4194303}k=k+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!i){break e}f=f-$h(1,p)}if(f==0){i=0;m:{c=g;if((n|0)>=(c|0)){break m}while(1){c=c-1|0;i=v[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break m}l=p;while(1){l=l-24|0;g=g-1|0;if(!v[(h+480|0)+(g<<2)>>2]){continue}break}break a}c=1;while(1){i=c;c=c+1|0;if(!v[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;A[(h+320|0)+(j<<3)>>3]=v[(r+g<<2)+52304>>2];c=0;f=0;if((d|0)>=1){while(1){f=f+A[(c<<3)+a>>3]*A[(h+320|0)+(j-c<<3)>>3];c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=$h(f,24-l|0);n:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;m=f;f=f*5.960464477539063e-8;o:{if(D(f)<2147483648){c=~~f;break o}c=-2147483648}f=m+ +(c|0)*-16777216;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}l=p}v[(h+480|0)+(g<<2)>>2]=c}f=$h(1,l);q:{if((g|0)<=-1){break q}c=g;while(1){A[(c<<3)+h>>3]=f*+v[(h+480|0)+(c<<2)>>2];f=f*5.960464477539063e-8;a=(c|0)>0;c=c-1|0;if(a){continue}break}if((g|0)<=-1){break q}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){r:{f=f+A[(c<<3)+55072>>3]*A[(a+c<<3)+h>>3];if((c|0)>=(n|0)){break r}i=c>>>0<d>>>0;c=c+1|0;if(i){continue}}break}A[(h+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<1){break v}f=A[(h+160|0)+(g<<3)>>3];c=g;while(1){m=f;a=c-1|0;d=(h+160|0)+(a<<3)|0;x=A[d>>3];f=x+f;A[(h+160|0)+(c<<3)>>3]=m+(x-f);A[d>>3]=f;d=(c|0)>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=A[(h+160|0)+(g<<3)>>3];c=g;while(1){m=f;a=c-1|0;d=(h+160|0)+(a<<3)|0;o=A[d>>3];f=o+f;A[(h+160|0)+(c<<3)>>3]=m+(o-f);A[d>>3]=f;d=(c|0)>2;c=a;if(d){continue}break}o=0;if((g|0)<=1){break v}while(1){o=o+A[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[h+160>>3];if(j){break t}A[b>>3]=f;f=A[h+168>>3];A[b+16>>3]=o;A[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){f=f+A[(h+160|0)+(g<<3)>>3];a=(g|0)>0;g=g-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){c=g;while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)>0;c=c-1|0;if(a){continue}break}}A[b>>3]=j?-f:f;f=A[h+160>>3]-f;c=1;if((g|0)>=1){while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break s}A[b>>3]=-f;f=A[h+168>>3];A[b+16>>3]=-o;A[b+8>>3]=-f}jb=h+560|0;return k&7}function wM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=jb-16|0;jb=i;a:{if(!be(d&255)){break a}j=(B(b,896)+a|0)+1074984|0;b:{c:{if(e?0:!(!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break c}if(nj(j)){break c}d=B(b,896)+a|0;e=d+1075060|0;if(!v[e>>2]|w[d+1075073|0]&4){break a}c=B(b,896)+a|0;h=c+1075004|0;g=c+1075008|0;if(!(v[h>>2]|v[g>>2])){break a}c=ey(a,b);if((c|0)==65535){break a}f=a+1074984|0;c=f+B(c,896)|0;xs(c,j);t[c+851|0]=0;t[c+827|0]=0;u[c+808>>1]=b+1;v[c+88>>2]=v[c+88>>2]&-918529;jt(c+810|0);v[c+696>>2]=0;v[c+88>>2]=v[c+88>>2]|2101248;v[e>>2]=0;v[j>>2]=0;v[j+4>>2]=0;c=f+B(b,896)|0;v[c+92>>2]=0;v[c+96>>2]=0;v[h>>2]=0;v[g>>2]=0;if(!(w[d+1075073|0]&2)){break b}a=a+1304392|0;if(!rd(a)){break b}Mh(v[a>>2],b,1);break b}e=B(b,896)+a|0;l=v[e+1075088>>2];c=x[a+480192>>1]<c>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!g){break d}f=d-1|0;c=x[ed(g+236|0,f)>>1];h=a+1074308|0;Eb(i+8|0,h,104);e:{if(Cb(i+8|0)){Eb(i,h,34);if(Cb(i)){break e}}d=w[fc(g+108|0,f)|0]}if((c-1&65535)>>>0<=3998){l=(B(c,104)+a|0)+484380|0;break d}Eb(i+8|0,h,43);if(!Cb(i+8|0)){break d}if(!zi(g)){break a}}if(w[e+1075073|0]&4){break a}h=a+1304392|0;m=a+1074308|0;if(b>>>0<256){q=b+1|0;c=b;while(1){f=(b|0)==(c|0);f:{if(x[a+480188>>1]>c>>>0?!f:0){break f}e=B(c,896)+a|0;if(x[e+1075792>>1]!=(q|0)?!f:0){break f}p=e+1075640|0;f=v[p>>2];if(!f){break f}k=e+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(w[f+17|0]-1|0){case 0:if(!d){break f}n=w[e+1075803|0]==(d|0)&(g|0)==(f|0);o=n;if(!g){break l}if(n){break i}break f;case 1:if(!l|v[e+1075088>>2]!=(l|0)){break f}if((g|0)==(f|0)){break g}Eb(i+8|0,m,104);if(!Cb(i+8|0)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(g){break j}o=(g|0)==(f|0)}if(o){break g}break f}if(!g){break f}n=w[g+34|0];if(!n){break f}if((n|0)==w[f+34|0]){break h}break f}if((g|0)!=(f|0)){break f}}if(!w[g+34|0]){break g}}if(!w[e+1075803|0]|w[f+18|0]>2){break g}Eb(i+8|0,m,34);qk(a,c&65535,rO(k,Cb(i+8|0))+255|0,0);t[e+1075806|0]=0}n:{o:{switch(w[v[p>>2]+18|0]){case 0:cn(a,k);v[e+1075672>>2]=0;if(!(w[e+1075073|0]&2)){break n}if(!rd(h)){break n}Mh(v[h>>2],c&65535,1);break n;case 1:cn(a,k);if(!(w[e+1075073|0]&2)){break n}if(!rd(h)){break n}uk(v[h>>2],c&65535);break n;case 2:break o;default:break n}}k=e+1075072|0;f=v[k>>2];v[k>>2]=f|4096;if(!(f&512)){break n}if(!rd(h)){break n}Eb(i+8|0,m,105);if(Cb(i+8|0)){break n}uk(v[h>>2],c&65535)}if(v[e+1075672>>2]){break f}v[e+1075680>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}e=0;g=0;p:{if(!nj(j)){break p}if(!be(w[(B(b,896)+a|0)+1075803|0])){break p}q:{c=xl(a,b,2,1);if(c-251>>>0<5){break q}if(!c){break p}g=v[(B(c,160)+a|0)+906140>>2];if(!g){break q}Eb(i+8|0,m,34);e=(s=g,y=rO(j,Cb(i+8|0)),z=b,r=v[v[g>>2]+96>>2],nb[r](s|0,y|0,z|0)|0);break p}g=0}if(Kh(j)?0:!e){break a}d=ey(a,b);if((d|0)==65535){break a}f=B(d,896)+a|0;c=f+1075072|0;l=f+1074984|0;r:{if(!(w[f+1075073|0]&2)){break r}if(!rd(h)){break r}Mh(v[h>>2],d,1)}xs(l,j);v[c>>2]=v[c>>2]&-917505;t[f+1075835|0]=0;k=x[a+480188>>1];t[f+1075811|0]=0;u[f+1075792>>1]=b>>>0<k>>>0?b+1|0:0;s:{if(!g|e^1){break s}e=w[(B(b,896)+a|0)+1075804|0];if(e>>>0>3|(e|0)==1){break s}qk(a,b,255,0);t[(B(b,896)+a|0)+1075806|0]=0}t:{u:{switch(w[(B(b,896)+a|0)+1075804|0]){case 2:cn(a,l);if(!(w[c+1|0]&2)){break t}if(!rd(h)){break t}uk(v[h>>2],b);Eb(i+8|0,m,105);if(!Cb(i+8|0)){break t}xy(v[h>>2],b,d);break t;case 0:v[(B(d,896)+a|0)+1075680>>2]=0;e=v[c>>2];v[c>>2]=e|4096;if(!(e&512)){break t}if(!rd(h)){break t}Mh(v[h>>2],b,1);break t;case 3:e=v[c>>2];v[c>>2]=e|4096;if(!(e&512)){break t}if(!rd(h)){break t}Eb(i+8|0,m,105);g=Cb(i+8|0);e=v[h>>2];if(g){xy(e,b,d);break t}uk(e,b);break t;case 1:break u;default:break t}}if(!(w[c+1|0]&2)){break t}if(!rd(h)){break t}xy(v[h>>2],b,d)}if(!v[(B(d,896)+a|0)+1075672>>2]){v[(B(d,896)+a|0)+1075680>>2]=0;v[c>>2]=v[c>>2]|2101248}a=B(b,896)+a|0;v[a+1075060>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075076|0;v[a>>2]=0;v[a+4>>2]=0}}jb=i+16|0}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=jb-128|0;jb=d;h=-1;a:{b:{c:{d:{if(!Gf(v[v[b>>2]-12>>2]+b|0)){break d}pf(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];am(d+104|0);ak(b,d+104|0,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=Og(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;dj(b,d+8|0);break d}u[d+86>>1]=0;xf(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}am(d+78|0);ak(b,d+78|0,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;xf(b,d+76|0);e=u[d+76>>1];if((e-3&65535)>>>0>1){break d}e:{f:{g:{h:{i:{j:{k:{if((e|0)<=3){e=Wb(d+112|0);v[114578]=0;f=W(722,b|0,e|0,65535)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}if(!f){break j}v[114578]=0;U(13,d- -64|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)!=1){break k}break b}e=Wb(d+112|0);v[114578]=0;f=W(724,b|0,e|0,255)|0;i=v[114578];v[114578]=0;if((i|0)==1){break c}if(!f){break i}v[114578]=0;U(13,d- -64|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}}Gb(a+40|0,d- -64|0);yb(d- -64|0);yb(e);u[d+62>>1]=0;xf(b,d+62|0);u[d+60>>1]=0;xf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Fi(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=eA(e);u[d+58>>1]=e;break l}xf(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Wb(d+112|0);v[114578]=0;u[d+40>>1]=0;Q(1617,b|0,d+40|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[114578]=0;g=W(722,b|0,e|0,65535)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}if(g){break q}break e}v[114578]=0;g=W(724,b|0,e|0,255)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}if(!g){break e}}v[114578]=0;U(13,d- -64|0,c|0,e|0);g=v[114578];v[114578]=0;if((g|0)==1){break p}v[114578]=0;g=Q(1618,i|0,d+40|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}Gb(g,d- -64|0);yb(d- -64|0);yb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}am(d- -64|0);ak(b,d- -64|0,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if(_J(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(d- -64|0);break f}if(!ZJ(b,c)){break d}}c=a+16|0;r:{if(u[d+86>>1]<=2){if(_J(b,c)){break r}break d}if(!ZJ(b,c)){break d}}l=a,m=Kb(a+16|0),v[l+36>>2]=m;u[d+56>>1]=0;xf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c+200&65535)>>>0>400){break d}u[d+54>>1]=0;xf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break d}v[d+48>>2]=0;Lo(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}am(d+40|0);ak(b,d+40|0,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}c=a+4|0;if(Kb(c)>>>0>32767){break d}f=a+32|0;s:{if(!(z[f>>2]>C(0)?u[a+30>>1]>=1:0)){if(!x[a>>1]){break s}break d}t:{switch(x[a>>1]-1|0){case 0:case 2:break t;default:break s}}if(Kb(c)>>>0<u[a+30>>1]>>>0){break d}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=pt(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[Ls(d+112|0,d+32|0,32408)>>2],v[l+36>>2]=m;Mo(a);h=1;if(x[a>>1]!=3){break d}if((dK(Kb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=kk(d+112|0);h=0;if(u[a+30>>1]>0){while(1){b=Pb(c,h-u[a+28>>1]|0);v[114578]=0;R(1619,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;c=Kb(c);v[114578]=0;u[d+34>>1]=(b+c|0)-1;u[d+30>>1]=0;ea(1613,a|0,e|0,f|0,d+32|0,d+30|0)|0;a=v[114578];v[114578]=0;h=1;if((a|0)!=1){Sf(e);break d}break h}yb(e);break d}yb(e);break d}b=P()|0;O()|0;Sf(e);break a}b=P()|0;O()|0}yb(e);break a}yb(e)}jb=d+128|0;return h|0}b=P()|0;O()|0;yb(e);break a}b=P()|0;O()|0;yb(e)}S(b|0);L()}function eda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-11360|0;jb=f;Jc(c);a:{b:{if(!Qb(c,4)){break b}c:{while(1){d:{uB(c,f+16|0);e:{if(!qd(f+16|0,20249,3)){d=f+4648|0;h=jb-16|0;jb=h;g=c;f:{if(Qb(c,7)){$t(h+8|0,d);Bd(g,h+8|0);break f}g=jb-16|0;jb=g;k=jb-16|0;jb=k;i=d+7|0;while(1){ff(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}jb=k+16|0;jb=g+16|0}jb=h+16|0;i=3;d=0;while(1){g=w[(f+4648|0)+i|0];if(g&128){break c}d=g|d<<7;i=i+1|0;if((i|0)!=7){continue}break}$b(c,d);break e}g:{if(qd(f+16|0,20253,3)){break g}if(!xQ(c,20257)){break g}$b(c,Cf(c)+16|0);break e}if(!qd(f+16|0,20263,3)){break e}if(!qd(f+16|0,20267,3)){break e}if(w[f+16|0]){break d}fg(c,2)}if(Qb(c,4)){continue}break b}break}if(zO(f+16|0)){break b}}i=0;break a}Jc(c);Oz(f+11336|0,c);i=v[f+11336>>2];v[114578]=0;c=T(414,f+11336|0)|0;d=v[114578];v[114578]=0;h:{i:{if((d|0)!=1){v[114578]=0;c=T(856,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break i}}i=P()|0;O()|0;break h}d=jb-16|0;jb=d;j=f+11320|0;v[j>>2]=0;v[j+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(358,j+8|0,d+12|0,d+8|0)|0;g=v[114578];v[114578]=0;j:{if((g|0)!=1){jb=d+16|0;break j}V(0)|0;O()|0;Ab();L()}Rb(f+4648|0,0,6668);v[114578]=0;Z(1238,f+4648|0);d=v[114578];v[114578]=0;k:{l:{m:{if((d|0)!=1){d=f+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=f+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[f+4624>>2]=0;v[f+4628>>2]=0;g=0;d=0;n:{o:{p:{while(1){v[114578]=0;h=Gg(460,i,l);k=v[114578];v[114578]=0;if((k|0)==1){break n}v[114578]=0;m=ea(1239,f+4648|0,c|0,h|0,f+16|0,f+4624|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break n}if((m|0)<0){break l}h=v[f+4624>>2];if((h|0)<0){break l}o=(m|0)<1;if(!(h|m)|(h?0:!o)){break l}q:{if((h|0)>=1){k=v[f+4636>>2];if((k|0)!=(g|0)?g:0){break l}h=v[f+4632>>2];if((h|0)!=(d|0)?d:0){break l}if((k|0)<1|h-1>>>0>1){break m}v[114578]=0;v[f+8>>2]=0;d=Gg(460,i,l);g=v[114578];v[114578]=0;if((g|0)==1){break q}v[114578]=0;v[f+4>>2]=d;d=W(1240,f+4624|0,f+8|0,f+4|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}d=v[d>>2];v[114578]=0;v[f+8>>2]=0;g=Gg(460,i,l);n=v[114578];v[114578]=0;if((n|0)==1){break p}v[114578]=0;v[f+4>>2]=g;g=W(1240,f+4624|0,f+8|0,f+4|0)|0;n=v[114578];v[114578]=0;if((n|0)==1){break p}c=c+d|0;d=i;g=v[g>>2];i=d-g|0;l=l-((g>>31)+(d>>>0<g>>>0)|0)|0;if(!o){p=f,q=cc(j),v[p+8>>2]=q;Md(f,f+8|0);v[114578]=0;aa(1241,j|0,v[f>>2],f+16|0,(f+16|0)+(B(h,m)<<1)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break o}}g=k;d=h}h=oc(j);if((l|0)<0?1:(l|0)<=0?i>>>0<1:0){break l}if((h>>>0)/(d>>>0)>>>0<268435457){continue}break l}break}i=P()|0;O()|0;break k}i=P()|0;O()|0;break k}i=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break k}_(i|0)|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;g=k;d=h;if((c|0)!=1){break l}i=P()|0;O()|0;break k}i=P()|0;O()|0;break k}i=P()|0;O()|0;break k}g=k;d=h}i=0;r:{s:{t:{u:{v:{if(!d|!g){break v}if(nd(j)){break v}if((oc(j)>>>0)/(d>>>0)>>>0>268435456){break v}v[114578]=0;Q(1242,a|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break r}if(!e){v[114578]=0;c=Q(85,f+16|0,20271)|0;h=v[114578];v[114578]=0;if((h|0)==1){break u}v[114578]=0;Q(371,((b<<5)+a|0)+946300|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break t}yb(c);v[114578]=0;c=B(b,104)+a|0;R(388,c+484380|0,0);h=v[114578];v[114578]=0;if((h|0)==1){break r}v[c+484404>>2]=g}g=B(b,104)+a|0;c=g+484380|0;p=c,q=(oc(j)>>>0)/(d>>>0)|0,v[p>>2]=q;h=g+484414|0;g=x[h>>1];u[h>>1]=(d|0)==2?g|65:g&65470|1;v[114578]=0;T(466,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break r}if(De(c)){d=bc(j);g=cc(j);b=v[(B(b,104)+a|0)+484400>>2];v[114578]=0;W(1243,d|0,g|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break r}}if(!e){b=v[a+480180>>2];v[114578]=0;U(1244,c|0,32,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break s}v[114578]=0;U(1245,c|0,a|0,0);a=v[114578];v[114578]=0;if((a|0)==1){break r}}i=De(c)}jC(j);Ec(f+11336|0);break a}i=P()|0;O()|0;break k}i=P()|0;O()|0;yb(c);break k}i=P()|0;O()|0;break k}i=P()|0;O()|0}jC(j)}Ec(f+11336|0);S(i|0);L()}jb=f+11360|0;return i|0}function ija(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,B=0,C=0;f=jb-48|0;jb=f;a:{b:{c:{d:{if(!c){break d}B=f,C=Gd(a),t[B+32|0]=C;g=f+32|0;d=b;e:{if(y[d+4>>2]<y[zb(d)>>2]){h=jb-16|0;jb=h;e=Mi(h,d,1);d=zb(d);k=v[e+4>>2];v[114578]=0;U(881,d|0,k|0,g|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[e+4>>2]=v[e+4>>2]+1;Mb(e);jb=h+16|0;break e}a=P()|0;O()|0;Mb(e);break a}h=jb-32|0;jb=h;k=zb(d);e=nh(h+8|0,Ki(d,Ac(d)+1|0),Ac(d),k);l=v[e+8>>2];v[114578]=0;U(881,k|0,l|0,g|0);g=v[114578];v[114578]=0;f:{g:{if((g|0)==1){break g}v[e+8>>2]=v[e+8>>2]+1;v[114578]=0;R(366,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}Rg(e);jb=h+32|0;break f}a=P()|0;O()|0;Rg(e);break a}}l=c-1|0;if(!l){break c}c=0;while(1){h:{i:{i=c&254;j:{if(!i){if(!Je(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){break j}break i}if((c&65535)>>>0<256){break i}}e=1;while(1){k:{l:{m:{c=i<<1&254;j=i>>>0>127;n:{o:{if(c){break o}if(!Je(a,f+32|0)){break n}d=w[f+32|0]<<1|1;c=d&255;j=d>>>0>255}e=j|e<<1;i=c<<1&254;if(i){break l}if(Je(a,f+32|0)){break m}}i=0;break k}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break k}if(c>>>0>127){continue}}break}p:{if((e|0)<=2){d=0;g=e-2|0;break p}c=Je(a,f+32|0);if(!c){break d}c=c?(w[f+32|0]|e<<8)-768|0:p;d=((c|0)>1279?2:1)+((c|0)>31999)|0;p=c^-1;g=0}c=i<<1&254;e=i>>>0>127;q:{if(c){break q}if(!Je(a,f+32|0)){break d}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}i=c<<1&254;c=c>>>0>127;r:{if(i){break r}if(!Je(a,f+32|0)){break d}c=w[f+32|0]<<1|1;i=c&255;c=c>>>0>255}e=c|(g<<2|(e?2:0));if(!e){e=1;while(1){s:{t:{u:{c=i<<1&254;j=i>>>0>127;v:{w:{if(c){break w}if(!Je(a,f+32|0)){break v}g=w[f+32|0]<<1|1;c=g&255;j=g>>>0>255}e=j|e<<1;i=c<<1&254;if(i){break t}if(Je(a,f+32|0)){break u}}i=0;break s}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break s}if(c>>>0>127){continue}}break}e=e+2|0}c=0;if((p|0)>-1){break b}h=d+e|0;if(h>>>0>l>>>0|(h|0)<1){break b}if((0-Ac(b)|0)>(p|0)){break b}B=f,C=cc(b),v[B+32>>2]=C;Md(f+40|0,f+32|0);t[f+24|0]=0;k=f+24|0;n=jb-32|0;jb=n;v[n+24>>2]=v[f+40>>2];c=b;d=v[c>>2];B=n,C=bc(c),v[B>>2]=C;e=$l(n+24|0,n)+d|0;x:{y:{g=h;z:{if(!g){break z}d=v[zb(c)>>2];j=v[c+4>>2];if(g>>>0<=d-j>>>0){d=g;m=j-e|0;if(d>>>0>m>>>0){Pp(c,g-m|0,k);d=m;if(!d){break z}}q=jb-16|0;jb=q;u=c;x=j;s=v[c+4>>2];z=e;m=e+(s-(e+g|0)|0)|0;o=Mi(q,c,j-m|0);A:{B:{if(j>>>0>m>>>0){j=m;while(1){r=zb(u);A=v[o+4>>2];v[114578]=0;U(881,r|0,A|0,j|0);r=v[114578];v[114578]=0;if((r|0)==1){break B}v[o+4>>2]=v[o+4>>2]+1;j=j+1|0;if(x>>>0>j>>>0){continue}break}}Mb(o);Fp(z,m,s);jb=q+16|0;break A}a=P()|0;O()|0;Mb(o);break a}j=e;if(e>>>0<=k>>>0){k=y[c+4>>2]>k>>>0?g+k|0:k}Th(j,d,k);break z}d=zb(c);d=nh(n,Ki(c,Ac(c)+g|0),e-v[c>>2]|0,d);v[114578]=0;U(702,d|0,g|0,k|0);g=v[114578];v[114578]=0;if((g|0)==1){break y}v[114578]=0;e=W(876,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break y}Rg(d)}Ng(e);jb=n+32|0;break x}a=P()|0;O()|0;Rg(d);break a}B=f,C=cc(b),v[B+16>>2]=C;B=f,C=qz(f+16|0,h),v[B+24>>2]=C;B=f,C=cf(f+24|0,p),v[B+32>>2]=C;B=f,C=cc(b),v[B+16>>2]=C;B=f,C=qz(f+16|0,h),v[B+24>>2]=C;c=h;while(1){B=f,C=xr(f+32|0),v[B+16>>2]=C;d=w[v[f+16>>2]];B=f,C=xr(f+24|0),v[B+8>>2]=C;t[v[f+8>>2]]=d;d=(c|0)>1;c=c-1|0;if(d){continue}break}c=l-h|0;break h}if(!Je(a,f+32|0)){break d}e=f+32|0;c=b;C:{if(v[c+4>>2]!=v[zb(c)>>2]){g=jb-16|0;jb=g;d=Mi(g,c,1);c=zb(c);h=v[d+4>>2];v[114578]=0;U(571,c|0,h|0,e|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[d+4>>2]=v[d+4>>2]+1;Mb(d);jb=g+16|0;break C}a=P()|0;O()|0;Mb(d);break a}g=jb-32|0;jb=g;h=zb(c);d=nh(g+8|0,Ki(c,Ac(c)+1|0),Ac(c),h);k=v[d+8>>2];v[114578]=0;U(571,h|0,k|0,e|0);e=v[114578];v[114578]=0;D:{E:{if((e|0)==1){break E}v[d+8>>2]=v[d+8>>2]+1;v[114578]=0;R(366,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break E}Rg(d);jb=g+32|0;break D}a=P()|0;O()|0;Rg(d);break a}}c=l-1|0}l=c;if(!l){break c}c=i<<1;continue}}c=0;break b}c=1}jb=f+48|0;return c|0}S(a|0);L()}function WY(){var a=0,b=0,c=0,d=0,e=0;Ld(463264);v[115816]=64704;v[114578]=0;b=Q(2513,463280,28)|0;a=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[114578]=0;c=Q(85,463440,64693)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}Kb(b);sE(b);rE(b);Ld(462944);v[115736]=66128;v[114578]=0;R(2514,463264,462944);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462952);v[115738]=66160;v[114578]=0;R(2515,463264,462952);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462960);t[462972]=0;v[115742]=0;v[115740]=64724;d=462968,e=mo(),v[d>>2]=e;v[114578]=0;R(2516,463264,462960);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462976);v[115744]=65308;v[114578]=0;R(2517,463264,462976);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(462984);v[115746]=65456;v[114578]=0;R(2518,463264,462984);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;Y(2519);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2520,463264,462992);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463008);v[115752]=65604;v[114578]=0;R(2521,463264,463008);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463016);v[115754]=65720;v[114578]=0;R(2522,463264,463016);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463024);u[231516]=11310;v[115756]=64824;Wb(463036);v[114578]=0;R(2523,463264,463024);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463056);v[115766]=46;v[115767]=44;v[115764]=64864;Wb(463072);v[114578]=0;R(2524,463264,463056);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463088);v[115772]=66192;v[114578]=0;R(2525,463264,463088);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463096);v[115774]=66436;v[114578]=0;R(2526,463264,463096);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463104);v[115776]=66648;v[114578]=0;R(2527,463264,463104);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463112);v[115778]=66880;v[114578]=0;R(2528,463264,463112);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;pE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2530,463264,463120);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463128);v[115782]=68012;v[114578]=0;R(2531,463264,463128);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463136);v[115784]=68128;v[114578]=0;R(2532,463264,463136);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463144);v[115786]=68244;v[114578]=0;R(2533,463264,463144);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;oE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2535,463264,463152);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;nE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2537,463264,463160);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;mE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2539,463264,463168);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;lE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2541,463264,463176);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463184);v[115798]=70404;v[115796]=67080;v[115798]=67128;v[114578]=0;R(2542,463264,463184);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463200);v[115802]=70440;v[115800]=67344;v[115802]=67392;v[114578]=0;R(2543,463264,463200);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;Y(2544);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2545,463264,463216);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;Y(2546);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2547,463264,463232);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;kE();a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(2549,463264,463248);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ld(463256);v[115814]=69136;v[114578]=0;R(2550,463264,463256);a=v[114578];v[114578]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(c)}vE(b)}S(a|0);L()}v[115410]=463264;return 461640}function h_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb+-64|0;jb=h;v[h+56>>2]=b;v[e>>2]=0;Bc(h,d);v[114578]=0;i=T(2456,h|0)|0;j=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Ob(h);S(a|0);L()}PE(a,f+24|0,h+56|0,c,e,i);break b}OE(a,f+16|0,h+56|0,c,e,i);break b}b=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=bj(a,v[h+56>>2],c,d,e,f,Tb(b),Tb(b)+(Fb(b)<<2)|0),v[k+56>>2]=l;break b}a=e;b=ci(h+56|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}g=v[16127];v[h+24>>2]=v[16126];v[h+28>>2]=g;g=v[16125];v[h+16>>2]=v[16124];v[h+20>>2]=g;g=v[16123];v[h+8>>2]=v[16122];v[h+12>>2]=g;g=v[16121];v[h>>2]=v[16120];v[h+4>>2]=g;k=h,l=bj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[16135];v[h+24>>2]=v[16134];v[h+28>>2]=g;g=v[16133];v[h+16>>2]=v[16132];v[h+20>>2]=g;g=v[16131];v[h+8>>2]=v[16130];v[h+12>>2]=g;g=v[16129];v[h>>2]=v[16128];v[h+4>>2]=g;k=h,l=bj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=ci(h+56|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=ci(h+56|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=ci(h+56|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=ci(h+56|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=ci(h+56|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=h+56|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!lr(a,b+8|0)){break H}if(!$j(i,8192,gl(a))){break H}Bm(a);continue}break}if(_j(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+56|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=fr(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=lc(h,64544,44);k=g,l=bj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[16152];g=v[16151];v[h+8>>2]=v[16150];v[h+12>>2]=g;g=v[16149];v[h>>2]=v[16148];v[h+4>>2]=g;k=h,l=bj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=e;b=ci(h+56|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}g=v[16163];v[h+24>>2]=v[16162];v[h+28>>2]=g;g=v[16161];v[h+16>>2]=v[16160];v[h+20>>2]=g;g=v[16159];v[h+8>>2]=v[16158];v[h+12>>2]=g;g=v[16157];v[h>>2]=v[16156];v[h+4>>2]=g;k=h,l=bj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=e;b=ci(h+56|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=bj(a,v[h+56>>2],c,d,e,f,Tb(b),Tb(b)+(Fb(b)<<2)|0),v[k+56>>2]=l;break b}NE(f+20|0,h+56|0,c,e,i);break b}a=ci(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(_j(c,a+8|0)){break M}b=4;if((um(i,gl(c))|0)!=37){break M}b=2;if(!_j(Bm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+56>>2]}jb=h- -64|0;return a|0}function uba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+4>>2]=0;v[a>>2]=20768;v[a+8>>2]=v[19815];b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;rp(a+24604|0);PL(a+24648|0,0);b=a+393352|0;v[b>>2]=8;v[b+4>>2]=0;u[b+4128>>1]=0;d=b+4120|0;v[d>>2]=0;v[d+4>>2]=0;d=b+4112|0;v[d>>2]=0;v[d+4>>2]=0;v[b+4104>>2]=0;v[b+4108>>2]=0;Rb(b+4132|0,0,40);vO(b+8|0,1024);Rb(b+4172|0,0,49824);Rb(b+53996|0,0,32832);v[a+480224>>2]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;l=Xx(a+480248|0);v[a+480272>>2]=0;d=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{while(1){v[114578]=0;b=T(1391,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}b=b+32|0;if((d|0)!=(b|0)){continue}break}b=jb-16|0;jb=b;f=a+484344|0;d=f;v[d>>2]=0;v[d+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1437,d+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;n:{if((d|0)!=1){jb=b+16|0;break n}break a}v[f+12>>2]=a;v[114578]=0;m=Q(1392,a+484360|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break l}d=a+900380|0;b=a+484380|0;while(1){v[114578]=0;b=Q(1012,b|0,0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}b=b+104|0;if((d|0)!=(b|0)){continue}break}v[114578]=0;T(1393,a+901404|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break j}g=a+946300|0;h=a+906300|0;b=0;while(1){v[114578]=0;d=(B(b,160)+a|0)+906300|0;T(1394,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}b=b+1|0;if((b|0)!=250){continue}break}d=a+1074300|0;i=a+946300|0;b=i;while(1){v[114578]=0;b=T(1162,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}b=b+32|0;if((d|0)!=(b|0)){continue}break}v[a+1074300>>2]=0;v[a+1074304>>2]=0;Wx(a+1074308|0);v[114578]=0;b=da(1395)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;b=T(1396,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[a+1074324>>2]=b;v[114578]=0;T(1397,a+1074328|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;T(1398,a+1074376|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;n=W(1333,a+1304360|0,a|0,255)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}d=jb-16|0;jb=d;v[114578]=0;v[d+12>>2]=0;b=a+1304392|0;W(1401,b|0,d+12|0,d+8|0)|0;c=v[114578];v[114578]=0;o:{if((c|0)!=1){jb=d+16|0;break o}break a}d=b;c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=0;b=a+1304396|0;W(1402,b|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;p:{if((e|0)!=1){jb=c+16|0;break p}break a}o=Wb(a+1304400|0);p=gd(a+1304412|0);j=a+1304424|0;Wb(j);q=NL(a+1304436|0);c=jb-16|0;jb=c;k=a+1304500|0;e=k;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1403,e+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;q:{if((e|0)!=1){jb=c+16|0;break q}break a}t[a+1304512|0]=0;c=a+1304520|0;v[c>>2]=0;v[c+4>>2]=0;v[c+32>>2]=0;v[c+36>>2]=1072693248;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[a+1304560>>2]=0;Wo(a+12|0);sp(a+8204|0);sp(a+12300|0);c=a+1074408|0;v[c>>2]=4;v[c+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;ML(a+900380|0);v[114578]=0;Z(1399,i|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[114578]=0;c=T(1400,12)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}v[c>>2]=0;v[c+4>>2]=0;v[c+8>>2]=0;b=jb-16|0;jb=b;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1438,c+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;r:{if((d|0)!=1){jb=b+16|0;break r}break a}v[a+4>>2]=c;return a|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;if(!b){break d}while(1){d=$m(d-160|0);if((h|0)!=(d|0)){continue}break}break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;Vx(k);ts(q);yb(j);yb(p);yb(o);ss(b);rs(d);$o(n)}while(1){g=$m(g-160|0);if((h|0)!=(g|0)){continue}break}}Vs(m)}Ux(f)}oe(l);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function nla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=jb-976|0;jb=e;Jc(b);f=jb-16|0;jb=f;h=e+872|0;FS(f+8|0,h);j=Hb(f+8|0);d=b;i=nc(d,ac(f,f+8|0));if((j|0)==(i|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(i|0)==(j|0);if(!d){GS(h)}a:{if(!d){break a}if(!JS(e+872|0)){break a}if(!Qb(b,id(IS(e+872|0),mb))){break a}b:{if(!c){break b}Hd(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480200>>2]=256;v[a+480204>>2]=8e5;d=Ub(e+96|0,12920);Gb(a+1304436|0,d);yb(d);d=Ub(e+96|0,12939);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;HS(e+24|0,2,e+872|4);Ic(e+96|0,e+24|0);Gb(a+1304400|0,e+96|0);yb(e+96|0);while(1){d=(g<<5)+a|0;f=d+480280|0;zg(f);h=f;f=(e+872|0)+g|0;v[h>>2]=!w[f+50|0]<<10;u[d+480284>>1]=(w[f+76|0]<<4|8)&248;g=g+1|0;if((g|0)!=16){continue}break}if(w[e+968|0]|w[e+969|0]<<8){Jy(a+1304424|0,b,w[e+968|0]|w[e+969|0]<<8,132,0)}g=0;f=jb-16|0;jb=f;d=jb-16|0;jb=d;h=e+96|0;gc(f+8|0,h,771);jb=d+16|0;j=Hb(f+8|0);d=b;i=nc(d,ac(f,f+8|0));if((j|0)==(i|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(i|0)==(j|0);if(!d){f=jb-16|0;jb=f;Rb(h,0,771);jb=f+16|0}if(!d){break a}d=a+484360|0;Yz(Vb(d),e+96|0,w[e+353|0],255,254);Oe(Vb(d),w[e+354|0]);Pc(b,w[e+919|0]|w[e+920|0]<<8);j=a+484344|0;o=c&1;c:{d:{while(1){d=(g<<1)+e|0;if(w[d+355|0]|w[d+356|0]<<8){ud(e+24|0,b,w[d+355|0]|w[d+356|0]<<8);d=w[d+355|0]|w[d+356|0]<<8;h=(d-2|0)/64|0;e:{if(!o){break e}v[114578]=0;f=W(404,j|0,g&65535,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!f){break e}v[114578]=0;i=T(389,e+24|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;Q(340,e+24|0,1)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}if(d>>>0>=66){p=h>>>0>1?h:1;k=0;while(1){d=_b(j,g);v[114578]=0;q=Q(497,d|0,k|0)|0;d=v[114578];v[114578]=0;l=0;if((d|0)==1){break d}while(1){v[114578]=0;R(595,e+80|0,e+24|0);d=v[114578];v[114578]=0;f:{g:{h:{if((d|0)!=1){d=B(l,6)+q|0;r=dd(e+80|0);f=Bf(e+80|0);m=Sh(e+80|0);n=w[e+80|0];if((n-1&255)>>>0>71){break h}t[d|0]=n+36;t[d+1|0]=w[r|0]+1;break g}break d}if(!(w[d|0]|w[f|0])){break f}}t[d+2|0]=1;s=d,z=(Cd(w[f|0],1,16)<<2)-4|0,t[s+4|0]=z}f=w[m|0]&15;t[d+5|0]=f;i:{j:{switch((w[m|0]>>>4|0)-3|0){case 0:t[d+5|0]=f<<2;break i;case 1:t[d+5|0]=(6/(f+1>>>0)|0)+1;break i;case 3:case 4:t[d+5|0]=f<<3;break i;case 7:t[d+4|0]=(f<<2)+4;t[d+2|0]=1;break i;case 8:t[d+5|0]=f|128;break i;case 9:break j;default:break i}}t[d+5|0]=(6/(f+1>>>0)|0)+1|13}t[d+3|0]=w[(w[m|0]>>>4|0)+12944|0];l=l+1|0;if((l|0)!=16){continue}break}k=k+1|0;if((p|0)!=(k|0)){continue}break}}d=_b(j,g);v[114578]=0;f=W(498,e+80|0,14,0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break d}f=Uh(Ne(f,i?i>>>0<h-2>>>0?i+1|0:-1:-1));v[114578]=0;Q(499,d|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}}Bb(e+24|0)}g=g+1|0;if((g|0)!=256){continue}break}g=1;if(!(c&2)){break a}CT(b,e+72|0);g=0;while(1){k:{l:{if(!(w[e+72+(g>>>3)|0]>>>(g&7)&1)){g=g+1|0;break l}if(!Xz(b,e+24|0)){break b}g=g+1|0;u[a+480190>>1]=g;yg(e+8|0,1,e+24|0);Ic(e+80|0,e+8|0);c=x[a+480190>>1];v[114578]=0;Q(371,((c<<5)+a|0)+946300|0,e+80|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}yb(e+80|0);f=(B(g,104)+a|0)+484380|0;d=f;Fd(d,0);c=e+24|0;v[d>>2]=w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24);v[d+4>>2]=w[c+38|0]|w[c+39|0]<<8|(w[c+40|0]<<16|w[c+41|0]<<24);h=w[c+42|0]|w[c+43|0]<<8|(w[c+44|0]<<16|w[c+45|0]<<24);v[d+24>>2]=16726;v[d+8>>2]=h;u[d+30>>1]=w[c+37|0]<<4;if(t[c+46|0]&1){v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}if(!(!(w[c+47|0]&8)|y[d+8>>2]<=y[d+4>>2])){u[d+34>>1]=x[d+34>>1]|2}ad(e+80|0,t[e+70|0]&1?16:8,1,0,0);tg(e+80|0,f,b)}if((g|0)!=64){continue}break b}break}g=P()|0;O()|0;yb(e+80|0);break c}g=P()|0;O()|0;Bb(e+24|0)}S(g|0);L()}g=1}jb=e+976|0;return g|0}function aI(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=jb-256|0;jb=e;A[e+248>>3]=c;a:{if(mj(b)){break a}g=w[fk(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;sk(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}Dd(e+216|0);f=v[e+216>>2];Dd(e+200|0);h=ek(f,v[e+204>>2],b);Dd(e+216|0);f=v[b>>2];g=v[b+4>>2];c:{d:{e:{f:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=qc(e+232|0,38235);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Hc(e+16|0,e+8|0)){d=ba(8)|0;v[114578]=0;R(2144,e+200|0,e+248|0);a=v[114578];v[114578]=0;g:{h:{i:{if((a|0)!=1){v[114578]=0;U(2119,e+216|0,39300,e+200|0);a=v[114578];v[114578]=0;if((a|0)==1){break i}mc(d,e+216|0);a=0;v[114578]=0;U(2009,d|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(e+216|0);break h}b=P()|0;O()|0;break g}b=P()|0;a=1;O()|0}yb(e+200|0);if(!a){break d}}ca(d|0);break d}if(!d){break f}d=ba(8)|0;v[114578]=0;f=Q(2142,e+168|0,b|0)|0;b=v[114578];v[114578]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[114578]=0;U(2119,e+184|0,39179,f|0);a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;U(2137,e+200|0,e+184|0,39315);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break q}v[114578]=0;R(2144,e+152|0,e+248|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}v[114578]=0;U(138,e+216|0,e+200|0,e+152|0);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break o}mc(d,e+216|0);v[114578]=0;U(2009,d|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(e+216|0);a=0;break n}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;a=1;O()|0;break m}b=P()|0;O()|0}yb(e+152|0)}yb(e+200|0)}yb(e+184|0)}yb(f)}if(!a){break d}ca(d|0);break d}v[e+144>>2]=f;v[e+148>>2]=g;d=qc(e+136|0,38235);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Hc(e+80|0,e+72|0)){d=ba(8)|0;v[114578]=0;R(2144,e+200|0,e+248|0);a=v[114578];v[114578]=0;s:{t:{u:{if((a|0)!=1){v[114578]=0;U(2119,e+216|0,39300,e+200|0);a=v[114578];v[114578]=0;if((a|0)==1){break u}mc(d,e+216|0);a=0;v[114578]=0;U(2009,d|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(e+216|0);break t}b=P()|0;O()|0;break s}b=P()|0;a=1;O()|0}yb(e+200|0);if(!a){break d}}ca(d|0);break d}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=qc(e+120|0,39022);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Hc(e- -64|0,e+56|0)){if(!w[a+28|0]){break f}c=A[e+248>>3];if(!(c<=4?!(c<=0):0)){a=ba(8)|0;v[114578]=0;d=Q(85,e+216|0,39320)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}mc(a,d);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(d);break d}b=zk(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;To(v[a>>2]);break f}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=qc(e+104|0,39040);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Hc(e+48|0,e+40|0)){if(!w[a+28|0]){break f}c=A[e+248>>3];if(!(c<=4?!(c<=0):0)){a=ba(8)|0;v[114578]=0;d=Q(85,e+216|0,39341)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,d);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(d);break d}b=P()|0;O()|0;ca(a|0);break d}b=zk(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;To(v[a>>2]);break f}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=qc(e+88|0,39137);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Hc(e+32|0,e+24|0)){break f}b=mn(A[e+248>>3]*65536);v[v[a+24>>2]+480236>>2]=b}jb=e+256|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function ne(a,b){var c=C(0),d=C(0),e=C(0),f=0,g=0,h=0,i=0,k=0,m=C(0),n=0,o=C(0),r=C(0),s=0,t=C(0),u=C(0),v=C(0),w=C(0);d=C(1);a:{b:{c:{k=(p(a),j(2));d:{if((k|0)==1065353216){break d}i=(p(b),j(2));f=i&2147483647;if(!f){break d}h=k&2147483647;c=C(a+b);if(!(f>>>0<2139095041?h>>>0<=2139095040:0)){break a}e:{f:{if((k|0)>-1){break f}n=2;if(f>>>0>1266679807){break e}if(f>>>0<1065353216){break f}g=150-(f>>>23|0)|0;s=f>>>g|0;n=0;if((f|0)!=s<<g){break e}n=2-(s&1)|0;break e}n=0}g=n;g:{if((f|0)!=1065353216){if((f|0)!=2139095040){break g}if((h|0)==1065353216){break d}c=(i|0)>-1?b:C(0);if(h>>>0>=1065353217){break a}c=(i|0)>-1?C(0):C(-b);break a}c=(i|0)>-1?a:C(C(1)/a);break a}c=C(a*a);if((i|0)==1073741824){break a}c=C(K(a));if(!((i|0)!=1056964608|(k|0)<0)){break a}d=C(D(a));if(!(h?(k&1073741823)!=1065353216:0)){d=(i|0)<0?C(C(1)/d):d;if((k|0)>-1){break d}if(!(g|h-1065353216)){a=C(d-d);c=C(a/a);break a}c=(g|0)==1?C(-d):d;break a}o=C(1);h:{if((k|0)>-1){break h}i:{switch(g|0){case 0:a=C(a-a);c=C(a/a);break a;case 1:break i;default:break h}}o=C(-1)}j:{if(f>>>0>=1291845633){c=(i|0)<0?C(C(o*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(o*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(h>>>0<=1065353207){break a}c=(i|0)>0?C(C(o*C(1.0000000150474662e30))*C(1.0000000150474662e30)):C(C(o*C(1.0000000031710769e-30))*C(1.0000000031710769e-30));if(h>>>0>=1065353224){break a}a=C(d+C(-1));r=C(a*C(1.44268798828125));d=C(C(a*C(7052607543300837e-21))+C(C(C(a*a)*C(C(.5)-C(a*C(C(a*C(-.25))+C(.3333333432674408)))))*C(-1.4426950216293335)));e=(l(2,(p(C(r+d)),j(2))&-4096),q());r=C(e-r);break j}f=h>>>0<8388608;h=f?(p(C(d*C(16777216))),j(2)):h;k=h&8388607;g=k|1065353216;h=(h>>23)+(f?-151:-127)|0;f=0;k:{if(k>>>0<1885298){break k}if(k>>>0<6140887){f=1;break k}g=g-8388608|0;h=h+1|0}k=f<<2;r=z[k+52240>>2];d=(l(2,g),q());m=z[k+52224>>2];c=C(d-m);t=C(C(1)/C(m+d));e=C(c*t);a=(l(2,(p(e),j(2))&-4096),q());u=C(a*a);v=a;w=c;c=(l(2,((g>>1&-536875008)+(f<<21)|0)+541065216|0),q());d=C(t*C(C(w-C(a*c))-C(a*C(d-C(c-m)))));c=C(C(e+a)*d);a=C(e*e);m=C(c+C(C(a*a)*C(C(a*C(C(a*C(C(a*C(C(a*C(C(a*C(.20697501301765442))+C(.23066075146198273)))+C(.2727281153202057)))+C(.3333333432674408)))+C(.4285714328289032)))+C(.6000000238418579))));a=(l(2,(p(C(C(u+C(3))+m)),j(2))&-4096),q());c=C(v*a);e=C(C(d*a)+C(e*C(m-C(C(a+C(-3))-u))));a=(l(2,(p(C(c+e)),j(2))&-4096),q());m=C(a*C(.9619140625));d=C(z[k+52232>>2]+C(C(C(e-C(a-c))*C(.9617967009544373))+C(a*C(-.00011736857413779944))));a=C(h|0);e=(l(2,(p(C(C(r+C(m+d))+a)),j(2))&-4096),q());r=C(C(C(e-a)-r)-m)}m=(l(2,i&-4096),q());a=C(e*m);b=C(C(C(d-r)*b)+C(C(b-m)*e));e=C(a+b);g=(p(e),j(2));if((g|0)>=1124073473){break c}l:{m:{if((g|0)==1124073472){n=134;if(!(C(b+C(4.299566569443414e-8))>C(e-a))){break m}break c}i=g&2147483647;if(!(!(b<=C(e-a))|(g|0)!=-1021968384)|i>>>0>=1125515265){break b}f=0;if(i>>>0<1056964609){break l}n=i>>>23|0}i=(8388608>>>n-126|0)+g|0;h=i>>>23&255;f=(i&8388607|8388608)>>>150-h|0;f=(g|0)<0?0-f|0:f;a=C(a-(l(2,i&-8388608>>h-127),q()));g=(p(C(b+a)),j(2))}e=(l(2,g&-32768),q());d=C(e*C(.693145751953125));e=C(C(e*C(14286065379565116e-22))+C(C(b-C(e-a))*C(.6931471824645996)));a=C(d+e);b=C(a*a);b=C(a-C(b*C(C(b*C(C(b*C(C(b*C(C(b*C(4.138136944220605e-8))+C(-16533901998627698e-22)))+C(661375597701408e-19)))+C(-.0027777778450399637)))+C(.1666666716337204))));c=C(C(a*b)/C(b+C(-2)));b=C(e-C(a-d));a=C(C(a-C(c-C(b+C(a*b))))+C(1));g=(p(a),j(2))+(f<<23)|0;n:{if((g|0)<=8388607){a=AG(a,f);break n}a=(l(2,g),q())}d=C(o*a)}c=d;break a}c=C(C(o*C(1.0000000150474662e30))*C(1.0000000150474662e30));break a}c=C(C(o*C(1.0000000031710769e-30))*C(1.0000000031710769e-30))}return c}function n_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;v[h+24>>2]=b;v[e>>2]=0;Bc(h+8|0,d);v[114578]=0;i=T(21,h+8|0)|0;j=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Ob(h+8|0);S(a|0);L()}SE(a,f+24|0,h+24|0,c,e,i);break b}RE(a,f+16|0,h+24|0,c,e,i);break b}b=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=cj(a,v[h+24>>2],c,d,e,f,Tb(b),Tb(b)+Fb(b)|0),v[k+24>>2]=l;break b}a=e;b=di(h+24|0,c,a,i,2);c=v[a>>2];B:{if(!(c&4|(b|0)<1|(b|0)>31)){v[f+12>>2]=b;break B}v[a>>2]=c|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=cj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=cj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=di(h+24|0,c,a,i,2);c=v[a>>2];C:{if(!(c&4|(b|0)>23)){v[f+8>>2]=b;break C}v[a>>2]=c|4}break b}a=e;b=di(h+24|0,c,a,i,2);c=v[a>>2];D:{if(!(c&4|(b|0)<1|(b|0)>12)){v[f+8>>2]=b;break D}v[a>>2]=c|4}break b}a=e;b=di(h+24|0,c,a,i,3);c=v[a>>2];E:{if(!(c&4|(b|0)>365)){v[f+28>>2]=b;break E}v[a>>2]=c|4}break b}a=e;b=di(h+24|0,c,a,i,2);c=v[a>>2];F:{if(!(c&4|(b|0)>12)){v[f+16>>2]=b-1;break F}v[a>>2]=c|4}break b}a=e;b=di(h+24|0,c,a,i,2);c=v[a>>2];G:{if(!(c&4|(b|0)>59)){v[f+4>>2]=b;break G}v[a>>2]=c|4}break b}a=h+24|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!to(a,b+8|0)){break H}if(!Kg(i,8192,bk(a))){break H}il(a);continue}break}if(fj(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+24|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=hr(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[64463]|w[64464]<<8|(w[64465]<<16|w[64466]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[64460]|w[64461]<<8|(w[64462]<<16|w[64463]<<24);v[h+8>>2]=w[64456]|w[64457]<<8|(w[64458]<<16|w[64459]<<24);v[h+12>>2]=g;k=h,l=cj(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[64471];v[h+8>>2]=w[64467]|w[64468]<<8|(w[64469]<<16|w[64470]<<24);k=h,l=cj(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=e;b=di(h+24|0,c,a,i,2);c=v[a>>2];J:{if(!(c&4|(b|0)>60)){v[f>>2]=b;break J}v[a>>2]=c|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=cj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=e;b=di(h+24|0,c,a,i,1);c=v[a>>2];K:{if(!(c&4|(b|0)>6)){v[f+24>>2]=b;break K}v[a>>2]=c|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}b=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=cj(a,v[h+24>>2],c,d,e,f,Tb(b),Tb(b)+Fb(b)|0),v[k+24>>2]=l;break b}QE(f+20|0,h+24|0,c,e,i);break b}a=di(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(fj(c,a+8|0)){break M}b=4;if((vm(i,bk(c))|0)!=37){break M}b=2;if(!fj(il(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+24>>2]}jb=h+32|0;return a|0}function mda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-48|0;jb=e;a:{b:{c:{i=a+24|0;d:{if(rd(i)){break d}h=a+4|0;k=Fb(h);a=jb-48|0;jb=a;g=a+40|0;b=g;v[b>>2]=-1;v[b+4>>2]=-1;e:{if(t[85360]&1){break e}if(!wd(85360)){break e}v[114578]=0;T(108,85356)|0;b=v[114578];v[114578]=0;if((b|0)!=1){vd(85360);break e}a=P()|0;O()|0;pe(85360);S(a|0);L()}b=jb-48|0;jb=b;v[114578]=0;c=Q(2838,0,b+32|0)|0;d=v[114578];v[114578]=0;f:{g:{h:{if((d|0)==1){break h}if(c){v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break h}a=v[114552];v[114578]=0;R(2825,a|0,70697);a=v[114578];v[114578]=0;if((a|0)!=1){break g}break h}c=Tq(b+16|0,b+32|0);v[b+4>>2]=v[b+36>>2]/1e3;d=Tq(b+8|0,b+4|0);v[114578]=0;c=tD(2840,c,d);d=mb;f=v[114578];v[114578]=0;if((f|0)!=1){break f}}V(0)|0;O()|0;Ab()}L()}v[b+24>>2]=c;v[b+28>>2]=d;c=pk(b+40|0,b+24|0);d=v[c+4>>2];jb=b+48|0;v[a+8>>2]=v[c>>2];v[a+12>>2]=d;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;c=jb-16|0;jb=c;b=jb-16|0;jb=b;l=b,m=Fma(v[a+16>>2],v[a+20>>2],1e3,0),v[l>>2]=m;v[b+4>>2]=mb;d=pk(b+8|0,b);f=v[d+4>>2];jb=b+16|0;jb=c+16|0;v[a+24>>2]=v[d>>2];v[a+28>>2]=f;b=v[a+24>>2];f=b<<8&16711680|b<<24;c=v[a+28>>2];j=(c<<24|b>>>8)&65280;d=((c&255)<<24|b>>>8)&-16777216|((c&16777215)<<8|b>>>24)&16711680|(c>>>8&65280|c>>>24);t[a+32|0]=d;t[a+33|0]=d>>>8;t[a+34|0]=d>>>16;t[a+35|0]=d>>>24;b=(c<<8|b>>>24)&255|j|f;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;OM(g,a+24|0,zb(a+24|0));b=jb-48|0;jb=b;v[114578]=0;c=Q(2838,1,b+32|0)|0;d=v[114578];v[114578]=0;i:{j:{k:{if((d|0)==1){break k}if(c){v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break k}a=v[114552];v[114578]=0;R(2825,a|0,70734);a=v[114578];v[114578]=0;if((a|0)!=1){break j}break k}c=Tq(b+16|0,b+32|0);d=Tq(b+8|0,b+32|4);v[114578]=0;c=tD(2841,c,d);d=mb;f=v[114578];v[114578]=0;if((f|0)!=1){break i}}V(0)|0;O()|0;Ab()}L()}v[b+24>>2]=c;v[b+28>>2]=d;c=pk(b+40|0,b+24|0);d=v[c+4>>2];jb=b+48|0;v[a+8>>2]=v[c>>2];v[a+12>>2]=d;b=v[a+12>>2];v[a+16>>2]=v[a+8>>2];v[a+20>>2]=b;c=jb-16|0;jb=c;b=jb-16|0;jb=b;d=v[a+20>>2];v[b>>2]=v[a+16>>2];v[b+4>>2]=d;d=pk(b+8|0,b);f=v[d+4>>2];jb=b+16|0;jb=c+16|0;v[a+24>>2]=v[d>>2];v[a+28>>2]=f;b=v[a+24>>2];f=b<<8&16711680|b<<24;c=v[a+28>>2];j=(c<<24|b>>>8)&65280;d=((c&255)<<24|b>>>8)&-16777216|((c&16777215)<<8|b>>>24)&16711680|(c>>>8&65280|c>>>24);t[a+32|0]=d;t[a+33|0]=d>>>8;t[a+34|0]=d>>>16;t[a+35|0]=d>>>24;b=(c<<8|b>>>24)&255|j|f;t[a+36|0]=b;t[a+37|0]=b>>>8;t[a+38|0]=b>>>16;t[a+39|0]=b>>>24;b=v[a+36>>2];v[a+24>>2]=v[a+32>>2];v[a+28>>2]=b;OM(g,a+24|0,zb(a+24|0));c=v[g>>2];g=v[g+4>>2];jb=a+48|0;if(k){b=hn(e+32|0);v[114578]=0;v[e+16>>2]=g;R(87,b|0,e+16|0);a=v[114578];v[114578]=0;l:{m:{n:{if((a|0)!=1){v[114578]=0;v[e+16>>2]=c;R(87,b|0,e+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}if(Fb(h)){a=0;while(1){c=w[kc(h,a)|0];v[114578]=0;v[e+16>>2]=c;R(87,b|0,e+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}a=a+1|0;if(Fb(h)>>>0>a>>>0){continue}break}}a=bc(b);c=cc(b);v[114578]=0;c=W(88,e+16|0,a|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;R(89,e+8|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}Hs(i,e+8|0);wf(e+8|0);oe(c);oe(b);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;oe(c);break a}mb=c;v[e+16>>2]=g;v[e+20>>2]=mb;b=e+32|0;a=hn(b);v[114578]=0;U(93,b|0,e+16|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)==1){b=P()|0;O()|0;oe(a);S(b|0);L()}v[114578]=0;R(89,e+8|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}Hs(i,e+8|0);wf(e+8|0);oe(b)}jb=e+48|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}oe(b);S(a|0);L()}function pM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;d=c&15;f=B(b,896)+a|0;e=f+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=f+1075072|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(v[a+480180>>2]==33554432){c=B(b,896)+a|0;e=c+1075684|0;if(!v[e>>2]){break a}c=v[c+1075088>>2];if(!c){break a}f=B(b,896)+a|0;d=x[B(d,24)+21024>>1];b=v[c+24>>2];g=Fma(b,b>>31,1712,0);c=(d>>>1|0)+g|0;b=mb;b=yc(Gma(c,c>>>0<g>>>0?b+1|0:b,d,0),mb);v[f+1075688>>2]=b;k=e,l=$f(a,w[f+1075803|0],0,b),v[k>>2]=l;break a}if(v[a+480180>>2]!=64){b=B(b,896)+a|0;c=d<<28>>24;v[b+1075752>>2]=c;d=x[(d<<1)+21456>>1];v[b+1075688>>2]=d;e=b+1075684|0;if(!v[e>>2]){break a}k=e,l=$f(a,w[b+1075803|0],c,d),v[k>>2]=l;break a}a=B(b,896)+a|0;b=v[a+1075088>>2];if(!b){break a}v[a+1075688>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075826|0]=c&3;break a}Eb(h+8|0,a+1074308|0,21);if(Cb(h+8|0)){t[(B(b,896)+a|0)+1075826|0]=d>>>0<4?d:0;break a}t[(B(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075829|0]=c&3;break a}Eb(h+8|0,a+1074308|0,21);if(Cb(h+8|0)){t[(B(b,896)+a|0)+1075829|0]=d>>>0<4?d:0;break a}t[(B(b,896)+a|0)+1075829|0]=c&7;break a;case 4:Eb(h+8|0,a+1074308|0,21);if(Cb(h+8|0)){a=B(b,896)+a|0;t[a+1075825|0]=0;t[a+1075832|0]=d>>>0<4?d:0;break a}t[(B(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];if(d>>>0>255){break a}e=a+1304392|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(d,896)+a|0;c:{if((i|0)!=x[c+1075792>>1]){break c}d:{e:{switch(j|0){case 0:cn(a,c+1074984|0);if(!(w[c+1075073|0]&2)){break d}if(!rd(e)){break d}uk(v[e>>2],d&65535);break d;case 1:g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!rd(e)){break d}uk(v[e>>2],d&65535);break d;default:break e}}v[c+1075680>>2]=0;g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!rd(e)){break d}Mh(v[e>>2],d&65535,1)}f=v[c+1075640>>2];if(!f){break c}g=w[f+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}nb[v[v[g>>2]+88>>2]](g,f,w[c+1075803|0]+255|0,0,b)}d=d+1|0;if((d&65535)!=256){continue}break}break a}pO(e,d,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}zl(a,e,d,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(d&15){case 0:v[e+88>>2]=v[e+88>>2]&-257;break f;case 1:v[e+692>>2]=128;v[e+88>>2]=v[e+88>>2]|256;break f;case 8:v[e+88>>2]=v[e+88>>2]&-25165825|16777216;break f;case 9:v[e+88>>2]=v[e+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[e+88>>2]=v[e+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[e+76>>2]|(v[e>>2]|v[e+4>>2])){break h}if(k=!cg(e+810|0),l=0,m=w[e+88|0]&2,m?k:l){break h}a=e;b=v[a+76>>2]-1|0;v[a>>2]=-1;v[a+4>>2]=b}v[e+88>>2]=v[e+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,896)+a|0;t[c+1075840|0]=d;Eb(h+8|0,a+1074308|0,35);if(Cb(h+8|0)){break a}if(!cg(c+1075794|0)){break a}b=v[(B(b,896)+a|0)+1075060>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 11:i:{if(d){break i}if(v[a+480180>>2]&16777248){d=1;break i}if(v[a+480180>>2]==2){break a}d=0}Eb(h+8|0,a+1074308|0,30);c=a;if(Cb(h+8|0)){a=1}else{a=v[a+480180>>2]==2}cy(c,b,d,a);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,896)+a|0)+1075848|0]=d}jb=h+16|0}function A2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-352|0;jb=d;a:{if(mj(b)){break a}e=w[fk(b)|0];f=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}f=0}c=f;sk(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}Dd(d+320|0);e=v[d+320>>2];Dd(d+304|0);e=ek(e,v[d+308>>2],b);Dd(d+320|0);c:{d:{e:{f:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=qc(d+336|0,38235);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114578]=0;c=Q(85,d+320|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}e=0;if(!c){break f}a=ba(8)|0;v[114578]=0;c=Q(2142,d+304|0,b|0)|0;b=v[114578];v[114578]=0;g:{h:{i:{if((b|0)!=1){v[114578]=0;U(2119,d+320|0,39179,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}mc(a,d+320|0);e=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(d+320|0);break h}b=P()|0;O()|0;break g}b=P()|0;e=1;O()|0}yb(c);if(!e){break d}}ca(a|0);break d}if(v[e+4>>2]){a=ba(8)|0;v[114578]=0;c=Q(85,d+320|0,39193)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=qc(d+288|0,38235);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Hc(d+152|0,d+144|0)){a=ba(8)|0;v[114578]=0;c=Q(85,d+320|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=qc(d+272|0,38917);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;j:{if(!Hc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=qc(d+256|0,39214);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Hc(d+120|0,d+112|0)){break j}}e=w[a+60|0]!=0;break f}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=qc(d+240|0,38935);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;k:{if(!Hc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=qc(d+224|0,39232);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Hc(d+88|0,d+80|0)){break k}}e=w[a+61|0]!=0;break f}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=qc(d+208|0,38954);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Hc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break f}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=qc(d+192|0,38972);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break f}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=qc(d+176|0,38996);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break f}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=qc(d+160|0,39070);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Hc(d+24|0,d+16|0)){break f}e=v[v[a+24>>2]+24668>>2]!=0}jb=d+352|0;return e|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-272|0;jb=e;d=e+24|0;g=jb-48|0;jb=g;Oz(g+24|0,b);v[114578]=0;R(703,g+8|0,g+24|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){break b}v[114578]=0;R(704,g+16|0,g+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=v[g+16>>2];f=v[g+20>>2];v[114578]=0;W(705,d|0,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}Ec(g+24|0);jb=g+48|0;break a}a=P()|0;O()|0;Ec(g+24|0);S(a|0);L()}v[114578]=0;g=W(673,e+128|0,e+24|0,8)|0;b=v[114578];v[114578]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((b|0)!=1){yb(e+24|0);if(c>>>0<2189){break i}v[114578]=0;b=Q(682,e+24|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}v[114578]=0;c=Q(683,e+8|0,14349)|0;d=v[114578];v[114578]=0;if((d|0)==1){break B}v[114578]=0;v[e>>2]=19466496;v[e+4>>2]=0;U(684,b|0,c|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break A}Ib(c);v[114578]=0;t[e|0]=0;c=Q(683,e+8|0,14357)|0;d=v[114578];v[114578]=0;if((d|0)==1){break k}d=0;v[114578]=0;W(685,b|0,e|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break z}Ib(c);if(!w[e|0]){v[114578]=0;d=T(686,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break y}}f=v[a+4>>2];v[114578]=0;c=Q(683,e+8|0,14368)|0;h=v[114578];v[114578]=0;if((h|0)==1){break x}v[114578]=0;X(687,b|0,f|0,c|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break w}Ib(c);v[114578]=0;c=Q(683,e+8|0,14370)|0;f=v[114578];v[114578]=0;if((f|0)==1){break v}v[114578]=0;X(688,b|0,a|0,c|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break u}Ib(c);v[114578]=0;c=Q(683,e+8|0,14372)|0;d=v[114578];v[114578]=0;if((d|0)==1){break t}v[114578]=0;d=a+484360|0;aa(689,b|0,d|0,c|0,690)|0;f=v[114578];v[114578]=0;if((f|0)==1){break s}Ib(c);v[114578]=0;c=Q(683,e+8|0,14374)|0;f=v[114578];v[114578]=0;if((f|0)==1){break r}v[114578]=0;aa(691,b|0,a+484344|0,c|0,692)|0;f=v[114578];v[114578]=0;if((f|0)==1){break q}Ib(c);v[114578]=0;f=T(686,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break p}v[114578]=0;c=Q(683,e+8|0,14380)|0;h=v[114578];v[114578]=0;if((h|0)==1){break o}v[114578]=0;X(693,b|0,d|0,c|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break n}Ib(c);if(v[b>>2]&1073741824){v[114578]=0;c=Q(2,e+8|0,14388)|0;d=v[114578];v[114578]=0;if((d|0)==1){break m}v[114578]=0;U(646,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}yb(c)}vg(b);break h}a=P()|0;O()|0;yb(e+24|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;yb(c);break j}a=P()|0;O()|0}vg(b);break d}b=gd(e+24|0);d=v[a+4>>2];v[114578]=0;f=T(686,a|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break g}v[114578]=0;d=aa(694,d|0,g|0,b|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}C:{if((d|0)!=1){v[114578]=0;c=Q(2,e+8|0,14437)|0;d=v[114578];v[114578]=0;D:{if((d|0)!=1){v[114578]=0;U(646,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break D}yb(c);break C}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(c);break f}v[114578]=0;d=T(686,a|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[114578]=0;X(695,g|0,a|0,d|0,c>>>0<2188|0);a=v[114578];v[114578]=0;if((a|0)==1){break g}}yb(b)}If(g);jb=e+272|0;return}a=P()|0;O()|0}yb(b);break d}a=P()|0;O()|0}If(g)}S(a|0);L()}function EU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-576|0;jb=e;Jc(b);g=jb-16|0;jb=g;f=e+72|0;GB(g+8|0,f);i=Hb(g+8|0);d=b;h=nc(d,ac(g,g+8|0));if((i|0)==(h|0)){$b(d,Hb(g+8|0))}jb=g+16|0;d=(h|0)==(i|0);if(!d){HB(f)}a:{if(!d){break a}if(!MB(e+72|0)){break a}b:{if(!c){break b}if(!Qb(b,id(LB(e+72|0),mb))){break a}Hd(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;d=Ub(e+40|0,11897);Gb(a+1304436|0,d);yb(d);d=Ub(e+40|0,11910);Gb(a+1304448|0,d);yb(d);Mc(a+1304460|0,x[e+72>>1]==26217?11897:11914);v[a+1304496>>2]=4;d=w[e+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){g=1;i=1;while(1){h=jb-16|0;jb=h;d=jb-16|0;jb=d;f=e+40|0;gc(h+8|0,f,25);jb=d+16|0;k=Hb(h+8|0);d=b;j=nc(d,ac(h,h+8|0));if((k|0)==(j|0)){$b(d,Hb(h+8|0))}jb=h+16|0;if((j|0)!=(k|0)){d=jb-16|0;jb=d;t[f|0]=0;t[f+1|0]=0;t[f+2|0]=0;t[f+3|0]=0;t[f+4|0]=0;t[f+5|0]=0;t[f+6|0]=0;t[f+7|0]=0;t[f+24|0]=0;t[f+16|0]=0;t[f+17|0]=0;t[f+18|0]=0;t[f+19|0]=0;t[f+20|0]=0;t[f+21|0]=0;t[f+22|0]=0;t[f+23|0]=0;t[f+8|0]=0;t[f+9|0]=0;t[f+10|0]=0;t[f+11|0]=0;t[f+12|0]=0;t[f+13|0]=0;t[f+14|0]=0;t[f+15|0]=0;jb=d+16|0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}d=(B(g,104)+a|0)+484380|0;Fd(d,0);v[d+24>>2]=8363;v[d>>2]=w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24);v[d+4>>2]=w[e+57|0]|w[e+58|0]<<8|(w[e+59|0]<<16|w[e+60|0]<<24);f=w[e+61|0]|w[e+62|0]<<8|(w[e+63|0]<<16|w[e+64|0]<<24);f=f>>>0>y[d>>2]?v[d+4>>2]?f:0:f;v[d+8>>2]=f;if(f){u[d+34>>1]=2;nn(d)}Qi(e+8|0,2,e+40|0);Ic(e+24|0,e+8|0);v[114578]=0;Q(371,((g<<5)+a|0)+946300|0,e+24|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}yb(e+24|0);i=i+1|0;g=i&65535;if(g>>>0<=x[a+480190>>1]){continue}break}}d=e+72|2;KB(e+24|0,3,d,36);Ic(e+40|0,e+24|0);Gb(a+1304400|0,e+40|0);yb(e+40|0);g=0;yO(a+1304424|0,Db(d),108,36,0);d=a+484360|0;JB(Vb(d),e+185|0,128);if(x[rc(Vb(d),w[e+184|0])>>1]<w[e+183|0]){break d}break c}a=P()|0;O()|0;yb(e+24|0);S(a|0);L()}Oe(Vb(d),w[e+184|0])}while(1){d=(g<<5)+a|0;zg(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;if((g|0)!=8){continue}break}h=a+484344|0;_f(h,w[e+183|0]);m=1;if(w[e+183|0]){n=c&1;f=0;while(1){f:{g:{if(n){if(rg(h,f&65535,64)){break g}}$b(b,1536);break f}v[e+24>>2]=-1;v[e+28>>2]=-1;k=0;while(1){g=Rn(_b(h,f),k);i=0;while(1){hq(e+40|0,b);d=dd(e+40|0);l=Bf(e+40|0);j=w[d|0];d=w[e+40|0];if(d>>>0<=253){t[g|0]=(d>>>2|0)+37;t[g+1|0]=(d<<4&48|j>>>4)+1;t[(e+24|0)+i|0]=255;d=w[e+40|0]}if((d|0)!=255){t[g+2|0]=1;t[g+4|0]=(((j&15)<<6|8)>>>0)/15}j=(e+24|0)+i|0;h:{i:{d=w[l|0];j:{if((d|0)!=255){t[j|0]=d;if(d&15|(d|0)==48){break j}break i}d=w[j|0];if((d|0)==255){break h}}l=d&15;t[g+5|0]=l;k:{if(d<<24>>24<0){break k}d=d>>>4|0;t[g+3|0]=w[d+11923|0];l:{switch(d-3|0){case 0:t[g+5|0]=l|32;break i;case 1:t[g+5|0]=B(l,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(l|0){case 0:t[g+5|0]=79;break h;case 1:break m;default:break k}}t[g+5|0]=244;break h}t[g+3|0]=0;break h}t[j|0]=255}g=g+6|0;i=i+1|0;if((i|0)!=8){continue}break}k=k+1|0;if((k|0)!=64){continue}break}d=(e+72|0)+f|0;g=d;if(w[d+369|0]<63){sl(_b(h,f),Uh(Ne(Qn(e+40|0,14,0),w[g+369|0])))}sl(_b(h,f),Uh(Qn(e+40|0,16,w[d+241|0])))}f=f+1|0;if(f>>>0<w[e+183|0]){continue}break}}if(!(c&2)){break a}g=1;c=ad(e+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){tg(c,(B(g&65535,104)+a|0)+484380|0,b);g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}}m=1}jb=e+576|0;return m|0}function gS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-144|0;jb=f;h=jb-16|0;jb=h;j=h+8|0;e=jb-16|0;jb=e;v[114578]=0;k=f+128|0;i=k;T(726,i+4|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{if((g|0)!=1){v[114578]=0;v[e+12>>2]=0;W(727,i+8|0,e+12|0,j|0)|0;j=v[114578];v[114578]=0;if((j|0)!=1){break c}break b}break b}m=i,n=hc(i),v[m>>2]=n;jb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=h+16|0;d:{e:{f:{if(d){v[114578]=0;U(711,a|0,k|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break f}break e}v[114578]=0;U(712,a|0,k|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break e}}i=Hv(f+112|0);g:{h:{if(x[b+480192>>1]){c=1;j=1;while(1){v[114578]=0;u[f+110>>1]=0;Q(713,a|0,f+110|0)|0;d=v[114578];v[114578]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((d|0)!=1){v[114578]=0;d=Q(714,k|0,f+110|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break h}v[f+104>>2]=d;h=((c<<2)+b|0)+900380|0;if(!v[h>>2]){break i}c=Hi(k);v[114578]=0;v[f+88>>2]=c;c=Q(715,f+104|0,f+88|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break x}if(!c){break j}v[114578]=0;c=T(716,f+104|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break w}v[114578]=0;c=Q(4,f+88|0,c+4|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break w}v[114578]=0;d=Q(2,f+72|0,14549)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}e=Hp(c,d);yb(d);if(!e){break v}v[v[h>>2]+44>>2]=0;break u}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}d=v[b+4>>2];v[114578]=0;d=Q(717,d|0,c|0)|0;e=v[114578];v[114578]=0;y:{z:{A:{B:{C:{D:{if((e|0)!=1){v[v[h>>2]+44>>2]=d;if(v[v[h>>2]+44>>2]){break u}v[114578]=0;d=Q(2,f+72|0,14569)|0;e=v[114578];v[114578]=0;if((e|0)==1){break D}E:{F:{if(Hp(c,d)){yb(d);break F}v[114578]=0;e=Q(2,f+56|0,14595)|0;g=v[114578];v[114578]=0;if((g|0)==1){break C}g=Hp(c,e);yb(e);yb(d);if(!g){break E}}v[114578]=0;R(718,f+72|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break B}e=v[b+4>>2];d=Gp(f+48|0,f+72|0);v[114578]=0;e=Q(719,e|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break A}ag(d);ag(f+72|0);if(e){break u}}g=bc(i);l=cc(i);d=c;e=jb-16|0;jb=e;v[e>>2]=l;v[e+8>>2]=g;G:{if(!Jb(e+8|0,e)){break G}while(1){if(Hp(v[e+8>>2],d)){break G}zn(e+8|0);if(Jb(e+8|0,e)){continue}break}}jb=e+16|0;v[f+72>>2]=v[e+8>>2];m=f,n=cc(i),v[m+56>>2]=n;if(!rl(f+72|0,f+56|0)){break y}v[114578]=0;R(720,i|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){break z}}b=P()|0;O()|0;break k}b=P()|0;O()|0;break k}b=P()|0;O()|0;yb(d);break k}b=P()|0;O()|0;break k}b=P()|0;O()|0;ag(d);ag(f+72|0);break k}v[114578]=0;d=Q(2,f+16|0,14601)|0;e=v[114578];v[114578]=0;if((e|0)==1){break t}v[114578]=0;U(721,f+32|0,d|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break s}v[114578]=0;e=Q(2,f|0,14610)|0;g=v[114578];v[114578]=0;if((g|0)==1){break r}v[114578]=0;U(3,f+56|0,f+32|0,e|0);g=v[114578];v[114578]=0;if((g|0)==1){break q}g=Hy(f+72|0,f+56|0);v[114578]=0;R(624,b|0,g|0);g=v[114578];v[114578]=0;if((g|0)==1){break p}yb(f+72|0);yb(f+56|0);yb(e);yb(f+32|0);yb(d)}v[v[h>>2]+44>>2]=0}yb(c);break i}b=P()|0;O()|0;break k}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;yb(f+72|0);yb(f+56|0)}yb(e)}yb(f+32|0)}yb(d);break k}b=P()|0;O()|0}yb(c);break g}if(!v[h>>2]){break i}v[v[h>>2]+44>>2]=0}j=j+1|0;c=j&65535;if(c>>>0<=x[b+480192>>1]){continue}break}}cl(i);$R(k);jb=f+144|0;return}b=P()|0;O()|0}cl(i);break d}b=P()|0;O()|0}$R(k);S(b|0);L()}function Zf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=jb-112|0;jb=k;l=h;o=i&2147483647;m=c-(b>>>0<1)|0;j=b-1|0;q=(j|0)==-1&(m|0)==-1;r=d;p=(c|0)==(m|0)&b>>>0>j>>>0|c>>>0>m>>>0;n=d+p|0;m=e&2147483647;j=m;j=n>>>0<p>>>0?j+1|0:j;p=n-1|0;a:{b:{j=j-(n>>>0<1)|0;if(!((p|0)==-1&(j|0)==2147418111?q:j>>>0>2147418111)){j=f;n=g-(j>>>0<1)|0;j=j-1|0;q=(j|0)!=-1|(n|0)!=-1;p=(g|0)==(n|0)&f>>>0>j>>>0|g>>>0>n>>>0;n=p+l|0;j=o;j=n>>>0<p>>>0?j+1|0:j;p=n;n=n-1|0;j=j-(p>>>0<1)|0;if((n|0)==-1&(j|0)==2147418111?q:(j|0)==2147418111&(n|0)!=-1|j>>>0<2147418111){break b}}if(!(!r&(m|0)==2147418112?!(b|c):m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!l&(o|0)==2147418112?!(f|g):o>>>0<2147418112)){i=i|32768;break a}if(!(b|r|(m^2147418112|c))){j=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:j;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|l|(o^2147418112|g))){break a}if(!(b|r|(c|m))){if(f|l|(g|o)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|l|(g|o)){break b}f=b;g=c;h=d;i=e;break a}q=(l|0)==(r|0)&(m|0)==(o|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:(m|0)==(o|0)&l>>>0>r>>>0|m>>>0<o>>>0;j=q;n=j?f:b;o=j?g:c;l=j?i:e;r=l;m=j?h:d;j=l&65535;i=q?e:i;e=i;h=q?d:h;p=i>>>16&32767;l=l>>>16&32767;if(!l){d=!(j|m);i=d<<6;l=E(d?n:m)+32|0;d=E(d?o:j);d=i+((d|0)==32?l:d)|0;qf(k+96|0,n,o,m,j,d-15|0);m=v[k+104>>2];n=v[k+96>>2];o=v[k+100>>2];l=16-d|0;j=v[k+108>>2]}f=q?b:f;g=q?c:g;i=e&65535;if(!p){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;qf(k+80|0,f,g,h,i,b-15|0);p=16-b|0;h=v[k+88>>2];i=v[k+92>>2];g=v[k+84>>2];f=v[k+80>>2]}b=h;c=i<<3|b>>>29;h=b<<3|g>>>29;i=c|524288;b=m;d=j<<3|b>>>29;m=b<<3|o>>>29;s=d;q=e^r;b=f;j=g<<3|b>>>29;b=b<<3;c=j;d=l-p|0;e=b;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;j=0;e=1;break c}qf(k- -64|0,b,c,h,i,128-d|0);Fm(k+48|0,b,c,h,i,d);h=v[k+56>>2];i=v[k+60>>2];j=v[k+52>>2];e=v[k+48>>2]|((v[k+64>>2]|v[k+72>>2])!=0|(v[k+68>>2]|v[k+76>>2])!=0)}f=j;d=m;p=s|524288;b=n;j=o<<3|b>>>29;c=b<<3;d:{if((q|0)<-1?1:(q|0)<=-1){o=e;b=c-e|0;m=h;n=d-h|0;e=(f|0)==(j|0)&c>>>0<e>>>0|f>>>0>j>>>0;h=n-e|0;c=j-((c>>>0<o>>>0)+f|0)|0;i=(p-((d>>>0<m>>>0)+i|0)|0)-(e>>>0>n>>>0)|0;if(!(b|h|(c|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}f=b;d=!(h|i);e=d<<6;g=E(d?b:h)+32|0;b=E(d?c:i);b=e+((b|0)==32?g:b)|0;b=b-12|0;qf(k+32|0,f,c,h,i,b);l=l-b|0;h=v[k+40>>2];i=v[k+44>>2];b=v[k+32>>2];c=v[k+36>>2];break d}b=c;g=b+e|0;c=f+j|0;c=b>>>0>g>>>0?c+1|0:c;b=g;g=(c|0)==(f|0)&e>>>0>b>>>0|c>>>0<f>>>0;e=d;f=d+h|0;d=i+p|0;d=e>>>0>f>>>0?d+1|0:d;e=g+f|0;h=e;i=h>>>0<f>>>0?d+1|0:d;if(!(i&1048576)){break d}b=b&1|((c&1)<<31|b>>>1);c=h<<31|c>>>1;l=l+1|0;h=(i&1)<<31|h>>>1;i=i>>>1|0}o=0;r=r&-2147483648;if((l|0)>=32767){h=o;i=r|2147418112;f=0;g=0;break a}if((l|0)>=1){e=l}else{qf(k+16|0,b,c,h,i,l+127|0);Fm(k,b,c,h,i,1-l|0);b=v[k>>2]|((v[k+16>>2]|v[k+24>>2])!=0|(v[k+20>>2]|v[k+28>>2])!=0);c=v[k+4>>2];h=v[k+8>>2];i=v[k+12>>2];e=0}j=(c&7)<<29|b>>>3;l=b&7;b=j+(l>>>0>4)|0;d=h<<29|c>>>3;c=b>>>0<j>>>0?d+1|0:d;f=b;g=c;b=(d|0)==(c|0)&b>>>0<j>>>0|c>>>0<d>>>0;d=o|((i&7)<<29|h>>>3);b=b+d|0;j=r|(i>>>3&65535|e<<16);h=b;i=b>>>0<d>>>0?j+1|0:j;e:{if((l|0)==4){j=i;c=0;d=g+c|0;e=f&1;b=f+e|0;d=b>>>0<f>>>0?d+1|0:d;f=b;g=d;c=(c|0)==(d|0)&b>>>0<e>>>0|c>>>0>d>>>0;b=c+h|0;h=b;i=b>>>0<c>>>0?j+1|0:j;break e}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;jb=k+112|0}function gma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-720|0;jb=e;Jc(b);f=jb-16|0;jb=f;i=e+104|0;oT(f+8|0,i);h=Hb(f+8|0);g=b;j=nc(g,ac(f,f+8|0));if((h|0)==(j|0)){$b(g,Hb(f+8|0))}jb=f+16|0;g=(h|0)==(j|0);if(!g){pT(i)}a:{if(!g){break a}if(!qT(e+104|0)){break a}b:{if(!c){break b}Hd(a,67108864);wi(a);d=w[e+129|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Ub(e,12631);Gb(a+1304436|0,d);yb(d);d=Ub(e,12643);Gb(a+1304448|0,d);yb(d);g=Ub(e+88|0,12648);v[114578]=0;R(219,e- -64|0,g|0);d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[e+84>>2]=w[e+128|0]>>>4;d=w[e+128|0];v[114578]=0;v[e+80>>2]=d&15;X(534,e|0,e- -64|0,e+84|0,e+80|0);d=v[114578];v[114578]=0;if((d|0)!=1){Gb(a+1304460|0,e);yb(e);Ib(e- -64|0);yb(g);v[a+1304496>>2]=2;In(Vb(a+484360|0),e+152|0,w[e+151|0]+1|0,65535,65535);g=0;while(1){d=g+1|0;i=B(d,104)+a|0;j=i+484380|0;Fd(j,1);f=(e+104|0)+(g<<2)|0;h=w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24);v[j>>2]=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);h=w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24);k=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);v[i+484384>>2]=k;h=w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24);v[i+484388>>2]=k+(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24));if(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24)){f=i+484414|0;u[f>>1]=x[f>>1]|2}nn(j);g=(e+104|0)+g|0;t[e|0]=w[g+548|0];t[e+64|0]=64;o=i+484410|0,p=w[pc(e,e- -64|0)|0]<<2,u[o>>1]=p;t[i+484417|0]=w[g+579|0]<<4;g=d;if((d|0)!=31){continue}break}sA(b,a+1304400|0,32);d=1;while(1){vB(b,((d<<5)+a|0)+946300|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){_f(a+484344|0,w[e+150|0]+1|0)}j=a+484344|0;d=0;e:{while(1){i=Yh(e- -64|0);f:{if(w[e+130|0]){v[114578]=0;g=T(485,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;U(343,e|0,b|0,g|0);break f}g=x[a+480188>>1];v[114578]=0;U(343,e|0,b|0,g<<8)}g=v[114578];v[114578]=0;if((g|0)==1){break e}f=d;Wd(i,e);Bb(e);g:{if(!k){break g}v[114578]=0;d=W(404,j|0,f&65535,64)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}if(!d){break g}if(!w[e+130|0]){d=0;if(!x[a+480188>>1]){break g}while(1){g=0;while(1){h=_b(j,f);v[114578]=0;h=W(472,h|0,g|0,d&65535)|0;l=v[114578];v[114578]=0;if((l|0)==1){break e}v[114578]=0;R(535,i|0,h|0);h=v[114578];v[114578]=0;if((h|0)==1){break e}g=g+1|0;if((g|0)!=64){continue}break}d=d+1|0;if(x[a+480188>>1]>(d&65535)>>>0){continue}break}break g}h=0;v[114578]=0;Q(536,i|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}while(1){d=_b(j,f);v[114578]=0;l=Q(497,d|0,h|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(x[a+480188>>1]){m=e+h|0;d=128;g=0;while(1){h:{if(!(w[m|0]&d)){break h}v[114578]=0;R(535,i|0,l+B(g,6)|0);n=v[114578];v[114578]=0;if((n|0)!=1){break h}break e}d=d>>>1|0;g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break}}h=h+1|0;if((h|0)!=64){continue}break}}Bb(i);d=f+1|0;if(f>>>0<w[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=ad(e,8,1,1,0);while(1){tg(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=P()|0;O()|0;Bb(i);break c}d=P()|0;O()|0;Ib(e- -64|0);break d}d=P()|0;O()|0}yb(g)}S(d|0);L()}d=1}jb=e+720|0;return d|0}function n9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-176|0;jb=e;pf(e+160|0,b);m=a;k=c;g=d;h=jb-48|0;jb=h;v[h+44>>2]=0;f=b;Fi(f,h+44|0);a:{b:{c:{if(v[h+44>>2]!=(Fj(32545)|0)){break c}v[h+40>>2]=0;Fi(f,h+40|0);i=-1;j=v[h+40>>2];if(j-1>>>0>1){break c}d:{e:{f:{if((j|0)<=1){j=Wb(h+24|0);v[114578]=0;l=W(722,f|0,j|0,256)|0;n=v[114578];v[114578]=0;if((n|0)==1){break b}if(!l){break e}v[114578]=0;U(13,h+8|0,g|0,j|0);l=v[114578];v[114578]=0;if((l|0)!=1){break f}break b}j=Wb(h+24|0);v[114578]=0;l=W(724,f|0,j|0,255)|0;n=v[114578];v[114578]=0;if((n|0)==1){break b}if(!l){break d}v[114578]=0;U(13,h+8|0,g|0,j|0);l=v[114578];v[114578]=0;if((l|0)==1){break b}}Gb(k,h+8|0);yb(h+8|0);yb(j);u[h+8>>1]=0;xf(f,h+8|0);v[h+24>>2]=0;Fi(f,h+24|0);k=v[h+24>>2];if(k>>>0>50){break c}g:{if(!k){break g}k=1;while(1){if(!TJ(m,f,g)){break c}if(y[h+24>>2]<=k>>>0){break g}k=k+1|0;continue}}v[h+24>>2]=0;Fi(f,h+24|0);i=v[h+24>>2]==(Fj(32550)|0)?1:-1;break c}yb(j);break c}yb(j)}jb=h+48|0;f=i;break a}a=P()|0;O()|0;yb(j);S(a|0);L()}h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(!f){Dn(v[v[b>>2]-12>>2]+b|0,0);f=v[e+172>>2];v[e+8>>2]=v[e+168>>2];v[e+12>>2]=f;f=v[e+164>>2];v[e>>2]=v[e+160>>2];v[e+4>>2]=f;dj(b,e);b=al(e+56|0,b);v[114578]=0;f=Q(683,e+40|0,32531)|0;g=v[114578];v[114578]=0;if((g|0)==1){break i}v[114578]=0;v[e+32>>2]=3;v[e+36>>2]=0;U(684,b|0,f|0,e+32|0);g=v[114578];v[114578]=0;if((g|0)==1){break j}Ib(f);v[114578]=0;t[e+31|0]=0;f=Q(683,e+40|0,32534)|0;g=v[114578];v[114578]=0;if((g|0)==1){break k}v[114578]=0;W(685,b|0,e+31|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break l}Ib(f);v[114578]=0;f=w[e+31|0];g=T(1625,b|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break m}v[114578]=0;i=T(1626,b|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break n}v[e+32>>2]=i;v[e+24>>2]=g;if(Jb(e+24|0,e+32|0)){f=f?0:d;while(1){v[114578]=0;u[e+22>>1]=65535;d=Q(683,e+40|0,32539)|0;g=v[114578];v[114578]=0;if((g|0)==1){break q}v[114578]=0;g=W(1627,b|0,e+24|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break p}Ib(d);t:{if(!g){v[114578]=0;X(1628,b|0,e+24|0,c|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break o}break t}v[114578]=0;d=Q(683,e+40|0,32541)|0;g=v[114578];v[114578]=0;u:{v:{if((g|0)!=1){v[114578]=0;g=W(1627,b|0,e+24|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break v}Ib(d);if(g){break u}v[114578]=0;W(1629,b|0,e+24|0,e+22|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break t}break o}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(d);break h}v[114578]=0;d=Q(683,e+40|0,32543)|0;g=v[114578];v[114578]=0;if((g|0)==1){break s}v[114578]=0;g=W(1627,b|0,e+24|0,d|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break r}Ib(d);if(g){break t}v[114578]=0;X(1630,b|0,e+24|0,a|0,f|0);d=v[114578];v[114578]=0;if((d|0)==1){break o}}Tf(e+24|0);if(Jb(e+24|0,e+32|0)){continue}break}}a=v[b>>2];vg(b);f=a&1073741824?-1:1}jb=e+176|0;return f|0}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(f);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Ib(f);break h}a=P()|0;O()|0}vg(b);S(a|0);L()}function OI(a){var b=0,c=C(0),d=C(0),e=0,f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=C(0),q=0,r=C(0),s=C(0),u=0,w=0,x=C(0);k=jb-16|0;jb=k;u=a,w=Ai(C(z[a+4256>>2]*C(3))),v[u+4264>>2]=w;u=a,x=C(Se(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[u+4268>>2]=x;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);u=k,x=ne(C(10),C(C(NI(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[k+8>>2]=1065353216;u=a,x=C(z[ol(k+12|0,k+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=x;e=a;d=ne(C(10),C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))*C(.0010000000474974513)));if(d!=C(1)){c=yo(C(C(MI(a)*C(6.2831854820251465))/z[a+4268>>2]));i=C(d+d);f=C(d*d);d=C(d*C(8));c=gn(C(C(C(C(c*i)+C(-2))+C(K(C(C(C(f*C(-4))+d)+C(C(C(C(f*C(4))*c)-d)*c)))))/C(i+C(-2))),C(0),C(1))}else{c=C(0)}z[e+4276>>2]=c;j=jb-16|0;jb=j;e=a;d=z[a+4268>>2];c=C(z[a+4232>>2]*C(.30000001192092896));z[j+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[j+8>>2]=1000593162;b=a;i=z[dx(j+12|0,j+8|0)>>2];f=C(d*C(C(c+C(.007000000216066837))+i));a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}v[b+4352>>2]=h;b=1;while(1){l=((B(b&1,24)+e|0)+(b<<1&-4)|0)+4352|0;f=C(C(C(z[(b<<2)+33600>>2]*i)+c)*d);b:{if(C(D(f))<C(2147483648)){h=~~f;break b}h=-2147483648}v[l>>2]=h;b=b+1|0;if((b|0)!=12){continue}break}z[j+12>>2]=C(C(z[e+4248>>2]*C(100))*C(.009091000072658062))+C(.09091000258922577);v[j+8>>2]=1065353216;c=C(z[ol(j+12|0,j+8|0)>>2]*d);i=C(c*C(.07500000298023224));c=C(c*C(.06700000166893005));b=0;while(1){h=(b<<2)+e|0;q=h+4316|0;f=ne(C(.9300000071525574),C(o|0));g=C(i*f);c:{if(C(D(g))<C(2147483648)){l=~~g;break c}l=-2147483648}v[q>>2]=l;l=h+4292|0;f=C(c*f);d:{if(C(D(f))<C(2147483648)){h=~~f;break d}h=-2147483648}v[l>>2]=h;b=b+1|0;if((b|0)!=6){o=b+o|0;continue}break}h=e+4348|0;c=C(d*C(.0035299998708069324));e:{if(C(D(c))<C(2147483648)){b=~~c;break e}b=-2147483648}v[h>>2]=b;h=e+4344|0;c=C(d*C(.0032500000670552254));f:{if(C(D(c))<C(2147483648)){b=~~c;break f}b=-2147483648}v[h>>2]=b;h=e+4340|0;d=C(d*C(.009999999776482582));g:{if(C(D(d))<C(2147483648)){b=~~d;break g}b=-2147483648}v[h>>2]=b;b=0;while(1){PI((B(b,24)+e|0)+4504|0,v[((b<<2)+e|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}jb=j+16|0;b=jb-16|0;jb=b;c=Mg(a,5);f=Mg(a,11);d=C(c*Mg(a,4));i=C(C(d*C(.03999999910593033))+C(c*C(.02250000089406967)));c=C(f*Mg(a,10));f=C(C(c*C(.03999999910593033))+C(f*C(.02250000089406967)));if(t[a+4264|0]&1){g=Mg(e,3);m=Mg(e,9);g=C(g*d);d=C(Mg(e,2)*g);i=C(C(C(g*C(.12250000238418579))+i)+C(d*C(.1444000005722046)));g=C(m*c);c=C(Mg(e,8)*g);f=C(C(C(g*C(.12250000238418579))+f)+C(c*C(.1444000005722046)))}Mg(e,12);g=z[e+4496>>2];m=Mg(e,1);n=Mg(e,7);r=Mg(e,0);s=Mg(e,6);u=b,x=ne(C(10),C(C(NI(e)+C(C(z[e+4236>>2]*C(12e3))+C(-1e4)))*C(.0005000000237487257))),z[u+12>>2]=x;v[b+8>>2]=1065353216;p=z[ol(b+12|0,b+8|0)>>2];g=C(g*g);c=C(n*C(g*c));n=C(s*c);d=C(m*C(g*d));g=C(r*d);m=C(C(C(n+g)*C(-.5))+C(1));z[e+4284>>2]=p*C(K(C(m/C(C(C(g+c)*C(.1444000005722046))+i))));z[e+4288>>2]=p*C(K(C(m/C(C(C(n+d)*C(.1444000005722046))+f))));jb=b+16|0;t[a+5046|0]=0;jb=k+16|0}function Xb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[115890]){break a}a=a+b|0;if(v[115891]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=463544,j=v[115886]&Jma(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+463848|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=463548,j=v[115887]&Jma(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[115888]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[115892]==(f|0)){v[115892]=d;a=v[115889]+a|0;v[115889]=a;v[d+4>>2]=a|1;if(v[115891]!=(d|0)){break a}v[115888]=0;v[115891]=0;return}if(v[115891]==(f|0)){v[115891]=d;a=v[115888]+a|0;v[115888]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=463544,j=v[115886]&Jma(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+463848|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=463548,j=v[115887]&Jma(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[115891]!=(d|0)){break f}v[115888]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+463584|0;c=v[115886];a=1<<a;k:{if(!(c&a)){v[115886]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+463848|0;l:{m:{c=v[115887];b=1<<e;n:{if(!(c&b)){v[115887]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[115894]-1|0;v[115894]=a?a:-1}}function WK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;if(b){h=a+327720|0;c=jb-400|0;jb=c;pN(c+384|0,8);v[114578]=0;ra(1210,c+368|0,9);g=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((g|0)!=1){v[114578]=0;g=Q(1211,c+352|0,14)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}v[114578]=0;R(1212,c+384|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break k}v[114578]=0;R(1212,c+368|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break k}oN(c+280|0,4900);oN(c+208|0,32e3);lN(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[114578]=0;f=Q(1213,c+104|0,c+384|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}Ns(c+120|0,c+280|0,f);Mf(f);v[114578]=0;f=Q(1213,c+72|0,c+368|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break i}Ns(c+88|0,c+208|0,f);Mf(f);v[114578]=0;f=Q(1213,c+40|0,c+120|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break h}Ns(c+56|0,c+136|0,f);Mf(f);v[114578]=0;f=Q(1213,c+8|0,c+88|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}Ns(c+24|0,c+136|0,f);Mf(f);kp(c+120|0);kp(c+56|0);kp(c+88|0);kp(c+24|0);kp(c+368|0);jp(c+120|0,yi(h,0));jp(c+56|0,yi(h,1));jp(c+88|0,yi(h,2));jp(c+24|0,yi(h,3));jp(c+368|0,yi(h,4));Mf(c+24|0);Mf(c+56|0);Mf(c+88|0);Mf(c+120|0);ip(g);Mf(c+368|0);Mf(c+384|0);jb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Mf(c+56|0)}Mf(c+88|0)}Mf(c+120|0)}ip(g)}Mf(c+368|0)}Mf(c+384|0);S(a|0);L()}Ax(a+131112|0,9.6377,.97);Ax(a+196648|0,8.5,.5);Ax(a+262184|0,2.7625,.425)}g=a+368680|0;if(!(r=0,s=VK(g,a),t=b,t?r:s)){i=a+24|0;o=A[a+8>>3];c=w[a+16|0];f=jb+-64|0;jb=f;while(1){p=+(k-4096|0)*.0001220703125;l=0;b=0;while(1){j=o;h=c;d=1;m=f+(b<<3)|0;e=+(b|0)-p;n=e+-3.5;if(!(D(n)<1e-8)){m:{n:{switch(h|0){case 0:d=.5-ze(e*.8975979010256552)*.5;break m;case 1:d=ze(e*.8975979010256552)*-.46+.54;break m;case 2:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.5+.42+e*.08;break m;case 3:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49364+.44959+e*.05677;break m;case 4:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49755+.42323+e*.07922;break m;case 5:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.48829+.35875+e*.14128+ze(d*3)*-.01168;break m;case 6:d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49703+.40217+e*.09392+ze(d*3)*-.00183;break m;case 7:break n;default:break m}}d=e*.8975979010256552;e=ze(d+d);d=ze(d)*-.49804+.40243+e*.09831+ze(d*3)*-.00122}e=n*3.141592653589793;j=ii(e*j)/e}j=j*d;A[m>>3]=j;l=j+l;b=b+1|0;if((b|0)!=8){continue}break}j=1/l;m=k<<3;b=0;while(1){q=i+(b+m<<1)|0;d=G(F(H(A[f+(b<<3)>>3]*32768*j+.5),32768),-32768);o:{if(D(d)<2147483648){h=~~d;break o}h=-2147483648}u[q>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if((k|0)!=8193){continue}break}jb=f- -64|0;b=v[a+20>>2];v[g+16>>2]=v[a+16>>2];v[g+20>>2]=b;b=v[a+12>>2];v[g+8>>2]=v[a+8>>2];v[g+12>>2]=b;b=v[a+4>>2];v[g>>2]=v[a>>2];v[g+4>>2]=b}}function iv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-96|0;jb=d;l=a;n=a;a:{b:{c:{d:{e:{if(!(o=0,p=!xd(a,11),q=v[a+4>>2],q?o:p)){e=v[a+28>>2];f=v[a+12>>2];c=v[a+64>>2];h=c+v[a+8>>2]|0;h=Og(d+80|0,h,c>>>0>h>>>0?f+1|0:f);c=v[h+12>>2];b=d;v[b+32>>2]=v[h+8>>2];v[b+36>>2]=c;b=v[h+4>>2];v[d+24>>2]=v[h>>2];v[d+28>>2]=b;dj(e,d+24|0);b=v[a+28>>2];if(Lt(v[v[b>>2]-12>>2]+b|0)){Jg(a,1073741826);break a}c=v[a+92>>2];i=a+44|0;g=i;b=od(g);f:{if(c>>>0>b>>>0){h=jb-32|0;jb=h;g:{m=c-b|0;h:{if(m>>>0<=v[zb(g)>>2]-v[g+4>>2]>>4>>>0){e=jb-16|0;jb=e;i:{f=lm(e,g,m);if(v[f+4>>2]!=v[f+8>>2]){while(1){c=zb(g);b=v[f+4>>2];v[114578]=0;R(216,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}b=v[f+4>>2]+16|0;v[f+4>>2]=b;if((b|0)!=v[f+8>>2]){continue}break}}Mb(f);jb=e+16|0;break h}a=P()|0;O()|0;Mb(f);S(a|0);L()}b=zb(g);c=Mq(g,od(g)+m|0);e=od(g);f=jb-16|0;jb=f;v[f+12>>2]=0;j=h+8|0;Tc(j+12|0,b);if(c){b=c;if(b>>>0>268435455){Fc(6967);L()}k=sc(b<<4,4)}v[j>>2]=k;b=(e<<4)+k|0;v[j+8>>2]=b;v[j+4>>2]=b;o=ec(j),p=(c<<4)+k|0,v[o>>2]=p;jb=f+16|0;v[114578]=0;R(211,j|0,m|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;R(212,g|0,j|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}oD(j)}jb=h+32|0;break f}a=P()|0;O()|0;oD(j);S(a|0);L()}if(b>>>0>c>>>0){c=v[g>>2]+(c<<4)|0;od(g);nD(g,c);mD(g)}}c=a+32|0;OD(c,v[a+92>>2]<<2);if(v[a+92>>2]){e=0;while(1){b=v[a+28>>2];if(Lt(v[v[b>>2]-12>>2]+b|0)){Jg(a,1073741828);break a}b=x[a+16>>1];u[d+78>>1]=b;if((b|0)==65535){jv(v[a+28>>2],d+78|0)}o=d,p=Ac(c),v[o+72>>2]=p;j:{if(!x[d+78>>1]){k=0;break j}k=x[d+78>>1];b=v[d+72>>2];if(k>>>0>-1-b>>>0){break j}io(c,b+k|0);ak(v[a+28>>2],xc(c,v[d+72>>2]),x[d+78>>1]);k=x[d+78>>1]}o=tc(i,e),p=k,u[o+12>>1]=p;b=v[d+72>>2];o=tc(i,e),p=b,v[o>>2]=p;if(xd(a,6)){Nj(v[a+28>>2],d+56|0);if(y[d+60>>2]>2147483647){break e}b=v[d+56>>2];o=tc(i,e),p=b,v[o+4>>2]=p}b=v[a+4>>2];k:{if(b){o=tc(i,e),p=b,v[o+8>>2]=p;break k}if(!xd(a,7)){break k}Nj(v[a+28>>2],d+56|0);if(y[d+60>>2]>2147483647){break d}b=v[d+56>>2];o=tc(i,e),p=b,v[o+8>>2]=p}l:{if(v[tc(i,e)+8>>2]==-1){break l}if(xd(a,6)){break l}if(e){b=e-1|0;b=v[tc(i,b)+4>>2]+v[tc(i,b)+8>>2]|0}else{b=0}o=tc(i,e),p=b,v[o+4>>2]=p}if(xd(a,8)){u[d+56>>1]=0;jv(v[a+28>>2],d+56|0);b=xd(a,9);hl(v[a+28>>2],x[d+56>>1]<<b,-1)}e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}}pf(d+56|0,v[a+28>>2]);b=v[d+68>>2];v[a+72>>2]=v[d+64>>2];v[a+76>>2]=b}Oj(a,4,1);b=v[a+88>>2];if((b|0)!=v[a+64>>2]){break c}c=v[a+76>>2];b=v[a+72>>2];break b}Jg(a,1073741829);break a}Jg(a,1073741829);break a}c=v[a+12>>2];e=b+v[a+8>>2]|0;c=e>>>0<b>>>0?c+1|0:c;b=e}v[n+80>>2]=b;v[l+84>>2]=c;l=v[a+28>>2];c=Og(d+40|0,b,c);b=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=b;b=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=b;dj(l,d+8|0);if(xd(a,6)){break a}if((o=0,p=!xd(a,7),q=v[a+4>>2],q?o:p)|!v[a+92>>2]){break a}c=a+44|0;l=v[a+80>>2];b=v[a+8>>2];l=l-b|0;e=0;while(1){b=tc(c,e);v[b+4>>2]=l+v[b+4>>2];e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}}jb=d+96|0}function ay(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=jb-16|0;jb=g;i=B(b,896)+a|0;m=i+1075782|0;h=x[m>>1];l=a+1074308|0;Eb(g+8|0,l,23);e=c&15;a:{b:{if(Cb(g+8|0)){if(!(v[a+1074392>>2]|!w[(B(b,896)+a|0)+1075794|0])){u[m>>1]=e;break b}f=x[m>>1];if(f){j=f-1|0;u[m>>1]=j;f=0;if(j&65535){break b}}u[m>>1]=e;f=1;break b}Eb(g+8|0,l,52);j=c&256;if(!(!j|!Cb(g+8|0))){c:{if(!(w[a+480209|0]&16)){break c}f=B(b,896)+a|0;if(w[f+1075795|0]){h=vS(f+1075794|0)?1:h}if(!w[(B(b,896)+a|0)+1075798|0]|w[f+1075796|0]!=1){break c}u[m>>1]=h;break a}f=0;if(h<<16>>16<(e|0)){break b}if(w[a+480209|0]&16){if(cg((B(b,896)+a|0)+1075794|0)){break b}}h=0;f=1;break b}if(v[a+480180>>2]&16777250){f=h&65535?!((h<<16>>16)%((e?e:1)|0)|0):0;h=h+1|0;break b}if(v[a+480180>>2]==16){f=v[a+1074392>>2]==(e|0)&(e|0)!=0;break b}d:{e:{f:{g:{h:{if(j){f=B(b,896)+a|0;if(w[f+1075796|0]==1){e=(w[f+1075799|0]>15)+e|0}e=e?e:1;break h}if(v[a+480208>>2]&4096?!j:0){break e}e=e?e:1;if(v[a+1074416>>2]){break g}}f=0;break f}f=!(y[a+1074392>>2]%(e>>>0)|0)}h=h+1|0;break d}h=v[a+480180>>2]&1048580?0:h}if(!(h<<16>>16<(e|0)|(w[(B(b,896)+a|0)+1075794|0]|!j?!v[a+1074392>>2]:0))){f=1}Eb(g+8|0,l,52);if(!Cb(g+8|0)|c){break b}f=!v[a+1074392>>2]}j=i+1074984|0;k=(B(b,896)+a|0)+1075060|0;i:{if(v[k>>2]){break i}Eb(g+8|0,l,38);if(!Cb(g+8|0)){break i}if(!nj(j)){break a}}Eb(g+8|0,l,106);if(z=0,A=Cb(g+8|0),C=v[(B(b,896)+a|0)+1075680>>2],C?z:A){break a}if(f){e=B(b,896)+a|0;o=e+1075672|0;v[g+4>>2]=v[o>>2];f=c>>>4&15;j:{if(!f){e=v[e+1075072>>2];break j}Eb(g+8|0,l,52);k:{if(z=Cb(g+8|0),A=0,C=w[(B(b,896)+a|0)+1075796|0]==1,C?z:A){break k}e=t[f+21872|0];if(e){v[g+4>>2]=B(e,v[g+4>>2])>>4;break k}v[g+4>>2]=v[g+4>>2]+(t[f+21888|0]<<2)}ce(g+4|0,0,256);f=(B(b,896)+a|0)+1075072|0;e=v[f>>2]|2097152;v[f>>2]=e}n=B(b,896)+a|0;p=n+1075684|0;q=v[p>>2];f=w[n+1075808|0];i=0;if(e&512){Eb(g+8|0,l,108);i=Cb(g+8|0)}if(!(!v[k>>2]|i^1|(f-1&255)>>>0>119)){wM(a,b,0,f,1)}l:{if(!(v[a+480180>>2]&1048580)){e=0;break l}e=(c|0)<256;if((c|0)>255){break l}k=w[(B(b,896)+a|0)+1075795|0];if(!k){break l}e=1;dp(a,j,k,0,0,1)}n=n+1075072|0;m:{if(!i){break m}k=(B(b,896)+a|0)+1075088|0;if(!v[k>>2]){break m}i=a+1304392|0;if(!rd(i)){break m}Mh(v[i>>2],b,1);Os(v[i>>2],b,v[k>>2]+68|0)}i=B(b,896)+a|0;k=i+1075644|0;r=v[k>>2];s=v[n>>2];v[k>>2]=0;Eb(g+8|0,l,23);Cs(a,j,f,Cb(g+8|0),e,0,b);if(!w[i+1075795|0]){v[k>>2]=r}if(!(!(s&4096)|v[a+480180>>2]!=4)){v[n>>2]=v[n>>2]|4096}e=i+1075794|0;v[o>>2]=v[g+4>>2];if(x[a+480192>>1]){t[e|0]=f;aL(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[e|0]|!q))){v[p>>2]=q}f=v[a+480180>>2];Eb(g+8|0,l,23);if(Cb(g+8|0)){v[j>>2]=0;v[j+4>>2]=0}f=f&16777250;n:{if(d-1>>>0>9){break n}e=v[(B(b,896)+a|0)+1075088>>2];if(!e){break n}o:{if((d|0)==1){b=v[(B(b,896)+a|0)+1075648>>2];break o}i=(B(b,896)+a|0)+1075648|0;b=v[(e+(d<<2)|0)+60>>2];v[i>>2]=b}cp(a,j,b)}h=f?h:0}Eb(g+8|0,l,52);a=Cb(g+8|0);Eb(g+8|0,l,23);if(Cb(g+8|0)){break a}u[m>>1]=(a&c>>>8)+h}jb=g+16|0}function JI(a){var b=C(0),c=C(0),d=0,e=C(0),f=0,g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=C(0),r=C(0),s=0,t=C(0);NM(a+4208|0,z[a+4272>>2]);c=C(C(z[a+4208>>2]*C(15920))+C(80));d=Se(v[a+16>>2]);o=ne(C(10),C(C(C(z[a+4216>>2]*C(30))+C(-15))*C(.02500000037252903)));b=C(C(c*C(6.2831854820251465))/C(d>>>0));c=zG(b);r=yo(b);s=a;t=c;k=C(C(C(b*C(.02888113260269165))*C(C(z[a+4212>>2]*C(35))+C(1)))/c);i=(l(2,(p(k),j(2))&-2147483648|1056964608),q());h=(p(k),j(2))&2147483647;c=(l(2,h),q());a:{if(h>>>0<=1118925334){b:{c:{d:{e:{f:{g:{f=(p(c),j(2));d=f&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((f|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((f|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=b;c=C(c-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}m=C(c*C(.5));g=C(c*m);b=C(C(g*C(C(g*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));n=b;b=C(C(3)-C(m*b));m=C(g*C(C(n-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*m)-g));if(!d){break b}e=C(C(C(c*C(m-e))-e)-g);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}c=C(c-e);b=C(C(c+c)+C(1));break b;default:break i}}f=d<<23;b=(l(2,f+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}g=(l(2,1065353216-f|0),q());d=(d|0)<23;c=C(C((d?C(C(1)-g):C(c-C(e+g)))+(d?C(c-e):C(1)))*b)}b=c}if(h>>>0<=1065353215){if(h>>>0<964689920){break a}k=C(i*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}k=C(i*C(b+C(b/C(b+C(1)))));break a}g=C(i+i);i=C(0);c=C(c+C(-162.88958740234375));h=(p(c),j(2));f=h>>>31|0;j:{k:{l:{m:{n:{n=c;o:{p:{d=h&2147483647;q:{if(d>>>0>=1118743632){b=c;if(d>>>0>2139095040){break j}b=C(c*C(1.7014118346046923e38));if(!((h|0)<0|d>>>0<1118925336)){break j}if(d>>>0<=1120924084|(h|0)>-1){break q}break l}if(d>>>0<1051816473){break n}if(d>>>0<1065686419){break p}}c=C(C(c*C(1.4426950216293335))+z[(f<<2)+52272>>2]);if(C(D(c))<C(2147483648)){d=~~c;break o}d=-2147483648;break o}d=!f-f|0}b=C(d|0);c=C(n+C(b*C(-.693145751953125)));i=C(b*C(1428606765330187e-21));b=C(c-i);break m}if(d>>>0<=956301312){break k}d=0;b=c}n=c;e=C(b*b);c=C(b-C(e*C(C(e*C(-.0027667332906275988))+C(.16666625440120697))));e=C(C(n+C(C(C(b*c)/C(C(2)-c))-i))+C(1));if(!d){break l}e=AG(e,d)}b=e;break j}b=C(c+C(1))}k=C(g*C(C(b*C(1.661534994731145e35))*C(1.661534994731145e35)))}b=C(t*k);e=C(b/o);c=C(e+C(1));z[s+4236>>2]=C(C(1)-e)/c;e=C(C(r*C(-2))/c);z[a+4232>>2]=e;b=C(b*o);z[a+4228>>2]=C(C(1)-b)/c;z[a+4224>>2]=e;z[a+4220>>2]=C(b+C(1))/c}function Pq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[115891]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=463544,j=v[115886]&Jma(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+463848|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=463548,j=v[115887]&Jma(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[115888]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[115892]==(f|0)){v[115892]=a;b=v[115889]+b|0;v[115889]=b;v[a+4>>2]=b|1;if(v[115891]!=(a|0)){break a}v[115888]=0;v[115891]=0;return}if(v[115891]==(f|0)){v[115891]=a;b=v[115888]+b|0;v[115888]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=463544,j=v[115886]&Jma(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+463848|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=463548,j=v[115887]&Jma(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[115891]!=(a|0)){break g}v[115888]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+463584|0;d=v[115886];b=1<<b;l:{if(!(d&b)){v[115886]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+463848|0;m:{d=v[115887];c=1<<e;n:{if(!(d&c)){v[115887]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function sW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-336|0;jb=d;g=jb-16|0;jb=g;v[a>>2]=0;e=a+32|0;OD(e,32);t[g+15|0]=0;i=g+15|0;a:{if(y[e+4>>2]<y[zb(e)>>2]){h=jb-16|0;jb=h;f=Mi(h,e,1);e=zb(e);j=v[f+4>>2];v[114578]=0;U(210,e|0,j|0,i|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[f+4>>2]=v[f+4>>2]+1;Mb(f);jb=h+16|0;break a}a=P()|0;O()|0;Mb(f);S(a|0);L()}h=jb-32|0;jb=h;f=e;j=zb(e);e=nh(h+8|0,Ki(e,Ac(e)+1|0),Ac(e),j);k=v[e+8>>2];v[114578]=0;U(210,j|0,k|0,i|0);i=v[114578];v[114578]=0;b:{c:{if((i|0)==1){break c}v[e+8>>2]=v[e+8>>2]+1;v[114578]=0;R(209,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}nm(e);jb=h+32|0;break b}a=P()|0;O()|0;nm(e);S(a|0);L()}}jb=g+16|0;e=v[a+28>>2];d:{if(!Gf(v[v[e>>2]-12>>2]+e|0)){Jg(a,1073741825);break d}pf(d- -64|0,v[a+28>>2]);e=d- -64|0;f=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=f;f=Qc(d- -64|0,3);g=v[a+28>>2];i=d+24|0;e=0;if(v[f>>2]){while(1){yh(g,e+i|0);e=e+1|0;if(e>>>0<y[f>>2]){continue}break}}if(qd(d+24|0,6931,3)){Jg(a,1073741827);break d}t[d+335|0]=0;yh(v[a+28>>2],d+335|0);sD(d- -64|0);f=b;g=d+24|0;h=d- -64|0;e=w[d+335|0];if(e){ak(v[a+28>>2],d- -64|0,e);b=w[d+335|0]}else{b=0}b=mm(g,h,b);e=kv(f,b);Ib(b);if(!e){Jg(a,1073741830)}if(w[a+3|0]&64){break d}yh(v[a+28>>2],d+63|0);e=w[d+63|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(_h(e,6)){Oj(a,9,1)}v[d+56>>2]=0;rD(v[a+28>>2],d+56|0);b=v[d+56>>2];t[d+55|0]=0;if(b>>>0>=2){yh(v[a+28>>2],d+63|0);f=w[d+63|0];if(!f){yh(v[a+28>>2],d+55|0);f=w[d+63|0]}hl(v[a+28>>2],b+(f?-1:-2)|0,-1)}v[d+40>>2]=0;v[d+44>>2]=0;e:{if(!_h(e,4)){break e}Nj(v[a+28>>2],d+40|0);b=v[d+44>>2];f=v[d+40>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break e}Jg(a,536871424)}if(_h(e,5)){yh(v[a+28>>2],d+63|0);hl(v[a+28>>2],w[d+63|0],-1)}f:{if(!_h(w[d+55|0],0)){break f}yh(v[a+28>>2],d+63|0);b=w[d+63|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break f}Jg(a,536871168)}v[a+4>>2]=0;b=1;if(_h(w[d+55|0],1)){rD(v[a+28>>2],a+4|0)}Oj(a,6,_h(e,2));Oj(a,7,_h(e,3));Oj(a,5,x[a+16>>1]!=0);Oj(a,8,_h(e,7));g:{if(xd(a,5)){break g}if(xd(a,6)){break g}if(xd(a,7)){break g}b=xd(a,8)}Oj(a,11,b);xd(a,11);b=w[d+55|0];if(_h(b,2)){u[d+24>>1]=0;jv(v[a+28>>2],d+24|0);hl(v[a+28>>2],B(x[d+24>>1],xd(a,9)?2:1),-1);b=w[d+55|0]}if(_h(b&255,3)){hl(v[a+28>>2],5,-1)}Nj(v[a+28>>2],d+40|0);c=v[d+44>>2];b=v[d+40>>2];if(!c&b>>>0>=16001|c){Jg(a,1073741831);break d}v[a+92>>2]=b;if(!b){Jg(a,536871040)}h:{if(!xd(a,11)){break h}Nj(v[a+28>>2],d+40|0);b=v[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break h}Jg(a,1073741829);break d}pf(d+8|0,v[a+28>>2]);yD(d+24|0,d+8|0,v[a+8>>2],v[a+12>>2]);b=v[d+36>>2];e=v[d+32>>2];if(!(b?0:(b|0)>0?1:(b|0)>=0)){Jg(a,1073741832);break d}v[a+88>>2]=e;b=a;i:{if(xd(a,11)){c=v[d+40>>2];break i}c=v[a+88>>2]}v[b+64>>2]=c;if(!xd(a,11)){c=v[a+12>>2];e=v[a+88>>2];f=e+v[a+8>>2]|0;c=f>>>0<e>>>0?c+1|0:c;v[a+72>>2]=f;v[a+76>>2]=c}Oj(a,10,1)}jb=d+336|0}function YC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=jb-144|0;jb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(v[19056]>=(c|0)){Ru(a+96|0,c);v[114578]=0;c=Q(2,a+80|0,1024)|0;d=v[114578];v[114578]=0;if((d|0)==1){break E}v[114578]=0;U(3,a+112|0,a+96|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break D}v[114578]=0;d=Q(4,a+48|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break C}v[114578]=0;e=Q(2,a+32|0,1027)|0;f=v[114578];v[114578]=0;if((f|0)==1){break B}v[114578]=0;U(5,a- -64|0,d|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break A}v[114578]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[114578];v[114578]=0;if((f|0)==1){break z}yb(a- -64|0);yb(e);yb(d);yb(a+112|0);yb(c);yb(a+96|0);if(v[b>>2]){c=v[b>>2]}else{c=1030}v[114578]=0;U(6,a+112|0,1,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break t}if(v[b+4>>2]){c=v[b+4>>2]}else{c=1030}v[114578]=0;U(6,a+96|0,1,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break s}b=v[b+8>>2];v[114578]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}v[114578]=0;b=Q(8,460904,1031)|0;c=v[114578];v[114578]=0;if((c|0)==1){break q}v[114578]=0;U(9,a- -64|0,0,a+112|0);c=v[114578];v[114578]=0;if((c|0)==1){break p}v[114578]=0;b=Q(10,b|0,a- -64|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break o}v[114578]=0;b=Q(8,b|0,1044)|0;c=v[114578];v[114578]=0;if((c|0)==1){break o}v[114578]=0;U(9,a+32|0,0,a+80|0);c=v[114578];v[114578]=0;if((c|0)==1){break n}v[114578]=0;b=Q(10,b|0,a+32|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[114578]=0;b=Q(8,b|0,1046)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[114578]=0;b=Q(8,b|0,1024)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[114578]=0;U(9,a+16|0,0,a+128|0);c=v[114578];v[114578]=0;if((c|0)==1){break l}v[114578]=0;b=Q(10,b|0,a+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}v[114578]=0;b=Q(8,b|0,1048)|0;c=v[114578];v[114578]=0;if((c|0)==1){break k}v[114578]=0;U(9,a|0,0,a+96|0);c=v[114578];v[114578]=0;if((c|0)==1){break j}v[114578]=0;b=Q(10,b|0,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;b=Q(8,b|0,1051)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;Q(11,b|0,12)|0;b=v[114578];v[114578]=0;if((b|0)==1){break i}yb(a);yb(a+16|0);yb(a+32|0);yb(a- -64|0);yb(a+80|0);yb(a+96|0);yb(a+112|0);yb(a+128|0)}jb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(a- -64|0)}yb(e)}yb(d)}yb(a+112|0)}yb(c)}yb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;yb(a)}yb(a+16|0)}yb(a+32|0)}yb(a- -64|0)}yb(a+80|0)}yb(a+96|0)}yb(a+112|0)}yb(a+128|0)}S(b|0);L()}function bI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-224|0;jb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(mj(b)){break a}d=w[fk(b)|0];c=1;b:{if((d|0)==33){break b}if((d|0)!=63){break a}c=0}e=c;sk(f+184|0,b,v[b+4>>2]-1|0);c=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=c}Dd(f+184|0);c=v[f+184>>2];Dd(f+168|0);g=ek(c,v[f+172>>2],b);Dd(f+184|0);c=v[b>>2];d=v[b+4>>2];c:{d:{e:{f:{if((g|0)==v[f+188>>2]){v[f+208>>2]=c;v[f+212>>2]=d;a=qc(f+200|0,38235);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Hc(f+16|0,f+8|0)){a=ba(8)|0;v[114578]=0;R(2143,f+168|0,f+216|0);b=v[114578];v[114578]=0;g:{h:{i:{if((b|0)!=1){v[114578]=0;U(2119,f+184|0,39300,f+168|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}mc(a,f+184|0);e=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break e}b=P()|0;O()|0;yb(f+184|0);break h}b=P()|0;O()|0;break g}b=P()|0;e=1;O()|0}yb(f+168|0);if(!e){break f}}ca(a|0);break f}if(!e){break c}c=ba(8)|0;v[114578]=0;d=Q(2142,f+136|0,b|0)|0;b=v[114578];v[114578]=0;a=1;j:{k:{l:{m:{n:{o:{p:{q:{r:{if((b|0)!=1){v[114578]=0;U(2119,f+152|0,39179,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break r}v[114578]=0;U(2137,f+168|0,f+152|0,39315);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break q}v[114578]=0;R(2143,f+120|0,f+216|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}v[114578]=0;U(138,f+184|0,f+168|0,f+120|0);b=v[114578];v[114578]=0;a=1;if((b|0)==1){break o}mc(c,f+184|0);v[114578]=0;U(2009,c|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break e}b=P()|0;O()|0;yb(f+184|0);a=0;break n}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;a=1;O()|0;break m}b=P()|0;O()|0}yb(f+120|0)}yb(f+168|0)}yb(f+152|0)}yb(d)}if(!a){break f}ca(c|0);break f}v[f+112>>2]=c;v[f+116>>2]=d;c=qc(f+104|0,38235);d=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=d;d=v[c+4>>2];v[f+56>>2]=v[c>>2];v[f+60>>2]=d;if(!Hc(f- -64|0,f+56|0)){break d}a=ba(8)|0;v[114578]=0;R(2143,f+168|0,f+216|0);b=v[114578];v[114578]=0;s:{t:{u:{if((b|0)!=1){v[114578]=0;U(2119,f+184|0,39300,f+168|0);b=v[114578];v[114578]=0;if((b|0)==1){break u}mc(a,f+184|0);e=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break e}b=P()|0;O()|0;yb(f+184|0);break t}b=P()|0;O()|0;break s}b=P()|0;e=1;O()|0}yb(f+168|0);if(!e){break f}}ca(a|0)}S(b|0)}L()}c=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=c;c=qc(f+88|0,39014);d=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=d;d=v[c+4>>2];v[f+40>>2]=v[c>>2];v[f+44>>2]=d;if(Hc(f+48|0,f+40|0)){QH(a,yc(v[f+216>>2],v[f+220>>2]));break c}c=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=c;b=qc(f+72|0,39162);c=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=c;c=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=c;if(!Hc(f+32|0,f+24|0)){break c}b=yc(v[f+216>>2],v[f+220>>2]);v[v[a+32>>2]+40>>2]=b>>>0>3?1:b}jb=f+224|0}function lL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=C(0),l=0,m=0,n=C(0),o=0,p=0,q=0,r=C(0),s=0,t=0,w=0,A=0,E=C(0),G=0;if(b){So(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;yL(a)}kL(a+24648|0);s=v[a+24620>>2];h=jb-144|0;jb=h;f=a+393352|0;c=v[f+4>>2];a:{if(c>>>0<=28){g=B(c,44)+82048|0;break a}v[f+4>>2]=0;g=82048}if(!(b?0:(g|0)==v[f+4112>>2])){v[f+4112>>2]=g;r=C(s>>>0);i=r;c=h+8|0;d=v[g+24>>2];v[c>>2]=d;e=v[g+16>>2];v[c+4>>2]=e;v[c+8>>2]=v[g+4>>2];l=(d|0)>(e|0)?d:e;if((l|0)<=-601){j=e;e=l+600|0;v[c+4>>2]=j-e;v[c>>2]=d-e}e=c;k=C(z[g+36>>2]*C(79.30999755859375));b:{if(C(D(k))<C(2147483648)){d=~~k;break b}d=-2147483648}v[e+16>>2]=d- -8192;d=c;k=C(C(z[g+32>>2]*C(117.9612045288086))+C(4915.05029296875));c:{if(C(D(k))<C(2147483648)){e=~~k;break c}e=-2147483648}v[d+20>>2]=(e|0)<32512?e:32512;l=0;k=z[g+8>>2];e=c;n=C(C(F(z[g+20>>2],C(.10000000149011612)))*i);d:{if(C(D(n))<C(2147483648)){d=~~n;break d}d=-2147483648}j=(d|0)<96;o=j?96:d;p=(o|0)>7500;n=C(z[g+28>>2]*i);e:{if(C(D(n))<C(2147483648)){m=~~n;break e}m=-2147483648}d=(m+(j?d-96|0:0)|0)+(p?o-7500|0:0)|0;j=(d|0)<128;m=j?128:d;t=(m|0)>3800;w=t?3800:m;v[e+24>>2]=w;j=j?d-128|0:0;e=c;i=C(k*i);f:{if(C(D(i))<C(2147483648)){d=~~i;break f}d=-2147483648}j=(d+j|0)+(t?m-3800|0:0)|0;v[e+32>>2]=j;o=p?7500:o;while(1){e=B(l,12);d=e+c|0;e=e+34032|0;u[d+42>>1]=x[e+10>>1];u[d+36>>1]=x[e+4>>1];p=x[e+6>>1]|x[e+8>>1]<<16;u[d+38>>1]=p;u[d+40>>1]=p>>>16;v[d+44>>2]=o+((B(v[e>>2],w)+50|0)/100|0);l=l+1|0;if((l|0)!=8){continue}break}e=c;i=C(j|0);k=C(ne(C(.0010000000474974513),(j|0)<4721?C(1):C(C(4720)/i))*C(32768));g:{if(C(D(k))<C(2147483648)){d=~~k;break g}d=-2147483648}v[e+12>>2]=d;i=C(z[g+12>>2]*i);A=c,E=ne(C(.0010000000474974513),i>C(4720)?C(C(4720)/i):C(1)),z[A+28>>2]=E;v[f+4124>>2]=v[h+40>>2];c=BI(CI(v[h+16>>2]),r);u[f+4190>>1]=c;u[f+4188>>1]=c;c=x[h+24>>1]<<1;u[f+4198>>1]=c;u[f+4196>>1]=c;while(1){c=(q<<4)+f|0;g=(h+8|0)+B(q,12)|0;d=v[g+44>>2];v[c+4204>>2]=d;v[c+4208>>2]=d;u[c+4212>>1]=x[g+36>>1];u[c+4214>>1]=x[g+42>>1];u[c+4216>>1]=x[g+40>>1];u[c+4218>>1]=x[g+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[f+53996>>2]=v[h+32>>2];e=f+4184|0;c=v[h+12>>2];if((c|0)>-9e3){c=AI(c)}else{c=0}v[e>>2]=c;e=f+54052|0;c=v[h+8>>2];if((c|0)>=-8999){c=AI(c)}else{c=0}v[e>>2]=c;c=v[h+28>>2];g=f+54036|0;v[g>>2]=268464128;v[g+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[f+54010>>1]=c;u[f+54008>>1]=c;u[f+54006>>1]=c;u[f+54004>>1]=c;v[h+4>>2]=v[h+20>>2];ce(h+4|0,0,32752);c=x[h+4>>1];u[f+54018>>1]=c;g=f+54014|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54012>>1]=c;i=z[h+36>>2];A=h,G=BI(C(i*i),r),v[A>>2]=G;ce(h,256,32512);c=x[h>>1];u[f+54026>>1]=c;g=f+54022|0;u[g>>1]=0;u[g+2>>1]=0;u[f+54020>>1]=c}if(b){v[f+4120>>2]=0;EI(f)}b=B(s,5);if(b>>>0>y[f+4124>>2]){v[f+4124>>2]=b}jb=h+144|0;b=a+1304392|0;if(rd(b)){zN(v[b>>2],v[a+24620>>2])}}function Y3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-160|0;jb=d;h=d+144|0;_H(h);v[h>>2]=83592;g=jb-16|0;jb=g;e=h+4|0;v[e>>2]=0;v[e+4>>2]=0;v[114578]=0;v[g+12>>2]=0;W(2201,e+8|0,g+12|0,g+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=g+16|0;break a}V(0)|0;O()|0;Ab();L()}g=a+24|0;Om(v[g>>2],h);e=w[a+62|0];f=w[a+61|0];i=w[a+60|0];j=v[g>>2];b=Ze(d+128|0,b);v[114578]=0;i=i?13:15;f=f?i&14:i;e=W(2145,j|0,b|0,(e?f&3:f)|0)|0;f=v[114578];v[114578]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if((f|0)!=1){Bb(b);if(!e){b=ba(8)|0;v[114578]=0;c=Q(85,d+112|0,38611)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break b}a=P()|0;O()|0;yb(c);break c}a=P()|0;O()|0;ca(b|0);break c}s:{if(w[a+63|0]){break s}v[114578]=0;R(2146,a|0,a+36|0);b=v[114578];v[114578]=0;if((b|0)!=1){break s}a=P()|0;O()|0;break c}t[a+28|0]=1;Om(v[g>>2],v[a+4>>2]);v[114578]=0;R(2147,d+112|0,h|0);b=v[114578];v[114578]=0;if((b|0)==1){break r}k=d,l=bc(d+112|0),v[k+104>>2]=l;k=d,l=cc(d+112|0),v[k+96>>2]=l;if(Jb(d+104|0,d+96|0)){g=a+68|0;while(1){b=v[d+104>>2];e=v[b>>2];v[114578]=0;f=e;e=b+4|0;U(2148,a|0,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}b=v[b>>2];v[114578]=0;R(2149,d+32|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(9,d+48|0,0,d+32|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}v[114578]=0;b=Q(85,d+16|0,38630)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}v[114578]=0;U(138,d- -64|0,d+48|0,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break m}v[114578]=0;U(801,d+80|0,d- -64|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break o}v[114578]=0;R(1535,g|0,d+80|0);e=v[114578];v[114578]=0;if((e|0)==1){break p}yb(d+80|0);yb(d- -64|0);yb(b);yb(d+48|0);yb(d+32|0);Tf(d+104|0);if(Jb(d+104|0,d+96|0)){continue}break}}k=d,l=vn(c),v[k+80>>2]=l;k=d,l=Hi(c),v[k+64>>2]=l;t:{while(1){v[114578]=0;b=Q(2150,d+80|0,d- -64|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}if(!b){break q}v[114578]=0;c=T(2151,d+80|0)|0;b=v[114578];v[114578]=0;u:{if((b|0)==1){break u}v[114578]=0;b=Q(120,d|0,c|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break u}v[114578]=0;X(2081,a|0,b|0,c+12|0,0);c=v[114578];v[114578]=0;if((c|0)==1){break t}yb(b);v[114578]=0;T(2152,d+80|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}break e}break}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(b);break d}a=P()|0;O()|0;Bb(b);break c}a=P()|0;O()|0;break c}Rw(d+112|0);Ur(h);jb=d+160|0;return}a=P()|0;O()|0;yb(d+80|0);break n}a=P()|0;O()|0}yb(d- -64|0);break l}a=P()|0;O()|0}yb(b);break j}a=P()|0;O()|0}yb(d+48|0);break h}a=P()|0;O()|0}yb(d+32|0);break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0}Rw(d+112|0)}Ur(h);S(a|0)}L()}function Y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-48|0;jb=c;if(mh(b)){h=lk(b);j=v[b+12>>2];f=c+32|0;e=Rz(f);a:{d=h;if(!d){break a}v[114578]=0;R(680,f|0,d|0);g=v[114578];v[114578]=0;if((g|0)!=1){v[114578]=0;R(1569,f|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;Dt(e);S(a|0);L()}b:{if(!j){break b}while(1){d=v[v[a>>2]-12>>2];v[114578]=0;d=T(1576,a+d|0)|0;e=v[114578];v[114578]=0;c:{if((e|0)!=1){d:{if(!d){break b}v[114578]=0;t[c+31|0]=0;Q(1577,a|0,c+31|0)|0;d=v[114578];v[114578]=0;e:{if((d|0)!=1){d=t[c+31|0];if(d){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((d|0)>-1){break f}v[114578]=0;Q(1577,a|0,c+30|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break f}break d}t[c+29|0]=0;Qh(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=d&127;d=(d?d-1|0:0)&65535;k=d>>>0>=h>>>0;B:{C:{if(!k){v[114578]=0;g=W(472,b|0,i|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(t[c+30|0]&1){break C}break z}g=c+16|0;e=w[c+30|0];if(!(e&1)){break B}}v[114578]=0;Q(1577,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break A}e=w[c+30|0]}if(e&2){break y}break x}e=w[c+29|0];l=Nc(f,d),m=e,t[l|0]=m}l=g,m=w[Nc(f,d)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[114578]=0;Q(1577,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break w}e=w[c+30|0]}if(e&4){break u}break t}e=w[c+29|0];l=Nc(f,d),m=e,t[l+1|0]=m}l=g,m=w[Nc(f,d)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[114578]=0;Q(1577,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break s}e=w[c+30|0]}if(e&8){break q}break p}e=w[c+29|0];l=Nc(f,d),m=e,t[l+2|0]=m}l=g,m=w[Nc(f,d)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[114578]=0;Q(1577,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break o}e=w[c+30|0]}if(e&16){break m}break l}e=w[c+29|0];l=Nc(f,d),m=e,t[l+4|0]=m}l=g,m=w[Nc(f,d)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[114578]=0;Q(1577,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(d>>>0<h>>>0){break k}e=w[c+30|0]}if(e&32){break i}break g}e=w[c+29|0];l=Nc(f,d),m=e,t[l+3|0]=m}l=g,m=w[Nc(f,d)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[114578]=0;Q(1577,a|0,c+29|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}if(k){break g}e=w[c+29|0];l=Nc(f,d),m=e,t[l+5|0]=m}l=g,m=w[Nc(f,d)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[114578]=0;Q(1577,a|0,c+15|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){d=w[c+15|0];v[114578]=0;W(1578,a|0,d|0,-1)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break c}}}}a=P()|0;O()|0;Ll(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}Ll(f)}jb=c+48|0}function w2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-192|0;jb=d;a:{if(mj(b)){break a}e=w[fk(b)|0];g=1;b:{if((e|0)==33){break b}if((e|0)!=63){break a}g=0}c=g;sk(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}Dd(d+160|0);e=v[d+160>>2];Dd(d+144|0);e=ek(e,v[d+148>>2],b);Dd(d+160|0);c:{d:{e:{f:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=qc(d+176|0,38235);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114578]=0;c=Q(85,d+160|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}f=0;if(!c){break f}a=ba(8)|0;v[114578]=0;e=Q(2142,d+144|0,b|0)|0;b=v[114578];v[114578]=0;g:{h:{i:{if((b|0)!=1){v[114578]=0;U(2119,d+160|0,39179,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}mc(a,d+160|0);c=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(d+160|0);break h}b=P()|0;O()|0;break g}b=P()|0;c=1;O()|0}yb(e);if(!c){break d}}ca(a|0);break d}if(v[e+4>>2]!=2){a=ba(8)|0;v[114578]=0;c=Q(85,d+160|0,39193)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=qc(d+128|0,38235);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Hc(d+72|0,d- -64|0)){a=ba(8)|0;v[114578]=0;c=Q(85,d+160|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=qc(d+112|0,39022);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break f}f=65536/+y[v[a+24>>2]+480244>>2];break f}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=qc(d+96|0,39040);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break f}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break f}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=qc(d+80|0,39137);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Hc(d+24|0,d+16|0)){break f}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}jb=d+192|0;return+f}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function _3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-128|0;jb=e;a:{if(Wc(b)){break a}g=w[fI(b)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;cr(e+112|0,b,0,Fb(b)-1|0);Gb(b,e+112|0);yb(e+112|0)}Dd(e+112|0);f=v[e+112>>2];Dd(e+96|0);f=dI(f,v[e+100>>2],b);Dd(e+112|0);c:{d:{e:{f:{g:{if((f|0)==v[e+116>>2]){if(Vd(b,38235)){a=ba(8)|0;v[114578]=0;U(2136,e+112|0,39300,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}mc(a,e+112|0);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break d}b=P()|0;O()|0;yb(e+112|0);break e}if(!d){break g}a=ba(8)|0;v[114578]=0;U(2136,e+80|0,39179,b|0);b=v[114578];v[114578]=0;h:{i:{j:{k:{l:{if((b|0)!=1){v[114578]=0;U(2137,e+96|0,e+80|0,39315);b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;U(801,e+112|0,e+96|0,c|0);b=v[114578];v[114578]=0;c=1;if((b|0)==1){break k}mc(a,e+112|0);v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=P()|0;O()|0;yb(e+112|0);c=0;break j}b=P()|0;O()|0;break h}b=P()|0;c=1;O()|0;break i}b=P()|0;O()|0}yb(e+96|0)}yb(e+80|0);if(!c){break e}}ca(a|0);break e}m:{switch(v[f+4>>2]){case 0:Hh(e+72|0,b);b=($F(c)|0)!=0;c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;cI(a,e,b,d);break g;case 1:Hh(e- -64|0,b);b=jb-160|0;jb=b;c=Dm(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;n:{if((h|0)==1){break c}v[114578]=0;U(123,b+8|0,f+(b+16|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}Ob(b+8|0);v[114578]=0;f=Q(178,c|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}g=v[v[f>>2]-12>>2];v[114578]=0;f=T(174,f+g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}g=v[b>>2];h=v[b+4>>2];If(c);jb=b+160|0;b=f?0:g;c=f?0:h;break n}f=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=f;bI(a,e+8|0,b,c,d);break g;case 2:Hh(e+56|0,b);b=jb-160|0;jb=b;c=Dm(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;o:{if((h|0)==1){break c}v[114578]=0;U(123,b+8|0,f+(b+16|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}Ob(b+8|0);v[114578]=0;f=Q(179,c|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}g=v[v[f>>2]-12>>2];v[114578]=0;f=T(174,f+g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}i=A[b>>3];If(c);jb=b+160|0;i=f?0:i;break o}b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;aI(a,e+16|0,i,d);break g;case 3:break m;default:break g}}Hh(e+48|0,b);Hh(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;$H(a,e+32|0,e+24|0,d)}jb=e+128|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}a=P()|0;O()|0;If(c);S(a|0);L()}function pja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[pc(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[pc(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=st(+(gR(e,b,c,d)>>>0)*1e-4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[pc(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[pc(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=pc(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[pc(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[pc(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[pc(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[pc(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[pc(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=41;h=a,i=un(id(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b-17&255)>>>0>=223){t[a+3|0]=9;h=a,i=zj(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){vj(a);break a}t[a+3|0]=0}jb=f+16|0}function Eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;e=jb-560|0;jb=e;a:{if(!Pc(b,1464)){break a}if(!An(b,e+556|0)){break a}Hd(a,1);d=a+1074308|0;wg(d,83);Nb(d,84,1);Nb(d,85,1);b:{if($d(e+556|0,16026)){d=Ub(e+32|0,16036);Gb(a+1304436|0,d);yb(d);d=Ub(e+32|0,16059);Gb(a+1304448|0,d);yb(d);d=Ub(e+32|0,16064);Gb(a+1304460|0,d);break b}if(!$d(e+556|0,16031)){break a}d=Ub(e+32|0,16081);Gb(a+1304436|0,d);yb(d);d=Ub(e+32|0,16093);Gb(a+1304448|0,d);yb(d);d=Ub(e+32|0,16097);Gb(a+1304460|0,d)}yb(d);v[a+1304496>>2]=2;d=0;Pc(b,0);Tz(b,a+1304400|0,20);u[a+480190>>1]=31;f=1;while(1){d=mz(b,e+32|0,(B(f,104)+a|0)+484380|0,((f<<5)+a|0)+946300|0,1)+d|0;f=f+1|0;if((f|0)!=32){continue}break}if(d>>>0>40){break a}dq(e+552|0,b);m=dd(e+552|0);i=e+552|0;if(w[i|0]>128){break a}g=e+32|0;f=jb-16|0;jb=f;d=b;c:{if(Qb(d,512)){_t(f+8|0,g);Bd(d,f+8|0);break c}iQ(g)}jb=f+16|0;d=e+544|0;f=e+32|0;g=w[m|0];d:{while(1){if(g>>>0>=w[f|0]){f=f+1|0;if((d|0)!=(f|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;lj(a,0);n=a+484360|0;eg(Vb(n),w[i|0]);u[e+30>>1]=0;j=a+484344|0;_f(j,w[i|0]);if(w[i|0]){g=0;while(1){s=rc(Vb(n),g),x=g,u[s>>1]=x;if(rg(j,g&65535,64)){p=g<<2;h=0;while(1){Pc(b,(w[e+32+(h+p)|0]<<8)+1468|0);f=Xe(_b(j,g),0,h&65535);d=0;while(1){ot(b,f);e:{f:{l=w[f+3|0];g:{if((l|0)!=14){if(!l){if(w[f+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[f+5|0]<=15){break f}}t[f+3|0]=0;break e}vj(f)}f=f+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=e,x=bc(_b(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){f=d;h:{if(w[v[e+24>>2]+3|0]!=17?w[v[e+24>>2]+3|0]!=16:0){break h}t[v[e+24>>2]+3|0]=16;k=0;if(w[v[e+24>>2]+5|0]<16){break h}if(!(!(w[v[e+24>>2]+5|0]&15)|(w[v[e+24>>2]+5|0]&15)==(w[v[e+24>>2]+5|0]>>>4|0))){q=w[v[e+24>>2]+5|0]>>>4|0;r=w[v[e+24>>2]+5|0]&15;k=1}d=v[e+24>>2];t[d+5|0]=w[d+5|0]>>>4}Cj(e+24|0);d=f+1|0;if((f&65535)>>>0<3){continue}break}t[e+31|0]=r;t[e+30|0]=q;d=k&255;f=0;i:{if(!d){break i}sl(_b(j,g),Ne(Qn(e+8|0,16,w[(e+d|0)+29|0]),h));d=k+1|0;f=(d&255)==3?1:d}k=f;h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Pc(b,(w[m|0]<<8)+1468|0);f=1;while(1){c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){tg(ad(e+8|0,8,1,0,0),c,b)}f=f+1|0;if((f|0)!=32){continue}break}}jb=e+560|0;return o|0}function S3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb-96|0;jb=d;a:{b:{c:{if(!(b<.8)){v[114578]=0;Z(2158,d+24|0);e=v[114578];v[114578]=0;d:{e:{f:{g:{h:{if((e|0)!=1){c=v[c>>2];v[114578]=0;R(2159,d+8|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}Om(v[d+24>>2],v[d+8>>2]);e=v[d+24>>2];c=Ze(d+80|0,a);v[114578]=0;a=W(2145,e|0,c|0,15)|0;e=v[114578];v[114578]=0;if((e|0)==1){break g}Bb(c);if(a){a=v[d+24>>2];v[114578]=0;T(1404,a|0)|0;a=v[114578];v[114578]=0;f=1;if((a|0)==1){break f}}Yc(d+8|0);Gh(d+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;break d}a=V(0)|0;O()|0;Bb(c);break e}a=V(0)|0;O()|0}Yc(d+8|0)}Gh(d+24|0);break c}if(!(b<.6)){v[114578]=0;Z(2158,d+24|0);e=v[114578];v[114578]=0;i:{j:{k:{l:{m:{if((e|0)!=1){c=v[c>>2];v[114578]=0;R(2159,d+8|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break m}Om(v[d+24>>2],v[d+8>>2]);e=v[d+24>>2];c=Ze(d- -64|0,a);v[114578]=0;a=W(2145,e|0,c|0,2)|0;e=v[114578];v[114578]=0;if((e|0)==1){break l}Bb(c);if(a){a=v[d+24>>2];v[114578]=0;T(1404,a|0)|0;a=v[114578];v[114578]=0;f=.8;if((a|0)==1){break k}}Yc(d+8|0);Gh(d+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;break i}a=V(0)|0;O()|0;Bb(c);break j}a=V(0)|0;O()|0}Yc(d+8|0)}Gh(d+24|0);break c}f=.2;if(!(b<.2)){v[114578]=0;Z(2158,d+24|0);e=v[114578];v[114578]=0;n:{o:{p:{q:{r:{if((e|0)!=1){c=v[c>>2];v[114578]=0;R(2159,d+8|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break r}Om(v[d+24>>2],v[d+8>>2]);e=v[d+24>>2];c=Ze(d+48|0,a);v[114578]=0;a=W(2145,e|0,c|0,0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}Bb(c);f=0;if(a){a=v[d+24>>2];v[114578]=0;T(1404,a|0)|0;a=v[114578];v[114578]=0;f=.6;if((a|0)==1){break p}}Yc(d+8|0);Gh(d+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;break n}a=V(0)|0;O()|0;Bb(c);break o}a=V(0)|0;O()|0}Yc(d+8|0)}Gh(d+24|0);break c}if(b<.1){break b}v[114578]=0;U(855,d+24|0,a|0,2048);c=v[114578];v[114578]=0;s:{t:{u:{if((c|0)!=1){v[114578]=0;c=T(414,d+24|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break t}e=v[d+24>>2];v[114578]=0;a=T(255,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break t}v[114578]=0;a=wD(2160,3,0,c,e,a,0);c=v[114578];v[114578]=0;if((c|0)==1){break t}a=a+1|0;if(a>>>0>=3){break u}f=A[(a<<3)+40512>>3];Ec(d+24|0);break b}a=V(0)|0;O()|0;break c}c=ba(8)|0;v[114578]=0;e=Q(85,d+8|0,38235)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(c,e);v[114578]=0;U(2009,c|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=V(0)|0;O()|0;yb(e);break s}a=V(0)|0;O()|0;ca(c|0);break s}a=V(0)|0;O()|0}Ec(d+24|0)}_(a|0)|0;$();f=0}jb=d+96|0;return+f}L()}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0;f=jb-32|0;jb=f;p=a+4|0;o=v[p>>2];n=a+20|0;s=v[Rc(n,b)+16>>2];a:{if(s+1>>>0<2){break a}h=(B(b,896)+o|0)+608|0;if(!Kh(h)){if(!w[Rc(n,b)+20|0]){break a}}i=B(b,896)+o|0;if(!v[i+712>>2]){break a}D=v[(v[i+696>>2]&2?i+692|0:i+684|0)>>2];g=v[i+688>>2];j=v[i+692>>2];Eb(f+24|0,v[a>>2]+1074308|0,31);u=Cb(f+24|0);y=i+1356|0;l=w[y|0];z=i+616|0;e=Iu(z,c);k=mb;m=k;v[f+24>>2]=e;v[f+28>>2]=k;if(w[i+696|0]&128){v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+m|0)}k=j-g|0;E=k<<1;e=B(b,896)+o|0;A=e;F=e+1308|0;m=e+1480|0;G=(l&17)!=1;b:{while(1){c:{if(d>>>0>q>>>0){g=(w[y|0]&17)==1;break c}t[m|0]=w[m|0]&254;e=Xe(_b(v[a>>2]+484344|0,x[v[p>>2]+60>>1]),v[v[p>>2]+48>>2],b);j=w[e+3|0];if(w[e+2|0]==11){gy(f+16|0,v[a>>2],e,0);l=hc(f+16|0);an(v[a>>2],h,v[f+16>>2]);g=1;if(w[l|0]){break c}}g=1;d:{switch(j-4|0){case 0:an(v[a>>2],h,w[e+5|0]);break c;case 2:break d;default:break c}}an(v[a>>2],h,0)}v[f+12>>2]=v[F>>2];if(u){os(v[a>>2],h)}if(!G){gL(v[a>>2],h,f+12|0);g=1}if(!u){os(v[a>>2],h)}v[f+8>>2]=0;iL(h,f+8|0);e:{f:{if(w[i+697|0]&2){break f}g:{if(!g){if(!w[Rc(n,b)+20|0]){break g}}if(w[m|0]&12){qO(h,C(1),0,v[a>>2]);e=w[m|0];t[m|0]=(e&8?-9:-5)&e}H=A,I=Ix(v[a>>2],h,v[f+12>>2],0),v[H+616>>2]=I;v[A+620>>2]=mb;H=Rc(n,b),I=0,t[H+20|0]=I;e=Iu(z,c);g=mb;j=g;v[f+24>>2]=e;v[f+28>>2]=g;if(!(w[i+696|0]&128)){break g}v[f+24>>2]=0-e;v[f+28>>2]=0-(((e|0)!=0)+j|0)}Sb(h,f+24|0);g=v[h+4>>2];j=g;l=v[h>>2];if(D>>>0>g>>>0){break f}e=v[i+696>>2];if(!(e&2)){break e}if(e&4){r=v[i+688>>2];l=r;e=l;if((e|0)>(j|0)?1:0){v[f+16>>2]=0;v[f+20>>2]=l<<1;H=h,I=ig(f+16|0,h),v[H>>2]=I;v[h+4>>2]=mb;v[i+696>>2]=v[i+696>>2]^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;r=v[i+688>>2];g=v[h+4>>2]}Eb(f+16|0,v[a>>2]+1074308|0,33);e=(g-r>>>0)%(E-Cb(f+16|0)>>>0)|0;j=e>>>0<k>>>0;h:{if(!j){v[h+4>>2]=v[i+692>>2]+(k-e|0);g=v[i+696>>2];if(!(j^(g&128)>>>7)){break h}break f}v[h+4>>2]=e+v[i+688>>2];g=v[i+696>>2];if(j^(g&128)>>>7){break f}}v[i+696>>2]=g^128;e=v[f+24>>2];g=0-(v[f+28>>2]+((e|0)!=0)|0)|0;v[f+24>>2]=0-e;v[f+28>>2]=g;break f}j=v[i+692>>2];if(j+k>>>0<=g>>>0){g=j+((g-j>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=j>>>0){continue}break}v[h>>2]=l;v[h+4>>2]=e}q=q+1|0;if((s|0)!=(q|0)){continue}break b}break}sO(h);v[(B(b,896)+o|0)+1316>>2]=0}H=Rc(n,b),I=0,v[H+16>>2]=I}jb=f+32|0}function AU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-384|0;jb=e;Jc(b);f=jb-16|0;jb=f;g=e+344|0;jB(f+8|0,g);i=Hb(f+8|0);d=b;j=nc(d,ac(f,f+8|0));if((i|0)==(j|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(i|0)==(j|0);if(!d){kB(g)}a:{b:{if(!d){break b}if(!DB(e+344|0)){break b}if(!Qb(b,id(CB(e+344|0),mb))){break b}c:{if(!c){break c}Hd(a,2097152);wi(a);h=1;lj(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[e+376|0];v[a+480204>>2]=B(w[e+377|0],1e4);u[a+480190>>1]=w[e+378|0];if(w[e+381|0]<w[e+380|0]){Oe(Vb(a+484360|0),w[e+381|0])}d=Ub(e+80|0,12002);Gb(a+1304436|0,d);yb(d);d=Ub(e+80|0,12022);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;lu(b,e+80|0);eq(Vb(a+484360|0),e+80|0,w[e+380|0],65535,65535);if(x[a+480190>>1]){i=1;while(1){BB(b,e+40|0);j=jb-16|0;jb=j;g=(B(h,104)+a|0)+484380|0;Fd(g,0);k=e+40|0;t[g+37|0]=w[k+22|0]<<4;t[j+15|0]=w[k+23|0];t[j+14|0]=64;m=g,n=w[pc(j+15|0,j+14|0)|0]<<2,u[m+30>>1]=n;t[g+36|0]=w[k+24|0];d=k+25|0;v[g>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=k+33|0;d:{if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0<3){break d}l=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=k+29|0;if(l>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break d}u[g+34>>1]=x[g+34>>1]|2;v[g+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[g+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))}jb=j+16|0;Tl(e+8|0,2,e+40|0);Ic(e+24|0,e+8|0);v[114578]=0;Q(371,((h<<5)+a|0)+946300|0,e+24|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}yb(e+24|0);i=i+1|0;h=i&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}$b(b,B(64-w[e+378|0]|0,37));f=a+484344|0;_f(f,w[e+379|0]);if(w[e+379|0]){h=c&1;i=0;while(1){e:{f:{if(h){if(rg(f,i&65535,64)){break f}}$b(b,2048);break e}d=_b(f,i);m=e,n=bc(d),v[m+40>>2]=n;m=e,n=cc(d),v[m+24>>2]=n;if(!Jb(e+40|0,e+24|0)){break e}while(1){d=v[e+40>>2];Sl(e+8|0,b);g=dd(e+8|0);j=Bf(e+8|0);k=Sh(e+8|0);l=w[e+8|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[g|0];t[d+3|0]=w[j|0];t[d+5|0]=w[k|0];vj(d);Cj(e+40|0);if(Jb(e+40|0,e+24|0)){continue}break}}i=i+1|0;if(i>>>0<w[e+379|0]){continue}break}}if(!(c&2)){break c}h=1;c=ad(e+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){tg(c,(B(h&65535,104)+a|0)+484380|0,b);h=h+1|0;if(x[a+480190>>1]>=(h&65535)>>>0){continue}break}}h=1}jb=e+384|0;return h|0}a=P()|0;O()|0;yb(e+24|0);S(a|0);L()}function wG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;g=jb-48|0;jb=g;o(+a);d=j(1)|0;h=j(0)|0;a:{b:{e=d;d=e;f=e&2147483647;c:{if(f>>>0<=1074752122){if((d&1048575)==598523){break c}if(f>>>0<=1073928572){if((e|0)>0?1:(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0?1:(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(f>>>0<=1075594811){if(f>>>0<=1075183036){if((f|0)==1074977148){break c}if((e|0)>0?1:(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((f|0)==1075388923){break c}if((e|0)>0?1:(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(f>>>0>1094263290){break b}}k=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+k*-1.5707963267341256;i=k*6.077100506506192e-11;a=c-i;A[b>>3]=a;o(+a);d=j(1)|0;j(0)|0;h=f>>>20|0;e=(h-(d>>>20&2047)|0)<17;if(D(k)<2147483648){d=~~k}else{d=-2147483648}d:{if(e){break d}i=c;a=k*6.077100506303966e-11;c=c-a;i=k*2.0222662487959506e-21-(i-c-a);a=c-i;A[b>>3]=a;e=h;o(+a);h=j(1)|0;j(0)|0;if((e-(h>>>20&2047)|0)<50){break d}i=c;a=k*2.0222662487111665e-21;c=c-a;i=k*8.4784276603689e-32-(i-c-a);a=c-i;A[b>>3]=a}A[b+8>>3]=c-a-i;break a}if(f>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,h|0);l(1,e&1048575|1096810496);a=+n();d=g+16|0;h=g+16|8;m=1;while(1){if(D(a)<2147483648){p=~~a}else{p=-2147483648}c=+(p|0);A[d>>3]=c;a=(a-c)*16777216;if(m){m=0;d=h;continue}break}A[g+32>>3]=a;p=g+16|0;m=g;f=(f>>>20|0)-1046|0;e:{if(a==0){d=1;while(1){h=d;d=d-1|0;if(A[(g+16|0)+(h<<3)>>3]==0){continue}break}d=h+1|0;break e}d=3}d=xG(p,m,f,d,1);a=A[g>>3];if((e|0)<-1?1:(e|0)<=-1){A[b>>3]=-a;A[b+8>>3]=-A[g+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[g+8>>3]}jb=g+48|0;return d}function w_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=Xv(g);o=Iv(g);ng(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114578]=0;g=Q(2482,m|0,g<<24>>24)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114578]=0;g=Q(2482,m|0,48)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[114578]=0;g=Q(2482,m|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;j=da(2452)|0;l=v[114578];v[114578]=0;e:{if((l|0)==1){break e}v[114578]=0;h=Rv(h,j);j=v[114578];v[114578]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;da(2452)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}v[114578]=0;h=bh(h);j=v[114578];v[114578]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Wc(k)){h=v[f>>2];v[114578]=0;aa(2470,m|0,i|0,g|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break f}l=0;v[114578]=0;Wj(i,g);h=v[114578];v[114578]=0;if((h|0)==1){break a}v[114578]=0;q=T(2467,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114578]=0;qo((i-a<<2)+d|0,h);i=v[114578];v[114578]=0;if((i|0)!=1){break f}break a}g:{if(t[kc(k,j)|0]<1){break g}if(t[kc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=q;j=(Fb(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114578]=0;p=Q(2482,m|0,p|0)|0;n=v[114578];v[114578]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[114578]=0;i=T(2471,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}j=v[f>>2];h=j+4|0;v[f>>2]=h;v[j>>2]=i;g=g+1|0;break h}v[114578]=0;i=Q(2482,m|0,i<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[114578]=0;aa(2470,m|0,g|0,c|0,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;yb(k);jb=k+16|0;return}a=P()|0;O()|0;yb(k);S(a|0);L()}function TP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-80|0;jb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=Od(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=jb-16|0;jb=b;d=Ci(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<1){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[de(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}g=c;d=(d|0)/32|0;c=d<<2;$i(g,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<1){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}Od(a,f);jb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=Od(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=jb-16|0;jb=f;d=Ci(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<1){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;b=v[de(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;d=v[g+4>>2];h=v[v[e+24>>2]>>2];j=v[e+28>>2];v[f+8>>2]=b;k=32-d|0;v[f+4>>2]=k;l=Lb(f+8|0,f+4|0);i=v[g>>2];j=h&(-1<<j&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>=1){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[e+24>>2]=h;v[g>>2]=b}if((d|0)<1){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=de(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<1){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}Od(a,g);jb=f+16|0}jb=e+80|0}function y2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-160|0;jb=d;a:{if(mj(b)){break a}f=w[fk(b)|0];e=1;b:{if((f|0)==33){break b}if((f|0)!=63){break a}e=0}c=e;sk(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}Dd(d+128|0);e=v[d+128>>2];Dd(d+112|0);e=ek(e,v[d+116>>2],b);Dd(d+128|0);c:{d:{e:{f:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=qc(d+144|0,38235);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114578]=0;c=Q(85,d+128|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}e=0;f=0;if(!c){break f}a=ba(8)|0;v[114578]=0;e=Q(2142,d+112|0,b|0)|0;b=v[114578];v[114578]=0;g:{h:{i:{if((b|0)!=1){v[114578]=0;U(2119,d+128|0,39179,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}mc(a,d+128|0);c=0;v[114578]=0;U(2009,a|0,83440,2017);b=v[114578];v[114578]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(d+128|0);break h}b=P()|0;O()|0;break g}b=P()|0;c=1;O()|0}yb(e);if(!c){break d}}ca(a|0);break d}if(v[e+4>>2]!=1){a=ba(8)|0;v[114578]=0;c=Q(85,d+128|0,39193)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=qc(d+96|0,38235);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){a=ba(8)|0;v[114578]=0;c=Q(85,d+128|0,39169)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(c);break d}b=P()|0;O()|0;ca(a|0);break d}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=qc(d+80|0,39014);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break f}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=qc(d- -64|0,39162);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Hc(d+24|0,d+16|0)){break f}a=v[v[a+32>>2]+40>>2];e=a;f=a>>31}jb=d+160|0;mb=f;return e|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function H_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=ru(g);o=Lv(g);ng(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114578]=0;g=Q(22,m|0,g<<24>>24)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114578]=0;g=Q(22,m|0,48)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[114578]=0;g=Q(22,m|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;j=da(2452)|0;l=v[114578];v[114578]=0;e:{if((l|0)==1){break e}v[114578]=0;h=Rv(h,j);j=v[114578];v[114578]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114578]=0;da(2452)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}v[114578]=0;h=bh(h);j=v[114578];v[114578]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Wc(k)){h=v[f>>2];v[114578]=0;aa(2447,m|0,i|0,g|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break f}l=0;v[114578]=0;Wj(i,g);h=v[114578];v[114578]=0;if((h|0)==1){break a}v[114578]=0;q=T(2438,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114578]=0;Wj((i-a|0)+d|0,h);i=v[114578];v[114578]=0;if((i|0)!=1){break f}break a}g:{if(t[kc(k,j)|0]<1){break g}if(t[kc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;j=(Fb(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114578]=0;p=Q(22,m|0,p|0)|0;n=v[114578];v[114578]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break h}v[114578]=0;i=T(2448,o|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[114578]=0;aa(2447,m|0,g|0,c|0,i|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;yb(k);jb=k+16|0;return}v[114578]=0;i=Q(22,m|0,i<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;yb(k);S(a|0);L()}function x4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Wb(a);v[114578]=0;Y(81);c=v[114578];v[114578]=0;a:{b:{if((c|0)==1){c=$a(83440,71204,71180,0)|0;d=O()|0;c:{d:{e:{if((ga(83440)|0)==(d|0)){c=_(c|0)|0;v[114578]=0;Q(1995,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;Q(1995,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;Q(1995,a|0,37713)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114578]=0;Q(1995,a|0,(b?b:34181)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ga(71204)|0)==(d|0)){c=_(c|0)|0;v[114578]=0;Q(1995,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Q(1995,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Q(1995,a|0,37697)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114578]=0;Q(1995,a|0,(b?b:34181)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ga(71180)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[114578]=0;Q(1995,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;Q(1995,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;Q(1995,a|0,37680)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114578]=0;Q(1995,a|0,(b?b:34181)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[114578]=0;Q(1995,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;Q(1995,a|0,37654)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;Q(1995,a|0,37657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Ab()}L()}return}yb(a);S(b|0);L()}function u2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-160|0;jb=e;a:{if(mj(c)){break a}g=w[fk(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;sk(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}Dd(e+128|0);f=v[e+128>>2];Dd(e+112|0);h=ek(f,v[e+116>>2],c);Dd(e+128|0);f=v[c>>2];g=v[c+4>>2];c:{d:{e:{f:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=qc(e+144|0,38235);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Hc(e+8|0,e)){a=ba(8)|0;v[114578]=0;b=Q(85,e+128|0,39169)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}c=P()|0;O()|0;yb(b);break d}if(d){b=ba(8)|0;v[114578]=0;d=Q(2142,e+112|0,c|0)|0;a=v[114578];v[114578]=0;g:{h:{i:{if((a|0)!=1){v[114578]=0;U(2119,e+128|0,39179,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break i}mc(b,e+128|0);a=0;v[114578]=0;U(2009,b|0,83440,2017);c=v[114578];v[114578]=0;if((c|0)!=1){break c}c=P()|0;O()|0;yb(e+128|0);break h}c=P()|0;O()|0;break g}c=P()|0;a=1;O()|0}yb(d);if(!a){break d}}ca(b|0);break d}Wb(a);break f}v[e+104>>2]=f;v[e+108>>2]=g;d=qc(e+96|0,38235);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Hc(e+56|0,e+48|0)){a=ba(8)|0;v[114578]=0;b=Q(85,e+128|0,39169)|0;c=v[114578];v[114578]=0;if((c|0)!=1){mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}c=P()|0;O()|0;yb(b);break d}c=P()|0;O()|0;ca(a|0);break d}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=qc(e+80|0,39058);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Hc(e+40|0,e+32|0)){j:{switch(v[b+52>>2]){case 0:Ub(a,39251);break f;case 1:Ub(a,39259);break f;case 2:Ub(a,39268);break f;default:break j}}Wb(a);break f}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=qc(e- -64|0,39101);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Hc(e+24|0,e+16|0)){k:{switch(v[b+56>>2]){case 0:Ub(a,39273);break f;case 1:Ub(a,39278);break f;case 2:Ub(a,39284);break f;case 3:Ub(a,39295);break f;default:break k}}Wb(a);break f}Wb(a)}jb=e+160|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function $U(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=jb-16|0;jb=f;a:{if((d|0)<1){a=0}else{io(c,d);v[f+4>>2]=b;v[f>>2]=a;a=Db(v[c>>2]);v[f+12>>2]=d;v[f+8>>2]=a;q=d;a=0;b=0;while(1){b:{e=Bg(f,b);m=Bg(f,b+4|0)<<8|Bg(f,b+5|0);g=Bg(f,b+6|0);i=Bg(f,b+7|0);t=b+8|0;c:{d:{e:{switch(e|0){case 0:b=0;if(!m){break d}while(1){tq(f,a+b|0,Bg(f,b+t|0));b=b+1|0;if((m|0)!=(b|0)){continue}break};break d;case 1:break e;default:break b}}k=Bg(f,b+10|0);tq(f,a,k);a=(a>>>0<d>>>0)+a|0;m=m+3&65532;r=i|g<<8;if(r>>>0<2){break c}j=b+11|0;b=r-1|0;g=0;o=0;l=0;p=0;while(1){i=Vf(j,g,1,f);f:{g:{h:{i:{j:{if((o|0)<=7){if(i){e=g;break g}g=g+1|0;l=8;break j}e=g+1|0;k:{if(!i){if(!Vf(j,e,1,f)){break g}e=2;l:{m:{h=g+2|0;if(!Vf(j,h,1,f)){break m}e=3;h=g+3|0;if(!Vf(j,h,1,f)){break m}e=Vf(j,h,3,f);g=g+6|0;break l}g=h+1|0}h=4;e=((l<<3)+e|0)-17|0;if((e|0)<=-1|e>>>0>=56){break a}l=w[e+11680|0];if((l|0)!=8){break i}break k}h=4;g=e;if((l|0)!=8){break i}}l=8;h=1;if((p|0)>19){break i}}h=0;break h}p=p+8|0}e=b;n:{if((e|0)<1){break n}while(1){i=(g|0)/8|0;e=i+j|0;n=Bg(f,e);k=k-((Bg(f,e+1|0)<<8|n<<16|Bg(f,e+2|0))<<(g-(i<<3)|0)+8>>32-l)|0;tq(f,a,k&255);e=b-1|0;g=g+l|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<1){break n}h=h-1|0;i=(b|0)>1;b=e;if(i){continue}break}}o=(o|0)==31?31:o+1|0;b=e;break f}o:{p:{h=e+1|0;if(!Vf(j,h,1,f)){e=2;break p}h=e+2|0;if(!Vf(j,h,1,f)){e=4;break p}h=e+3|0;if(!Vf(j,h,1,f)){e=6;break p}g=e+5|0;if(!Vf(j,e+4|0,1,f)){h=Vf(j,g,3,f)+8|0;g=e+8|0;break o}h=Vf(j,g,5,f)+16|0;g=e+10|0;break o}g=h+2|0;h=Vf(j,h+1|0,1,f)+e|0}q:{if(Vf(j,g,1,f)){i=-256;e=12;break q}g=g+1|0;e=Vf(j,g,1,f);i=e?-4352:0;e=e?14:8}g=g+1|0;n=Vf(j,g,e,f);if((h|0)>=3){s=o-((h|0)!=3)|0;o=(s|0)>0?s-1|0:0}g=e+g|0;if((h|0)<1|(b|0)<1){break f}e=(a+i|0)+(n^-1)|0;i=b;while(1){b=f;k=a;n=e;s=f;if(y[f+12>>2]<=e>>>0){break a}u=k;k=w[n+v[s+8>>2]|0];tq(b,u,k);b=i-1|0;a=(a>>>0<d>>>0)+a|0;if((h|0)<2){break f}e=e+1|0;h=h-1|0;n=(i|0)>1;i=b;if(n){continue}break}}p=p-(p>>3)|0;if((b|0)>0){continue}break}break c}a=a+m|0;r=m}b=m+t|0;q=q-r|0;if((q|0)>0){continue}}break}io(c,v[f+12>>2]-q|0);a=nd(c)^1}jb=f+16|0;return a|0}a=ba(8)|0;v[114578]=0;T(354,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);S(b|0);L()}ja(a|0,77224,265);L()}function bN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-96|0;jb=f;t[f+95|0]=d;d=0;m=hp(a);n=rj(m);u[b>>1]=0;a:{if(n){while(1){o=x[rc(m,d)>>1];b:{if(!dg(v[a+24>>2]+484344|0,o)){break b}d=x[b>>1];if(wc(a)>>>0<=d>>>0){v[c>>2]=0;a=1;break a}l=sd(a,x[b>>1]);uj(f+72|0,l);xk(f- -64|0,l);d=v[f+76>>2];v[f+32>>2]=v[f+72>>2];v[f+36>>2]=d;d=v[f+68>>2];v[f+24>>2]=v[f+64>>2];v[f+28>>2]=d;k=f+80|0;e=f+32|0;h=f+24|0;d=jb-32|0;jb=d;c:{if(w[f+95|0]){g=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=g;e=Ci(h,e);h=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=h;h=jb-16|0;jb=h;v[h+12>>2]=e;i=d+8|0;g=v[i+4>>2];d:{if(g){v[h+8>>2]=32-g;e=Lb(h+8|0,h+12|0);j=v[i>>2];e=v[e>>2];g=v[j>>2]&(-1<<g&-1>>>v[h+8>>2]-e);if(g){Uc(k,j,Ema(g));break d}g=v[h+12>>2];if((g|0)==(e|0)){WM(k,i,e);break d}e=g-e|0;v[h+12>>2]=e;v[i>>2]=j+4}if(e>>>0>=32){g=v[i>>2];while(1){j=v[g>>2];if(j){Uc(k,g,Ema(j));break d}g=g+4|0;v[i>>2]=g;e=e-32|0;v[h+12>>2]=e;if(e>>>0>31){continue}break}}e:{if(!e){g=v[i>>2];break e}g=v[i>>2];i=v[g>>2]&-1>>>32-e;if(!i){break e}Uc(k,g,Ema(i));break d}Uc(k,g,e)}jb=h+16|0;break c}g=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=g;e=Ci(h,e);h=v[d+20>>2];v[d>>2]=v[d+16>>2];v[d+4>>2]=h;g=jb-16|0;jb=g;v[g+12>>2]=e;h=d;i=v[d+4>>2];f:{if(i){v[g+8>>2]=32-i;e=v[Lb(g+8|0,g+12|0)>>2];j=-1<<i&-1>>>v[g+8>>2]-e;i=v[h>>2];j=j&(v[i>>2]^-1);if(j){Uc(k,i,Ema(j));break f}j=v[g+12>>2];if((j|0)==(e|0)){WM(k,h,e);break f}e=j-e|0;v[g+12>>2]=e;v[h>>2]=i+4}if(e>>>0>=32){i=v[h>>2];while(1){j=v[i>>2];if((j|0)!=-1){Uc(k,i,Ema(j^-1));break f}i=i+4|0;v[h>>2]=i;e=e-32|0;v[g+12>>2]=e;if(e>>>0>31){continue}break}}g:{if(!e){i=v[h>>2];break g}i=v[h>>2];h=(v[i>>2]^-1)&-1>>>32-e;if(!h){break g}Uc(k,i,Ema(h));break f}Uc(k,i,e)}jb=g+16|0}jb=d+32|0;d=c;h:{if(w[f+95|0]){xk(f+56|0,l);h=0;if(aN(f+80|0,f+56|0)){break h}if(w[f+95|0]){break b}}xk(f+56|0,l);if(aN(f+80|0,f+56|0)^1){uj(f+48|0,l);a=v[f+84>>2];b=v[f+80>>2];v[f+40>>2]=b;v[f+44>>2]=a;c=v[f+52>>2];v[f+16>>2]=v[f+48>>2];v[f+20>>2]=c;v[f+8>>2]=b;v[f+12>>2]=a;h=pP(f+16|0,f+8|0);break h}if(y[l+4>>2]>=y[_b(v[a+24>>2]+484344|0,o)+12>>2]){break b}h=v[l+4>>2]}v[d>>2]=h;a=1;break a}d=x[b>>1]+1|0;u[b>>1]=d;d=d&65535;if(n>>>0>d>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}jb=f+96|0;return a|0}function Xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-48|0;jb=l;f=v[a+4>>2];e=Od(l+40|0,b);j=Od(l+32|0,c);d=jb-16|0;jb=d;e=SP(Od(d+8|0,e),Od(d,j));jb=d+16|0;d=e+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){e=v[a>>2];v[(d>>>0<33?e:e+(d-1>>>3&536870908)|0)>>2]=0}d=Od(l+24|0,b);c=Od(l+16|0,c);Tn(l+8|0,a,f);b=l;j=jb-48|0;jb=j;a=l+8|0;a:{if(v[d+4>>2]==v[a+4>>2]){d=Od(j+40|0,d);c=Od(j+32|0,c);f=Od(j+24|0,a);a=jb-16|0;jb=a;c=Ci(c,d);v[a+12>>2]=c;b:{if((c|0)<1){break b}e=v[d+4>>2];if(e){g=32-e|0;v[a+8>>2]=g;c=v[de(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;e=v[f>>2];g=-1<<v[d+4>>2]&-1>>>g-c;v[e>>2]=v[e>>2]&(g^-1)|g&v[v[d>>2]>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;v[f>>2]=e+(c>>>3&536870908);v[d>>2]=v[d>>2]+4;c=v[a+12>>2]}e=(c|0)/32|0;c=e<<2;$i(v[f>>2],v[d>>2],c);e=v[a+12>>2]-(e<<5)|0;v[a+12>>2]=e;v[f>>2]=c+v[f>>2];if((e|0)<1){break b}c=c+v[d>>2]|0;v[d>>2]=c;d=v[f>>2];i=d;n=v[d>>2];d=-1>>>32-e|0;v[i>>2]=n&(d^-1)|d&v[c>>2];v[f+4>>2]=v[a+12>>2]}Od(b,f);jb=a+16|0;break a}e=Od(j+16|0,d);c=Od(j+8|0,c);d=Od(j,a);f=jb-16|0;jb=f;a=Ci(c,e);v[f+12>>2]=a;c:{if((a|0)<1){break c}c=v[e+4>>2];d:{if(!c){c=v[d+4>>2];break d}c=32-c|0;v[f+8>>2]=c;a=v[de(f+8|0,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-a;g=v[d+4>>2];k=v[v[e>>2]>>2];i=v[e+4>>2];v[f+8>>2]=a;m=32-g|0;v[f+4>>2]=m;n=Lb(f+8|0,f+4|0);h=v[d>>2];k=k&(-1<<i&-1>>>c-a);c=v[d+4>>2];g=v[e+4>>2];i=c>>>0>g>>>0?k<<c-g:k>>>g-c|0;g=v[n>>2];v[h>>2]=i|v[h>>2]&(-1<<c&-1>>>m-g^-1);i=c+g|0;c=i&31;v[d+4>>2]=c;h=h+(i>>>3&536870908)|0;v[d>>2]=h;a=a-g|0;if((a|0)>=1){v[h>>2]=v[h>>2]&(-1>>>32-a^-1)|k>>>g+v[e+4>>2];v[d+4>>2]=a;c=a}v[e>>2]=v[e>>2]+4;a=v[f+12>>2]}g=32-c|0;if((a|0)>=32){k=-1<<c;i=k^-1;h=v[e>>2];while(1){a=v[d>>2];h=v[h>>2];v[a>>2]=i&v[a>>2]|h<<c;v[d>>2]=a+4;v[a+4>>2]=k&v[a+4>>2]|h>>>g;m=v[f+12>>2];a=m-32|0;v[f+12>>2]=a;h=v[e>>2]+4|0;v[e>>2]=h;if((m|0)>63){continue}break}}if((a|0)<1){break c}k=v[v[e>>2]>>2];v[f+8>>2]=g;c=de(f+12|0,f+8|0);e=v[d>>2];h=v[d+4>>2];c=v[c>>2];i=v[e>>2]&(-1<<h&-1>>>g-c^-1);g=k&-1>>>32-a;v[e>>2]=i|g<<h;a=c+h|0;v[d+4>>2]=a&31;a=e+(a>>>3&536870908)|0;v[d>>2]=a;e=v[f+12>>2]-c|0;v[f+12>>2]=e;if((e|0)<1){break c}v[a>>2]=v[a>>2]&(-1>>>32-e^-1)|g>>>c;v[d+4>>2]=v[f+12>>2]}Od(b,d);jb=f+16|0}jb=j+48|0;jb=l+48|0}function XT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0;e=jb-32|0;jb=e;j=Rh(e+24|0);if(v[a+12>>2]){q=j+3|0;r=j+5|0;s=j+4|0;x=j+2|0;z=j+1|0;A=e+16|5;C=e+16|3;while(1){D=Rn(a,n);while(1){a:{if(!Qb(c,1)){break a}k=Gd(c);if((k|0)==255){break a}h=k&31;d=lk(a)>>>0>h>>>0;h=B(h,6)+D|0;if(k&64){l=1}else{f=Gd(c);g=f<<24>>24;b:{c:{d:{f=f&127;switch(f|0){case 0:break b;case 1:break d;default:break c}}t[(d?h:e+24|0)|0]=255;break b}if(!(!b|f>>>0>121)){t[(d?h:e+24|0)|0]=f-1;break b}if((f-12&255)>>>0>96|b){break b}t[(d?h:e+24|0)|0]=f+13}E=d?h+1|0:z,F=Gd(c),t[E|0]=F;l=(g|0)<0}if(l){p=d?h:j;g=d?h+3|0:q;f=d?h+5|0:r;o=d?h+4|0:s;m=d?h+2|0:x;h=d?h:e+24|0;while(1){d=h;v[e+16>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);u[e+20>>1]=w[d+4|0]|w[d+5|0]<<8;d=Gd(c);l=d&128;i=d&63;e:{if(d&64){t[m|0]=1;t[o|0]=i;break e}d=Gd(c);t[f|0]=d;f:{g:{if(i>>>0<=15){t[g|0]=i;vj(p);h:{i:{j:{d=w[g|0];switch(d-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[f|0]=B(w[f|0]&15,17);break f}t[g|0]=0;t[m|0]=1;v[e+12>>2]=w[f|0]+1>>>1;v[e+8>>2]=64;E=o,F=v[de(e+12|0,e+8|0)>>2],t[E|0]=F;break f}if((d|0)!=19){break f}if(w[f|0]==128){break g}ux(p);break f}if(i>>>0>44){break f}i=i-16|0;t[g|0]=w[i+12272|0];k:{switch(i|0){case 0:if(d>>>0>1){break g}t[f|0]=d|158;break f;case 1:case 2:t[e+12|0]=15;E=f,F=w[pc(e+12|0,f)|0]|224,t[E|0]=F;break f;case 5:case 6:v[e+12>>2]=16;v[e+8>>2]=d+1;E=f,F=v[de(e+12|0,e+8|0)>>2]/2|240,t[E|0]=F;break f;case 14:l:{m:{n:{o:{p:{i=d>>>4|0;switch(i-1|0){case 1:break n;case 0:break o;default:break p}}switch(i-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[f|0]=d|240;break f}t[g|0]=3;t[f|0]=d|240;break f}t[g|0]=11;t[f|0]=(d<<3&120)+8|15;break f}t[g|0]=11;t[f|0]=(d&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[e+12>>2]=d+1>>>1;v[e+8>>2]=64;E=f,F=v[de(e+12|0,e+8|0)>>2],t[E|0]=F;break f}t[g|0]=0}sx(g,f,C,A);if(Xm(w[e+19|0])>>>0<=Xm(w[g|0])>>>0){break e}q:{if(w[m|0]){break q}if(!tx(g,f,1)){break q}t[m|0]=w[g|0];t[o|0]=w[f|0]}t[g|0]=w[e+19|0];t[f|0]=w[e+21|0]}if(l){continue}break}}if(!(k&128)){continue}}break}n=n+1|0;if(n>>>0<y[a+12>>2]){continue}break}}jb=e+32|0}function U4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb-80|0;jb=k;a:{b:{c:{j=ko(1,32);d:{e:{if(!j){a=ba(4)|0;Zk(a);v[114578]=0;U(2009,a|0,71204,2008);a=v[114578];v[114578]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+16>>2]=0;v[j+20>>2]=0;v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j+24>>2]=0;v[j+28>>2]=0;v[j>>2]=c?c:1997;d=Ks(k- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,k+48|0,c|0)|0;f=v[114578];v[114578]=0;i:{if((f|0)!=1){v[114578]=0;f=Q(2010,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break i}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}v[114578]=0;c=Q(85,k+48|0,c|0)|0;e=v[114578];v[114578]=0;j:{if((e|0)!=1){v[114578]=0;Q(2011,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114578]=0;a=T(1400,96)|0;i=v[114578];v[114578]=0;k:{l:{m:{if((i|0)!=1){v[114578]=0;v[k+44>>2]=c;v[k+40>>2]=e;v[k+36>>2]=f;v[k+32>>2]=b;U(2012,k+48|0,j|0,j+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break m}b=Ho(k+24|0,k+48|0);v[114578]=0;c=v[k+44>>2];v[k+16>>2]=v[k+40>>2];v[k+20>>2]=c;c=v[k+36>>2];v[k+8>>2]=v[k+32>>2];v[k+12>>2]=c;aa(2086,a|0,k+8|0,b|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break l}v[j+28>>2]=a;Yc(b);Yc(k+48|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;tk(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Yc(b);Yc(k+48|0)}Xb(a)}tk(d);_(i|0)|0;v[114578]=0;X(1989,37229,j|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){a=v[j+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[114578]=0;X(1989,37229,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=k+80|0;return j|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function gaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-1136|0;jb=e;Jc(b);f=jb-16|0;jb=f;g=e+1112|0;EK(f+8|0,g);i=Hb(f+8|0);d=b;j=nc(d,ac(f,f+8|0));if((i|0)==(j|0)){$b(d,Hb(f+8|0))}jb=f+16|0;d=(i|0)==(j|0);if(!d){FK(g)}a:{if(!d){break a}if(!JK(e+1112|0)){break a}d=e+1120|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=(Lj(b)|0)){break a}g=e+1128|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))!=(nf(b)|0)){break a}if(!c){h=1;break a}Rb(e+1056|0,0,56);d=e+1056|0;i=-2;b:{if(!d){break b}v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+8>>2]=0;f=v[d+32>>2];if(!f){v[d+32>>2]=2299;f=2299}if(!v[d+36>>2]){v[d+36>>2]=2300}f=nb[f|0](v[d+40>>2],1,43784)|0;i=-4;if(!f){break b}v[d+28>>2]=f;v[f+43780>>2]=1;v[f+10992>>2]=0;v[f+10996>>2]=0;v[f>>2]=0;v[f+11008>>2]=15;v[f+11e3>>2]=1;v[f+11004>>2]=0;i=0}if(i){break a}d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[e+1052>>2]=d;h=e+1132|0;h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);i=(h|0)!=0;f=pS(e+1040|0,h);c:{d:{e:{f:{if(!h){g=1;break f}g=1;if(!d){break f}while(1){v[114578]=0;v[e+12>>2]=1024;d=Q(333,e+12|0,e+1052|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}d=v[d>>2];v[114578]=0;W(261,b|0,e+16|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;k=W(1557,k|0,e+16|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[e+1072>>2]=h;v[e+1060>>2]=d;v[e+1056>>2]=e+16;g=v[f>>2];v[114578]=0;v[e+1068>>2]=g+l;j=Q(1558,e+1056|0,0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}m=v[e+1052>>2]-d|0;v[e+1052>>2]=m;g=(j|0)!=1;d=v[e+1072>>2];i=(d|0)!=0;if(!d|(j|0)==1){break f}l=(h+l|0)-d|0;h=d;if(m){continue}break}}v[114578]=0;T(1559,e+1056|0)|0;b=v[114578];v[114578]=0;g:{h:{if((b|0)!=1){h=0;b=e+1124|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(k|0)|i|g)){v[114578]=0;R(833,e|0,f|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;b=W(834,e+16|0,e|0,0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}v[114578]=0;h=W(1497,a|0,b|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}Bb(b)}fe(f);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(b);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}fe(f);S(a|0);L()}jb=e+1136|0;return h|0}function Oda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;v[h+24>>2]=d;k=Mj(a,c);pf(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(xd(a,5)){break a}}f=v[h+24>>2];d=jb-160|0;jb=d;i=al(d+56|0,v[a+28>>2]);v[114578]=0;g=Q(683,d+40|0,18621)|0;e=v[114578];v[114578]=0;b:{c:{d:{e:{if((e|0)!=1){v[114578]=0;v[d+24>>2]=19466496;v[d+28>>2]=0;U(684,i|0,g|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}Ib(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ib(g);break c}v[114578]=0;t[d+39|0]=0;g=Q(683,d+40|0,18628)|0;e=v[114578];v[114578]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[114578]=0;W(685,i|0,d+39|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break q}Ib(g);g=Wb(d+40|0);v[114578]=0;e=Q(683,d+24|0,18630)|0;j=v[114578];v[114578]=0;if((j|0)==1){break p}v[114578]=0;W(1182,i|0,g|0,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break o}Ib(e);v[114578]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}v[114578]=0;R(487,b|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}yb(d+24|0);v[114578]=0;u[d+22>>1]=0;e=Q(683,d+24|0,18632)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[114578]=0;W(1183,i|0,d+22|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}Ib(e);jg(d+22|0,x[v[19811]+12>>1]);v[114578]=0;e=Q(683,d+24|0,18634)|0;f=v[114578];v[114578]=0;if((f|0)==1){break k}f=v[Qc(d+16|0,x[d+22>>1])>>2];v[114578]=0;aa(1184,i|0,b|0,e|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}Ib(e);v[114578]=0;u[d+14>>1]=65535;e=Q(683,d+24|0,18636)|0;f=v[114578];v[114578]=0;if((f|0)==1){break i}v[114578]=0;f=W(1183,i|0,d+14|0,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Ib(e);if(!((f|0)==1|j>>>0<=l>>>0)){Oe(b,x[d+14>>1])}yb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ib(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(d+24|0);break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0}yb(g)}vg(i);S(a|0);L()}vg(i);jb=d+160|0}Zi(a,k,c,h+16|0);jb=h+32|0}function Zw(a){a=a|0;var b=0,c=0,d=C(0),e=0;Rb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[114578]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}fa(1916,e|0,67,5,c|0,b|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[114578]=0;fa(1916,a+4528|0,62,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[114578]=0;fa(1916,a+4552|0,53,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[114578]=0;fa(1916,a+4576|0,43,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[114578]=0;fa(1916,a+4600|0,32,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[114578]=0;fa(1916,a+4624|0,22,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[114578]=0;fa(1916,a+4648|0,75,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[114578]=0;fa(1916,a+4672|0,69,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[114578]=0;fa(1916,a+4696|0,60,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[114578]=0;fa(1916,a+4720|0,48,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[114578]=0;fa(1916,a+4744|0,36,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[114578]=0;fa(1916,a+4768|0,25,5,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1916,a+4792|0,0,0,0,0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[114578]=0;fa(1916,a+4816|0,3,0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[114578]=0;fa(1916,a+4840|0,3,0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1916,a+4864|0,407,1,c|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1916,a+4888|0,400,1,c|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1916,a+4912|0,10,0,c|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;fa(1916,a+4936|0,10,0,c|0,-1);c=v[114578];v[114578]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(71204)|0;if((O()|0)==(ga(71204)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=jb-80|0;jb=e;t=v[a+16>>2];h=Qf(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];x=h,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[h+16>>2];if(b){x=h,y=Pf(a+8|0,b),v[x>>2]=y;v[h+4>>2]=mb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){b=0;f=b;j=g;v[e+72>>2]=g;v[e+76>>2]=b;i=((((i&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Ad(v[h+8>>2],(u[(g<<1|2)+i>>1]+u[i+((g&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(f,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=Kf(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;p=v[i>>2];b=Yb(p,-16777216,16776704);s=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);q=v[a+68>>2];w=q;q=q>>31;v[i+4>>2]=p;p=v[a+72>>2];r=k>>31;k=f<<8;f=k;f=Fma(l,r,f,f>>31);l=mb;r=(e+8|0)+(j<<2)|0;j=Fma(s,s>>31,b,b>>31);f=j+f|0;b=mb+l|0;b=f>>>0<j>>>0?b+1|0:b;l=f;f=Fma(w,q,g,g>>31);g=l+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[r>>2]=(b|0)/256;v[i>>2]=b-(k&p);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;jb=e+80|0}function sI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-80|0;jb=j;a:{b:{c:{d:{e:{f:{k=ko(1,28);if(!k){a=ba(4)|0;Zk(a);v[114578]=0;U(2009,a|0,71204,2008);a=v[114578];v[114578]=0;if((a|0)!=1){break a}break f}v[k+24>>2]=0;v[k+16>>2]=0;v[k+20>>2]=0;v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1997;d=Ks(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,j+48|0,c|0)|0;f=v[114578];v[114578]=0;j:{if((f|0)!=1){v[114578]=0;f=Q(2010,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}v[114578]=0;c=Q(85,j+48|0,c|0)|0;e=v[114578];v[114578]=0;k:{if((e|0)!=1){v[114578]=0;Q(2011,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114578]=0;a=T(1400,80)|0;i=v[114578];v[114578]=0;l:{m:{n:{if((i|0)!=1){v[114578]=0;v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;U(2012,j+48|0,k|0,k+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break n}b=Ho(j+24|0,j+48|0);v[114578]=0;c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;aa(2013,a|0,j+8|0,b|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break m}v[k+24>>2]=a;Yc(b);Yc(j+48|0);tk(d);c=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Yc(b);Yc(j+48|0)}Xb(a)}tk(d);_(i|0)|0;v[114578]=0;X(1989,34722,k|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Xb(Sr(a))}c=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Xb(a);v[k+20>>2]=0}Xb(k);break d}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114578]=0;X(1989,34722,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=j+80|0;return c|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function vH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=jb-48|0;jb=f;v[f+40>>2]=c;v[f+44>>2]=b;v[f+36>>2]=d;j=v[a+8>>2];v[f+28>>2]=f+36;v[f+24>>2]=f+40;b=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=b;v[f+16>>2]=a;v[f+20>>2]=f+44;b=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=b;c=f;a:{b:{switch(v[j+40>>2]){case 0:d=jb-80|0;jb=d;e=v[c>>2];i=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;k=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=k;Eh(b- -64|0,b+32|0,i);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);k=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;n=b+16|0;c=jb-16|0;jb=c;if(k){while(1){i=0;if(g){while(1){h=A[ch(b,i,l)>>3];fc(j,i);A[c+8>>3]=h;Rf(c+8|0,-1,1);h=A[c+8>>3]*32768;A[c+8>>3]=h;h=Sd(h);c:{if(D(h)<2147483648){m=~~h;break c}m=-2147483648}e=Vc(m);q=Mm(n,i,l),r=e,u[q>>1]=r;i=i+1|0;if((g|0)!=(i|0)){continue}break}}l=l+1|0;if((k|0)!=(l|0)){continue}break}}jb=c+16|0;jb=d+80|0;break a;case 2:Kw(c,zb(j));break a;case 3:j=Ug(j);d=jb-80|0;jb=d;e=v[c>>2];l=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;k=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=k;Eh(b- -64|0,b+32|0,l);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);l=v[v[c+12>>2]>>2];k=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;n=b+16|0;c=jb-16|0;jb=c;if(l){o=j+16|0;while(1){e=0;if(k){while(1){h=Sd(A[ch(b,e,i)>>3]*134217728);g=Ve(j,e);m=g;g=sj(h)+(v[g>>2]>>1)|0;p=g;g=Jr(o)+g&-4096;v[m>>2]=p-g;A[c+8>>3]=+(g|0)*7.450580596923828e-9;Rf(c+8|0,-1,1);h=A[c+8>>3]*32768;A[c+8>>3]=h;h=Sd(h);d:{if(D(h)<2147483648){g=~~h;break d}g=-2147483648}g=Vc(g);q=Mm(n,e,i),r=g,u[q>>1]=r;e=e+1|0;if((k|0)!=(e|0)){continue}break}}i=i+1|0;if((l|0)!=(i|0)){continue}break}}jb=c+16|0;jb=d+80|0;break a;case 1:Kw(c,zb(j));break a;default:break b}}Kw(c,zb(j))}v[a+4>>2]=v[a+4>>2]+v[f+36>>2];jb=f+48|0}function an(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Eb(f+8|0,a+1074308|0,15);if(Cb(f+8|0)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+831|0];t[b+832|0]=c;t[b+831|0]=c}c:{if(tj(b)){e=v[a+1074392>>2];i=v[b+880>>2];d:{if(c){v[b+776>>2]=c;break d}c=v[b+776>>2];if(!c){break c}}d=v[b+708>>2];e:{f:{if((d|0)>=1){if((c|0)<0){break f}break e}if(!d|(c|0)<1){break e}}c=0-c|0;v[b+776>>2]=c}g=b;h=(+(e>>>0)+1)*+(c|0)/+y[a+1074416>>2];g:{if(D(h)<2147483648){c=~~h;break g}c=-2147483648}v[g+880>>2]=c;if(w[b+90|0]&16){c=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,c);v[b+880>>2]=c}a=c-(e?i:0)|0;c=a>>31;e=d>>31;if((e+d^e)>>>0<=(c^a+c)>>>0){if(!d){break c}v[b+708>>2]=0;v[b+876>>2]=d+v[b+876>>2];t[b+872|0]=w[b+872|0]|8;break c}v[b+708>>2]=d-a;v[b+876>>2]=a+v[b+876>>2];t[b+872|0]=w[b+872|0]|8;break c}d=1;h:{if(!(t[b+872|0]&1)|v[a+480180>>2]&524352){break h}if(v[a+1074416>>2]==1){Eb(f+8|0,a+1074308|0,6);if(Cb(f+8|0)){break h}}d=0;if(v[a+480180>>2]!=8){break h}d=(w[a+480208|0]&2)>>>1|0}if(!(v[a+480180>>2]!=268435456|c>>>0<240)){d=t[b+872|0]&1;c=c-240|0}if(c){v[b+776>>2]=(v[a+480180>>2]==64?B(c,10):c)<<2}e=v[b+708>>2];c=v[b+700>>2];i:{if(!c){c=0;break i}if(!e|d^1){break i}g=b;j:{if((c|0)<(e|0)){d=v[b+776>>2];k:{if(!(w[a+480208|0]&16)){break k}if(v[a+480180>>2]==4){c=v[b+700>>2];break k}c=v[b+776>>2]/4|0;c=v[((c>>>0<255?c:255)<<2)+25312>>2];d=c;e=c>>31;c=v[b+700>>2];d=Fma(d,e,c,c>>31)+32768|0;c=mb;d=yc(Gma(d,d>>>0<32768?c+1|0:c,65536,0),mb);c=v[b+700>>2];d=d-c|0;d=(d|0)>1?d:1}e=v[b+708>>2];c=c+d|0;c=(c|0)>(e|0)?e:c;break j}if((c|0)<=(e|0)){break i}d=0-v[b+776>>2]|0;l:{if(!(w[a+480208|0]&16)){break l}if(v[a+480180>>2]==4){c=v[b+700>>2];break l}c=v[b+776>>2]/4|0;c=v[((c>>>0<255?c:255)<<2)+26336>>2];d=c;e=c>>31;c=v[b+700>>2];d=Fma(d,e,c,c>>31)+32768|0;c=mb;d=yc(Gma(d,d>>>0<32768?c+1|0:c,65536,0),mb);c=v[b+700>>2];d=d-c|0;d=(d|0)<-1?d:-1}e=v[b+708>>2];c=c+d|0;c=(c|0)<(e|0)?e:c}v[g+700>>2]=c}if((c|0)!=(e|0)){break c}Eb(f+8|0,a+1074308|0,25);if(j=!Cb(f+8|0),k=0,l=v[a+480180>>2]!=1,l?j:k){break c}v[b+708>>2]=0}jb=f+16|0}function Dy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0;a:{if(!De(a)){break a}nn(a);if(c){c=b;o=jb-16|0;jb=o;f=a;if(De(a)){e=x[f+34>>1];p=v[f+4>>2];h=v[f+8>>2];n=v[f>>2];s=!(e&2)|(p>>>0>=h>>>0|n>>>0<h>>>0);q=v[f+12>>2];g=v[f+16>>2];z=!(e&8)|(q>>>0>=g>>>0|g>>>0>n>>>0);A=c+1304360|0;d=c+1074984|0;k=e&4;m=e&16;while(1){b:{if((f|0)!=v[d+104>>2]){break b}c=v[d+76>>2];if(!c){break b}c:{d:{e:{j=d;f:{g:{if(z){break g}i=v[d+88>>2];if(i&2048){break g}v[d+84>>2]=g;v[d+80>>2]=q;e=m;c=g;break f}if(s){break e}v[d+84>>2]=h;v[d+80>>2]=p;i=v[d+88>>2];e=k;c=h}v[j+76>>2]=c;l=i|2;v[d+88>>2]=l;r=d+88|0;j=1;if(!e){break d}i=i|6;j=1;e=1;break c}l=v[d+88>>2]&-3;v[d+88>>2]=l;r=d+88|0;j=0}i=l&-5;e=0}v[d+88>>2]=i;if(y[d+4>>2]>c>>>0){i=i&-129;v[d+88>>2]=i;l=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=l}if(!e){v[r>>2]=i&-129}if(j){break b}v[d+76>>2]=n}d=d+896|0;if((A|0)!=(d|0)){continue}break}}jb=o+16|0}if((sq(a)|0)==2){d=0;f=jb+-64|0;jb=f;e=ue(a);j=e<<6;h=v[a+20>>2];g=h+(B(e,v[a>>2])<<1)|0;while(1){if(e){k=B(d,e);m=B(e,d^-1);c=0;while(1){u[g+(c+k<<1)>>1]=x[g+(c-e<<1)>>1];u[h+(c+m<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<5)|0;c=x[a+34>>1];if(c&2){k=v[a+8>>2];g=v[a+4>>2];Eb(f+32|0,b+1074308|0,33);eO(f+40|0,d,h+(B(e,g)<<1)|0,k-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Eb(f+32|0,b+1074308|0,33);eO(f+8|0,d+(j<<1)|0,h+(B(a,e)<<1)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}jb=f- -64|0;return}if((sq(a)|0)!=1){break a}d=0;f=jb+-64|0;jb=f;e=ue(a);j=e<<6;h=v[a+20>>2];g=h+B(e,v[a>>2])|0;while(1){if(e){k=B(d,e);m=B(e,d^-1);c=0;while(1){t[g+(c+k|0)|0]=w[g+(c-e|0)|0];t[h+(c+m|0)|0]=w[c+h|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<4)|0;c=x[a+34>>1];if(c&2){k=v[a+8>>2];g=v[a+4>>2];Eb(f+32|0,b+1074308|0,33);dO(f+40|0,d,h+B(e,g)|0,k-g|0,e,(c&4)>>>2|0,Cb(f+32|0));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];Eb(f+32|0,b+1074308|0,33);dO(f+8|0,d+j|0,h+B(a,e)|0,g-a|0,e,(c&16)>>>4|0,Cb(f+32|0))}jb=f- -64|0}}function xD(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=jb-128|0;jb=j;a:{b:{c:{if(!el(f,g,h,i,0,0,0,0)){break c}k=f;m=g;p=h;n=i&65535;o=i>>>16&32767;d:{e:{if((o|0)!=32767){l=4;if(o){break e}l=k|p|(m|n)?3:2;break d}l=!(k|p|(m|n))}}r=e>>>16|0;n=r&32767;if((n|0)==32767){break c}if(l){break b}}td(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];pF(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}l=n<<16;o=d;q=l|e&65535;m=q;q=i>>>16&32767;k=i&65535|q<<16;if((el(b,c,o,m,f,g,h,k)|0)<=0){if(el(b,c,o,m,f,g,p,k)){h=b;i=c;break a}td(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(n){i=c;h=b}else{td(j+96|0,b,c,o,m,0,0,0,1081540608);h=v[j+108>>2];m=h;o=v[j+104>>2];n=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){td(j+80|0,f,g,p,k,0,0,0,1081540608);f=v[j+92>>2];k=f;p=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;m=m&65535|65536;if((n|0)>(q|0)){while(1){k=o;l=p;t=k-l|0;l=m-((k>>>0<l>>>0)+s|0)|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;l=l-(k>>>0>t>>>0)|0;k=t-k|0;f:{if((l|0)>0?1:(l|0)>=0){m=h;h=h-f|0;i=i-((f>>>0>m>>>0)+g|0)|0;if(!(h|k|(i|l))){td(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}l=l<<1|k>>>31;o=k<<1|i>>>31;break f}l=m<<1|o>>>31;o=o<<1|i>>>31}m=l;l=i<<1|h>>>31;h=h<<1;i=l;n=n-1|0;if((q|0)<(n|0)){continue}break}n=q}l=o;q=l-p|0;k=m-((l>>>0<p>>>0)+s|0)|0;l=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=k-(l>>>0>q>>>0)|0;p=q-l|0;g:{if((k|0)<0){p=o;k=m;break g}o=h;h=h-f|0;i=i-((f>>>0>o>>>0)+g|0)|0;if(h|p|(i|k)){break g}td(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;n=n-1|0;m=i<<1|h>>>31;h=h<<1;i=m;c=b;b=p;k=k<<1|b>>>31;p=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((n|0)<=0){td(j- -64|0,h,i,p,k&65535|(b|n+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=p;e=k&65535|(b|n)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;jb=j+128|0}function nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0;e=jb-80|0;jb=e;u=v[a+16>>2];h=Qf(e+48|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];x=h,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[h+16>>2];if(b){x=h,y=Pf(a+8|0,b),v[x>>2]=y;v[h+4>>2]=mb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];i=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=i;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){b=0;f=b;j=g;v[e+72>>2]=g;v[e+76>>2]=b;i=(((i&2147483647)<<1|g>>>31)&-2)+u|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|j>>>31;Ad(v[h+8>>2],t[(g|1)+i|0]+t[i+(g&-2)|0]<<5);zd(v[h+8>>2],4);Sb(e+72|0,h);if((b|0)<2){break b}b=b-1|0;j=v[e+72>>2];f=v[e+76>>2];continue}}b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(f,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}d=d-1|0;f=Kf(b,v[h+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];l=k;i=(e+32|0)+(j<<3)|0;p=v[i>>2];b=Yb(p,-16777216,16776704);s=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);q=v[a+68>>2];w=q;q=q>>31;v[i+4>>2]=p;p=v[a+72>>2];r=k>>31;k=f<<8;f=k;f=Fma(l,r,f,f>>31);l=mb;r=(e+8|0)+(j<<2)|0;j=Fma(s,s>>31,b,b>>31);f=j+f|0;b=mb+l|0;b=f>>>0<j>>>0?b+1|0:b;l=f;f=Fma(w,q,g,g>>31);g=l+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[r>>2]=(b|0)/256;v[i>>2]=b-(k&p);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;g=v[e+24>>2];i=v[e+28>>2];continue}break}g=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=i;jb=e+80|0}
function fL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;e=B(b,896)+a|0;a:{if(w[e+1075074|0]&2){j=1;b:{if(!(w[a+480209|0]&16)){break b}j=0;if(!(v[a+480180>>2]&16777248)){break b}j=!(w[a+480208|0]&4)}if(v[a+480180>>2]==64){a=B(b,896)+a|0;b=a+1075823|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075828|0],167)}t[b|0]=d+1;break a}g=e+1074984|0;c:{if(!j){break c}Eb(h+8|0,a+1074308|0,21);if(!Cb(h+8|0)){break c}e=B(b,896)+a|0;f=e+1075823|0;t[f|0]=w[f|0]+(w[e+1075827|0]<<2)}f=B(b,896)+a|0;i=f+1075826|0;k=f+1075823|0;e=Hx(a,w[i|0],w[k|0]);d:{if(tj(g)){z[d>>2]=C(C(B(w[f+1075828|0],e)|0)*C(6510417279059766e-21))+z[d>>2];c=f+1075856|0;d=w[c|0];t[c|0]=d&243|8;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break d}t[c|0]=d|12;break d}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}e=v[a+480180>>2]&5?(w[i|0]&3)==1?0-e|0:e:e;g=a+1074308|0;Eb(h+8|0,g,21);d=Cb(h+8|0);f=v[a+480208>>2];e:{if(d){d=f&4;e=d?e:0-e|0;d=d?5:6;break e}d=5;f:{if(f&131072){break f}d=8;if(v[a+480180>>2]==1024){break f}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break f}d=6}Eb(h+8|0,g,80);if(!Cb(h+8|0)){break e}d=w[(B(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(B(w[(B(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;f=0-d|0;g:{if(!(w[a+480208|0]&16)|v[a+480180>>2]==4){break g}e=v[c>>2];if((d|0)<=-1){d=_x(a,f>>>2|0);d=yc(Gma(Fma(d,d>>31,e,e>>31),mb,65536,0),mb);e=v[c>>2];d=d-e|0;g=f&3;if(!g){break g}i=d;d=eM(a,g);d=(i+yc(Gma(Fma(d,d>>31,e,e>>31),mb,65536,0),mb)|0)-v[c>>2]|0;break g}g=d&3;d=Zx(a,d>>>2|0);d=yc(Gma(Fma(d,d>>31,e,e>>31),mb,65536,0),mb);e=v[c>>2];d=d-e|0;if(!g){break g}i=d;d=dM(a,g);d=(i+yc(Gma(Fma(d,d>>31,e,e>>31),mb,65536,0),mb)|0)-v[c>>2]|0}v[c>>2]=v[c>>2]+d;c=$x(a,b);if(!c){break d}d=c;e=f<<16>>16;g=v[(B(b,896)+a|0)+1075640>>2];i=2;h:{if(!g){break h}i=w[g+33|0]}nb[v[v[c>>2]+84>>2]](d,e,i<<24>>24,b)}if(!j){break a}Eb(h+8|0,a+1074308|0,21);if(Cb(h+8|0)){break a}t[k|0]=w[k|0]+w[(B(b,896)+a|0)+1075827|0];break a}if(!(w[e+1075654|0]&2)){break a}a=$x(a,b);if(!a){break a}nb[v[v[a>>2]+84>>2]](a,0,0,b)}jb=h+16|0}function Uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-48|0;jb=g;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}t=b;w=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;m=v[a+48>>2];v[g+36>>2]=m;k=v[a+52>>2];v[g+40>>2]=k;l=v[a+56>>2];v[g+44>>2]=l;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=i;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+w|0;e=(j>>>16&65520)+t|0;j=u[e+14>>1];i=u[e+12>>1];l=u[e+10>>1];q=u[e+8>>1];x=u[e+6>>1];n=u[e+4>>1];r=u[e+2>>1];s=u[e>>1];h=0;k=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],r)+B(u[b+(e|-12)>>1],s)|0)+B(u[b+(e|-4)>>1],n)|0)+B(u[b+e>>1],x)|0)+B(u[b+(e|4)>>1],q)|0)+B(u[b+(e|8)>>1],l)|0)+B(i,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=k&1;k=0;f=1;if(e){continue}break}while(1){k=(g+8|0)+(h<<2)|0;j=v[k>>2];i=v[a+60>>2];e=(g+32|0)+(h<<3)|0;h=v[e>>2];b=Yb(h,-16777216,16776704);q=v[a+64>>2];f=Yb(v[e+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[e+4>>2]=h;s=v[a+72>>2];j=j<<8;h=j;h=Fma(i,i>>31,h,h>>31);i=mb;l=k;k=Fma(q,q>>31,b,b>>31);h=k+h|0;b=mb+i|0;b=h>>>0<k>>>0?b+1|0:b;i=h;h=Fma(r,n,f,f>>31);f=i+h|0;b=mb+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[l>>2]=(b|0)/256;v[e>>2]=b-(j&s);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);o=b+o|0;b=o>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];k=v[g+40>>2];m=v[g+36>>2];h=v[g+32>>2];break e}b=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;jb=g+48|0}function sl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;a:{b:{if(nd(a)|y[a+12>>2]<=y[b+4>>2]){break b}c=x[b+8>>1]>=lk(a)>>>0;g=x[b+8>>1];if((g|0)!=65535?c:0){break b}f=g;if((f&65535)==65535){g=lk(a)-1|0;f=0}d=Xe(a,v[b+4>>2],f&65535);i=w[b+12|0];k=i&4;c:{d:{if(i&2){break d}l=g&65535;if(l>>>0<(f&65535)>>>0){break d}j=w[b+10|0];e=f;c=d;while(1){e:{if(!k){if((j|0)!=w[c+3|0]){break e}break c}if((j|0)==w[c+2|0]){break c}}c=c+6|0;e=e+1|0;if((e&65535)>>>0<=l>>>0){continue}break}}j=g&65535;if(j>>>0>=(f&65535)>>>0){e=f;c=d;while(1){f:{if(!k){if(w[c+3|0]){break f}t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break c}if(w[c+2|0]){break f}t[c+2|0]=w[b+10|0];t[c+4|0]=w[b+11|0];break c}c=c+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(i&1)){break g}i=v[Wm(a)+480180>>2]&2;e=w[b+12|0];h:{if(e&4){break h}g=g&65535;if(g>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(w[d+3|0]-9|0){case 4:if(!CK(v[Wm(a)+8>>2],1)){break i}c=1;t[d+2|0]=1;t[d+4|0]=w[d+5|0];t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}c=d;k:{if(i){e=w[d+5|0];if(e>>>0>128){break i}t[d+2|0]=2;t[d+3|0]=w[b+10|0];a=1;break k}t[d+2|0]=2;t[d+3|0]=w[b+10|0];e=w[d+5|0];a=2}t[c+4|0]=a+e>>>a;t[d+5|0]=w[b+11|0];break c}d=d+6|0;f=f+1|0;if(g>>>0>=(f&65535)>>>0){continue}break}e=w[b+12|0]}l:{if(e&4){c=w[b+11|0];d=13;m:{switch(w[b+10|0]-1|0){case 1:c=un(B(i?2:4,c));e=w[b+12|0];d=9;break;case 0:break m;default:break l}}t[b+11|0]=c;t[b+10|0]=d;e=e&254;t[b+12|0]=e;break l}f=w[b+11|0];t[h+14|0]=f;d=b;c=w[b+10|0];n:{o:{if(!(!i|(c|0)!=9)){if(f>>>0>128){break n}c=2;f=(f&254)>>>1|0;break o}t[h+15|0]=c;if(!tx(h+15|0,h+14|0,1)){break n}c=w[h+15|0];if(!c){break n}e=w[b+12|0];f=w[h+14|0]}t[d+11|0]=f;t[b+10|0]=c;t[b+12|0]=e&254}e=w[b+12|0]}c=1;if(e&1){break g}t[b+12|0]=e^4;if(sl(a,b)){break a}}p:{q:{d=v[b>>2];if((d|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){break q}d=v[b>>2]}if((d|0)!=2){break b}c=0;d=v[b+4>>2];if(!d){break a}v[b+4>>2]=d-1;break p}v[b+4>>2]=v[b+4>>2]+1}t[b+12|0]=w[b+12|0]|1;c=sl(a,b);break a}c=1;break a}c=0}jb=h+16|0;return c|0}function Vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;e=jb-48|0;jb=e;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}w=b;x=v[a+16>>2];g=v[a+44>>2];v[e+32>>2]=g;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;o=v[a+40>>2];p=v[a+36>>2];h=v[a+4>>2];j=v[a>>2];v[e+24>>2]=j;v[e+28>>2]=h;v[e+16>>2]=i;v[e+20>>2]=f;e:{if(d){while(1){h=(((h&2147483647)<<1|j>>>31)&-2)+x|0;b=(j>>>16&65520)+w|0;f=u[b+14>>1];j=u[b+12>>1];i=u[b+10>>1];l=u[b+8>>1];q=u[b+6>>1];y=u[b+4>>1];n=u[b+2>>1];r=u[b>>1];g=0;m=1;k=1;b=0;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[h+(b|-4)|0],n)+B(t[h+(b|-6)|0],r)|0)+B(t[h+(b|-2)|0],y)|0)+B(t[b+h|0],q)|0)+B(t[h+(b|2)|0],l)|0)+B(t[h+(b|4)|0],i)|0)+B(j,t[h+(b|6)|0])|0)+B(f,t[h+(b|8)|0])<<8)/32768;s=k&1;k=0;b=1;if(s){continue}break}while(1){k=(e+8|0)+(g<<2)|0;j=v[k>>2];i=v[a+60>>2];h=(e+32|0)+(g<<3)|0;g=v[h>>2];b=Yb(g,-16777216,16776704);q=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[h+4>>2]=g;s=v[a+72>>2];j=j<<8;g=j;g=Fma(i,i>>31,g,g>>31);i=mb;l=k;k=Fma(q,q>>31,b,b>>31);g=k+g|0;b=mb+i|0;b=g>>>0<k>>>0?b+1|0:b;i=g;g=Fma(r,n,f,f>>31);f=i+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[l>>2]=(b|0)/256;v[h>>2]=b-(j&s);g=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[e+8>>2]);o=b+o|0;b=o>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;j=v[e+24>>2];h=v[e+28>>2];continue}break}j=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];g=v[e+32>>2];break e}b=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=g;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=h;jb=e+48|0}function T4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb-48|0;jb=k;a:{b:{c:{j=ko(1,32);d:{e:{if(!j){a=ba(4)|0;Zk(a);v[114578]=0;U(2009,a|0,71204,2008);a=v[114578];v[114578]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+16>>2]=0;v[j+20>>2]=0;v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j+24>>2]=0;v[j+28>>2]=0;v[j>>2]=c?c:1997;d=Ks(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,k+16|0,c|0)|0;f=v[114578];v[114578]=0;i:{if((f|0)!=1){v[114578]=0;f=Q(2010,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break i}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}v[114578]=0;c=Q(85,k+16|0,c|0)|0;e=v[114578];v[114578]=0;j:{if((e|0)!=1){v[114578]=0;Q(2011,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114578]=0;c=T(1400,96)|0;e=v[114578];v[114578]=0;k:{l:{m:{if((e|0)!=1){v[114578]=0;U(2012,k+16|0,j|0,j+4|0);e=v[114578];v[114578]=0;if((e|0)==1){break m}e=Ho(k+8|0,k+16|0);v[114578]=0;ea(2087,c|0,a|0,b|0,e|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break l}v[j+28>>2]=c;Yc(e);Yc(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;tk(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;Yc(e);Yc(k+16|0)}Xb(c)}tk(d);_(i|0)|0;v[114578]=0;X(1989,37255,j|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){a=v[j+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[114578]=0;X(1989,37255,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=k+48|0;return j|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}
function rH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;d=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;c=e;a:{b:{switch(v[d+40>>2]){case 0:b=jb-80|0;jb=b;f=v[c>>2];h=v[f+4>>2];v[b+40>>2]=v[f+20>>2];j=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=j;Lm(b- -64|0,b+32|0,h);f=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];l=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;m=b+16|0;c=b;h=jb-16|0;jb=h;if(j){while(1){f=0;if(l){while(1){i=A[ch(c,f,k)>>3];fc(d,f);A[h+8>>3]=i;Rf(h+8|0,-1,1);i=A[h+8>>3]*32768;A[h+8>>3]=i;i=Sd(i);c:{if(D(i)<2147483648){g=~~i;break c}g=-2147483648}g=Vc(g);q=Km(m,f,k),r=g,u[q>>1]=r;f=f+1|0;if((l|0)!=(f|0)){continue}break}}k=k+1|0;if((j|0)!=(k|0)){continue}break}}jb=h+16|0;jb=b+80|0;break a;case 2:Hw(c,zb(d));break a;case 3:k=Ug(d);b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];v[b+40>>2]=v[d+20>>2];j=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=j;Lm(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];l=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;m=b+16|0;c=b;d=jb-16|0;jb=d;if(j){n=k+16|0;while(1){h=0;if(l){while(1){i=Sd(A[ch(c,h,f)>>3]*134217728);g=Ve(k,h);o=g;g=sj(i)+(v[g>>2]>>1)|0;p=g;g=Jr(n)+g&-4096;v[o>>2]=p-g;A[d+8>>3]=+(g|0)*7.450580596923828e-9;Rf(d+8|0,-1,1);i=A[d+8>>3]*32768;A[d+8>>3]=i;i=Sd(i);d:{if(D(i)<2147483648){g=~~i;break d}g=-2147483648}g=Vc(g);q=Km(m,h,f),r=g,u[q>>1]=r;h=h+1|0;if((l|0)!=(h|0)){continue}break}}f=f+1|0;if((j|0)!=(f|0)){continue}break}}jb=d+16|0;jb=b+80|0;break a;case 1:Hw(c,zb(d));break a;default:break b}}Hw(c,zb(d))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function OZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=jb-1072|0;jb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+956>>2]=a+960;j=bw(a+960|0,100,64687,a+16|0);v[a+48>>2]=2427;n=Rd(a+536|0,0,a+48|0);v[a+48>>2]=2427;m=Rd(a+528|0,0,a+48|0);l=a+544|0;a:{b:{c:{if(j>>>0>=100){v[114578]=0;j=da(2452)|0;l=v[114578];v[114578]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[114578]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=aa(2474,a+956|0,j|0,64687,a|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}f=v[a+956>>2];if(!f){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}ye(n,f);ye(m,pd(j<<2));if(qj(m)){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[114578]=0;Bc(a+520|0,d);f=v[114578];v[114578]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[114578]=0;p=T(2456,a+520|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}v[114578]=0;f=v[a+956>>2];aa(2470,p|0,f|0,f+j|0,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}o=j?w[v[a+956>>2]]==45:o;h=Wb(a+488|0);g=tf(a+472|0);f=tf(a+456|0);v[114578]=0;na(2510,c|0,o|0,a+520|0,a+512|0,a+508|0,a+504|0,h|0,g|0,f|0,a+452|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}v[a+36>>2]=2427;i=Rd(a+40|0,0,a+36|0);c=v[a+452>>2];k:{if((c|0)<(j|0)){k=Fb(f)+(j-c<<1|1)|0;break k}k=Fb(f)+2|0}c=a+48|0;k=(Fb(g)+k|0)+v[a+452>>2]|0;if(k>>>0<101){break h}ye(i,pd(k<<2));c=v[i>>2];if(c){break h}v[114578]=0;Y(2428);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[114578]=0;sa(2511,c|0,a+36|0,a+32|0,k|0,l|0,(j<<2)+l|0,p|0,o|0,a+512|0,v[a+508>>2],v[a+504>>2],h|0,g|0,f|0,v[a+452>>2]);j=v[114578];v[114578]=0;if((j|0)!=1){v[114578]=0;b=ka(2486,b|0,c|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break d}}}j=P()|0;O()|0;Gc(i)}Lc(f);Lc(g);yb(h)}Ob(a+520|0);break a}Gc(i);Lc(f);Lc(g);yb(h);Ob(a+520|0);Gc(m);Gc(n);jb=a+1072|0;return b|0}L()}j=P()|0;O()|0}Gc(m);Gc(n);S(j|0);L()}function uga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb+-64|0;jb=d;u[d+62>>1]=c;jg(d+62|0,32);f=Ql(a);v[114578]=0;R(795,f|0,x[d+62>>1]);a=v[114578];v[114578]=0;a:{if((a|0)!=1){b:{c:{if(!x[d+62>>1]){break c}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}u[d+24>>1]=1;f:{if(!x[b+480190>>1]){break f}while(1){g:{if(De(vp(b,x[d+24>>1]))){break g}i=d,j=iz(bc(f),cc(f),d+24|0),v[i+48>>2]=j;i=d,j=cc(f),v[i+40>>2]=j;if(!rl(d+48|0,d+40|0)){break g}u[d+60>>1]=x[d+24>>1];a=1;if(!x[b+480192>>1]){break f}while(1){c=v[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=ct(c);if((c|0)==(e|0)){break h}while(1){if(x[c>>1]==x[d+60>>1]){u[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if(x[b+480192>>1]>=(a&65535)>>>0){continue}break}break f}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break e}a=kt(d+48|0);v[114578]=0;c=Q(1050,b|0,a|0)|0;e=v[114578];v[114578]=0;i:{j:{if((e|0)==1){break j}k:{if(c){v[114578]=0;Q(1051,b|0,a|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break j}e=1;if(!x[b+480192>>1]){break k}while(1){c=v[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=ct(c);if((c|0)==(g|0)){break l}while(1){m:{if(y[a+4>>2]<=x[c>>1]){break m}ee(d+40|0,a,x[c>>1]);if(Cb(d+40|0)){break m}u[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break k}ke(a);break c}uj(d+24|0,a);v[114578]=0;U(1052,d+32|0,d+24|0,1);c=v[114578];v[114578]=0;if((c|0)!=1){xk(d+16|0,a);v[114578]=0;t[d+15|0]=0;X(1053,d+40|0,d+32|0,d+16|0,d+15|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}}}c=P()|0;O()|0;ke(a);break a}uj(d,a);i=d,j=Ci(d+40|0,d),u[i+60>>1]=j;ke(a);if(x[d+60>>1]>=4e3){break d}}v[114578]=0;R(463,f|0,d+60|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}if(x[b+480190>>1]>=x[d+60>>1]){break d}u[b+480190>>1]=x[d+60>>1]}h=h+1|0;if(x[d+62>>1]>(h&65535)>>>0){continue}break}}jb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}kf(f);S(c|0);L()}function qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=jb-80|0;jb=e;q=v[a+16>>2];i=Qf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];x=i,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[i+16>>2];if(b){x=i,y=Pf(a+8|0,b),v[x>>2]=y;v[i+4>>2]=mb}b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;h=v[a+52>>2];v[e+40>>2]=h;l=v[a+56>>2];v[e+44>>2]=l;r=v[a+24>>2];s=v[a+20>>2];j=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=j;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){b=0;g=b;h=f;v[e+72>>2]=f;v[e+76>>2]=b;j=((((j&2147483647)<<1|f>>>31)&2147483646)<<1)+q|0;a:{b=v[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|h>>>31;Ad(v[i+8>>2],(u[(f<<1|2)+j>>1]+u[j+((f&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break a}b=b-1|0;h=v[e+72>>2];g=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];f=v[b+4>>2];if(f){k=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(k,(u[(b<<1|2)+j>>1]+u[j+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[i+8>>2],f);b=v[i+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;h=Kf(b,v[i+12>>2]);v[e+12>>2]=h;v[e+8>>2]=h;g=0;l=1;while(1){k=v[a+60>>2];o=k;j=(e+32|0)+(g<<3)|0;m=v[j>>2];b=Yb(m,-16777216,16776704);p=v[a+64>>2];f=Yb(v[j+4>>2],-16777216,16776704);n=v[a+68>>2];t=n;n=n>>31;v[j+4>>2]=m;m=v[a+72>>2];k=k>>31;h=h<<8;k=Fma(o,k,h,h>>31);o=mb;w=(e+8|0)+(g<<2)|0;g=k;k=Fma(p,p>>31,b,b>>31);g=g+k|0;b=mb+o|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=Fma(t,n,f,f>>31);f=k+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[w>>2]=(b|0)/256;v[j>>2]=b-(h&m);if(l){g=1;l=0;h=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],r);Sb(e+24|0,e+16|0);if(d){c=c+8|0;f=v[e+24>>2];j=v[e+28>>2];continue}break}f=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];h=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=h;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=f;v[a+4>>2]=j;jb=e+80|0}function SZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;a=jb-464|0;jb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;v[a+348>>2]=a+352;j=bw(a+352|0,100,64687,a+16|0);v[a+48>>2]=2427;n=Rd(a+232|0,0,a+48|0);v[a+48>>2]=2427;m=Rd(a+224|0,0,a+48|0);l=a+240|0;a:{b:{c:{if(j>>>0>=100){v[114578]=0;j=da(2452)|0;l=v[114578];v[114578]=0;if((l|0)==1){break b}v[a>>2]=f;v[a+4>>2]=g;v[114578]=0;v[a+8>>2]=h;v[a+12>>2]=i;j=aa(2474,a+348|0,j|0,64687,a|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}f=v[a+348>>2];if(!f){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}ye(n,f);ye(m,pd(j));if(qj(m)){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)==1){break b}break c}l=v[m>>2]}v[114578]=0;Bc(a+216|0,d);f=v[114578];v[114578]=0;d:{e:{f:{g:{h:{i:{j:{if((f|0)!=1){v[114578]=0;p=T(21,a+216|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}v[114578]=0;f=v[a+348>>2];aa(2447,p|0,f|0,f+j|0,l|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break j}o=j?w[v[a+348>>2]]==45:o;h=Wb(a+192|0);g=Wb(a+176|0);f=Wb(a+160|0);v[114578]=0;na(2508,c|0,o|0,a+216|0,a+208|0,a+207|0,a+206|0,h|0,g|0,f|0,a+156|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}v[a+36>>2]=2427;i=Rd(a+40|0,0,a+36|0);c=v[a+156>>2];k:{if((c|0)<(j|0)){k=Fb(f)+(j-c<<1|1)|0;break k}k=Fb(f)+2|0}c=a+48|0;k=(Fb(g)+k|0)+v[a+156>>2]|0;if(k>>>0<101){break h}ye(i,pd(k));c=v[i>>2];if(c){break h}v[114578]=0;Y(2428);b=v[114578];v[114578]=0;if((b|0)!=1){break c}break g}j=P()|0;O()|0;break a}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}k=v[d+4>>2];v[114578]=0;sa(2509,c|0,a+36|0,a+32|0,k|0,l|0,j+l|0,p|0,o|0,a+208|0,t[a+207|0],t[a+206|0],h|0,g|0,f|0,v[a+156>>2]);j=v[114578];v[114578]=0;if((j|0)!=1){v[114578]=0;b=ka(17,b|0,c|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break d}}}j=P()|0;O()|0;Gc(i)}yb(f);yb(g);yb(h)}Ob(a+216|0);break a}Gc(i);yb(f);yb(g);yb(h);Ob(a+216|0);Gc(m);Gc(n);jb=a+464|0;return b|0}L()}j=P()|0;O()|0}Gc(m);Gc(n);S(j|0);L()}function Cka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0);c=jb+-64|0;jb=c;e=jb-16|0;jb=e;f=b+16|0;FR(e+8|0,f);d=a;g=Hb(e+8|0);h=nc(a,ac(e,e+8|0));if((g|0)==(h|0)){$b(d,Hb(e+8|0))}jb=e+16|0;if((g|0)!=(h|0)){d=jb-16|0;jb=d;Rb(f,0,128);jb=d+16|0}dS(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;ud(c+48|0,a,Cf(a));v[114578]=0;d=T(332,c+48|0)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)==1){break b}v[114578]=0;e=b+4|0;R(508,e|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(698,c+40|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;Q(699,c+48|0,c+40|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;d=T(392,a|0)|0;e=v[114578];v[114578]=0;c:{if((e|0)==1){break c}v[114578]=0;U(343,c+24|0,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}v[114578]=0;a=T(339,c+24|0)|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){e:{f:{g:{if(!a){break g}while(1){v[114578]=0;a=Q(258,c+24|0,5)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if(!a){break g}v[114578]=0;Q(700,c+24|0,c+20|0)|0;a=v[114578];v[114578]=0;h:{if((a|0)!=1){a=4;if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))==1414682436|(w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))==1196380752){break h}v[114578]=0;a=T(392,c+24|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[114578]=0;U(343,c|0,c+24|0,a|0);a=v[114578];v[114578]=0;i:{j:{if((a|0)!=1){if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))!=1414682436){break j}v[114578]=0;i=C(Aa(701,c|0));a=v[114578];v[114578]=0;if((a|0)==1){break e}z[b+144>>2]=i;break i}a=P()|0;O()|0;break d}if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))!=1196380752){break i}v[114578]=0;a=T(392,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}v[b+148>>2]=a}Bb(c);continue}}Bb(c+24|0);Bb(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0;Bb(c);break d}a=P()|0;O()|0}Bb(c+24|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Bb(c+48|0);S(a|0);L()}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=jb-208|0;jb=c;f=1;e=v[a+12>>2];k=1<<e;n=2;if(e>>>0>=2){j=k;while(1){j=j>>>2|0;if(j){p=B(f,3);q=f<<1;l=0;while(1){PK(c+192|0,tc(a,l<<1));PK(c+176|0,tc(a,l));Jh(c+160|0,c+176|0,c+192|0);e=l<<n;o=f+e|0;if(e>>>0<o>>>0){while(1){d=tc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+f|0;d=tc(b,g);h=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=h;h=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=h;h=e+q|0;d=tc(b,h);m=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=m;m=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=m;m=e+p|0;d=tc(b,m);i=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=i;i=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=i;ok(c+80|0,c+144|0,c+128|0);vi(c- -64|0,c+144|0,c+128|0);ok(c+48|0,c+112|0,c+96|0);vi(c+16|0,c+112|0,c+96|0);Jh(c+32|0,30864,c+16|0);ok(c+16|0,c+80|0,c+48|0);d=tc(b,e);i=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=i;i=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=i;ok(c,c- -64|0,c+32|0);Jh(c+16|0,c+192|0,c);d=tc(b,g);i=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=i;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;vi(c,c+80|0,c+48|0);Jh(c+16|0,c+176|0,c);d=tc(b,h);h=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=h;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;vi(c,c- -64|0,c+32|0);Jh(c+16|0,c+160|0,c);d=tc(b,m);h=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=h;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((o|0)!=(e|0)){continue}break}}l=l+1|0;if((l|0)!=(j|0)){continue}break}e=v[a+12>>2]}f=f<<2;n=n+2|0;if(n>>>0<=e>>>0){continue}break}}a:{if(!(e&1)){break a}j=k>>>1|0;if(!j){break a}e=0;while(1){k=e+j|0;a=tc(b,k);f=v[a+12>>2];v[c+200>>2]=v[a+8>>2];v[c+204>>2]=f;f=v[a+4>>2];v[c+192>>2]=v[a>>2];v[c+196>>2]=f;vi(c+176|0,tc(b,e),c+192|0);a=tc(b,k);f=v[c+188>>2];v[a+8>>2]=v[c+184>>2];v[a+12>>2]=f;k=v[c+180>>2];v[a>>2]=v[c+176>>2];v[a+4>>2]=k;xx(tc(b,e),c+192|0);e=e+1|0;if((j|0)!=(e|0)){continue}break}}jb=c+208|0}function Pv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[21203]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[f|0];if(d){v[a>>2]=d&57343;a=a+4|0;f=f+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return $e(f)|0}e=1;break g}e=0;break h}e=1}while(1){if(!e){e=w[f|0]>>>3|0;if((e-16|e+(g>>26))>>>0>7){break f}h=f+1|0;e=h;n:{if(!(g&33554432)){break n}if((w[h|0]&192)!=128){break f}h=f+2|0;e=h;if(!(g&524288)){break n}if((w[h|0]&192)!=128){break f}e=f+3|0}f=e;d=d-1|0;e=1;continue}while(1){g=w[f|0];o:{if(f&3|g-1>>>0>126){break o}g=v[f>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[f+4>>2];e=f+4|0;f=e;if(!((g-16843009|g)&-2139062144)){continue}break}f=e}e=g&255;if(e-1>>>0<=126){d=d-1|0;f=f+1|0;continue}break}e=e-194|0;if(e>>>0>50){break e}f=f+1|0;g=v[(e<<2)+60112>>2];e=0;continue}}while(1){if(!e){if(!d){break a}while(1){p:{e=w[f|0];h=e-1|0;q:{r:{if(h>>>0>126){g=e;break r}if(f&3|d>>>0<5){break q}s:{while(1){g=v[f>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[f+1|0];v[a+8>>2]=w[f+2|0];v[a+12>>2]=w[f+3|0];a=a+16|0;f=f+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[f|0]}e=g&255;h=e-1|0}if(h>>>0>126){break p}}v[a>>2]=e;a=a+4|0;f=f+1|0;d=d-1|0;if(d){continue}break a}break}e=e-194|0;if(e>>>0>50){break e}f=f+1|0;g=v[(e<<2)+60112>>2];e=1;continue}h=w[f|0];e=h>>>3|0;if((e-16|e+(g>>26))>>>0>7){break f}t:{u:{i=f+1|0;e=h-128|g<<6;h=i;v:{if((e|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}i=f+2|0;e=h|e<<6;h=i;if((e|0)>-1){break v}h=w[i|0]-128|0;if(h>>>0>63){break u}e=h|e<<6;h=f+3|0}f=h;v[a>>2]=e;d=d-1|0;a=a+4|0;break t}v[114552]=25;f=f-1|0;break c}e=0;continue}}f=f-1|0;if(g){break d}g=w[f|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[114552]=25;if(!a){break b}}v[b>>2]=f}return-1}v[b>>2]=f;return c|0}function s9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{switch(b|0){case 0:e=jb-16|0;jb=e;f=Wb(a);c:{d:{if(Fb(c)){while(1){d=v[hj(c,i)>>2];e:{if(d>>>0>=2097152){v[114578]=0;R(110,f|0,63);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break d}b=0;f:{g:{h:{while(1){h=d&63;t[(e+10|0)+b|0]=h;a=b+1|0;d=d>>>6|0;if(!d){break h}b=a;if((a|0)!=6){continue}break}a=7;b=1;break g}if(!b){v[114578]=0;R(110,f|0,t[e+10|0]);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break d}b=7-b|0;if((a|0)!=2){break g}if((h|0)==1){break f}a=2;b=6}h=a+e|0;b=(-1<<a^-1)<<b;d=a;while(1){i:{j:{if((a|0)==(d|0)){g=w[h+9|0];v[114578]=0;R(110,f|0,(b|g)<<24>>24);g=v[114578];v[114578]=0;if((g|0)==1){break i}d=d-1|0;break j}v[114578]=0;d=d-1|0;R(110,f|0,t[d+(e+10|0)|0]|-128);g=v[114578];v[114578]=0;if((g|0)==1){break i}}if(d){continue}break e}break}break d}v[114578]=0;R(110,f|0,t[e+10|0]|64);a=v[114578];v[114578]=0;if((a|0)==1){break d}}i=i+1|0;if(Fb(c)>>>0>i>>>0){continue}break}}jb=e+16|0;break c}a=P()|0;O()|0;yb(f);S(a|0);L()}return;case 1:b=0;d=Wb(a);a=Fb(c);v[114578]=0;R(111,d|0,a|0);a=v[114578];v[114578]=0;k:{if((a|0)!=1){l:{if(Fb(c)){while(1){a=v[hj(c,b)>>2];m:{if(a>>>0<=127){v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break m}break l}v[114578]=0;R(110,d|0,63);a=v[114578];v[114578]=0;if((a|0)==1){break l}}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break k}}break a}return;case 2:b=0;d=Wb(a);a=Fb(c);v[114578]=0;R(111,d|0,a|0);a=v[114578];v[114578]=0;n:{if((a|0)!=1){o:{if(Fb(c)){while(1){a=v[hj(c,b)>>2];p:{if(a>>>0<=255){v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break p}break o}v[114578]=0;R(110,d|0,63);a=v[114578];v[114578]=0;if((a|0)==1){break o}}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break n}}break a}return;case 3:Ko(a,c,1520);return;case 4:Ko(a,c,2544);return;case 5:Ko(a,c,3568);return;case 6:Ko(a,c,4592);return;case 7:Ko(a,c,5616);return;default:break b}}Wb(a);return}a=P()|0;O()|0;yb(d);S(a|0);L()}function rI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb-48|0;jb=k;a:{b:{c:{d:{e:{f:{j=ko(1,28);if(!j){a=ba(4)|0;Zk(a);v[114578]=0;U(2009,a|0,71204,2008);a=v[114578];v[114578]=0;if((a|0)!=1){break a}break f}v[j+24>>2]=0;v[j+16>>2]=0;v[j+20>>2]=0;v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1997;d=Ks(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[114578]=0;c=Q(85,k+16|0,c|0)|0;f=v[114578];v[114578]=0;j:{if((f|0)!=1){v[114578]=0;f=Q(2010,d|0,c|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break j}v[114578]=0;Q(484,f|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}v[114578]=0;c=Q(85,k+16|0,c|0)|0;e=v[114578];v[114578]=0;k:{if((e|0)!=1){v[114578]=0;Q(2011,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114578]=0;c=T(1400,80)|0;e=v[114578];v[114578]=0;l:{m:{n:{if((e|0)!=1){v[114578]=0;U(2012,k+16|0,j|0,j+4|0);e=v[114578];v[114578]=0;if((e|0)==1){break n}e=Ho(k+8|0,k+16|0);v[114578]=0;ea(2014,c|0,a|0,b|0,e|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}v[j+24>>2]=c;Yc(e);Yc(k+16|0);tk(d);c=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;Yc(e);Yc(k+16|0)}Xb(c)}tk(d);_(i|0)|0;v[114578]=0;X(1989,34745,j|0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Xb(Sr(a))}c=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Xb(a);v[j+20>>2]=0}Xb(j);break d}i=V(0)|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114578]=0;X(1989,34745,0,g|0,h|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=k+48|0;return c|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=jb-48|0;jb=f;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}r=b;s=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=h;v[f+20>>2]=e;if(d){while(1){l=1;e=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;b=(j>>>16&65520)+r|0;j=u[b+14>>1];h=u[b+12>>1];n=u[b+10>>1];o=u[b+8>>1];p=u[b+6>>1];m=u[b+4>>1];q=u[b+2>>1];x=u[b>>1];k=0;b=1;i=0;while(1){g=i<<1;v[(f+8|0)+(i<<2)>>2]=(((((((B(u[e+(g|-8)>>1],q)+B(u[e+(g|-12)>>1],x)|0)+B(u[e+(g|-4)>>1],m)|0)+B(u[e+g>>1],p)|0)+B(u[e+(g|4)>>1],o)|0)+B(u[e+(g|8)>>1],n)|0)+B(u[e+(g|12)>>1],h)|0)+B(j,u[e+(g|16)>>1])|0)/32768;g=b;b=0;i=1;if(g){continue}break}while(1){i=(f+8|0)+(k<<2)|0;j=v[i>>2];h=v[a+60>>2];n=h;g=(f+32|0)+(k<<3)|0;k=v[g>>2];b=Yb(k,-16777216,16776704);o=v[a+64>>2];e=Yb(v[g+4>>2],-16777216,16776704);m=v[a+68>>2];q=m;m=m>>31;v[g+4>>2]=k;k=v[a+72>>2];p=h>>31;j=j<<8;h=j;h=Fma(n,p,h,h>>31);n=mb;p=i;i=h;h=Fma(o,o>>31,b,b>>31);i=i+h|0;b=mb+n|0;b=h>>>0>i>>>0?b+1|0:b;h=i;i=Fma(q,m,e,e>>31);e=h+i|0;b=mb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|e>>>24;v[p>>2]=(b|0)/256;v[g>>2]=b-(j&k);k=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],t);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;jb=f+48|0}function H3(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=C(0),g=C(0),h=0,i=C(0),k=C(0),m=C(0),n=C(0),o=0;d=jb-16|0;jb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if(!((a|0)>-1?a>>>0>=8388608:0)){g=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}g=C(C(c-c)/C(0));if((a|0)<=-1){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;n=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));i=C(c*C(c*C(.5)));k=C(c/C(c+C(2)));f=C(k*k);m=C(f*f);g=c;c=(l(2,(p(C(c-i)),j(2))&-4096),q());f=C(C(C(g-c)-i)+C(k*C(i+C(C(f*C(C(m*C(.2849878668785095))+C(.6666666269302368)))+C(m*C(C(m*C(.24279078841209412))+C(.40000972151756287)))))));c=C(C(n*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(f*C(.434326171875))+C(C(n*C(7.903415166765626e-7))+C(C(f+c)*C(-3168997136526741e-20))))))}g=c}f=C(g*C(2e3));if(!(C(D(f))<C(2147483648))){break c}a=~~f;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=jb-16|0;jb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){d=ba(8)|0;v[114578]=0;b=Q(85,b|0,39833)|0;a=v[114578];v[114578]=0;if((a|0)==1){break k}mc(d,b);v[114578]=0;U(2009,d|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break i}a=P()|0;O()|0;yb(b);break j}jb=b+16|0;a=v[(a<<24>>24<<2)+40536>>2];break h}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}break b;case 3:v[d>>2]=0;e=jb-80|0;jb=e;a=v[a+24>>2]+24604|0;v[e+40>>2]=v[a+32>>2];v[e>>2]=v[a+36>>2];b=v[zf(e+40|0,e)>>2];o=d;l:{if(v[a+32>>2]==v[rp(e+40|0)+32>>2]){h=-1;if(v[a+36>>2]==v[rp(e)+36>>2]){break l}}h=0;if((b|0)<1){break l}h=(b+500|0)/1e3|0}v[o>>2]=h;jb=e+80|0;a=v[d>>2];break b;default:break d}}e=ba(8)|0;v[114578]=0;d=Q(85,d|0,38669)|0;a=v[114578];v[114578]=0;m:{if((a|0)!=1){mc(e,d);v[114578]=0;U(2009,e|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break m}b=P()|0;O()|0;ca(e|0)}S(b|0);L()}a=-2147483648}jb=d+16|0;return a|0}L()}function rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0;e=jb-80|0;jb=e;q=v[a+16>>2];i=Qf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];x=i,y=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[x+12>>2]=y;b=v[i+16>>2];if(b){x=i,y=Pf(a+8|0,b),v[x>>2]=y;v[i+4>>2]=mb}b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;h=v[a+52>>2];v[e+40>>2]=h;l=v[a+56>>2];v[e+44>>2]=l;r=v[a+24>>2];s=v[a+20>>2];j=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=j;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){b=0;g=b;h=f;v[e+72>>2]=f;v[e+76>>2]=b;j=(((j&2147483647)<<1|f>>>31)&-2)+q|0;a:{b=v[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|h>>>31;Ad(v[i+8>>2],t[(f|1)+j|0]+t[j+(f&-2)|0]<<5);zd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break a}b=b-1|0;h=v[e+72>>2];g=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];f=v[b+4>>2];if(f){k=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;Ad(k,t[(b|1)+j|0]+t[j+(b&-2)|0]<<5);zd(v[i+8>>2],f);b=v[i+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}d=d-1|0;h=Kf(b,v[i+12>>2]);v[e+12>>2]=h;v[e+8>>2]=h;g=0;l=1;while(1){k=v[a+60>>2];o=k;j=(e+32|0)+(g<<3)|0;m=v[j>>2];b=Yb(m,-16777216,16776704);p=v[a+64>>2];f=Yb(v[j+4>>2],-16777216,16776704);n=v[a+68>>2];u=n;n=n>>31;v[j+4>>2]=m;m=v[a+72>>2];k=k>>31;h=h<<8;k=Fma(o,k,h,h>>31);o=mb;w=(e+8|0)+(g<<2)|0;g=k;k=Fma(p,p>>31,b,b>>31);g=g+k|0;b=mb+o|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=Fma(u,n,f,f>>31);f=k+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;v[w>>2]=(b|0)/256;v[j>>2]=b-(h&m);if(l){g=1;l=0;h=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],r);Sb(e+24|0,e+16|0);if(d){c=c+8|0;f=v[e+24>>2];j=v[e+28>>2];continue}break}f=v[e+24>>2];j=v[e+28>>2];l=v[e+44>>2];h=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=h;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=f;v[a+4>>2]=j;jb=e+80|0}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=a;d=w[b+2|0];a:{b:{if((d-16&255)>>>0<=128){t[a+2|0]=1;d=(d-16|0)/2|0;break b}c:{switch((d+96&240)>>>4|0){case 0:t[a+2|0]=4;d=d&15;break b;case 1:t[a+2|0]=3;d=d&15;break b;case 2:t[a+2|0]=6;d=d&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;d=d&15}t[c+4|0]=d}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{c=w[b+4|0];if(c>>>0<=28){switch(c|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(c-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((c|0)==128){break e}if((c|0)!=157){break d}t[a+2|0]=15;c=w[b+6|0];t[a+3|0]=20;t[a+4|0]=c>>>3;t[e+15|0]=15;g=a,h=w[pc(b+5|0,e+15|0)|0]|208,t[g+5|0]=h;break d}c=w[b+6|0];d=w[b+5|0];if(!(c|d)){break d}t[a+5|0]=d;t[a+3|0]=c;vj(a);f=w[b+6|0]==15;break d}t[a+3|0]=2;g=a,h=zj(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=3;g=a,h=zj(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=4;g=a,h=zj(w[b+6|0]<<4|w[b+5|0]>>>4),t[g+5|0]=h;break d}t[a+3|0]=5;t[a+5|0]=w[b+6|0]&240|w[b+5|0]>>>4;break d}c=w[b+5|0];if(c){t[a+5|0]=c;t[a+3|0]=9;break d}if((w[b+6|0]-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=w[b+6|0]>>>1;break d}c=w[b+6|0];if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=w[b+5|0]&15;break d}t[a+3|0]=w[b+6|0];t[a+5|0]=w[b+5|0];Ty(a,1);f=(w[a+3|0]&254)==16;break d}t[a+3|0]=18;t[a+5|0]=w[b+5|0];break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1;break d}t[a+3|0]=31;t[a+5|0]=w[b+6|0]>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=w[b+6|0]>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}jb=e+16|0;return f|0}function Zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=jb-48|0;jb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}r=b;s=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;k=v[a+48>>2];v[f+36>>2]=k;j=v[a+52>>2];v[f+40>>2]=j;l=v[a+56>>2];v[f+44>>2]=l;w=v[a+24>>2];x=v[a+20>>2];h=v[a+4>>2];i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=h;v[f+16>>2]=g;v[f+20>>2]=e;if(d){while(1){e=(((h&2147483647)<<1|i>>>31)&-2)+s|0;b=(i>>>16&65520)+r|0;i=u[b+14>>1];g=u[b+12>>1];n=u[b+10>>1];o=u[b+8>>1];p=u[b+6>>1];m=u[b+4>>1];q=u[b+2>>1];y=u[b>>1];j=0;l=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],q)+B(t[e+(b|-6)|0],y)|0)+B(t[e+(b|-2)|0],m)|0)+B(t[b+e|0],p)|0)+B(t[e+(b|2)|0],o)|0)+B(t[e+(b|4)|0],n)|0)+B(t[e+(b|6)|0],g)|0)+B(i,t[e+(b|8)|0])<<8)/32768;h=k;k=0;b=1;if(h){continue}break}while(1){e=(f+8|0)+(j<<2)|0;i=v[e>>2];g=v[a+60>>2];n=g;k=(f+32|0)+(j<<3)|0;j=v[k>>2];b=Yb(j,-16777216,16776704);o=v[a+64>>2];h=Yb(v[k+4>>2],-16777216,16776704);m=v[a+68>>2];q=m;m=m>>31;v[k+4>>2]=j;j=v[a+72>>2];p=g>>31;i=i<<8;g=i;g=Fma(n,p,g,g>>31);n=mb;p=e;e=g;g=Fma(o,o>>31,b,b>>31);e=e+g|0;b=mb+n|0;b=e>>>0<g>>>0?b+1|0:b;g=e;e=Fma(q,m,h,h>>31);h=g+e|0;b=mb+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;v[p>>2]=(b|0)/256;v[k>>2]=b-(i&j);j=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],w);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];l=v[f+44>>2];j=v[f+40>>2];k=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=l;v[a+52>>2]=j;v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=h;jb=f+48|0}function Qq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return pd(b)}if(b>>>0>=4294967232){v[114552]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=v[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=v[116006]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}v[f+4>>2]=j&1|g|2;c=f+g|0;v[c+4>>2]=d|3;v[h+4>>2]=v[h+4>>2]|1;Pq(c,d);break b}if(v[115892]==(h|0)){e=e+v[115889]|0;if(e>>>0<=g>>>0){break a}v[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;v[d+4>>2]=c|1;v[115889]=c;v[115892]=d;break b}if(v[115891]==(h|0)){d=e+v[115888]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){v[f+4>>2]=j&1|g|2;e=f+g|0;v[e+4>>2]=c|1;d=d+f|0;v[d>>2]=c;v[d+4>>2]=v[d+4>>2]&-2;break c}v[f+4>>2]=d|j&1|2;c=d+f|0;v[c+4>>2]=v[c+4>>2]|1;c=0;e=0}v[115891]=e;v[115888]=c;break b}d=v[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=v[h+8>>2];c=d>>>3|0;d=v[h+12>>2];if((d|0)==(e|0)){n=463544,o=v[115886]&Jma(-2,c),v[n>>2]=o;break d}v[e+12>>2]=d;v[d+8>>2]=e;break d}l=v[h+24>>2];i=v[h+12>>2];e:{if((i|0)!=(h|0)){c=v[h+8>>2];v[c+12>>2]=i;v[i+8>>2]=c;break e}f:{e=h+20|0;c=v[e>>2];if(c){break f}e=h+16|0;c=v[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=v[e>>2];if(c){continue}e=i+16|0;c=v[i+16>>2];if(c){continue}break}v[d>>2]=0}if(!l){break d}d=v[h+28>>2];c=(d<<2)+463848|0;g:{if(v[c>>2]==(h|0)){v[c>>2]=i;if(i){break g}n=463548,o=v[115887]&Jma(-2,d),v[n>>2]=o;break d}v[(v[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}v[i+24>>2]=l;c=v[h+16>>2];if(c){v[i+16>>2]=c;v[c+24>>2]=i}c=v[h+20>>2];if(!c){break d}v[i+20>>2]=c;v[c+24>>2]=i}if(m>>>0<=15){v[f+4>>2]=j&1|k|2;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;break b}v[f+4>>2]=j&1|g|2;d=f+g|0;v[d+4>>2]=m|3;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;Pq(d,m)}c=f}if(c){return c+8|0}f=pd(b);if(!f){return 0}c=v[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;lc(f,a,b>>>0>c>>>0?c:b);Xb(a);return f}function wH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-48|0;jb=f;v[f+40>>2]=c;v[f+44>>2]=b;v[f+36>>2]=d;e=v[a+8>>2];v[f+28>>2]=f+36;v[f+24>>2]=f+40;b=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=b;v[f+16>>2]=a;v[f+20>>2]=f+44;b=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=b;c=f;a:{b:{switch(v[e+40>>2]){case 0:b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];g=v[d+24>>2];v[b+40>>2]=v[d+20>>2];v[b+44>>2]=g;g=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=g;Eh(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;k=b+16|0;c=b;if(h){while(1){d=0;if(g){while(1){i=v[Of(c,d,j)>>2];fc(e,d);i=i-2147481600>>>12|0;i=i>>>0>491520?i:491520;o=Mm(k,d,j),p=(i|0)<557055?i:557055,u[o>>1]=p;d=d+1|0;if((g|0)!=(d|0)){continue}break}}j=j+1|0;if((h|0)!=(j|0)){continue}break}}jb=b+80|0;break a;case 2:Lw(c,zb(e));break a;case 3:j=Ug(e);d=jb-80|0;jb=d;e=v[c>>2];g=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;k=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=k;Eh(b- -64|0,b+32|0,g);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);g=v[v[c+12>>2]>>2];k=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;i=b+16|0;if(g){m=j+16|0;while(1){c=0;if(k){while(1){e=v[Of(b,c,h)>>2];l=Ve(j,c);e=e+(v[l>>2]>>1)|0;n=e;e=Jr(m)+e&-4096;v[l>>2]=n-e;e=e-2147481600>>>12|0;e=e>>>0>491520?e:491520;o=Mm(i,c,h),p=(e|0)<557055?e:557055,u[o>>1]=p;c=c+1|0;if((k|0)!=(c|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=d+80|0;break a;case 1:Lw(c,zb(e));break a;default:break b}}Lw(c,zb(e))}v[a+4>>2]=v[a+4>>2]+v[f+36>>2];jb=f+48|0}function pi(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=0;if(!(nb[v[v[a>>2]+132>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(nb[v[v[a>>2]+132>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((nb[v[v[a>>2]+148>>2]](a)|0)<1){break a}if(!nJ(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(n*k);j=C(n*j);l=a+44|0;m=Pd(l,0);l=Pd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;p=h;k=C(z[g+m>>2]+z[h>>2]);h=c+g|0;z[p>>2]=C(k-C(z[g+l>>2]+C(k+z[h>>2])))+C(z[d+g>>2]*j);z[h>>2]=C(z[e+g>>2]*j)-k;i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*j)-z[d+g>>2])+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*j)-z[e+g>>2])+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[d+g>>2])-C(z[g+m>>2]*k);h=c+g|0;z[h>>2]=C(z[h>>2]+z[e+g>>2])-C(z[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[g+m>>2])-C(z[d+g>>2]*j);h=c+g|0;z[h>>2]=C(z[h>>2]+z[g+l>>2])-C(z[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*k)+C(z[d+g>>2]*j))+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*k)+C(z[e+g>>2]*j))+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=nJ(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;n=C(z[d+g>>2]-z[g+m>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=C(z[h>>2]+C(n*j))+C(o*k);g=c+g|0;z[g>>2]=C(C(o*j)+C(n*k))+z[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(nb[v[v[a>>2]+132>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[d>>2]+z[a+m>>2];d=a+c|0;z[d>>2]=z[d>>2]+z[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0),u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(rh(m)){A=Pd(m,0);B=Pd(m,1);D=jd(m,0);E=jd(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){j=a+4304|0;i=q+1|0;u=i+v[a+4272>>2]&4095;l=j+(u<<4)|0;w=i+v[a+4276>>2]&4095;g=((w<<4)+j|0)+4|0;x=i+v[a+4280>>2]&4095;n=((x<<4)+j|0)+8|0;y=i+v[a+4284>>2]&4095;h=((y<<4)+j|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){u=u-1&4095;i=(u<<4)+j|0;e=z[i>>2];r=r&1023;I=(r<<3)+G|0;p=z[I+4>>2];J=z[h>>2];K=z[n>>2];L=z[g>>2];M=z[l>>2];N=z[B>>2];O=z[A>>2];t=z[a+4232>>2];w=w-1&4095;l=(w<<4)+j|0;k=z[l+4>>2];f=C(C(t*z[I>>2])+C(k*C(.6180340051651001)));h=o<<3;g=h+G|0;z[g+4>>2]=k-C(f*C(.6180340051651001));k=e;e=C(C(p*t)-C(e*C(.6180340051651001)));z[g>>2]=k+C(e*C(.6180340051651001));z[i>>2]=f;z[l+4>>2]=e;s=s&1023;g=(s<<3)+H|0;p=z[g+4>>2];x=x-1&4095;n=(x<<4)+j|0;f=z[n+8>>2];t=z[a+4236>>2];e=C(t*z[g>>2]);y=y-1&4095;g=(y<<4)+j|0;k=z[g+12>>2];e=C(e+C(k*C(.6180340051651001)));h=h+H|0;z[h+4>>2]=k-C(e*C(.6180340051651001));k=f;f=C(C(p*t)-C(f*C(.6180340051651001)));z[h>>2]=k+C(f*C(.6180340051651001));z[n+8>>2]=e;z[g+12>>2]=f;f=C(z[i>>2]+e);e=C(O+C(1.0000000031710769e-30));z[D>>2]=f+C(z[a+4224>>2]*e);f=C(N+C(1.0000000031710769e-30));z[E>>2]=C(C(z[a+4224>>2]*f)+z[l+4>>2])+z[g+12>>2];h=(q<<4)+j|0;p=z[a+4228>>2];e=C(p*e);z[h>>2]=C(C(z[a+4240>>2]*z[i>>2])+e)+C(M*z[a+4244>>2]);f=C(p*f);z[h+4>>2]=C(C(z[a+4248>>2]*z[l+4>>2])+f)+C(L*z[a+4252>>2]);z[h+8>>2]=C(C(z[a+4256>>2]*z[n+8>>2])-f)+C(K*z[a+4260>>2]);z[h+12>>2]=C(C(z[a+4264>>2]*z[g+12>>2])+e)+C(J*z[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;B=B+4|0;A=A+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=i;F=F-1|0;if(F){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;pi(a,b,c,jd(m,0),jd(m,1),d)}}function UJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;i=Qc(h+8|0,b);vt(i);if(v[a>>2]==(b|0)){v[a>>2]=v[i>>2]}d=zb(a);v[d>>2]=v[d>>2]-1;d=v[hc(a)>>2];a:{b:{e=v[b>>2];c:{if(!e){a=b;break c}if(!v[b+4>>2]){a=b;break b}a=b;g=v[a+4>>2];d:{if(!g){if(!ug(a)){while(1){a=v[a+8>>2];if(!ug(a)){continue}break}}a=v[a+8>>2];break d}a=VQ(g)}e=v[a>>2];if(e){break b}}e=v[a+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[a+8>>2];g=0}e:{f:{if(ug(a)){v[v[a+8>>2]>>2]=e;if((a|0)==(d|0)){d=e;c=0;break e}c=v[a+8>>2]+4|0;break f}v[v[a+8>>2]+4>>2]=e;c=v[a+8>>2]}c=v[c>>2]}j=!w[a+12|0];if((a|0)!=(b|0)){v[a+8>>2]=v[b+8>>2];g:{if(ug(b)){f=v[a+8>>2];break g}f=v[a+8>>2]+4|0}v[f>>2]=a;f=v[b>>2];v[a>>2]=f;xn(f,a);f=v[b+4>>2];v[a+4>>2]=f;if(f){xn(f,a)}t[a+12|0]=w[b+12|0];d=(b|0)==(d|0)?a:d}if(!(j|!d)){h:{if(g){while(1){a=ug(c);b=w[c+12|0];i:{j:{if(!a){if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Ep(v[c+8>>2]);a=v[c>>2];d=(a|0)==(d|0)?c:d;c=v[a+4>>2]}b=v[c>>2];k:{l:{m:{if(!(w[b+12|0]?0:b)){a=v[c+4>>2];if(w[a+12|0]?0:a){break m}t[c+12|0]=0;n:{a=v[c+8>>2];if((a|0)!=(d|0)){if(w[a+12|0]){break n}}else{a=d}t[a+12|0]=1;break h}if(!ug(a)){break j}a=v[a+8>>2]+4|0;break i}a=v[c+4>>2];if(!a){break l}}if(!w[a+12|0]){break k}}t[b+12|0]=1;t[c+12|0]=0;Dp(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;Ep(v[c+8>>2]);break h}if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Dp(v[c+8>>2]);a=v[c+4>>2];d=(a|0)==(d|0)?c:d;c=v[a>>2]}b=v[c>>2];o:{if(w[b+12|0]?0:b){break o}a=v[c+4>>2];if(!(w[a+12|0]?0:a)){t[c+12|0]=0;a=v[c+8>>2];if(!((a|0)!=(d|0)?w[a+12|0]:0)){t[a+12|0]=1;break h}if(ug(a)){a=v[a+8>>2]+4|0;break i}a=v[a+8>>2];break i}if(b){if(!w[b+12|0]){break o}a=v[c+4>>2]}t[a+12|0]=1;t[c+12|0]=0;Ep(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;Dp(v[c+8>>2]);break h}a=v[a+8>>2]}c=v[a>>2];continue}}t[e+12|0]=1}}jb=h+16|0;return v[i>>2]}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb-208|0;jb=c;f=1;e=v[a+12>>2];h=1<<e;if(e&1){i=h>>>1|0;if(i){e=0;while(1){j=e+i|0;f=tc(b,j);d=v[f+12>>2];v[c+200>>2]=v[f+8>>2];v[c+204>>2]=d;d=v[f+4>>2];v[c+192>>2]=v[f>>2];v[c+196>>2]=d;vi(c+176|0,tc(b,e),c+192|0);f=tc(b,j);d=v[c+188>>2];v[f+8>>2]=v[c+184>>2];v[f+12>>2]=d;j=v[c+180>>2];v[f>>2]=v[c+176>>2];v[f+4>>2]=j;xx(tc(b,e),c+192|0);e=e+1|0;if((i|0)!=(e|0)){continue}break}e=v[a+12>>2]}f=2;h=h>>>3|0}else{h=h>>>2|0}j=e&-2;if(j){while(1){if(f){o=B(h,3);p=h<<1;i=0;while(1){e=tc(a,i<<1);d=v[e+12>>2];v[c+200>>2]=v[e+8>>2];v[c+204>>2]=d;d=v[e+4>>2];v[c+192>>2]=v[e>>2];v[c+196>>2]=d;e=tc(a,i);d=v[e+12>>2];v[c+184>>2]=v[e+8>>2];v[c+188>>2]=d;d=v[e+4>>2];v[c+176>>2]=v[e>>2];v[c+180>>2]=d;Jh(c+160|0,c+176|0,c+192|0);e=i<<j;m=h+e|0;if(e>>>0<m>>>0){while(1){d=tc(b,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=e+h|0;Jh(c+128|0,c+192|0,tc(b,g));k=e+p|0;Jh(c+112|0,c+176|0,tc(b,k));n=e+o|0;Jh(c+96|0,c+160|0,tc(b,n));ok(c+80|0,c+144|0,c+112|0);vi(c- -64|0,c+144|0,c+112|0);ok(c+48|0,c+128|0,c+96|0);Bl(c+16|0,-A[3858],-A[3859]);vi(c,c+128|0,c+96|0);Jh(c+32|0,c+16|0,c);ok(c+16|0,c+80|0,c+48|0);d=tc(b,e);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;l=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=l;vi(c+16|0,c+80|0,c+48|0);d=tc(b,g);l=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=l;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ok(c+16|0,c- -64|0,c+32|0);d=tc(b,k);k=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=k;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;vi(c+16|0,c- -64|0,c+32|0);d=tc(b,n);k=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=k;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;e=e+1|0;if((m|0)!=(e|0)){continue}break}}i=i+1|0;if((f|0)!=(i|0)){continue}break}}h=h>>>2|0;f=f<<2;j=j-2|0;if(j){continue}break}}jb=c+208|0}function C2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-96|0;jb=e;a:{if(Wc(c)){break a}g=w[fI(c)|0];f=1;b:{if((g|0)==33){break b}if((g|0)!=63){break a}f=0}d=f;cr(e+80|0,c,0,Fb(c)-1|0);Gb(c,e+80|0);yb(e+80|0)}Dd(e+80|0);f=v[e+80>>2];Dd(e+72|0);g=dI(f,v[e+76>>2],c);Dd(e+80|0);c:{d:{e:{f:{g:{if(v[e+84>>2]==(g|0)){if(Vd(c,38235)){a=ba(8)|0;v[114578]=0;b=Q(85,e+80|0,39169)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}c=P()|0;O()|0;yb(b);break d}if(!d){break g}a=ba(8)|0;v[114578]=0;U(2136,e+80|0,39179,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,e+80|0);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break c}c=P()|0;O()|0;yb(e+80|0);break d}c=P()|0;O()|0;ca(a|0);break d}f=Wb(e+80|0);h:{i:{j:{k:{switch(v[g+4>>2]){case 0:Hh(e- -64|0,c);v[114578]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(2077,b|0,e+8|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;t[e+72|0]=b;R(2141,a|0,e+72|0);a=v[114578];v[114578]=0;if((a|0)!=1){break h}}break j;case 1:Hh(e+56|0,c);v[114578]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=vD(b,e+16|0,d);c=mb;d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2143,a|0,e+72|0);a=v[114578];v[114578]=0;if((a|0)!=1){break h}}break j;case 2:Hh(e+48|0,c);v[114578]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(2079,b|0,e+24|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[114578]=0;A[e+72>>3]=h;R(2144,a|0,e+72|0);a=v[114578];v[114578]=0;if((a|0)!=1){break h}}break j;case 3:break k;default:break i}}Hh(e+40|0,c);v[114578]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;X(2080,a|0,b|0,e+32|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){break h}}c=P()|0;O()|0;yb(f);break d}cd(a,f)}yb(f);break f}Wb(a)}jb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function Dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-48|0;jb=g;x=v[a+16>>2];j=v[a+44>>2];v[g+32>>2]=j;m=v[a+48>>2];v[g+36>>2]=m;i=v[a+52>>2];v[g+40>>2]=i;h=v[a+56>>2];v[g+44>>2]=h;p=v[a+40>>2];q=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+x|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];h=u[f+36>>1];l=u[f+34>>1];n=u[f+32>>1];r=u[f+30>>1];s=u[f+28>>1];o=u[f+26>>1];t=u[f+24>>1];j=0;i=1;f=0;while(1){w=(g+8|0)+(f<<2)|0;f=f<<1;v[w>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],n)|0)+B(h,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],o)+B(u[e+(f|-12)>>1],t)|0)+B(u[e+(f|-4)>>1],s)|0)+B(u[e+f>>1],r)|0)/2|0)|0)/16384;w=i&1;i=0;f=1;if(w){continue}break}while(1){i=(g+8|0)+(j<<2)|0;k=v[i>>2];h=v[a+60>>2];l=h;f=(g+32|0)+(j<<3)|0;n=v[f>>2];e=Yb(n,-16777216,16776704);r=v[a+64>>2];j=Yb(v[f+4>>2],-16777216,16776704);o=v[a+68>>2];t=o;o=o>>31;v[f+4>>2]=n;n=v[a+72>>2];s=h>>31;k=k<<8;h=k;h=Fma(l,s,h,h>>31);l=mb;s=i;i=h;h=Fma(r,r>>31,e,e>>31);i=i+h|0;e=mb+l|0;e=i>>>0<h>>>0?e+1|0:e;h=i;i=Fma(t,o,j,j>>31);j=h+i|0;e=mb+e|0;e=j>>>0<i>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;v[s>>2]=(e|0)/256;v[f>>2]=e-(k&n);j=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];q=v[a+28>>2]+q|0;f=q>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);p=e+p|0;l=p>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];h=v[g+44>>2];i=v[g+40>>2];m=v[g+36>>2];j=v[g+32>>2];break a}l=p>>12;f=q>>12}v[a+40>>2]=p;v[a+20>>2]=f;v[a+36>>2]=q;v[a+56>>2]=h;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=j;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;jb=g+48|0}function Eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-48|0;jb=g;x=v[a+16>>2];j=v[a+44>>2];v[g+32>>2]=j;m=v[a+48>>2];v[g+36>>2]=m;i=v[a+52>>2];v[g+40>>2]=i;h=v[a+56>>2];v[g+44>>2]=h;p=v[a+40>>2];q=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+x|0;m=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];h=u[f+36>>1];l=u[f+34>>1];n=u[f+32>>1];r=u[f+30>>1];s=u[f+28>>1];o=u[f+26>>1];w=u[f+24>>1];j=0;i=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],n)|0)+B(h,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],o)+B(t[e+(f|-6)|0],w)|0)+B(t[e+(f|-2)|0],s)|0)+B(t[e+f|0],r)<<8)/2|0)|0)/16384;y=i&1;i=0;f=1;if(y){continue}break}while(1){i=(g+8|0)+(j<<2)|0;k=v[i>>2];h=v[a+60>>2];l=h;f=(g+32|0)+(j<<3)|0;n=v[f>>2];e=Yb(n,-16777216,16776704);r=v[a+64>>2];j=Yb(v[f+4>>2],-16777216,16776704);o=v[a+68>>2];w=o;o=o>>31;v[f+4>>2]=n;n=v[a+72>>2];s=h>>31;k=k<<8;h=k;h=Fma(l,s,h,h>>31);l=mb;s=i;i=h;h=Fma(r,r>>31,e,e>>31);i=i+h|0;e=mb+l|0;e=i>>>0<h>>>0?e+1|0:e;h=i;i=Fma(w,o,j,j>>31);j=h+i|0;e=mb+e|0;e=j>>>0<i>>>0?e+1|0:e;j=j+8388608|0;if(j>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|j>>>24;v[s>>2]=(e|0)/256;v[f>>2]=e-(k&n);j=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];q=v[a+28>>2]+q|0;l=q>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);p=e+p|0;f=p>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];h=v[g+44>>2];i=v[g+40>>2];m=v[g+36>>2];j=v[g+32>>2];break a}f=p>>12;l=q>>12}v[a+40>>2]=p;v[a+20>>2]=l;v[a+36>>2]=q;v[a+56>>2]=h;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=j;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;jb=g+48|0}function sH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;d=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;c=e;a:{b:{switch(v[d+40>>2]){case 0:b=jb-80|0;jb=b;f=v[c>>2];h=v[f+4>>2];v[b+40>>2]=v[f+20>>2];i=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=i;Lm(b- -64|0,b+32|0,h);f=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;g=b+16|0;c=b;if(h){while(1){f=0;if(i){while(1){j=v[Of(c,f,k)>>2];fc(d,f);j=j-2147481600>>>12|0;j=j>>>0>491520?j:491520;o=Km(g,f,k),p=(j|0)<557055?j:557055,u[o>>1]=p;f=f+1|0;if((i|0)!=(f|0)){continue}break}}k=k+1|0;if((h|0)!=(k|0)){continue}break}}jb=b+80|0;break a;case 2:Iw(c,zb(d));break a;case 3:k=Ug(d);b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];v[b+40>>2]=v[d+20>>2];i=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=i;Lm(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(h){m=k+16|0;while(1){d=0;if(i){while(1){g=v[Of(c,d,f)>>2];l=Ve(k,d);g=g+(v[l>>2]>>1)|0;n=g;g=Jr(m)+g&-4096;v[l>>2]=n-g;g=g-2147481600>>>12|0;g=g>>>0>491520?g:491520;o=Km(j,d,f),p=(g|0)<557055?g:557055,u[o>>1]=p;d=d+1|0;if((i|0)!=(d|0)){continue}break}}f=f+1|0;if((h|0)!=(f|0)){continue}break}}jb=b+80|0;break a;case 1:Iw(c,zb(d));break a;default:break b}}Iw(c,zb(d))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function a8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=C(0),x=0,y=0,A=C(0),B=0,E=0,F=0,G=C(0);a:{if(!v[a+4276>>2]){break a}j=a+44|0;if(!rh(j)){break a}o=Pd(j,0);p=Pd(j,1);q=jd(j,0);r=jd(j,1);y=nb[v[v[a>>2]+188>>2]](a)|0;e=C(nb[v[v[a>>2]+196>>2]](a));w=C(nb[v[v[a>>2]+184>>2]](a));s=nb[v[v[a>>2]+208>>2]](a)|0;if(d){k=a+4260|0;A=C(e*C(.009999999776482582));B=s&1;n=v[a+4256>>2];f=v[a+4272>>2];E=s>>>0>1;t=d;while(1){i=z[o>>2];l=z[p>>2];h=Tm(a,f+n|0);f=Tm(a,f);e=z[Pb(k,h)>>2];F=Pb(k,f),G=C(C(A*e)+C(C(l+i)*C(.5))),z[F>>2]=G;b:{if(y){g=z[a+4244>>2];e=C(z[a+4236>>2]+g);z[a+4236>>2]=e;g=C(g+z[a+4240>>2]);z[a+4240>>2]=g;if(!(e<=C(1))){e=C(e+C(-2));z[a+4236>>2]=e}if(!(g<=C(1))){z[a+4240>>2]=g+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));g=C(D(z[a+4240>>2]));g=C(C(g+g)+C(-1));break b}g=z[a+4244>>2];m=z[a+4240>>2];e=C(C(g*m)+z[a+4236>>2]);z[a+4236>>2]=e;g=C(m-C(e*g));z[a+4240>>2]=g}m=z[Pb(k,Tm(a,v[a+4280>>2]+v[a+4272>>2]|0))>>2];F=q,G=C(C(C(C(m-i)+C(C(C(z[Pb(k,Tm(a,v[a+4284>>2]+v[a+4272>>2]|0))>>2]-m)*C(.000244140625))*C(v[a+4280>>2]&4095)))*w)+i),z[F>>2]=G;i=z[Pb(k,Tm(a,v[a+4288>>2]+v[a+4272>>2]|0))>>2];F=r,G=C(C(C(C(i-l)+C(C(C(z[Pb(k,Tm(a,v[a+4292>>2]+v[a+4272>>2]|0))>>2]-i)*C(.000244140625))*C(v[a+4288>>2]&4095)))*w)+l),z[F>>2]=G;u=a;n=v[a+4256>>2];f=n;i=z[a+4248>>2];l=C(i*(B?g:e));c:{if(C(D(l))<C(2147483648)){h=~~l;break c}h=-2147483648}x=f+(E?h:0-h|0)|0;v[u+4288>>2]=x;f=s>>>0<4;u=a;e=C(i*e);d:{if(C(D(e))<C(2147483648)){h=~~e;break d}h=-2147483648}f=(f?h:0-h|0)+n|0;v[u+4280>>2]=f;v[a+4292>>2]=x+4096;v[a+4284>>2]=f+4096;p=p+4|0;o=o+4|0;r=r+4|0;q=q+4|0;h=a;f=v[a+4272>>2];if((f|0)<=0){f=f+(v[a+4276>>2]<<12)|0}f=f-4096|0;v[h+4272>>2]=f;t=t-1|0;if(t){continue}break}}pi(a,b,c,jd(j,0),jd(j,1),d)}}function v_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=jb-432|0;jb=i;v[i+424>>2]=37;v[i+428>>2]=0;j=br(i+424|1,64442,v[c+4>>2]);v[i+380>>2]=i+384;a=le();a:{if(j){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;l=i- -64|0;v[l>>2]=e;v[l+4>>2]=f;v[i+48>>2]=k;a=af(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=af(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2427;k=Rd(i+368|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){v[114578]=0;a=da(2452)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[114578]=0;a=aa(2474,i+380|0,a|0,i+424|0,i|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break e}break c}v[114578]=0;a=da(2452)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114578]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=aa(2474,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}}e=v[i+380>>2];if(!e){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(k,e)}e=v[i+380>>2];g=e+a|0;h=mg(e,g,c);v[i+116>>2]=2427;f=Rd(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;e=i+384|0;break g}a=pd(a<<3);if(!a){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(f,a);e=v[i+380>>2]}v[114578]=0;Bc(i+104|0,c);j=v[114578];v[114578]=0;h:{i:{if((j|0)!=1){v[114578]=0;ia(2485,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Ob(i+104|0);v[114578]=0;a=ka(2486,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(f);Gc(k);jb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(i+104|0);break f}c=P()|0;O()|0}Gc(f);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function G_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;i=jb-256|0;jb=i;v[i+248>>2]=37;v[i+252>>2]=0;j=br(i+248|1,64442,v[c+4>>2]);v[i+204>>2]=i+208;a=le();a:{if(j){k=v[c+8>>2];v[i+72>>2]=g;v[i+76>>2]=h;l=i- -64|0;v[l>>2]=e;v[l+4>>2]=f;v[i+48>>2]=k;a=af(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=af(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2427;k=Rd(i+192|0,0,i+128|0);b:{c:{d:{if((a|0)>=30){e:{if(j){v[114578]=0;a=da(2452)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=e;v[i+20>>2]=f;v[i+24>>2]=g;v[i+28>>2]=h;v[i>>2]=j;v[114578]=0;a=aa(2474,i+204|0,a|0,i+248|0,i|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break e}break c}v[114578]=0;a=da(2452)|0;j=v[114578];v[114578]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114578]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=aa(2474,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}}e=v[i+204>>2];if(!e){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(k,e)}e=v[i+204>>2];g=e+a|0;h=mg(e,g,c);v[i+116>>2]=2427;f=Rd(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;e=i+208|0;break g}a=pd(a<<1);if(!a){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(f,a);e=v[i+204>>2]}v[114578]=0;Bc(i+104|0,c);j=v[114578];v[114578]=0;h:{i:{if((j|0)!=1){v[114578]=0;ia(2475,e|0,h|0,g|0,a|0,i+116|0,i+112|0,i+104|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Ob(i+104|0);v[114578]=0;a=ka(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(f);Gc(k);jb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(i+104|0);break f}c=P()|0;O()|0}Gc(f);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function tH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);f=jb-48|0;jb=f;v[f+40>>2]=c;v[f+44>>2]=b;v[f+36>>2]=d;h=v[a+8>>2];v[f+28>>2]=f+36;v[f+24>>2]=f+40;b=v[f+28>>2];v[f+8>>2]=v[f+24>>2];v[f+12>>2]=b;v[f+16>>2]=a;v[f+20>>2]=f+44;b=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=b;c=f;a:{b:{switch(v[h+40>>2]){case 0:d=jb-80|0;jb=d;e=v[c>>2];g=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;j=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=j;Eh(b- -64|0,b+32|0,g);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);j=v[v[c+12>>2]>>2];c=v[v[c+8>>2]>>2];g=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=g;g=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=g;v[b+8>>2]=v[e+8>>2];g=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=g;e=b+16|0;if(j){while(1){g=0;if(c){while(1){k=A[ch(b,g,i)>>3];fc(h,g);m=qn(e,g,i),n=C(k),z[m>>2]=n;g=g+1|0;if((c|0)!=(g|0)){continue}break}}i=i+1|0;if((j|0)!=(i|0)){continue}break}}jb=d+80|0;break a;case 2:Jw(c,zb(h));break a;case 3:j=Ug(h);d=jb-80|0;jb=d;e=v[c>>2];h=v[e+4>>2];b=v[e+24>>2];v[d+40>>2]=v[e+20>>2];v[d+44>>2]=b;i=v[e+16>>2];b=d;v[b+32>>2]=v[e+12>>2];v[b+36>>2]=i;Eh(b- -64|0,b+32|0,h);e=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[e+8>>2];c=v[e+4>>2];v[b>>2]=v[e>>2];v[b+4>>2]=c;e=b+16|0;if(h){while(1){c=0;if(i){while(1){k=A[ch(b,c,g)>>3];Ve(j,c);l=sj(Sd(k*134217728));m=qn(e,c,g),n=C(+(l|0)*7.450580596923828e-9),z[m>>2]=n;c=c+1|0;if((i|0)!=(c|0)){continue}break}}g=g+1|0;if((h|0)!=(g|0)){continue}break}}jb=d+80|0;break a;case 1:Jw(c,zb(h));break a;default:break b}}Jw(c,zb(h))}v[a+4>>2]=v[a+4>>2]+v[f+36>>2];jb=f+48|0}function ps(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-160|0;jb=h;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}f=v[c+4>>2];if(!f&y[c>>2]>=oh(b)>>>0|f){break h}b=ba(8)|0;v[114578]=0;Q(214,b|0,20525)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break g}a=P()|0;O()|0;ca(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[114578]=0;Q(1405,b|0,20525)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break f}a=P()|0;O()|0;ca(b|0);break a}f=wh(h+128|0,b);d=jb-16|0;jb=d;ho(d+8|0,wh(d,f));e=jb-16|0;jb=e;i=wh(e+8|0,d+8|0);g=jb-16|0;jb=g;f=h+136|0;OC(f,wh(g+8|0,i));jb=g+16|0;jb=e+16|0;v[f+16>>2]=0;v[f+12>>2]=0;jb=d+16|0;i:{j:{if(a&2){d=Uo(h+104|0,f);v[114578]=0;j=Q(1406,d|0,c|0)|0;e=v[114578];v[114578]=0;d=1;if((e|0)==1){break i}if((j|0)==1){break j}e=Uo(h+80|0,f);v[114578]=0;e=Q(1407,e|0,c|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}k=(e|0)==1;if(k){break j}g=Uo(h+56|0,f);v[114578]=0;g=Q(1408,g|0,c|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}l=(g|0)==1;if(l){break j}i=Uo(h+32|0,f);v[114578]=0;i=Q(1409,i|0,c|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break c}if((i|0)==1){break j}d=(j|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(i|0)==-1?-1:l?d:(g|0)==-1?-1:d}if(a&1){a=77744;while(1){d=v[a>>2];if(d){e=Uo(h+8|0,f);v[114578]=0;e=Q(d|0,e|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}j=(e|0)==-1?-1:j}a=a+12|0;if((a|0)!=78200){continue}break}}if(c){d=0;if((j|0)!=-1){break j}a=v[c+4>>2];c=v[c>>2];v[114578]=0;a=Gg(448,c,a);c=v[114578];v[114578]=0;if((c|0)!=1){d=oh(b)>>>0<a>>>0?-1:0;break j}a=P()|0;O()|0;break a}d=0;if((j|0)!=-1){break j}d=oh(b)>>>0>2047?1:-1}jb=h+160|0;return d}a=P()|0;O()|0;break a}ja(b|0,71464,24);L()}ja(b|0,71360,24);L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}S(a|0);L()}function P2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;g=gh(a);a=b+24|0;f=Vb(v[a>>2]+484360|0);v[114578]=0;i=T(2193,f|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)==1){break c}v[114578]=0;R(1533,g|0,i|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=x[rc(Vb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[114578]=0;d=Q(917,d+484344|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}f:{if(d){c=_b(v[a>>2]+484344|0,x[rc(Vb(v[a>>2]+484360|0),f)>>1]);v[114578]=0;R(2191,e|0,c|0);c=v[114578];v[114578]=0;g:{h:{i:{if((c|0)!=1){v[114578]=0;U(2185,e+16|0,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;R(1535,g|0,e+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}yb(e+16|0);yb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(e+16|0)}yb(e);break a}v[114578]=0;d=da(963)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114578]=0;c=Q(85,e+16|0,38847)|0;d=v[114578];v[114578]=0;j:{if((d|0)!=1){v[114578]=0;R(1535,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break j}yb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}v[114578]=0;d=da(962)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114578]=0;c=Q(85,e+16|0,38856)|0;d=v[114578];v[114578]=0;k:{if((d|0)!=1){v[114578]=0;R(1535,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break k}yb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}v[114578]=0;c=Q(85,e+16|0,38865)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;R(1535,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}yb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}ld(g);S(a|0);L()}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-144|0;jb=c;e=al(c+40|0,a);v[114578]=0;d=Q(683,c+24|0,32299)|0;a=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[114578]=0;v[c>>2]=19466496;v[c+4>>2]=0;U(684,e|0,d|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break n}Ib(d);if(v[e>>2]&1073741824){break e}v[114578]=0;d=Q(683,c+24|0,32304)|0;a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;aa(1570,e|0,b|0,d|0,1571)|0;a=v[114578];v[114578]=0;if((a|0)==1){break l}Ib(d);v[114578]=0;v[c+20>>2]=0;v[c+16>>2]=0;d=Q(683,c+24|0,32309)|0;a=v[114578];v[114578]=0;if((a|0)==1){break k}v[114578]=0;W(1572,e|0,c+20|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break j}Ib(d);v[114578]=0;d=Q(683,c+24|0,32314)|0;a=v[114578];v[114578]=0;if((a|0)==1){break i}v[114578]=0;W(1572,e|0,c+16|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break h}Ib(d);a=b;d=v[c+16>>2];f=v[c+20>>2];o:{if(!f){break o}if(d>>>0<f>>>0|f>>>0>y[v[Wm(a)+8>>2]+40>>2]){break o}if(d>>>0>y[v[Wm(a)+8>>2]+40>>2]){break o}v[a+20>>2]=d;v[a+16>>2]=f}d=Xx(c+24|0);v[114578]=0;f=Q(683,c|0,32319)|0;a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;aa(1573,e|0,d|0,f|0,674)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}Ib(f);if(nd(d)){break f}v[114578]=0;U(1574,d|0,v[c+20>>2],16777216);a=v[114578];v[114578]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;Ib(f);break b}v[114578]=0;R(1575,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}oe(d)}vg(e);jb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}oe(d)}vg(e);S(a|0);L()}function BO(a){a=a|0;var b=0,c=0,d=0;Rb(a,0,288);Ly(a+288|0);sp(a+800|0);t[a+2|0]=w[18178];b=w[18176]|w[18177]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[18181];b=w[18179]|w[18180]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[18185]|w[18186]<<8|(w[18187]<<16|w[18188]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[18182]|w[18183]<<8|(w[18184]<<16|w[18185]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[18189]|w[18190]<<8|(w[18191]<<16|w[18192]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[18192]|w[18193]<<8|(w[18194]<<16|w[18195]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[18200];b=w[18196]|w[18197]<<8|(w[18198]<<16|w[18199]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;b=jb-80|0;jb=b;v[b+76>>2]=0;d=Ub(b- -64|0,18062);v[114578]=0;R(512,b+48|0,a+288|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114578]=0;Q(471,b+48|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}yb(d);break c}a=P()|0;O()|0;yb(d);break b}jb=b+80|0;break a}S(a|0);L()}d=a+800|0;b=0;a=jb+-64|0;jb=a;e:{f:{g:{h:{i:{j:{while(1){v[a+60>>2]=b;v[a+60>>2]=b<<3;qA(a+32|0,b>>>0<16?18126:18061);v[114578]=0;R(510,a+16|0,a+60|0);c=v[114578];v[114578]=0;if((c|0)==1){break j}v[114578]=0;U(511,a+48|0,a+32|0,a+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}v[114578]=0;R(512,a+8|0,d+(b<<5)|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}v[114578]=0;Q(471,a+8|0,a+48|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break h}yb(a+48|0);yb(a+16|0);Ib(a+32|0);b=b+1|0;if((b|0)!=128){continue}break}jb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;yb(a+48|0)}yb(a+16|0)}Ib(a+32|0);S(b|0);L()}}function q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;d=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}b=(b|0)==1?2:b;if(b>>>0>4|!(1<<b&21)){break a}f=v[c+11e3>>2];j=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}h=(b|0)==4;g=v[c+11004>>2];if(g?!h:0){break a}d=v[c+11008>>2]>0?9:8;v[c+11004>>2]=h|g;if(!(!f|(b|0)!=4)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];b=XG(c,v[a>>2],e+12|0,b,b,e+8|0,d|4);v[c+43780>>2]=b;d=v[e+12>>2];v[a>>2]=d+v[a>>2];v[a+4>>2]=v[a+4>>2]-d;v[a+8>>2]=d+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];d=-3;if((b|0)<0){break a}if(!b){d=1;break a}v[c+43780>>2]=-1;d=-5;break a}f=v[c+10996>>2];if(!f){i=(b|0)!=4;k=i?d|2:d;h=c+11012|0;b=v[c+10992>>2];while(1){d=v[a+4>>2];v[e+8>>2]=32768-b;v[e+12>>2]=d;f=XG(c,v[a>>2],e+12|0,h,b+h|0,e+8|0,k);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[c+10996>>2]=b;d=v[a+16>>2];b=b>>>0<d>>>0?b:d;lc(v[a+12>>2],h+v[c+10992>>2]|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=v[c+10996>>2]-b|0;v[c+10996>>2]=g;b=b+v[c+10992>>2]&32767;v[c+10992>>2]=b;if((f|0)<0){break b}d=-5;if(j?0:(f|0)==1){break a}if(!i){if(!f){d=g?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){d=0;if(g|!v[a+4>>2]){break a}if(v[a+16>>2]){continue}break a}break}d=!g;break a}b=v[a+16>>2];b=b>>>0>f>>>0?f:b;lc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;d=0;if(v[c+43780>>2]){break a}d=!a;break a}d=-3}jb=e+16|0;return d|0}function Nf(a,b,c,d,e){var f=0,g=0,h=0;g=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=g;f=x[a+20>>1];b=x[a+70>>1]+(f+x[a+22>>1]|0)|0;b=w[a+79|0]?x[v[a>>2]+3836>>1]+b|0:b;a:{b:{c:{switch(v[a+16>>2]){case 0:c=x[v[a>>2]+3832>>1];c=f+(c&x[a+34>>1]?0:x[a+24>>1]?B((f^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((c>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0)|0;u[a+20>>1]=c;if(c<<16>>16>0){break b}v[a+16>>2]=1;u[a+20>>1]=0;break b;case 1:c=x[v[a>>2]+3832>>1];c=f+(c&x[a+46>>1]?0:x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((c>>>x[a+44>>1]&7)<<1)>>1]|0:0)|0;u[a+20>>1]=c;f=c<<16>>16;c=x[a+28>>1];if((f|0)<(c|0)){break b}v[a+16>>2]=2;u[a+20>>1]=c;break b;case 2:if(w[a+78|0]){break b}case 3:c=0;h=x[v[a>>2]+3832>>1];f=f+(x[a+58>>1]&h?0:x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((h>>>x[a+56>>1]&7)<<1)>>1]|0:0)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:break c}}c=0;v[a+72>>2]=0;break a}d=e?(u[a+74>>1]+u[a+72>>1]>>e)+d|0:d;e=b<<3;c=(g>>>10|0)+d|0;d=c&255;b=c&65535;d:{e:{switch(x[a+12>>1]){case 0:c=(b&512)>>>9|0;b=x[((b&256?d^255:d)<<1)+19296>>1];break d;case 1:c=0;b=x[((b&512?0:b&256?d^255:d)<<1)+19296>>1];break d;case 2:c=0;b=x[((b&256?d^255:d)<<1)+19296>>1];break d;case 3:c=0;b=x[((b&256?0:d)<<1)+19296>>1];break d;case 4:f:{if(b&512){d=19296;c=0;break f}d=(((d<<1^b<<24>>31)&254)<<1)+19296|0;c=(b&256)>>>8|0}b=x[d>>1];break d;case 5:c=0;if(b&512){b=19296}else{d=d<<1&254;b=((b&128?d^255:d)<<1)+19296|0}b=x[b>>1];break d;case 6:c=(c&512)>>>9|0;b=0;break d;default:break e}}c=c<<3&4088;f=c^4088;d=c;c=(b&512)>>>9|0;b=c?f:d}u[a+74>>1]=x[a+72>>1];d=a;a=b+e|0;a=(a&65535)>>>0<8191?a:8191;c=0-c^x[((a&255)<<1)+18784>>1]+1024>>>((a&65280)>>>8)<<1;u[d+72>>1]=c}return c<<16>>16}function ska(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-32|0;jb=g;v[g+24>>2]=d;i=Mj(a,c);pf(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!i){if(xd(a,5)){break a}}j=v[g+24>>2];d=jb-160|0;jb=d;h=al(d+56|0,v[a+28>>2]);v[114578]=0;f=Q(683,d+8|0,18638)|0;e=v[114578];v[114578]=0;b:{c:{d:{e:{if((e|0)!=1){v[114578]=0;v[d+48>>2]=19466496;v[d+52>>2]=0;U(684,h|0,f|0,d+48|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}Ib(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f);break c}v[114578]=0;t[d+48|0]=0;t[d+47|0]=0;f=Q(683,d+8|0,18630)|0;e=v[114578];v[114578]=0;f:{if((e|0)!=1){v[114578]=0;W(1187,h|0,d+48|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}Ib(f);if(!w[d+48|0]){break b}Ue(d+48|0,50);v[114578]=0;f=Q(683,d+8|0,18646)|0;e=v[114578];v[114578]=0;g:{h:{i:{j:{if((e|0)!=1){v[114578]=0;W(1187,h|0,d+47|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break j}Ib(f);f=Nh(b);e=w[d+48|0];if(f>>>0<e>>>0){f=Cy(d+8|0,v[b+12>>2]);v[114578]=0;U(1188,b|0,e|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break i}Dl(f)}e=0;f=x[Di(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){Oe(Di(b,e&255),f);e=Di(b,w[d+7|0]);v[114578]=0;R(1189,d+8|0,d+7|0);k=v[114578];v[114578]=0;if((k|0)==1){break h}v[114578]=0;X(1190,h|0,e|0,d+8|0,j|0);e=v[114578];v[114578]=0;if((e|0)==1){break g}Ib(d+8|0);e=w[d+7|0]+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];f=Nh(b);t[b+16|0]=e>>>0<f>>>0?w[d+47|0]:0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f);break c}e=P()|0;O()|0;Dl(f);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(d+8|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f)}vg(h);S(e|0);L()}vg(h);jb=d+160|0}Zi(a,i,c,g+16|0);jb=g+32|0}function wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;j=c+484344|0;_f(j,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){f=v[a+8>>2];g=Cf(a);$b(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Gd(a)+1|0;break b}c=hg(a)}d=hg(a);Pc(a,f+g|0);ud(e+16|0,a,d);v[114578]=0;c=W(404,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}c:{if(!c|!d){break c}c=_b(j,i);k=e,l=bc(c),v[k+8>>2]=l;k=e,l=cc(c),v[k>>2]=l;if(!Jb(e+8|0,e)){break c}while(1){d=v[e+8>>2];v[114578]=0;c=T(389,e+16|0)|0;f=v[114578];v[114578]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){v[114578]=0;f=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d|0]=f}if(c&2){break e}break d}break a}t[d|0]=c;c=255}v[114578]=0;f=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d+1|0]=f}f=0;if(c&4){v[114578]=0;f=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}}if(c&8){v[114578]=0;g=T(389,e+16|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}t[d+3|0]=g}if(c&16){v[114578]=0;c=T(389,e+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d+5|0]=c}c=d;g:{h:{g=w[d|0];if(!g){break h}h=255;if((g|0)==97){break g}if(g>>>0>96){break h}h=g+12|0;break g}h=0}t[c|0]=h;i:{if(w[d+5|0]|w[d+3|0]){v[114578]=0;Z(574,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){break i}break a}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=f-16|0;j:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;t[d+4|0]=c;f=f-96>>4;t[d+2|0]=w[f+17983|0];if((f|0)!=6){break j}t[d+4|0]=c<<2}Cj(e+8|0);if(Jb(e+8|0,e)){continue}break}}Bb(e+16|0);i=i+1|0;if(i>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}jb=e+32|0;return}a=P()|0;O()|0;Bb(e+16|0);S(a|0);L()}function hr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=Qs(c,d);v[i+4>>2]=2427;m=Rd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=pd(k);if(!j){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}ye(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114578]=0;h=Q(2429,a|0,i+120|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114578]=0;b=Q(2430,a|0,i+120|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114578]=0;n=T(2431,a|0)|0;b=v[114578];v[114578]=0;g:{if((b|0)!=1){if(g){break g}v[114578]=0;n=Q(2432,e|0,n|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114578]=0;T(2433,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[kc(b,q)|0];j:{if(g){break j}v[114578]=0;p=Q(2432,e|0,p<<24>>24)|0;s=v[114578];v[114578]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Fb(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Gc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Wc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Gc(m);S(b|0)}L()}function YZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-624|0;jb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2489;b=Rd(a+200|0,a+208|0,a+16|0);v[114578]=0;Bc(a+192|0,e);h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114578]=0;h=T(2456,a+192|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[a+191|0]=0;e=v[e+4>>2];v[114578]=0;c=ta(2500,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(!c){break f}c=w[64683]|w[64684]<<8|(w[64685]<<16|w[64686]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[64680]|w[64681]<<8|(w[64682]<<16|w[64683]<<24);v[a+176>>2]=w[64676]|w[64677]<<8|(w[64678]<<16|w[64679]<<24);v[a+180>>2]=c;v[114578]=0;aa(2470,h|0,a+176|0,a+186|0,a+128|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[a+4>>2]=2427;d=Rd(a+8|0,0,a+4|0);c=a+16|0;if((v[a+196>>2]-v[b>>2]|0)<393){break g}ye(d,pd((v[a+196>>2]-v[b>>2]>>2)+2|0));if(v[d>>2]){break h}v[114578]=0;Y(2428);c=v[114578];v[114578]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+196>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((hF(a+16|0,a)|0)!=1){v[114578]=0;Z(2491,64660);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break d}Gc(d)}else{j=c,k=w[(a+176|0)+(Fv(a+128|0,a+168|0,e)-(a+128|0)>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;continue}break}}v[114578]=0;c=Q(2462,a+616|0,a+608|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Ob(a+192|0);Gc(b);jb=a+624|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Gc(d)}Ob(a+192|0)}Gc(b);S(e|0);L()}L()}function Q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Wb(a+208|0);v[114578]=0;Bc(a+16|0,d);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){v[114578]=0;b=T(2456,a+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}v[114578]=0;aa(2470,b|0,64400,64426,a+224|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}Ob(a+16|0);c=Wb(a+192|0);b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114578]=0;d=Q(2461,a+344|0,a+336|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Fb(c)+b|0)){d=Fb(c);b=Fb(c);v[114578]=0;R(149,c|0,b<<1);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=d+b}v[114578]=0;d=T(2463,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}v[114578]=0;d=Yj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}if(d){break c}v[114578]=0;T(2465,a+344|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ob(a+16|0);break a}v[114578]=0;R(149,c|0,v[a+188>>2]-b|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=Tb(c);v[114578]=0;d=da(2452)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[a>>2]=f;v[114578]=0;b=aa(2453,b|0,d|0,64433,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114578]=0;b=Q(2462,a+344|0,a+336|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(c);yb(h);jb=a+352|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Wb(a+208|0);v[114578]=0;Bc(a+16|0,d);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){v[114578]=0;b=T(21,a+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}v[114578]=0;aa(2447,b|0,64400,64426,a+224|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}Ob(a+16|0);c=Wb(a+192|0);b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114578]=0;d=Q(2429,a+264|0,a+256|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Fb(c)+b|0)){d=Fb(c);b=Fb(c);v[114578]=0;R(149,c|0,b<<1);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=Kc(c);v[114578]=0;R(149,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=d+b}v[114578]=0;d=T(2431,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}v[114578]=0;d=Zj(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}if(d){break c}v[114578]=0;T(2433,a+264|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ob(a+16|0);break a}v[114578]=0;R(149,c|0,v[a+188>>2]-b|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=Tb(c);v[114578]=0;d=da(2452)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[a>>2]=f;v[114578]=0;b=aa(2453,b|0,d|0,64433,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(c);yb(h);jb=a+272|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function fr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=Qs(c,d);v[i+4>>2]=2427;m=Rd(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=pd(k);if(!j){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}ye(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114578]=0;h=Q(2461,a|0,i+120|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114578]=0;b=Q(2462,a|0,i+120|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114578]=0;n=T(2463,a|0)|0;b=v[114578];v[114578]=0;g:{if((b|0)!=1){if(g){break g}v[114578]=0;n=Q(2464,e|0,n|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114578]=0;T(2465,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[hj(b,q)>>2];j:{if(g){break j}v[114578]=0;p=Q(2464,e|0,p|0)|0;s=v[114578];v[114578]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Fb(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Gc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Wc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Gc(m);S(b|0)}L()}function Vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-48|0;jb=k;a:{if(!Qb(a,1)){break a}d=b;c=Bk(d);b:{if(c>>>0<64){m=jb-32|0;jb=m;c:{l=64-c|0;d:{if(l>>>0<=(v[zb(d)>>2]-v[d+4>>2]|0)/33>>>0){c=jb-16|0;jb=c;e=c;v[c>>2]=d;f=v[d+4>>2];v[c+4>>2]=f;v[c+8>>2]=f+B(l,33);e:{if(v[c+4>>2]!=v[c+8>>2]){while(1){h=zb(d);f=v[e+4>>2];v[114578]=0;R(765,h|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}f=v[e+4>>2]+33|0;v[e+4>>2]=f;if((f|0)!=v[e+8>>2]){continue}break}}Mb(e);jb=c+16|0;break d}a=P()|0;O()|0;Mb(e);S(a|0);L()}n=zb(d);i=m+8|0;f=Bk(d)+l|0;j=jb-16|0;jb=j;v[j+12>>2]=f;g=jb-16|0;jb=g;e=d;zb(d);v[g+12>>2]=130150524;v[114578]=0;v[g+8>>2]=2147483647;h=Q(33,g+12|0,g+8|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)!=1){jb=g+16|0;c=v[h>>2];break f}V(0)|0;O()|0;Ab();L()}g:{if(c>>>0>=f>>>0){e=Jl(e);if(e>>>0<c>>>1>>>0){v[j+8>>2]=e<<1;c=v[bd(j+8|0,j+12|0)>>2]}jb=j+16|0;break g}fd();L()}f=Bk(d);g=0;h=jb-16|0;jb=h;v[h+12>>2]=0;Tc(i+12|0,n);if(c){e=c;if(c>>>0>130150524){Fc(14703);L()}g=sc(B(e,33),1)}v[i>>2]=g;e=B(f,33)+g|0;v[i+8>>2]=e;v[i+4>>2]=e;o=ec(i),p=B(c,33)+g|0,v[o>>2]=p;jb=h+16|0;v[114578]=0;R(763,i|0,l|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}v[114578]=0;R(764,d|0,i|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}zR(i)}jb=m+32|0;break b}a=P()|0;O()|0;zR(i);S(a|0);L()}if(c>>>0>64){c=v[d>>2]+2112|0;Bk(d);yR(d,c);Jl(d);Bk(d)}}g=Gd(a);if(!g){break a}while(1){g=g-1|0;h=jb-16|0;jb=h;f=k+8|0;Bz(h+8|0,f);e=Hb(h+8|0);c=a;d=nc(c,ac(h,h+8|0));if((e|0)==(d|0)){$b(c,Hb(h+8|0))}jb=h+16|0;d=(d|0)==(e|0);if(!d){c=jb-16|0;jb=c;wR(f);jb=c+16|0}h:{if(!d){break h}c=w[k+8|0];if(c>>>0>63){break h}lc(CR(b,c),k+8|0,33)}if(g&255){continue}break}}jb=k+48|0}function Iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=jb-48|0;jb=f;s=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;i=v[a+48>>2];v[f+36>>2]=i;l=v[a+52>>2];v[f+40>>2]=l;m=v[a+56>>2];v[f+44>>2]=m;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;if(d){while(1){m=1;h=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];k=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];n=u[e+28>>1];r=u[e+26>>1];x=u[e+24>>1];l=0;e=1;i=0;while(1){g=i<<1;v[(f+8|0)+(i<<2)>>2]=(((((B(u[h+(g|8)>>1],o)+B(u[h+(g|4)>>1],p)|0)+B(u[h+(g|12)>>1],k)|0)+B(j,u[h+(g|16)>>1])|0)/2|0)+((((B(u[h+(g|-8)>>1],r)+B(u[h+(g|-12)>>1],x)|0)+B(u[h+(g|-4)>>1],n)|0)+B(u[h+g>>1],q)|0)/2|0)|0)/16384;g=e;e=0;i=1;if(g){continue}break}while(1){i=(f+8|0)+(l<<2)|0;j=v[i>>2];k=v[a+60>>2];o=k;g=(f+32|0)+(l<<3)|0;l=v[g>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];h=Yb(v[g+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[g+4>>2]=l;l=v[a+72>>2];k=k>>31;j=j<<8;k=Fma(o,k,j,j>>31);o=mb;q=i;i=k;k=Fma(p,p>>31,e,e>>31);i=i+k|0;e=mb+o|0;e=i>>>0<k>>>0?e+1|0:e;k=i;i=Fma(r,n,h,h>>31);h=k+i|0;e=mb+e|0;e=h>>>0<i>>>0?e+1|0:e;h=h+8388608|0;if(h>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|h>>>24;v[q>>2]=(e|0)/256;v[g>>2]=e-(j&l);l=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],t);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];l=v[f+40>>2];i=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=l;v[a+48>>2]=i;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;jb=f+48|0}function d_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2489;b=Rd(a+152|0,a+160|0,a+16|0);v[114578]=0;Bc(a+144|0,e);h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114578]=0;h=T(21,a+144|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}t[a+143|0]=0;e=v[e+4>>2];v[114578]=0;c=ta(2490,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(!c){break f}c=w[64683]|w[64684]<<8|(w[64685]<<16|w[64686]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[64680]|w[64681]<<8|(w[64682]<<16|w[64683]<<24);v[a+128>>2]=w[64676]|w[64677]<<8|(w[64678]<<16|w[64679]<<24);v[a+132>>2]=c;v[114578]=0;aa(2447,h|0,a+128|0,a+138|0,a+118|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break i}v[a+4>>2]=2427;d=Rd(a+8|0,0,a+4|0);c=a+16|0;if((v[a+148>>2]-v[b>>2]|0)<99){break g}ye(d,pd((v[a+148>>2]-v[b>>2]|0)+2|0));if(v[d>>2]){break h}v[114578]=0;Y(2428);c=v[114578];v[114578]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+148>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((hF(a+16|0,a)|0)!=1){v[114578]=0;Z(2491,64660);c=v[114578];v[114578]=0;if((c|0)!=1){break a}break d}Gc(d)}else{j=c,k=w[((Sm(a+118|0,a+128|0,e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;continue}break}}v[114578]=0;c=Q(2430,a+280|0,a+272|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Ob(a+144|0);Gc(b);jb=a+288|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Gc(d)}Ob(a+144|0)}Gc(b);S(e|0);L()}L()}function fp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0;e=jb-16|0;jb=e;v[e+12>>2]=u[b+792>>1]+w[b+857|0];v[e+8>>2]=u[b+794>>1]+(w[b+858|0]&127);ce(e+12|0,0,127);ce(e+8|0,0,127);m=a+1074308|0;Eb(e,m,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+792>>1]=0;t[b+857|0]=i;j=v[e+8>>2];u[b+794>>1]=0;t[b+858|0]=j}Eb(e,m,36);i=B(i,d+256|0);n=(i|0)/256|0;j=Cb(e);l=v[e+8>>2];a:{if(!(l|!j|(i|0)<65024)){n=-1;a=b+810|0;if(!cg(a)){break a}if(Fs(a)|x[b+808>>1]|(v[b>>2]|v[b+4>>2])){break a}a=v[b+88>>2];if(a&8192){break a}v[b+88>>2]=a&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;f=ne(C(10),C(C(0-l|0)*C(.00937500037252903)));i=jb-16|0;jb=i;h=C(B(v[e+12>>2],d+256|0)>>>0);l=i;d=a;b:{if(v[a+480180>>2]!=33554432){g=C(110);k=C(C(h/(w[d+480209|0]&128?C(10240):C(12288)))+C(.25));break b}g=C(125);k=C(h*C(9227362170349807e-20))}o=l,p=Lh(C(ne(C(2),k)*g)),v[o+12>>2]=p;ce(i+12|0,120,2e4);j=v[i+12>>2];d=v[d+24620>>2];jb=i+16|0;Eb(e,m,36);h=C(C(((d|0)<j<<1?d>>>1|0:j)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){g=C(C(y[a+24620>>2])/h);h=C(C(f+C(-1))+C(g*f));z[e>>2]=h;f=C(g*g);break c}g=C(h/C(y[a+24620>>2]));f=C(f+f);z[e>>2]=g*C(C(1)-f);NM(e,C(2));h=C(C(f-z[e>>2])/g);z[e>>2]=h;f=C(C(1)/C(g*g))}g=C(C(h+f)+C(1));h=C(C(C(f+f)+h)/g);k=C(C(16777216)/g);f=C(C(-f)/g);d:{if(w[b+865|0]==1){o=b,p=Lh(C(C(16777216)-k)),v[o+60>>2]=p;o=b,p=Lh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Lh(C(f*C(16777216))),v[o+68>>2]=p;a=-1;break d}o=b,p=Lh(k),v[o+60>>2]=p;o=b,p=Lh(C(h*C(16777216))),v[o+64>>2]=p;o=b,p=Lh(C(f*C(16777216))),v[o+68>>2]=p;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}jb=e+16|0;return n}function Xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;g=jb-16|0;jb=g;a:{b:{c:{h=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?h>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?h>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?h>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?h>>>0>2147483648:0){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}r=v[a+16>>2];j=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=e;v[g>>2]=h;v[g+4>>2]=f;e:{if(d){while(1){b=e+r|0;f=t[b+4|0];e=(i>>>16&65520)+o|0;i=u[e+14>>1];h=t[b+3|0];s=u[e+12>>1];w=t[b+2|0];x=u[e+10>>1];y=t[b+1|0];z=u[e+8>>1];A=t[b|0];C=u[e+6>>1];D=t[b-1|0];E=u[e+4>>1];F=t[b-2|0];G=u[e+2>>1];H=t[b-3|0];I=u[e>>1];b=v[a+60>>2];J=b;K=b>>31;b=Yb(m,-16777216,16776704);n=v[a+64>>2];e=Yb(j,-16777216,16776704);L=v[a+72>>2];M=v[a+32>>2];j=c;N=v[c>>2];b=Fma(n,n>>31,b,b>>31);n=mb;p=b;b=v[a+68>>2];q=Fma(b,b>>31,e,e>>31);e=p+q|0;b=mb+n|0;b=e>>>0<q>>>0?b+1|0:b;p=e;i=(((((((B(F,G)+B(H,I)|0)+B(D,E)|0)+B(A,C)|0)+B(y,z)|0)+B(w,x)|0)+B(h,s)|0)+B(f,i)<<8)/32768<<8;e=i;f=Fma(J,K,e,e>>31);e=p+f|0;b=mb+b|0;b=e>>>0<f>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}e=(b&16777215)<<8|e>>>24;b=(e|0)/256|0;l=v[a+28>>2]+l|0;f=l>>12;v[j>>2]=B(b,f)+N;k=k+M|0;h=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,h);b=e-(i&L)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];e=v[g+12>>2];j=m;m=b;continue}break}i=v[g+8>>2];e=v[g+12>>2];j=m;break e}h=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=j;v[a+44>>2]=b;v[a+24>>2]=h;v[a>>2]=i;v[a+4>>2]=e;jb=g+16|0}function Wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+8>>2];f=v[a+12>>2];d:{if((f|0)<1?1:(f|0)<=1?i>>>0<=805306368:0){if((f|0)>-2?1:(f|0)>=-2?i>>>0>=3489660928:0){break c}if((f|0)>-2?1:(f|0)>=-2?i>>>0>2147483647:0){break d}break b}if((f|0)>1?1:(f|0)>=1?i>>>0>2147483648:0){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}s=v[a+16>>2];j=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];g=v[a>>2];v[h+8>>2]=g;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(g>>>16&65520)+p|0;f=u[b>>1];e=(e<<1)+s|0;g=u[e-6>>1];i=u[b+2>>1];n=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];H=u[e+8>>1];r=v[a+60>>2];b=Yb(m,-16777216,16776704);o=v[a+64>>2];e=Yb(j,-16777216,16776704);I=v[a+72>>2];J=v[a+32>>2];j=c;K=v[c>>2];b=Fma(o,o>>31,b,b>>31);o=mb;q=b;n=(((((((B(i,n)+B(f,g)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(G,H)|0)/32768<<8;b=n;f=Fma(r,r>>31,b,b>>31);g=q+f|0;b=mb+o|0;b=f>>>0>g>>>0?b+1|0:b;q=g;g=v[a+68>>2];g=Fma(g,g>>31,e,e>>31);e=q+g|0;b=mb+b|0;b=e>>>0<g>>>0?b+1|0:b;e=e+8388608|0;if(e>>>0<8388608){b=b+1|0}e=(b&16777215)<<8|e>>>24;b=(e|0)/256|0;l=v[a+28>>2]+l|0;f=l>>12;v[j>>2]=B(b,f)+K;k=k+J|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);b=e-(n&I)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;g=v[h+8>>2];e=v[h+12>>2];j=m;m=b;continue}break}g=v[h+8>>2];e=v[h+12>>2];j=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=j;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=g;v[a+4>>2]=e;jb=h+16|0}function Jba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;k=jb-32|0;jb=k;b=a+8|0;us(b,Ke(b));m=zb(b),n=0,v[m>>2]=n;m=b,n=hc(b),v[m>>2]=n;m=hc(b),n=0,v[m>>2]=n;v[a+32>>2]=0;v[a+36>>2]=0;f=a+4|0;v[v[f>>2]>>2]=0;v[v[f>>2]+40>>2]=v[v[a>>2]+480196>>2];v[v[f>>2]+44>>2]=v[v[a>>2]+480204>>2];v[v[f>>2]+68>>2]=v[v[a>>2]+480200>>2];e=x[v[a>>2]+480188>>1];b=k;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;i=b+8|0;b=i;v[b>>2]=0;v[b+4>>2]=0;t[b+21|0]=255;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;v[b+8>>2]=0;v[b+12>>2]=0;h=jb-16|0;jb=h;v[h+12>>2]=e;d=a+20|0;a:{if(We(d)>>>0>=e>>>0){m=h,n=Id(d),v[m+8>>2]=n;c=v[d>>2];b=i;g=v[Lb(h+12|0,h+8|0)>>2];if(g){while(1){e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;e=x[b+18>>1]|x[b+20>>1]<<16;l=x[b+14>>1]|x[b+16>>1]<<16;u[c+14>>1]=l;u[c+16>>1]=l>>>16;u[c+18>>1]=e;u[c+20>>1]=e>>>16;e=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=e;c=c+24|0;g=g-1|0;if(g){continue}break}}b=v[h+12>>2];c=v[h+8>>2];if(b>>>0>c>>>0){YL(d,b-c|0,i);break a}b=v[d>>2]+B(b,24)|0;Id(d);ZL(d,b);up(d);break a}b=d;if(v[b>>2]){Id(b);_L(b);up(b);Xo(zb(b),v[b>>2],We(b));m=zb(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0}c=Jk(d,e);if(sT(d)>>>0<c>>>0){fd();L()}zb(b);g=c;if(c>>>0>178956970){Fc(20384);L()}g=sc(B(g,24),8);v[b>>2]=g;v[b+4>>2]=g;m=zb(b),n=g+B(c,24)|0,v[m>>2]=n;Wt(b,0);YL(d,e,i)}jb=h+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(j,896);pn((b+v[f>>2]|0)+608|0,v[a>>2],j&65535);t[(b+v[f>>2]|0)+1445|0]=0;t[(b+v[f>>2]|0)+1444|0]=0;t[(b+v[f>>2]|0)+1429|0]=0;t[(b+v[f>>2]|0)+1432|0]=0;t[(b+v[f>>2]|0)+1427|0]=0;j=j+1|0;if(j>>>0<x[v[a>>2]+480188>>1]){continue}break}}jb=k+32|0}function Jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=jb-48|0;jb=f;s=v[a+16>>2];g=v[a+44>>2];v[f+32>>2]=g;e=v[a+48>>2];v[f+36>>2]=e;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;w=v[a+24>>2];x=v[a+20>>2];l=v[a+4>>2];i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=l;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;if(d){while(1){h=(((l&2147483647)<<1|i>>>31)&-2)+s|0;m=1;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];j=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];n=u[e+28>>1];r=u[e+26>>1];y=u[e+24>>1];k=0;e=1;g=0;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[h+(g|4)|0],o)+B(t[h+(g|2)|0],p)|0)+B(t[h+(g|6)|0],j)|0)+B(i,t[h+(g|8)|0])<<8)/2|0)+((((B(t[h+(g|-4)|0],r)+B(t[h+(g|-6)|0],y)|0)+B(t[h+(g|-2)|0],n)|0)+B(t[g+h|0],q)<<8)/2|0)|0)/16384;l=e;e=0;g=1;if(l){continue}break}while(1){h=(f+8|0)+(k<<2)|0;i=v[h>>2];j=v[a+60>>2];o=j;l=(f+32|0)+(k<<3)|0;k=v[l>>2];e=Yb(k,-16777216,16776704);p=v[a+64>>2];g=Yb(v[l+4>>2],-16777216,16776704);n=v[a+68>>2];r=n;n=n>>31;v[l+4>>2]=k;k=v[a+72>>2];j=j>>31;i=i<<8;j=Fma(o,j,i,i>>31);o=mb;q=h;h=j;j=Fma(p,p>>31,e,e>>31);h=h+j|0;e=mb+o|0;e=h>>>0<j>>>0?e+1|0:e;j=h;h=Fma(r,n,g,g>>31);g=j+h|0;e=mb+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;v[q>>2]=(e|0)/256;v[l>>2]=e-(i&k);k=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],w);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];l=v[f+28>>2];continue}break}i=v[f+24>>2];l=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];g=v[f+32>>2];e=v[f+36>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=e;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=l;jb=f+48|0}function pH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;d=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;c=e;a:{b:{switch(v[d+40>>2]){case 0:b=jb-80|0;jb=b;f=v[c>>2];g=v[f+4>>2];v[b+40>>2]=v[f+20>>2];i=v[f+16>>2];v[b+32>>2]=v[f+12>>2];v[b+36>>2]=i;Do(b- -64|0,b+32|0,g);f=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);g=v[v[c+12>>2]>>2];i=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[f+8>>2];c=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(g){while(1){f=0;if(i){while(1){k=A[ch(c,f,h)>>3];fc(d,f);m=Of(j,f,h),n=C(k),z[m>>2]=n;f=f+1|0;if((i|0)!=(f|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=b+80|0;break a;case 2:Gw(c,zb(d));break a;case 3:i=Ug(d);b=jb-80|0;jb=b;d=v[c>>2];h=v[d+4>>2];v[b+40>>2]=v[d+20>>2];g=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=g;Do(b- -64|0,b+32|0,h);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);h=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(h){while(1){d=0;if(g){while(1){k=A[ch(c,d,f)>>3];Ve(i,d);l=sj(Sd(k*134217728));m=Of(j,d,f),n=C(+(l|0)*7.450580596923828e-9),z[m>>2]=n;d=d+1|0;if((g|0)!=(d|0)){continue}break}}f=f+1|0;if((h|0)!=(f|0)){continue}break}}jb=b+80|0;break a;case 1:Gw(c,zb(d));break a;default:break b}}Gw(c,zb(d))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;s=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;g=v[a+56>>2];v[b+44>>2]=g;o=v[a+40>>2];p=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){l=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;h=(j>>>21&2040)+27888|0;j=u[h+6>>1];g=u[h+4>>1];k=u[h+2>>1];m=u[h>>1];h=0;i=1;f=0;while(1){n=(b+8|0)+(f<<2)|0;f=f<<1;v[n>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],m)|0)+B(g,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;q=i&1;i=0;f=1;if(q){continue}break}while(1){i=(b+8|0)+(h<<2)|0;j=v[i>>2];g=v[a+60>>2];k=g;h=(b+32|0)+(h<<3)|0;m=v[h>>2];e=Yb(m,-16777216,16776704);q=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);n=v[a+68>>2];t=n;n=n>>31;v[h+4>>2]=m;m=v[a+72>>2];r=g>>31;j=j<<8;g=j;g=Fma(k,r,g,g>>31);k=mb;r=i;i=g;g=Fma(q,q>>31,e,e>>31);i=i+g|0;e=mb+k|0;e=i>>>0<g>>>0?e+1|0:e;g=i;i=Fma(t,n,f,f>>31);f=g+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[r>>2]=(e|0)/256;v[h>>2]=e-(j&m);h=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];p=v[a+28>>2]+p|0;f=p>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);o=e+o|0;k=o>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];g=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}k=o>>12;f=p>>12}v[a+40>>2]=o;v[a+20>>2]=f;v[a+36>>2]=p;v[a+56>>2]=g;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;jb=b+48|0}function tx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;i=b,j=w[pc(b,f+15|0)|0],t[i|0]=j;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){h=w[d+20832|0];m:{n:{if(c){if(g>>>0<=h>>>0){break n}break m}if((g|0)!=(h|0)){break m}}t[a|0]=11;t[b|0]=d;break a}e=d>>>0<9;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[pc(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}jb=f+16|0;return e}function oO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=jb-32|0;jb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;if(!(b&2)){break a}b=w[a+14|0];if(b>>>0<=w[a+13|0]){break a}if(Kb(a)>>>0<=b>>>0){break a}while(1){d=Dc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Kb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Kb(a)>>>0<=b>>>0){break a}d=x[Dc(a,w[a+14|0])>>1];e=Dc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Dc(a,b)>>1]-1&65535;d=qp(a,b,64,64);q=f,r=bc(a),v[q+8>>2]=r;q=f,r=pp(f+8|0,w[a+14|0]),v[q+16>>2]=r;e=Md(f+24|0,f+16|0);i=Cp(f,b,d&255);g=jb-32|0;jb=g;v[g+24>>2]=v[e>>2];b=a;d=v[a>>2];q=g,r=bc(a),v[q>>2]=r;d=d+(tt(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[zb(a)>>2]){j=v[b+4>>2];if((j|0)!=(d|0)){break d}tR(b,i);break c}e=zb(b);e=Un(g,Be(b,Kb(b)+1|0),d-v[b>>2]>>2,e);v[114578]=0;R(1159,e|0,i|0);k=v[114578];v[114578]=0;e:{if((k|0)==1){break e}v[114578]=0;d=W(1160,b|0,e|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Wh(e);break c}a=P()|0;O()|0;Wh(e);S(a|0);L()}l=jb-16|0;jb=l;k=d;n=b;o=v[b+4>>2];b=(o-(d+4|0)|0)+d|0;h=qe(l,n,j-b>>2);f:{g:{if(b>>>0<j>>>0){e=b;while(1){m=zb(n);p=v[h+4>>2];v[114578]=0;U(767,m|0,p|0,e|0);m=v[114578];v[114578]=0;if((m|0)==1){break g}v[h+4>>2]=v[h+4>>2]+4;e=e+4|0;if(j>>>0>e>>>0){continue}break}}Mb(h);Fp(k,b,o);jb=l+16|0;break f}a=P()|0;O()|0;Mb(h);S(a|0);L()}u[d>>1]=x[i>>1];t[d+2|0]=w[i+2|0]}Ng(d);jb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}jb=f+32|0}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;f=gh(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(ni(b)){Fo(c+56|0);break n}v[114578]=0;R(2189,c+40|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break m}v[114578]=0;R(2175,c+56|0,c+40|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}rf(c+40|0)}a=b+36|0;o:{if(ni(b)){break o}a=v[c+56>>2]}e=Id(a);v[114578]=0;R(1533,f|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break k}h=c,i=bc(a),v[h+32>>2]=i;h=c,i=cc(a),v[h+24>>2]=i;if(Jb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Di(v[a>>2]+484360|0,w[e+16|0]);v[114578]=0;R(2190,c+8|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break j}v[114578]=0;U(9,c+40|0,0,c+8|0);d=v[114578];v[114578]=0;if((d|0)==1){break i}v[114578]=0;R(1535,f|0,c+40|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}yb(c+40|0);yb(c+8|0);p:{if(!Wc(LH(f))){break p}d=w[e+12|0];v[114578]=0;d=Q(546,b|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}if(!d){break p}d=v[a>>2];v[114578]=0;d=T(686,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}b=_b(v[a>>2]+484344|0,x[rc(b,v[e+12>>2])>>1]);v[114578]=0;R(2191,c+8|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;X(440,c+40|0,0,d|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}Gb(LH(f),c+40|0);yb(c+40|0);yb(c+8|0)}Ik(c+32|0);if(Jb(c+32|0,c+24|0)){continue}break}}gk(c+56|0);jb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;rf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;yb(c+40|0)}yb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(c+8|0);break b}b=P()|0;O()|0}gk(c+56|0)}ld(f);S(b|0);L()}function pU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;Jc(c);a:{if(!Qb(c,3)){break a}while(1){hq(f+8|0,c);i=dd(f+8|0);d=Bf(f+8|0);g=f+8|0;if(y[a+12>>2]<=w[g|0]){break a}e=Xe(a,w[g|0],b);h=w[i|0];b:{if(h>>>0<=126){if(!(h|w[d|0])){t[e|0]=254;break b}t[e|0]=h+1;if(w[d|0]==255){break b}if(!w[e+1|0]){t[e+1|0]=j}t[e+2|0]=1;t[e+4|0]=w[d|0];break b}c:{switch(h-127|0){case 0:d=w[g|0]+t[d|0]|0;if((d|0)<0|(d|0)>=v[a+12>>2]<<16>>16){break b}d=Xe(a,d,b);g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[e|0]=g;t[e+1|0]=g>>>8;t[e+2|0]=g>>>16;t[e+3|0]=g>>>24;d=w[d+4|0]|w[d+5|0]<<8;t[e+4|0]=d;t[e+5|0]=d>>>8;break b;case 1:j=w[d|0]+1|0;t[e+1|0]=j;break b;default:break c}}d=t[d|0];t[f+7|0]=d;g=0;h=h&127;if(h>>>0<=23){g=w[h+12144|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{h=w[i|0];switch((h&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break e}}if((d|0)>-1){break f}d=0-d&15;break e}t[f+6|0]=64;d=w[pc(f+7|0,f+6|0)|0];if(w[e+2|0]>1){break e}t[e+4|0]=d;t[e+2|0]=1;break b}if((d|0)>-1){g=3;break d}d=0-d&127;t[f+7|0]=d;break e}if(!d){break b}if((d|0)<=-1){d=0-d|-16;t[f+7|0]=d;break e}d=d<<4|15;t[f+7|0]=d;break e}if(!d){break b}g=(d|0)>-1;if(!g){d=0-d&15;t[f+7|0]=d;h=w[i|0]}g=g?3:2;d=((h|0)==22?-32:-16)|d;t[f+7|0]=d;break d}d=d&15|-48;t[f+7|0]=d;break e}d=d&15|-64;t[f+7|0]=d;break e}d=d- -64&127;if(!w[e+3|0]){break e}o:{switch(w[e+2|0]){case 0:case 2:break o;default:break b}}t[e+2|0]=2;t[e+4|0]=d>>>1;break b}d=d<<4}if(!(g&255)){break b}}t[e+5|0]=d;t[e+3|0]=g}if(Qb(c,3)){continue}break}}jb=f+16|0}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;b=jb-48|0;jb=b;s=v[a+16>>2];i=v[a+44>>2];v[b+32>>2]=i;l=v[a+48>>2];v[b+36>>2]=l;h=v[a+52>>2];v[b+40>>2]=h;g=v[a+56>>2];v[b+44>>2]=g;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+s|0;f=(j>>>21&2040)+27888|0;j=u[f+6>>1];g=u[f+4>>1];k=u[f+2>>1];m=u[f>>1];i=0;l=1;h=1;f=0;while(1){v[(b+8|0)+(f<<2)>>2]=(((B(t[e+f|0],k)+B(t[e+(f|-2)|0],m)|0)+B(g,t[e+(f|2)|0])|0)+B(j,t[e+(f|4)|0])<<8)/16384;p=h&1;h=0;f=1;if(p){continue}break}while(1){h=(b+8|0)+(i<<2)|0;j=v[h>>2];g=v[a+60>>2];k=g;f=(b+32|0)+(i<<3)|0;m=v[f>>2];e=Yb(m,-16777216,16776704);p=v[a+64>>2];i=Yb(v[f+4>>2],-16777216,16776704);q=v[a+68>>2];w=q;q=q>>31;v[f+4>>2]=m;m=v[a+72>>2];r=g>>31;j=j<<8;g=j;g=Fma(k,r,g,g>>31);k=mb;r=h;h=g;g=Fma(p,p>>31,e,e>>31);h=h+g|0;e=mb+k|0;e=h>>>0<g>>>0?e+1|0:e;g=h;h=Fma(w,q,i,i>>31);i=g+h|0;e=mb+e|0;e=i>>>0<h>>>0?e+1|0:e;i=i+8388608|0;if(i>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|i>>>24;v[r>>2]=(e|0)/256;v[f>>2]=e-(j&m);i=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;k=o>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);n=e+n|0;f=n>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];g=v[b+44>>2];h=v[b+40>>2];l=v[b+36>>2];i=v[b+32>>2];break a}f=n>>12;k=o>>12}v[a+40>>2]=n;v[a+20>>2]=k;v[a+36>>2]=o;v[a+56>>2]=g;v[a+52>>2]=h;v[a+48>>2]=l;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=j;v[a+4>>2]=e;jb=b+48|0}function xv(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:while(1){h=b-4|0;b:while(1){d=a;c:while(1){d:{e:{f:{g:{h:{i:{j:{k:{a=b-d|0;e=a>>2;switch(e|0){case 4:break j;case 2:break k;case 0:case 1:break d;case 3:break g;case 5:break i;default:break h}}a=b-4|0;if(!Jd(a,d)){break d}Zb(d,a);return}wv(d,d+4|0,d+8|0,b-4|0);return}vv(d,d+4|0,d+8|0,d+12|0,b-4|0);return}if((a|0)<=123){h=b;f=jb-16|0;jb=f;e=d;c=d+8|0;qm(d,d+4|0,c);b=d+12|0;while(1){if((b|0)!=(h|0)){if(Jd(b,c)){v[f+12>>2]=v[b>>2];d=b;while(1){l:{a=c;v[d>>2]=v[a>>2];if((a|0)==(e|0)){a=e;break l}d=a;c=d-4|0;if(Jd(f+12|0,c)){continue}}break}v[a>>2]=v[f+12>>2]}c=b;b=b+4|0;continue}break}jb=f+16|0;return}g=((e|0)/2<<2)+d|0;m:{if((a|0)>=3997){a=(e|0)/4<<2;i=vv(d,a+d|0,g,a+g|0,h);break m}i=qm(d,g,h)}a=h;if(!Jd(d,g)){while(1){a=a-4|0;if((d|0)==(a|0)){f=d+4|0;if(Jd(d,h)){break e}while(1){if((f|0)==(h|0)){break d}if(Jd(d,f)){Zb(f,h);f=f+4|0;break e}else{f=f+4|0;continue}}}if(!Jd(a,g)){continue}break}Zb(d,a);i=i+1|0}e=d+4|0;if(e>>>0>=a>>>0){break f}while(1){f=e;e=e+4|0;if(Jd(f,g)){continue}while(1){a=a-4|0;if(!Jd(a,g)){continue}break}if(a>>>0<f>>>0){e=f;break f}else{Zb(f,a);g=(f|0)==(g|0)?a:g;i=i+1|0;continue}}}qm(d,d+4|0,b-4|0);break d}n:{if((e|0)==(g|0)){break n}if(!Jd(g,e)){break n}Zb(e,g);i=i+1|0}if(!i){f=ND(d,e);a=e+4|0;if(ND(a,b)){b=e;a=d;if(!f){continue a}break d}if(f){continue b}}if((e-d|0)<(b-e|0)){xv(d,e,c);a=e+4|0;continue b}xv(e+4|0,b,c);b=e;a=d;continue a}a=h;if((f|0)==(a|0)){break d}while(1){e=f;f=e+4|0;if(!Jd(d,e)){continue}while(1){a=a-4|0;if(Jd(d,a)){continue}break}if(a>>>0<=e>>>0){d=e;continue c}else{Zb(e,a);continue}}}break}break}break}}function R_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-384|0;jb=a;v[a+368>>2]=c;v[a+376>>2]=b;Gv(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Wb(a+200|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114578]=0;b=Q(2461,a+376|0,a+368|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+196>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+196>>2]=b+c}v[114578]=0;b=T(2463,a+376|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=er(b,a+23|0,a+22|0,c,a+196|0,v[a+236>>2],v[a+232>>2],a+216|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2465,a+376|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114578]=0;X(2450,a|0,c|0,v[a+196>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114578]=0;Ee(a+216|0,a+32|0,v[a+28>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+376|0,a+368|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];yb(d);yb(a+216|0);jb=a+384|0;break a}}b=P()|0;O()|0;yb(d);yb(a+216|0);S(b|0);L()}return b|0}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;Jv(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Wb(a+208|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114578]=0;b=Q(2429,a+280|0,a+272|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+204>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+204>>2]=b+c}v[114578]=0;b=T(2431,a+280|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=gr(b,a+23|0,a+22|0,c,a+204|0,t[a+239|0],t[a+238|0],a+224|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2433,a+280|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114578]=0;X(2450,a|0,c|0,v[a+204>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114578]=0;Ee(a+224|0,a+32|0,v[a+28>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+280|0,a+272|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];yb(d);yb(a+224|0);jb=a+288|0;break a}}b=P()|0;O()|0;yb(d);yb(a+224|0);S(b|0);L()}return b|0}function oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;g=jb-48|0;jb=g;p=v[a+16>>2];h=Qf(g+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=Pf(a+8|0,b),v[t>>2]=w;v[h+4>>2]=mb}k=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];f=v[a+4>>2];e=v[a>>2];v[g+8>>2]=e;v[g+12>>2]=f;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(d){while(1){b=0;i=b;v[g+40>>2]=e;v[g+44>>2]=b;f=(f<<1)+p|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],u[(i<<1)+f>>1]/4<<16>>16);zd(v[h+8>>2],4);Sb(g+40|0,h);if((b|0)<2){break b}b=b-1|0;i=v[g+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Ad(b,u[f+(v[g+44>>2]<<1)>>1]/4<<16>>16);zd(v[h+8>>2],e);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);i=v[a+60>>2];b=Yb(n,-16777216,16776704);j=v[a+64>>2];f=Yb(k,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];k=c;s=v[c>>2];o=e<<8;e=o;e=Fma(i,i>>31,e,e>>31);i=mb;j=Fma(j,j>>31,b,b>>31);e=j+e|0;b=mb+i|0;b=e>>>0<j>>>0?b+1|0:b;i=e;e=v[a+68>>2];e=Fma(e,e>>31,f,f>>31);f=i+e|0;b=mb+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;m=v[a+28>>2]+m|0;i=m>>12;v[k>>2]=B(b,i)+s;l=l+r|0;j=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);b=f-(q&o)|0;Sb(g+8|0,g);if(d){c=c+8|0;e=v[g+8>>2];f=v[g+12>>2];k=n;n=b;continue}break}e=v[g+8>>2];f=v[g+12>>2];k=n;break a}j=l>>12;i=m>>12;b=n}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=k;v[a+44>>2]=b;v[a+24>>2]=j;v[a>>2]=e;v[a+4>>2]=f;jb=g+48|0}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-16|0;jb=d;a:{if(!Qb(a,2)){rg(c+484344|0,b,64);break a}j=c+484344|0;h=Cd(Wp(a),1,1024);if(!rg(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){n=Rn(_b(j,b),i);g=0;if(k){while(1){Sl(d+8|0,a);e=dd(d+8|0);o=Bf(d+8|0);c=B(g,6)+n|0;f=w[Sh(d+8|0)|0];t[c+5|0]=f;l=0;m=w[d+8|0];if((m-1&255)>>>0<=35){t[c|0]=m+48;l=w[e|0]+1|0}e=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[e|0]=f&15;break b;case 2:t[c+3|0]=3;t[e|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=36;t[d+7|0]=15;p=e,q=w[pc(d+7|0,e)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=35;t[d+6|0]=15;p=e,q=w[pc(d+6|0,e)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=36;t[d+5|0]=15;p=e,q=w[pc(d+5|0,e)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=35;t[d+4|0]=15;p=e,q=w[pc(d+4|0,e)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[e|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:jt(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[e|0]=f&15;break b;case 5:t[e|0]=f<<4;break b;case 6:t[d+3|0]=f&15;t[d+2|0]=14;p=e,q=w[pc(d+3|0,d+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[d+1|0]=f&15;t[d|0]=14;p=e,q=w[pc(d+1|0,d)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[e|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}jb=d+16|0}function hh(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;a:{if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;h=c&d;b:{if(h){kn(e,f);break b}kn(e,0)}t[f+40|0]=!h;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){zy((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}d=(B(b&256?d+9|0:d,44)+a|0)+16|0;v[g+8>>2]=d;f=v[d+36>>2];v[g+12>>2]=f;a=1;e=f?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}a=c&32;FN(d,a>>>5|0);h=c>>>2&7;EN(d,h);c=c&3;DN(d,c);if(!f){break a}b=1;d=(a|0)!=0;while(1){a=v[(g+8|0)+(b<<2)>>2];FN(a,d);EN(a,h);DN(a,c);b=b+1|0;if((e|0)!=(b|0)){continue}break}break a}CN(d,c);if(!f){break a}while(1){CN(v[(g+8|0)+(a<<2)>>2],c);a=a+1|0;if((e|0)!=(a|0)){continue}break}break a}t[d+42|0]=(c&32)>>>5;t[d+41|0]=(c&16)>>>4;a=c>>>1&7;u[d+30>>1]=a?9-a|0:0;u[d+32>>1]=c&1;break a}if((d|0)!=224?d>>>0>=129:0){break a}f=b&31;if(-4144960>>>f&1){break a}e=a;a=t[f+19888|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;ln(a);u[a+14>>1]=x[((c&15)<<1)+19920>>1];break a;case 1:u[a+68>>1]=w[(c>>>6|0)+19952|0];BN(a);u[a+22>>1]=(c&63)<<2;break a;case 2:u[a+24>>1]=c>>>4;ln(a);u[a+26>>1]=c&15;ln(a);break a;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;ln(a);break a;case 6:break d;default:break a}}u[a+12>>1]=c&7}jb=g+16|0}function dla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-96|0;jb=d;b=b&4095;u[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=Fma(e,e>>31,1e4,0)+14780|0;b=mb;b=Gma(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((((b|0)/-4|0)+e|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<=-1){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Ub(d- -64|0,13390);v[114578]=0;R(219,d+80|0,e|0);f=v[114578];v[114578]=0;h=(B(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){v[114578]=0;g=b;b=h+2|0;f=(b|0)/12|0;v[d+44>>2]=g+f;R(191,d+48|0,d+44|0);g=v[114578];v[114578]=0;if((g|0)==1){break o}v[114578]=0;v[d+28>>2]=(b-B(f,12)|0)+1;R(193,d+32|0,d+28|0);b=v[114578];v[114578]=0;if((b|0)==1){break n}v[114578]=0;v[d+12>>2]=(((B(h,306)+5|0)/-10|0)+c|0)+1;R(193,d+16|0,d+12|0);b=v[114578];v[114578]=0;if((b|0)==1){break m}v[114578]=0;fa(619,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break l}yb(d+16|0);yb(d+32|0);yb(d+48|0);Ib(d+80|0);yb(e);break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;yb(d+16|0)}yb(d+32|0)}yb(d+48|0)}Ib(d+80|0)}yb(e);break a}c=Ub(d,13414);v[114578]=0;R(219,d+80|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;R(620,d+48|0,d+94|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(247,a|0,d+80|0,d+48|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}yb(d+48|0);Ib(d+80|0);yb(c)}jb=d+96|0;return}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+48|0)}Ib(d+80|0)}yb(c)}S(b|0);L()}function hD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-128|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=v[b>>2];l:{if(!b){Ub(a,7037);break l}if(!(b&65535)){e=Ub(c+96|0,7045);v[114578]=0;R(219,c+112|0,e|0);d=v[114578];v[114578]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){v[114578]=0;v[c+24>>2]=b>>>24;R(220,c+80|0,c+24|0);d=v[114578];v[114578]=0;if((d|0)==1){break r}v[114578]=0;v[c+8>>2]=b>>>16&255;R(221,c- -64|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break q}v[114578]=0;X(222,a|0,c+112|0,c+80|0,c- -64|0);a=v[114578];v[114578]=0;if((a|0)==1){break p}yb(c- -64|0);yb(c+80|0);Ib(c+112|0);yb(e);break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;yb(c- -64|0)}yb(c+80|0)}Ib(c+112|0)}break a}e=Ub(c+48|0,7051);v[114578]=0;R(219,c+112|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break k}v[114578]=0;v[c+44>>2]=b>>>24;R(220,c+80|0,c+44|0);d=v[114578];v[114578]=0;if((d|0)==1){break j}v[114578]=0;v[c+40>>2]=b>>>16&255;R(221,c- -64|0,c+40|0);d=v[114578];v[114578]=0;if((d|0)==1){break i}v[114578]=0;v[c+20>>2]=b>>>8&255;R(221,c+24|0,c+20|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}v[114578]=0;v[c+4>>2]=b&255;R(221,c+8|0,c+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;ma(223,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break f}yb(c+8|0);yb(c+24|0);yb(c- -64|0);yb(c+80|0);Ib(c+112|0);yb(e)}jb=c+128|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;yb(c+8|0)}yb(c+24|0)}yb(c- -64|0)}yb(c+80|0)}Ib(c+112|0)}yb(e);S(b|0);L()}function YI(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=jb-16|0;jb=d;k=d,l=C(_w(z[a+4216>>2])/C(Se(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(K(C(C(yo(C(z[ol(d+12|0,d+8|0)>>2]*C(6.2831854820251465)))*C(.4000000059604645))+C(.6000000238418579))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));f=a;b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[f+4272|0]=c;f=a;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[f+4273|0]=e;h=ne(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))*C(.05000000074505806)));k=d,l=C(_w(z[a+4220>>2])/C(Se(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[ol(d+12|0,d+8|0)>>2];k=d,l=C(_w(z[a+4224>>2])/C(Se(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(z[ol(d+12|0,d+8|0)>>2]*C(3.1415927410125732));e=jb-16|0;jb=e;f=(p(b),j(2));c=f&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Hm(+b,0);break c}if(c>>>0<=1081824209){g=+b;if(c>>>0<=1075235811){b=Hm(((f|0)>-1?-1.5707963267948966:1.5707963267948966)+g,1);break c}b=Hm(((f|0)>-1?-3.141592653589793:3.141592653589793)+g,0);break c}if(c>>>0<=1088565717){g=+b;if(c>>>0<=1085271519){b=Hm(((f|0)>-1?-4.71238898038469:4.71238898038469)+g,1);break c}b=Hm(((f|0)>-1?-6.283185307179586:6.283185307179586)+g,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=pw(b,e+8|0);b=Hm(A[e+8>>3],c&1)}jb=e+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=yo(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+33376>>2];jb=d+16|0}function x_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-384|0;jb=f;v[f+376>>2]=37;v[f+380>>2]=0;g=br(f+376|1,64441,v[c+4>>2]);v[f+332>>2]=f+336;a=le();a:{if(g){h=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=h;a=af(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=af(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2427;h=Rd(f+320|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){v[114578]=0;a=da(2452)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114578]=0;A[f+8>>3]=e;a=aa(2474,f+332|0,a|0,f+376|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break e}break c}v[114578]=0;a=da(2452)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114578]=0;a=aa(2474,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}}g=v[f+332>>2];if(!g){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(h,g)}g=v[f+332>>2];j=g+a|0;k=mg(g,j,c);v[f+68>>2]=2427;i=Rd(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;g=f+336|0;break g}a=pd(a<<3);if(!a){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(i,a);g=v[f+332>>2]}v[114578]=0;Bc(f+56|0,c);l=v[114578];v[114578]=0;h:{i:{if((l|0)!=1){v[114578]=0;ia(2485,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}Ob(f+56|0);v[114578]=0;a=ka(2486,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(i);Gc(h);jb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(f+56|0);break f}c=P()|0;O()|0}Gc(i);break b}L()}c=P()|0;O()|0}Gc(h);S(c|0);L()}function J_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-208|0;jb=f;v[f+200>>2]=37;v[f+204>>2]=0;g=br(f+200|1,64441,v[c+4>>2]);v[f+156>>2]=f+160;a=le();a:{if(g){h=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=h;a=af(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=af(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2427;h=Rd(f+144|0,0,f+80|0);b:{c:{d:{if((a|0)>=30){e:{if(g){v[114578]=0;a=da(2452)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114578]=0;A[f+8>>3]=e;a=aa(2474,f+156|0,a|0,f+200|0,f|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break e}break c}v[114578]=0;a=da(2452)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114578]=0;a=aa(2474,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}}g=v[f+156>>2];if(!g){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)==1){break c}break d}ye(h,g)}g=v[f+156>>2];j=g+a|0;k=mg(g,j,c);v[f+68>>2]=2427;i=Rd(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;g=f+160|0;break g}a=pd(a<<1);if(!a){v[114578]=0;Y(2428);a=v[114578];v[114578]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ye(i,a);g=v[f+156>>2]}v[114578]=0;Bc(f+56|0,c);l=v[114578];v[114578]=0;h:{i:{if((l|0)!=1){v[114578]=0;ia(2475,g|0,k|0,j|0,a|0,f+68|0,f- -64|0,f+56|0);g=v[114578];v[114578]=0;if((g|0)==1){break i}Ob(f+56|0);v[114578]=0;a=ka(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break h}Gc(i);Gc(h);jb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(f+56|0);break f}c=P()|0;O()|0}Gc(i);break b}L()}c=P()|0;O()|0}Gc(h);S(c|0);L()}function pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;g=jb-48|0;jb=g;p=v[a+16>>2];h=Qf(g+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=Pf(a+8|0,b),v[u>>2]=w;v[h+4>>2]=mb}k=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];f=v[a+4>>2];e=v[a>>2];v[g+8>>2]=e;v[g+12>>2]=f;b=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=b;a:{if(d){while(1){b=0;i=b;v[g+40>>2]=e;v[g+44>>2]=b;f=f+p|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],t[f+i|0]<<6);zd(v[h+8>>2],4);Sb(g+40|0,h);if((b|0)<2){break b}b=b-1|0;i=v[g+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];e=v[b+4>>2];if(e){Ad(b,t[f+v[g+44>>2]|0]<<6);zd(v[h+8>>2],e);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);i=v[a+60>>2];b=Yb(n,-16777216,16776704);j=v[a+64>>2];f=Yb(k,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];k=c;s=v[c>>2];o=e<<8;e=o;e=Fma(i,i>>31,e,e>>31);i=mb;j=Fma(j,j>>31,b,b>>31);e=j+e|0;b=mb+i|0;b=e>>>0<j>>>0?b+1|0:b;i=e;e=v[a+68>>2];e=Fma(e,e>>31,f,f>>31);f=i+e|0;b=mb+b|0;b=f>>>0<e>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;m=v[a+28>>2]+m|0;i=m>>12;v[k>>2]=B(b,i)+s;l=l+r|0;j=l>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);b=f-(q&o)|0;Sb(g+8|0,g);if(d){c=c+8|0;e=v[g+8>>2];f=v[g+12>>2];k=n;n=b;continue}break}e=v[g+8>>2];f=v[g+12>>2];k=n;break a}j=l>>12;i=m>>12;b=n}v[a+40>>2]=l;v[a+20>>2]=i;v[a+36>>2]=m;v[a+48>>2]=k;v[a+44>>2]=b;v[a+24>>2]=j;v[a>>2]=e;v[a+4>>2]=f;jb=g+48|0}function kI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0);d=jb-48|0;jb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}lc(d+8|0,v[a>>2]+24604|0,40);v[d+8>>2]=b;Kx(v[a>>2],d+8|0);break d;case 2:f=a+24|0;a=v[f>>2];b=a+24664|0;e=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=e;b=a+24656|0;e=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=e;b=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=b;e=d;g=jb-16|0;jb=g;b=3;f:{g:{h:{a=c;if(!a|(a|0)>7){break h}b=2;if((a|0)>2){break h}b=1;if((a|0)==2){break h}b=0;if((a|0)>0){break h}a=ba(8)|0;v[114578]=0;b=Q(85,g|0,39884)|0;c=v[114578];v[114578]=0;i:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break g}c=P()|0;O()|0;yb(b);break i}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}jb=g+16|0;break f}L()}t[e+8|0]=b;if(!Tw(d+8|0,v[f>>2]+24648|0)){break d}Jx(v[f>>2],d+8|0);break d;case 3:b=a+24|0;lc(d+8|0,v[b>>2]+24604|0,40);a=d+8|0;e=jb-48|0;jb=e;j:{if((c|0)==-1){ul(a,v[rp(e+8|0)+32>>2]);kn(a,v[rp(e+8|0)+36>>2]);break j}if((c|0)<=0){ul(a,0);kn(a,0);break j}c=B(c,1e3);ul(a,c);kn(a,c)}jb=e+48|0;if(v[v[b>>2]+24640>>2]==v[d+44>>2]?v[v[b>>2]+24636>>2]==v[d+40>>2]:0){break d}Kx(v[b>>2],d+8|0);break d;default:a=ba(8)|0;v[114578]=0;c=Q(85,d+8|0,38669)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b;case 0:break e}}h=a,i=ne(C(10),C(C(c|0)*C(.0005000000237487257))),z[h+48>>2]=i}jb=d+48|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;s=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;f=v[a+48>>2];v[b+36>>2]=f;j=v[a+52>>2];v[b+40>>2]=j;k=v[a+56>>2];v[b+44>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){f=i>>>18|0;l=1;e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+s|0;g=0;j=1;h=0;while(1){k=h<<1;i=u[k+e>>1];v[(b+8|0)+(h<<2)>>2]=i+((B(f,u[e+(k|4)>>1]-i|0)|0)/16384|0);i=j&1;j=0;h=1;if(i){continue}break}while(1){h=(b+8|0)+(g<<2)|0;j=v[h>>2];f=v[a+60>>2];k=f;i=(b+32|0)+(g<<3)|0;o=v[i>>2];e=Yb(o,-16777216,16776704);r=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];t=p;p=p>>31;v[i+4>>2]=o;o=v[a+72>>2];q=f>>31;j=j<<8;f=j;f=Fma(k,q,f,f>>31);k=mb;q=h;h=f;f=Fma(r,r>>31,e,e>>31);h=h+f|0;e=mb+k|0;e=h>>>0<f>>>0?e+1|0:e;f=h;h=Fma(t,p,g,g>>31);g=f+h|0;e=mb+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;v[q>>2]=(e|0)/256;v[i>>2]=e-(j&o);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;h=n>>12;v[c>>2]=v[c>>2]+B(h,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];k=v[b+44>>2];j=v[b+40>>2];f=v[b+36>>2];l=v[b+32>>2];break a}g=m>>12;h=n>>12}v[a+40>>2]=m;v[a+20>>2]=h;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=j;v[a+48>>2]=f;v[a+44>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=jb-16|0;jb=h;a:{b:{c:{j=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?j>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?j>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?j>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?j>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];f=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=(i>>>16&65520)+m|0;g=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);H=v[a+72>>2];I=v[c>>2];b=Fma(l,l>>31,b,b>>31);l=mb;n=b;i=(((((((B(j,s)+B(g,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;g=Fma(o,o>>31,b,b>>31);e=n+g|0;b=mb+l|0;b=e>>>0<g>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=Fma(e,e>>31,f,f>>31);f=n+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=B(f,r)+I;v[c+4>>2]=v[c+4>>2]+B(f,q);b=b-(i&H)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=_s(t[a+36|0],t[a+37|0]),v[i+24>>2]=j;u[a+36>>1]=0;if((b|0)!=1){break a}e=Fma(v[a+24>>2],0,8272,0)+4181|0;d=mb;i=a,j=id(Ima(e,e>>>0<4181?d+1|0:d,8363,0),mb),v[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=Fma(v[a+24>>2],0,8363,0)+4136|0;d=mb;i=a,j=id(Ima(e,e>>>0<4136?d+1|0:d,8272,0),mb),v[i+24>>2]=j}d=jb-16|0;jb=d;h=d+8|0;e=v[a+24>>2];g=0;b:{if(!e){break b}g=mn(vo(+(e>>>0)*.00011957431543704412)*2215.9795828054475)}kG(h,Yb(g,-16384,16383),128);t[a+36|0]=v[d+8>>2];t[a+37|0]=v[d+12>>2];jb=d+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}d=c&4;if(d){e=x[a+34>>1];if(!(e&32)){u[a+28>>1]=128;u[a+34>>1]=e|32}Ue(a+40|0,15);Ue(a+41|0,63)}c:{if(!w[a+41|0]|(!d|!(b&16777248)?!(c&16777248?b&4:0):0)){break c}d=w[a+40|0];if(!d){break c}b=w[a+39|0];if(b){i=a,j=un(id(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0)),t[i+39|0]=j;break c}t[a+39|0]=255}d:{e:{if((c|0)!=4){if((c|0)==16777216){break d}if((c|0)!=32|w[a+38|0]!=2){break e}t[a+38|0]=3;break e}if(w[a+38|0]!=4){break e}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}f:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;op(a,0,f);break f}if(!(w[a+35|0]&2)|(c|0)!=2){break f}a=a+68|0;b=fc(a,8);t[b|0]=w[b|0]&3;a=fc(a,9);t[a|0]=w[a|0]&3}jb=f+32|0}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?i>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?i>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?i>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?i>>>0>2147483648:0){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=e+o|0;g=t[b+4|0];e=(j>>>16&65520)+m|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[c>>2];b=Fma(l,l>>31,b,b>>31);l=mb;L=b;b=v[a+68>>2];n=Fma(b,b>>31,f,f>>31);f=L+n|0;b=mb+l|0;b=f>>>0<n>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(g,j)<<8)/32768<<8;g=Fma(H,I,e,e>>31);f=f+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;if(f>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=B(f,q)+K;v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(e&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;jb=h+16|0}function fF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-272|0;jb=h;g=v[b>>2];v[h+12>>2]=g;m=a?a:h+16|0;e=0;a:{b:{c:{d=a?d:256;if(!d|!g){break c}f=c>>>0>=d>>>0;if(!(f|c>>>0>32)){break b}while(1){k=f?d:c;c=c-k|0;l=0;n=jb-16|0;jb=n;d:{e:{f:{g:{f=m;if(f){if(k>>>0>=4){break g}g=k;break f}f=0;j=v[h+12>>2];g=v[j>>2];if(!g){break d}while(1){if(g>>>0<=127){f=f+1|0}else{l=-1;k=ck(n+12|0,g,0);if((k|0)==-1){break d}f=f+k|0}g=v[j+4>>2];j=j+4|0;l=f;if(g){continue}break}break d}j=v[h+12>>2];g=k;while(1){i=v[j>>2];h:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}l=-1;i=ck(f,i,0);if((i|0)==-1){break d}g=g-i|0;f=f+i|0;break h}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g>>>0>3){continue}break}}if(g){j=v[h+12>>2];while(1){i=v[j>>2];i:{if(i-1>>>0>=127){if(!i){t[f|0]=0;v[h+12>>2]=0;break e}l=-1;i=ck(n+12|0,i,0);if((i|0)==-1){break d}if(g>>>0<i>>>0){break e}ck(f,v[j>>2],0);g=g-i|0;f=f+i|0;break i}t[f|0]=i;g=g-1|0;j=v[h+12>>2];f=f+1|0}j=j+4|0;v[h+12>>2]=j;if(g){continue}break}}l=k;break d}l=k-g|0}jb=n+16|0;if((l|0)==-1){d=0;g=v[h+12>>2];e=-1;break c}f=(h+16|0)==(m|0);m=f?m:l+m|0;e=e+l|0;d=d-(f?0:l)|0;g=v[h+12>>2];if(!d|!g){break c}f=c>>>0>=d>>>0;if(f|c>>>0>=33){continue}break}break b}if(!g){break a}}if(!d|!c){break a}f=e;while(1){j:{k=ck(m,v[g>>2],0);k:{if(k+1>>>0<=1){e=-1;if(k){break a}v[h+12>>2]=0;break k}g=v[h+12>>2]+4|0;v[h+12>>2]=g;f=f+k|0;d=d-k|0;if(d){break j}}e=f;break a}m=k+m|0;e=f;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=v[h+12>>2]}jb=h+272|0;return e|0}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;Gv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2461,a+360|0,a+352|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+180>>2]=b+c}v[114578]=0;b=T(2463,a+360|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=er(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2465,a+360|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=C(va(2446,c|0,v[a+180>>2],e|0));b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114578]=0;Ee(a+200|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+360|0,a+352|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;k=v[a+56>>2];v[b+44>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>10&4194048;e=(((e&2147483647)<<1|h>>>31)&-2)+q|0;f=0;l=1;i=1;g=0;while(1){h=t[e+g|0];v[(b+8|0)+(g<<2)>>2]=((B(j,t[e+(g|2)|0]-h|0)|0)/16384|0)+(h<<8);h=i&1;i=0;g=1;if(h){continue}break}while(1){i=(b+8|0)+(f<<2)|0;j=v[i>>2];k=v[a+60>>2];h=(b+32|0)+(f<<3)|0;f=v[h>>2];e=Yb(f,-16777216,16776704);p=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);o=v[a+68>>2];r=o;o=o>>31;v[h+4>>2]=f;s=v[a+72>>2];j=j<<8;f=j;f=Fma(k,k>>31,f,f>>31);k=mb;u=i;i=Fma(p,p>>31,e,e>>31);f=i+f|0;e=mb+k|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=Fma(r,o,g,g>>31);g=i+f|0;e=mb+e|0;e=g>>>0<f>>>0?e+1|0:e;g=g+8388608|0;if(g>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|g>>>24;v[u>>2]=(e|0)/256;v[h>>2]=e-(j&s);f=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];k=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;jb=b+48|0}function h$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;Jv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2429,a+264|0,a+256|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=b+c}v[114578]=0;b=T(2431,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=gr(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2433,a+264|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=C(va(2446,c|0,v[a+188>>2],e|0));b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function MZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=jb-16|0;jb=x;v[c>>2]=a;z=d&512;while(1){if((y|0)==4){if(Fb(n)>>>0>1){C=x,D=Ed(n),v[C+8>>2]=D;C=c,D=wj(pp(x+8|0,1),Vj(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}jb=x+16|0}else{a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=jr(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 3:if(Wc(n)){break a}q=v[hj(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;break a;case 2:if(Wc(m)|!z){break a}C=c,D=wj(Ed(m),Vj(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}A=v[c>>2];e=h?e+4|0:e;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!$j(g,2048,v[r>>2])){break c}r=r+4|0;continue}break}s=o;if((s|0)>=1){while(1){p=(s|0)<1;if(!(p|e>>>0>=r>>>0)){r=r-4|0;q=v[r>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=q;s=s-1|0;continue}break}if(p){u=0}else{u=jr(g,48)}p=v[c>>2];while(1){q=p+4|0;if((s|0)>=1){v[p>>2]=u;s=s-1|0;p=q;continue}break}v[c>>2]=q;v[p>>2]=j}d:{if((e|0)==(r|0)){q=jr(g,48);p=v[c>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=q;break d}q=-1;e:{if(Wc(l)){break e}q=t[kc(l,0)|0]}p=0;s=0;while(1){if((e|0)!=(r|0)){u=p+1|0;f:{if((p|0)!=(q|0)){break f}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;s=s+1|0;if(Fb(l)>>>0<=s>>>0){q=p;u=1;break f}if(w[kc(l,s)|0]==127){q=-1;u=1;break f}q=t[kc(l,s)|0];u=1}p=u;r=r-4|0;B=v[r>>2];u=v[c>>2];v[c>>2]=u+4;v[u>>2]=B;continue}break}r=v[c>>2]}qo(A,r)}y=y+1|0;continue}break}}function S_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;Gv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Wb(a+184|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2461,a+360|0,a+352|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+180>>2]=b+c}v[114578]=0;b=T(2463,a+360|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=er(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2465,a+360|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=+oa(2449,c|0,v[a+180>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114578]=0;Ee(a+200|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+360|0,a+352|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function f$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;Jv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Wb(a+192|0);b=Kc(d);v[114578]=0;R(149,d|0,b|0);b=v[114578];v[114578]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114578]=0;b=Q(2429,a+264|0,a+256|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Fb(d)+c|0)){b=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=b+c}v[114578]=0;b=T(2431,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;b=gr(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114578];v[114578]=0;if((g|0)==1){break d}if(b){break c}v[114578]=0;T(2433,a+264|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114578]=0;h=+oa(2449,c|0,v[a+188>>2],e|0);b=v[114578];v[114578]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;Fd(b,2);Hk(e+16|0,2,a+1|0);Ic(e+32|0,e+16|0);v[114578]=0;Q(372,b+43|0,e+32|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){yb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;g=b,h=v[Lb(e+32|0,e+16|0)>>2],v[g+4>>2]=h;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);g=b,h=v[Lb(e+32|0,b)>>2],v[g+8>>2]=h;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>y[b+4>>2]?d>>>0>=2:0){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}vh(e+16|0,a+16|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;vh(e+16|0,a+20|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+4|0]=f;t[d+5|0]=f>>>8;t[d+6|0]=f>>>16;t[d+7|0]=f>>>24;vh(e+16|0,a+24|0);d=e+32|0;f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;op(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[pc(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=c?a&65535:a;v[b+24>>2]=a;b:{c:{if(!a){c=8363;break c}c=1024;if(a>>>0>1023){break b}}v[b+24>>2]=c}jb=e+48|0;return}a=P()|0;O()|0;yb(e+32|0);S(a|0);L()}function qK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=jb-16|0;jb=h;a:{if((b|0)==(c|0)){break a}v[h+12>>2]=-1953789045;mK(b,c,h+12|0);d=c-b>>2;v[h+8>>2]=d;n=Kb(a);g=n+1|0;v[h+4>>2]=g;k=v[bd(h+4|0,h+8|0)>>2];j=v[((v[h+8>>2]<<2)+b|0)-4>>2];c=d;e=c;f=11;b:{if(c>>>0>622){break b}f=7;if(d>>>0>67){break b}f=5;if(d>>>0>38){break b}f=3;if(d>>>0>6){break b}f=d-1>>>1|0}l=e-f>>>1|0;c=(l<<2)+b|0;e=B(is(j^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=e+v[c>>2];o=l+f|0;c=(o<<2)+b|0;d=c;f=v[c>>2];c=e+n|0;v[d>>2]=f+c;v[b>>2]=c;if(n){m=v[h+8>>2];c=1;while(1){e=c-1|0;d=((c+l>>>0)%(m>>>0)<<2)+b|0;f=(c>>>0)%(m>>>0)|0;i=(f<<2)+b|0;p=B(is(v[((e>>>0)%(m>>>0)<<2)+b>>2]^(v[d>>2]^v[i>>2])),1664525);v[d>>2]=p+v[d>>2];d=Pb(a,e);m=v[h+8>>2];e=((c+o>>>0)%(m>>>0)<<2)+b|0;j=e;q=v[e>>2];e=v[d>>2]+(f+p|0)|0;v[j>>2]=q+e;v[i>>2]=e;c=c+1|0;if(n>>>0>=c>>>0){continue}break}}c=v[h+8>>2];if(g>>>0<k>>>0){while(1){a=((g+l>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=B(is(v[((g-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[e>>2])),1664525);v[a>>2]=i+v[a>>2];c=v[h+8>>2];a=((g+o>>>0)%(c>>>0)<<2)+b|0;f=a;j=v[a>>2];a=d+i|0;v[f>>2]=j+a;v[e>>2]=a;g=g+1|0;if((k|0)!=(g|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}g=k;while(1){a=((g+l>>>0)%(c>>>0)<<2)+b|0;d=(g>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=B(is(v[((g-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[e>>2]|0)|0),1566083941);v[a>>2]=i^v[a>>2];c=v[h+8>>2];a=((g+o>>>0)%(c>>>0)<<2)+b|0;f=a;j=v[a>>2];a=i-d|0;v[f>>2]=j^a;v[e>>2]=a;g=g+1|0;if(g>>>0<c+k>>>0){continue}break}}jb=h+16|0}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=jb-48|0;jb=e;p=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;h=v[a+48>>2];v[e+36>>2]=h;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;q=v[a+24>>2];r=v[a+20>>2];g=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=g;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){l=1;j=((((g&2147483647)<<1|i>>>31)&2147483646)<<1)+p|0;b=(i>>>21&2040)+27888|0;i=u[b+6>>1];k=u[b+4>>1];o=u[b+2>>1];m=u[b>>1];f=0;b=1;h=0;while(1){g=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[g+j>>1],o)+B(u[j+(g|-4)>>1],m)|0)+B(u[j+(g|4)>>1],k)|0)+B(i,u[j+(g|8)>>1])|0)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){i=(e+8|0)+(f<<2)|0;j=v[i>>2];k=v[a+60>>2];g=(e+32|0)+(f<<3)|0;f=v[g>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];h=Yb(v[g+4>>2],-16777216,16776704);n=v[a+68>>2];s=n;n=n>>31;v[g+4>>2]=f;t=v[a+72>>2];j=j<<8;f=j;f=Fma(k,k>>31,f,f>>31);k=mb;w=i;i=Fma(m,m>>31,b,b>>31);f=i+f|0;b=mb+k|0;b=f>>>0<i>>>0?b+1|0:b;o=f;f=Fma(s,n,h,h>>31);h=o+f|0;b=mb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;if(h>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|h>>>24;v[w>>2]=(b|0)/256;v[g>>2]=b-(j&t);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];g=v[e+28>>2];continue}break}i=v[e+24>>2];g=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];h=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=h;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=g;jb=e+48|0}function Ww(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;a:{b:{c:{if(w[c|0]&2){if(v[b>>2]==-2147483648){e=Hj(d+48|0,1,45);b=v[b>>2];v[114578]=0;v[d+188>>2]=b;U(137,d+192|0,d+188|0,c|0);b=v[114578];v[114578]=0;d:{e:{if((b|0)!=1){v[114578]=0;U(138,a|0,e|0,d+192|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}yb(d+192|0);yb(e);break b}c=P()|0;O()|0;break d}c=P()|0;O()|0;yb(d+192|0)}yb(e);break a}e=v[b>>2];if((e|0)>-1){break c}e=Hj(d+48|0,1,45);b=v[b>>2];v[114578]=0;v[d+188>>2]=0-b;U(137,d+192|0,d+188|0,c|0);b=v[114578];v[114578]=0;f:{g:{if((b|0)!=1){v[114578]=0;U(138,a|0,e|0,d+192|0);a=v[114578];v[114578]=0;if((a|0)==1){break g}yb(d+192|0);yb(e);break b}c=P()|0;O()|0;break f}c=P()|0;O()|0;yb(d+192|0)}yb(e);break a}e=dh(d+48|0);f=v[v[e>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}v[114578]=0;U(123,d+40|0,f+(d+48|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break l}Ob(d+40|0);v[114578]=0;R(139,e|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break l}v[114578]=0;R(124,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;R(125,d+8|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break l}v[114578]=0;U(140,d+24|0,d+8|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break k}v[114578]=0;U(141,a|0,d+24|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break j}yb(d+24|0);yb(d+8|0);Yd(e);break b}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;yb(d+24|0)}yb(d+8|0)}Yd(e);break a}v[d+48>>2]=e;Xr(a,d+48|0,c)}jb=d+208|0;return}S(c|0);L()}function i8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=jb-16|0;jb=i;e=b+1304396|0;if(!rd(e)){c=i+8|0;d=Pe(12);v[114578]=0;g=T(1752,d|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){d=jb-16|0;jb=d;v[114578]=0;v[d+12>>2]=g;W(1758,c|0,d+12|0,d+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;Xb(d);S(a|0);L()}IL(e,Nd(i+8|0));ss(i+8|0)}d=v[e>>2];g=0;c=jb-80|0;jb=c;e=Ub(c+48|0,EL(a));v[114578]=0;R(1604,c- -64|0,e|0);f=v[114578];v[114578]=0;b:{c:{d:{e:{if((f|0)!=1){yb(e);j=c,k=bc(d),v[j+40>>2]=k;j=c,k=cc(d),v[j+32>>2]=k;if(Jb(c+40|0,c+32|0)){e=0;while(1){d=0;f=v[c+40>>2];if(v[v[f>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){d=v[v[f>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}h=v[f>>2];v[114578]=0;R(1753,c|0,h+8|0);h=v[114578];v[114578]=0;f:{g:{h:{i:{if((h|0)!=1){v[114578]=0;R(1604,c+16|0,c|0);h=v[114578];v[114578]=0;if((h|0)==1){break i}h=uf(c+16|0,c- -64|0);yb(c+16|0);yb(c);if((d&h)!=1){break g}g=v[f>>2];e=3;break f}d=P()|0;O()|0;break h}d=P()|0;O()|0;yb(c)}e=c- -64|0;break c}if(!(d^1|(e|0)>1)){g=v[f>>2];e=2;break f}d=h&(e|0)<1;g=d?v[f>>2]:g;e=d?1:e}_d(c+40|0);if(Jb(c+40|0,c+32|0)){continue}break}break e}d=0;break d}d=P()|0;O()|0;break c}d=0;if(!g){break d}e=v[g+4>>2];if(!e){break d}v[114578]=0;a=W(e|0,g|0,b|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){d=(a|0)!=0;break d}d=P()|0;e=c- -64|0;O()|0;break c}yb(c- -64|0);jb=c+80|0;break b}yb(e);S(d|0);L()}jb=i+16|0;return d|0}function gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-48|0;jb=c;d=x[a+480190>>1];t[c+32|0]=0;eN(b,d+1|0,c+32|0);if(x[a+480192>>1]){g=rq(c+32|0);d=a+484344|0;k=c,l=bc(d),v[k+24>>2]=l;k=c,l=cc(d),v[k+16>>2]=l;if(Jb(c+24|0,c+16|0)){while(1){a:{i=v[c+24>>2];if(!mh(i)){break a}d=x[a+480188>>1];v[114578]=0;t[c|0]=0;U(1425,g|0,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){b:{k=c,l=bc(i),v[k+8>>2]=l;j=0;if(!v[i+12>>2]){break a}while(1){f=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{d=v[c+8>>2];v[114578]=0;d=T(553,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}e:{if(!d){break e}d=w[v[c+8>>2]+1|0];if(!w[v[c+8>>2]+1|0]){d=w[xc(g,f)|0]}e=d&255;if(e){f:{if(e>>>0>256){break f}e=v[((w[v[c+8>>2]+1|0]<<2)+a|0)+900380>>2];if(!e){break f}e=x[ed(e+236|0,w[v[c+8>>2]]-1|0)>>1];if(e>>>0>x[a+480190>>1]){break f}ee(c,b,e);ge(c,1)}k=xc(g,f),l=d,t[k|0]=l;break e}d=x[a+480192>>1];if(!d){break e}e=d;while(1){h=v[((d<<2)+a|0)+900380>>2];g:{if(!h){break g}h=x[ed(h+236|0,w[v[c+8>>2]]-1|0)>>1];if(h>>>0>x[a+480190>>1]){break g}ee(c,b,h);ge(c,1)}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}Cj(c+8|0);f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[i+12>>2]){continue}break}break a}}a=P()|0;O()|0;fe(g);S(a|0);L()}sy(c+24|0);if(Jb(c+24|0,c+16|0)){continue}break}}d=x[a+480190>>1];h:{if(!d){f=0;break h}f=0;e=d;while(1){ee(c,b,d);if(!Cb(c)){f=De((B(d,104)+a|0)+484380|0)+f|0}d=d-1|0;e=e-1|0;if(e&65535){continue}break}}fe(g)}jb=c+48|0;return f&65535}function QZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=jb-16|0;jb=x;v[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(Fb(n)>>>0>1){C=x,D=Ed(n),v[C+8>>2]=D;C=c,D=wj(cf(x+8|0,1),sf(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}jb=x+16|0;return}a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Nk(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(Wc(n)){break a}q=w[kc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(Wc(m)|!A){break a}C=c,D=wj(Ed(m),sf(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=h?e+1|0:e;s=e;while(1){c:{if(f>>>0<=s>>>0){break c}if(!Kg(g,2048,t[s|0])){break c}s=s+1|0;continue}break}q=o;if((q|0)>=1){while(1){p=(q|0)<1;if(!(p|e>>>0>=s>>>0)){s=s-1|0;p=w[s|0];r=v[c>>2];v[c>>2]=r+1;t[r|0]=p;q=q-1|0;continue}break}if(p){p=0}else{p=Nk(g,48)}while(1){r=v[c>>2];v[c>>2]=r+1;if((q|0)>=1){t[r|0]=p;q=q-1|0;continue}break}t[r|0]=j}d:{if((e|0)==(s|0)){q=Nk(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break d}p=-1;e:{if(Wc(l)){break e}p=t[kc(l,0)|0]}q=0;u=0;while(1){if((e|0)==(s|0)){break d}r=q+1|0;f:{if((p|0)!=(q|0)){break f}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;u=u+1|0;if(Fb(l)>>>0<=u>>>0){p=q;r=1;break f}if(w[kc(l,u)|0]==127){p=-1;r=1;break f}p=t[kc(l,u)|0];r=1}q=r;s=s-1|0;r=w[s|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=r;continue}}Wj(B,v[c>>2])}y=y+1|0;continue}}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb+-64|0;jb=c;u[c+62>>1]=b;f=rj(a);b=f;e=c+48|0;g=ju(e);a:{if(!b){break a}v[114578]=0;R(920,e|0,b|0);h=v[114578];v[114578]=0;if((h|0)!=1){v[114578]=0;R(1173,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bq(g);S(a|0);L()}b:{c:{if(!f){break c}b=0;while(1){i=rc(e,b),j=b-d|0,u[i>>1]=j;v[114578]=0;g=Q(1170,a|0,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}d=(x[g>>1]==x[c+62>>1])+d|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}if(!(d&65535)){break c}b=bc(a);d=cc(a);v[114578]=0;b=W(1171,b|0,d|0,c+62|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[c+32>>2]=b;b=Md(c+40|0,c+32|0);i=c,j=cc(a),v[i+16>>2]=j;d=v[Md(c+24|0,c+16|0)>>2];b=v[b>>2];v[114578]=0;W(1172,a|0,b|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}i=c,j=bc(a),v[i+32>>2]=j;i=c,j=cc(a),v[i+16>>2]=j;if(Jb(c+32|0,c+16|0)){while(1){b=x[v[c+32>>2]>>1];d=v[a+24>>2];v[114578]=0;d=Q(444,d+484344|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}d:{if(!d){break d}b=_b(v[a+24>>2]+484344|0,b);i=c,j=bc(b),v[i+8>>2]=j;i=c,j=cc(b),v[i>>2]=j;if(!Jb(c+8|0,c)){break d}while(1){b=v[c+8>>2];e:{if(w[b+3|0]!=12){break e}d=w[b+5|0];if(oc(e)>>>0<=d>>>0){break e}i=b,j=w[rc(e,w[b+5|0])|0],t[i+5|0]=j}Cj(c+8|0);if(Jb(c+8|0,c)){continue}break}}te(c+32|0);if(Jb(c+32|0,c+16|0)){continue}break}}b=x[a+28>>1];if(oc(e)>>>0<=b>>>0){break c}i=a,j=x[rc(e,x[a+28>>1])>>1],u[i+28>>1]=j}kf(e);jb=c- -64|0;return}a=P()|0;O()|0;kf(e);S(a|0);L()}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=ym(d,a+224|0);xm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2461,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2463,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2465,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=jo(2440,c,v[a+188>>2],e,b);c=mb;h=v[114578];v[114578]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=ym(d,a+224|0);xm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2461,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2463,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2465,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=jo(2444,c,v[a+188>>2],e,b);c=mb;h=v[114578];v[114578]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function pj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-32|0;jb=f;m=hp(a);j=rj(m);c=j;d=a;e=wc(d);a:{if(c>>>0>e>>>0){k=jb-32|0;jb=k;b:{h=c-e|0;c:{if(h>>>0<=(v[zb(d)>>2]-v[d+4>>2]|0)/12>>>0){g=jb-16|0;jb=g;d:{c=bl(g,d,h);if(v[c+4>>2]!=v[c+8>>2]){while(1){e=zb(d);h=v[c+4>>2];v[114578]=0;R(1237,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}e=v[c+4>>2]+12|0;v[c+4>>2]=e;if((e|0)!=v[c+8>>2]){continue}break}}Mb(c);jb=g+16|0;break c}a=P()|0;O()|0;Mb(c);S(a|0);L()}i=zb(d);c=tm(d,wc(d)+h|0);n=wc(d);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,i);if(c){g=c;if(c>>>0>357913941){Fc(20181);L()}g=sc(B(g,12),4)}v[e>>2]=g;i=B(n,12)+g|0;v[e+8>>2]=i;v[e+4>>2]=i;o=ec(e),p=B(c,12)+g|0,v[o>>2]=p;jb=l+16|0;v[114578]=0;R(1234,e|0,h|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1235,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}XM(e)}jb=k+32|0;break a}a=P()|0;O()|0;XM(e);S(a|0);L()}if(c>>>0<e>>>0){c=v[d>>2]+B(c,12)|0;wc(d);YM(d,c);ft(d)}}e:{if(!b){break e}d=a+12|0;Ms(d);if(yd(d)>>>0>1023){break e}v[f+28>>2]=0;c=v[a+24>>2]+484344|0;o=f,p=bc(c),v[o+24>>2]=p;o=f,p=cc(c),v[o+16>>2]=p;if(Jb(f+24|0,f+16|0)){while(1){v[f+12>>2]=v[v[f+24>>2]+12>>2];o=f,p=v[bd(f+28|0,f+12|0)>>2],v[o+28>>2]=p;sy(f+24|0);if(Jb(f+24|0,f+16|0)){continue}break}c=v[f+28>>2]}else{c=0}fN(d,c)}if(j){d=0;while(1){c=sd(a,d);g=ry(a,x[rc(m,d)>>1]);f:{if(b){t[f+28|0]=0;eN(c,g,f+28|0);break f}cz(c,g,0)}d=d+1|0;if((j|0)!=(d|0)){continue}break}}jb=f+32|0}function sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-48|0;jb=f;m=v[a+16>>2];h=Qf(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];s=h,t=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+12>>2]=t;b=v[h+16>>2];if(b){s=h,t=Pf(a+8|0,b),v[s>>2]=t;v[h+4>>2]=mb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];g=v[a>>2];v[f+8>>2]=g;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(!d){b=k;k=i;break a}while(1){b=0;j=b;v[f+40>>2]=g;v[f+44>>2]=b;e=(e<<1)+m|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],u[(j<<1)+e>>1]/4<<16>>16);zd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){Ad(b,u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Yb(k,-16777216,16776704);l=v[a+64>>2];i=Yb(i,-16777216,16776704);p=v[a+72>>2];q=v[c>>2];r=g>>31;g=e<<8;e=g;e=Fma(j,r,e,e>>31);j=mb;l=Fma(l,l>>31,b,b>>31);e=l+e|0;b=mb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Fma(e,e>>31,i,i>>31);i=j+e|0;b=mb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;i=(b|0)/256|0;v[c>>2]=B(i,o)+q;v[c+4>>2]=v[c+4>>2]+B(i,n);b=b-(g&p)|0;Sb(f+8|0,f);if(d){c=c+8|0;g=v[f+8>>2];e=v[f+12>>2];i=k;k=b;continue}break}g=v[f+8>>2];e=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=g;v[a+4>>2]=e;jb=f+48|0}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;e=jb-48|0;jb=e;p=v[a+16>>2];g=v[a+44>>2];v[e+32>>2]=g;b=v[a+48>>2];v[e+36>>2]=b;f=v[a+52>>2];v[e+40>>2]=f;l=v[a+56>>2];v[e+44>>2]=l;q=v[a+24>>2];r=v[a+20>>2];i=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){j=(((i&2147483647)<<1|h>>>31)&-2)+p|0;b=(h>>>21&2040)+27888|0;h=u[b+6>>1];k=u[b+4>>1];o=u[b+2>>1];m=u[b>>1];f=0;l=1;b=1;g=0;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+j|0],o)+B(t[j+(g|-2)|0],m)|0)+B(t[j+(g|2)|0],k)|0)+B(h,t[j+(g|4)|0])<<8)/16384;i=b;b=0;g=1;if(i){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=v[h>>2];k=v[a+60>>2];i=(e+32|0)+(f<<3)|0;f=v[i>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);n=v[a+68>>2];s=n;n=n>>31;v[i+4>>2]=f;w=v[a+72>>2];j=j<<8;f=j;f=Fma(k,k>>31,f,f>>31);k=mb;x=h;h=Fma(m,m>>31,b,b>>31);f=h+f|0;b=mb+k|0;b=f>>>0<h>>>0?b+1|0:b;o=f;f=Fma(s,n,g,g>>31);g=o+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[x>>2]=(b|0)/256;v[i>>2]=b-(j&w);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];i=v[e+28>>2];continue}break}h=v[e+24>>2];i=v[e+28>>2];l=v[e+44>>2];f=v[e+40>>2];g=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=l;v[a+52>>2]=f;v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=h;v[a+4>>2]=i;jb=e+48|0}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=ym(d,a+224|0);xm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2461,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2463,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2465,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2436,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=ym(d,a+224|0);xm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2461,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2463,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2465,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2441,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function W_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=ym(d,a+224|0);xm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2461,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2463,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2465,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2442,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function V_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Xg(d);h=ym(d,a+224|0);xm(a+208|0,d,a+332|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2461,a+344|0,a+336|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2463,a+344|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break d}v[114578]=0;g=Yj(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114578];v[114578]=0;if((i|0)==1){break d}if(g){break c}v[114578]=0;T(2465,a+344|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114578]=0;b=aa(2443,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2462,a+344|0,a+336|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Sx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=89;i=92;j=91;k=85;l=84;m=83;n=5;o=107;p=106;q=96;c=88;r=82;s=80;t=78;u=79;v=77;w=57;x=47;d=10;e=8;f=7;a=Wx(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if((b|0)!=32?!c:0){break c}Nb(a,0,1);Nb(a,7,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,11,1);Nb(a,12,1);Nb(a,13,1);Nb(a,14,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,19,1);Nb(a,20,1);Nb(a,21,1);Nb(a,22,1);Nb(a,23,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,27,1);Nb(a,28,1);Nb(a,29,1);Nb(a,30,1);Nb(a,31,1);Nb(a,32,1);Nb(a,33,1);Nb(a,34,1);Nb(a,35,1);Nb(a,36,1);Nb(a,37,1);Nb(a,38,1);Nb(a,39,1);Nb(a,40,1);Nb(a,41,1);Nb(a,42,1);Nb(a,43,1);Nb(a,44,1);Nb(a,45,1);Nb(a,46,1);Nb(a,47,1);Nb(a,48,1);Nb(a,103,1);Nb(a,50,1);Nb(a,87,1);Nb(a,88,1);Nb(a,100,1);Nb(a,102,1);Nb(a,104,1);if(!c){break a}d=108;e=105;f=99;break b;case 3:Nb(a,0,1);Nb(a,4,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,17,1);Nb(a,40,1);Nb(a,51,1);Nb(a,52,1);Nb(a,53,1);Nb(a,54,1);Nb(a,55,1);Nb(a,56,1);Nb(a,57,1);Nb(a,58,1);Nb(a,59,1);Nb(a,60,1);Nb(a,61,1);Nb(a,62,1);Nb(a,63,1);Nb(a,64,1);Nb(a,65,1);Nb(a,66,1);Nb(a,67,1);Nb(a,68,1);o=98;p=93;q=90;c=89;r=88;s=86;t=76;u=75;v=74;w=73;x=72;d=71;e=70;g=69;case 1:Nb(a,g,1);Nb(a,e,1);Nb(a,d,1);Nb(a,x,1);Nb(a,w,1);Nb(a,v,1);n=u;m=t;l=s;k=r;j=c;i=q;c=p;h=o;break;case 2:break c;case 0:break d}}Nb(a,n,1);Nb(a,m,1);Nb(a,l,1);Nb(a,k,1);g=j;f=i;e=c;d=h}Nb(a,g,1)}Nb(a,f,1);Nb(a,e,1);Nb(a,d,1)}}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);zm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2429,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2431,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2433,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=jo(2440,c,v[a+188>>2],e,b);c=mb;g=v[114578];v[114578]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);zm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2429,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2431,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2433,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=jo(2444,c,v[a+188>>2],e,b);c=mb;g=v[114578];v[114578]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);zm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2429,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2431,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2433,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2436,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);zm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2429,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2431,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2433,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2441,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function l$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);zm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2429,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2431,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2433,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2442,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=Xg(d);zm(a+208|0,d,a+255|0);d=Wb(a+192|0);c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114578]=0;g=Q(2429,a+264|0,a+256|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Fb(d)+c|0)){g=Fb(d);c=Fb(d);v[114578]=0;R(149,d|0,c<<1);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=Kc(d);v[114578]=0;R(149,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114578]=0;g=T(2431,a+264|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break d}v[114578]=0;g=Zj(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,64400);h=v[114578];v[114578]=0;if((h|0)==1){break d}if(g){break c}v[114578]=0;T(2433,a+264|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114578]=0;b=aa(2443,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114578];v[114578]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114578]=0;Ee(a+208|0,a+16|0,v[a+12>>2],e);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;b=Q(2430,a+264|0,a+256|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function aL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb-16|0;jb=c;d=B(b,896)+a|0;a:{if(v[d+1075072>>2]&134218752){break a}if(!nj(d+1074984|0)){break a}h=v[(B(b,896)+a|0)+1075640>>2];if(w[h+15|0]&2){break a}d=xl(a,b,2,1);if(d-251>>>0<5|!d){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}e=B(b,896)+a|0;d=w[e+1075794|0];b:{if(w[e+1075796|0]==1){t[c+8|0]=64;f=w[pc(e+1075798|0,c+8|0)|0];break b}f=255;if(w[e+1075797|0]!=13){break b}t[c+8|0]=64;f=w[pc((B(b,896)+a|0)+1075799|0,c+8|0)|0]}j=a+1074308|0;Eb(c+8|0,j,2);if(Cb(c+8|0)){if(d){e=a;f=b;if(be(d)){d=w[fc(h+108|0,d-1|0)|0]}qk(e,f,d,x[(B(b,896)+a|0)+1075672>>1]);break a}if((f|0)==255){break a}nb[v[v[g>>2]+76>>2]](g,39,f,b);break a}k=v[h+4>>2];if(d){e=k<<2;v[c+4>>2]=e;if(!w[h+35|0]){e=v[(B(b,896)+a|0)+1075672>>2];v[c+4>>2]=e}i=u[(B(b,896)+a|0)+1075772>>1];Eb(c+8|0,j,28);l=c,m=(Cb(c+8|0)?i<<2:i)+e|0,v[l+4>>2]=m;ce(c+4|0,0,256);e=d;i=b;if(be(d)){e=w[fc(h+108|0,d-1|0)|0]}qk(a,i,e&255,x[c+4>>1])}e=w[h+35|0];Eb(c+8|0,j,101);a=(d|0)!=0;c:{if(Cb(c+8|0)){break c}a=be(d)}if(a|(f|0)==255?!(a&(e|0)==1):0){break a}d:{switch(w[h+36|0]){case 1:if((f|0)!=255){oJ(g,f<<1);break a}oJ(g,k<<1);break a;case 0:break d;default:break a}}if((f|0)!=255){t[c+8|0]=127;t[c+4|0]=f<<1;m=g,n=7,o=w[pc(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],nb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=k<<1;p=g,o=7,n=w[Lb(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],nb[l](p|0,o|0,n|0,m|0)}jb=c+16|0}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=jb-48|0;jb=f;m=v[a+16>>2];h=Qf(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];s=h,u=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+12>>2]=u;b=v[h+16>>2];if(b){s=h,u=Pf(a+8|0,b),v[s>>2]=u;v[h+4>>2]=mb}i=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];g=v[a>>2];v[f+8>>2]=g;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(!d){b=k;k=i;break a}while(1){b=0;j=b;v[f+40>>2]=g;v[f+44>>2]=b;e=e+m|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){Ad(v[h+8>>2],t[e+j|0]<<6);zd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];g=v[b+4>>2];if(g){Ad(b,t[e+v[f+44>>2]|0]<<6);zd(v[h+8>>2],g);b=v[h+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}e=Kf(b,v[h+12>>2]);g=v[a+60>>2];j=g;b=Yb(k,-16777216,16776704);l=v[a+64>>2];i=Yb(i,-16777216,16776704);p=v[a+72>>2];q=v[c>>2];r=g>>31;g=e<<8;e=g;e=Fma(j,r,e,e>>31);j=mb;l=Fma(l,l>>31,b,b>>31);e=l+e|0;b=mb+j|0;b=e>>>0<l>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Fma(e,e>>31,i,i>>31);i=j+e|0;b=mb+b|0;b=e>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;i=(b|0)/256|0;v[c>>2]=B(i,o)+q;v[c+4>>2]=v[c+4>>2]+B(i,n);b=b-(g&p)|0;Sb(f+8|0,f);if(d){c=c+8|0;g=v[f+8>>2];e=v[f+12>>2];i=k;k=b;continue}break}g=v[f+8>>2];e=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=g;v[a+4>>2]=e;jb=f+48|0}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=(e<<1)+q|0;j=u[g-6>>1];e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+24>>1];o=u[g-4>>1];r=u[e+26>>1];s=u[g-2>>1];t=u[e+28>>1];w=u[g>>1];x=u[e+30>>1];y=u[g+2>>1];z=u[e+32>>1];A=u[g+4>>1];C=u[e+34>>1];D=u[g+6>>1];E=u[e+36>>1];F=u[g+8>>1];G=u[e+38>>1];g=v[a+60>>2];H=g;I=g>>31;e=Yb(n,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[a+32>>2];g=c;L=v[g>>2];e=Fma(k,k>>31,e,e>>31);k=mb;M=e;e=v[a+68>>2];p=Fma(e,e>>31,f,f>>31);e=M+p|0;f=mb+k|0;f=e>>>0<p>>>0?f+1|0:f;k=e;i=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(F,G)|0)/2|0)+((((B(o,r)+B(i,j)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=i;j=Fma(H,I,e,e>>31);e=k+j|0;f=mb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(f,j)+L;l=l+K|0;o=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,o);g=e-(i&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=n;n=g;continue}break}i=v[h+8>>2];e=v[h+12>>2];f=n;break a}o=l>>12;j=m>>12;g=n}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=g;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function iV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-48|0;jb=f;Jc(b);Gq(a);a:{if(!Ff(b,f+40|0)){break a}if(!uC(f+40|0)){break a}if(!c){i=1;break a}if(!Qb(b,4)){break a}ev(a);dv(f+24|0);cv(Tg(a)+28|0,f+24|0);Fq(f+24|0);j=v[Tg(a)+28>>2];c=Lj(b);if(c&1){break a}d=c-4|0;Pc(b,d);c=Gd(b);c=Gd(b)<<8|c<<16|Gd(b);if(!c){break a}v[114578]=0;R(331,j|0,c|0);g=v[114578];v[114578]=0;i=1;if((g|0)==1){a=V(71204)|0;if((O()|0)==(ga(71204)|0)){_(a|0)|0;$();i=0;break a}S(a|0);L()}Pc(b,4);g=tC(b);k=Db(v[j>>2]);e=jb-32|0;jb=e;t[e+24|0]=w[g|0];t[e+25|0]=w[g+1|0];t[e+26|0]=w[g+2|0];t[e+27|0]=w[g+3|0];b=sC(e+8|0);d=d+g|0;v[b+12>>2]=d-4;v[b+8>>2]=g;Ti(b,w[d-1|0]);g=c;b:{if(!c){break b}while(1){if(!Ti(b,1)){v[e+4>>2]=1;while(1){d=Ti(b,2);v[e+4>>2]=d+v[e+4>>2];if((d|0)==3){continue}break}Cc(e+4|0,c);c:{if(!v[e+4>>2]){break c}d=1;while(1){c=c-1|0;o=k+c|0,p=Ti(b,8),t[o|0]=p;if(y[e+4>>2]<=d>>>0){break c}d=d+1|0;continue}}if(!c){break b}}d=Ti(b,2);v[e+4>>2]=d+2;d:{if((d|0)==3){d=b;h=7;e:{if(!Ti(b,1)){break e}h=w[fc(e+24|0,3)|0]}l=Ti(d,h);while(1){d=Ti(b,3);v[e+4>>2]=d+v[e+4>>2];if((d|0)==7){continue}break}break d}l=Ti(b,w[fc(e+24|0,d)|0])}Cc(e+4|0,c);h=0;m=v[e+4>>2];if(m){while(1){d=0;n=c+l|0;if(g>>>0>n>>>0){d=w[k+n|0]}c=c-1|0;t[k+c|0]=d;h=h+1|0;if((m|0)!=(h|0)){continue}break}}if(c){continue}break}}jb=e+32|0;Vi(f+8|0,j);_u(f+16|0,f+8|0);b=fo(f+24|0,f+16|0,0);Wd(Tg(a)+12|0,b);Bb(b)}jb=f+48|0;return i|0}function bJ(a){var b=C(0),c=0,d=C(0),e=0,f=C(0),g=0,h=C(0),i=C(0),k=C(0),m=0,n=C(0),o=0,r=C(0);e=jb-16|0;jb=e;c=Se(v[a+16>>2]);o=a,r=ne(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))*C(.05000000074505806))),z[o+4232>>2]=r;f=C(C(c>>>0)*C(.0010000000474974513));o=a,r=ne(C(10),C(C(-1)/C(C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))*f))),z[o+4236>>2]=r;o=a,r=ne(C(10),C(C(-1)/C(C(C(z[a+4216>>2]*C(2950))+C(50))*f))),z[o+4240>>2]=r;v[e+12>>2]=1325400064;g=e;b=C(ne(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))*C(.05000000074505806)))*C(2147483648));c=(p(b),j(2));a:{b:{c:{if(!((c|0)>-1?c>>>0>=8388608:0)){d=C(C(-1)/C(b*b));if(!(c&2147483647)){break a}d=C(C(b-b)/C(0));if((c|0)<=-1){break a}c=(p(C(b*C(33554432))),j(2));m=-152;break c}if(c>>>0>2139095039){break b}m=-127;b=C(0);if((c|0)==1065353216){break b}}c=c+4913933|0;n=C((c>>>23|0)+m|0);b=C((l(2,(c&8388607)+1060439283|0),q())+C(-1));h=C(b/C(b+C(2)));i=C(h*h);k=C(i*i);d=b;b=C(b*C(b*C(.5)));b=C(C(n*C(.6931381225585938))+C(d+C(C(C(n*C(905800061445916e-20))+C(h*C(b+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287)))))))-b)))}d=b}z[g+8>>2]=C(d*C(96817624))+C(67108864);o=a,r=C(z[ol(e+12|0,e+8|0)>>2]*C(4.656612873077393e-10)),z[o+4244>>2]=r;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);g=a;b=C(C(C(z[a+4228>>2]*C(4))*f)+C(2));d:{if(C(D(b))<C(2147483648)){a=~~b;break d}a=-2147483648}v[g+4252>>2]=a;jb=e+16|0}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];n=v[a+44>>2];q=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=e+q|0;j=t[g-3|0];e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+24>>1];o=t[g-2|0];r=u[e+26>>1];s=t[g-1|0];w=u[e+28>>1];x=t[g|0];y=u[e+30>>1];z=t[g+1|0];A=u[e+32>>1];C=t[g+2|0];D=u[e+34>>1];E=t[g+3|0];F=u[e+36>>1];G=t[g+4|0];H=u[e+38>>1];g=v[a+60>>2];I=g;J=g>>31;e=Yb(n,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);K=v[a+72>>2];L=v[a+32>>2];g=c;M=v[g>>2];e=Fma(k,k>>31,e,e>>31);k=mb;N=e;e=v[a+68>>2];p=Fma(e,e>>31,f,f>>31);e=N+p|0;f=mb+k|0;f=e>>>0<p>>>0?f+1|0:f;k=e;i=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(G,H)<<8)/2|0)+((((B(o,r)+B(i,j)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=i;j=Fma(I,J,e,e>>31);e=k+j|0;f=mb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(f,j)+M;l=l+L|0;o=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,o);g=e-(i&K)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=n;n=g;continue}break}i=v[h+8>>2];e=v[h+12>>2];f=n;break a}o=l>>12;j=m>>12;g=n}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=g;v[a+24>>2]=o;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function Qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;s=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;g=v[a+52>>2];v[b+40>>2]=g;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+s|0;h=u[e>>1];v[b+8>>2]=h;v[b+12>>2]=u[e+2>>1];f=0;l=1;while(1){g=v[a+60>>2];k=g;i=(b+32|0)+(f<<3)|0;o=v[i>>2];e=Yb(o,-16777216,16776704);r=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];t=p;p=p>>31;v[i+4>>2]=o;o=v[a+72>>2];q=g>>31;h=h<<8;g=h;g=Fma(k,q,g,g>>31);k=mb;q=(b+8|0)+(f<<2)|0;f=g;g=Fma(r,r>>31,e,e>>31);f=f+g|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;j=Fma(t,p,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[q>>2]=(e|0)/256;v[i>>2]=e-(h&o);if(l){f=1;l=0;h=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];g=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}k=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=k;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-16|0;jb=f;a:{if(yt(a)){break a}l=d+484344|0;i=Cd(Gd(a)+1|0,1,1024);if(!rg(l,b,i)){break a}d=x[d+480188>>1];if(!d|!i){break a}m=d-1|0;while(1){if(!Qb(a,1)){break a}g=Gd(a);b:{if(!g){j=j+1|0;break b}d=_b(l,b);u[f+14>>1]=g&31;u[f+12>>1]=m;d=Xe(d,j,x[lf(f+14|0,f+12|0)>>1]);if(!(g&224)){break b}c:{if(!(g&128)){break c}o=d,p=Gd(a),t[o+5|0]=p;d:{e=Gd(a);if(e>>>0>=26){break d}e=w[e+31824|0];t[d+3|0]=e;e:{switch(e-1|0){case 0:if(!w[d+5|0]){break d}break c;case 12:if(w[d+2|0]){break c}t[d+2|0]=1;e=Cd(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break c;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break c}t[d+5|0]=e;break c;case 8:e=w[d+5|0];if(e>>>0<=128){o=d,p=zj(e<<1),t[o+5|0]=p;break c}if((e|0)!=164){break c}t[d+5|0]=145;t[d+3|0]=20;break c;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break c;case 18:ux(d);break c;case 16:if(w[d+5|0]>31){break c}t[d+3|0]=16;break c;case 27:break e;default:break c}}n=d;e=w[d+5|0];h=e&240;k=2;f:{g:{if((h|0)==16){break g}if((h|0)!=32){break f}k=3}t[n+3|0]=k}t[d+5|0]=e&15|224;break c}t[d+3|0]=0}h:{if(!(g&64)){break h}dq(f+8|0,a);e=dd(f+8|0);t[d+1|0]=w[f+8|0];e=w[e|0];t[d|0]=e;h=255;if((e|0)!=128){h=253;if(e>>>0<129){break h}}t[d|0]=h}if(!(g&32)){break b}t[d+2|0]=1;e=Gd(a);t[d+4|0]=e;if(!c){break b}t[d+4|0]=(e<<6>>>0)/127}if(j>>>0<i>>>0){continue}break}}jb=f+16|0}function bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=fc(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=ed(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=ed(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}pz(a+484|0,b+48|0,0);pz(a+590|0,b+68|0,0);pz(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<=-1){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[pc(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[lf(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[lf(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;xu(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;wu(b,w[a|0]&127,w[a|0]>>>7|0);jb=e+16|0}function ZG(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-16|0;jb=g;a:{b:{c:{i=(b|0)>=0;f=a+8|0;d:{if(nl(f)){f=nl(f);break d}f=Qr(f)}if(!((f|0)>(b|0)?i:0)){b=ba(8)|0;v[114578]=0;c=Q(85,g|0,40673)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}if(c>>>0>=120){b=ba(8)|0;v[114578]=0;c=Q(85,g|0,40692)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0);break b}h=a+32|0;a=ey(v[h>>2],65535);a=(a|0)==65535?255:a;u[g>>1]=a;a=v[h>>2]+B(a,896)|0;f=a+1074984|0;pn(f,v[h>>2],65535);c=c+1|0;t[a+1075808|0]=c;t[a+1075805|0]=c;u[a+1075792>>1]=0;yl(f);dp(v[h>>2],f,b+1|0,0,1,1);v[a+1075680>>2]=65536;Cs(v[h>>2],f,c,0,1,1,65535);l=a+1075676|0,m=mn(jy(e*128,-128,128)+128),v[l>>2]=m;l=a+1075672|0,m=mn(jy(d*256,0,256)),v[l>>2]=m;a=v[h>>2]+1074466|0;i=a;f=(x[v[h>>2]+480212>>1]<<1)+a|0;j=f;k=g;c=g;b=f;e:{if((b|0)==(a|0)){break e}c=x[c>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((j|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[k>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=py(i,b);u[v[h>>2]+480212>>1]=a;jb=g+16|0;return x[g>>1]}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Ada(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-48|0;jb=d;e=nN(d+32|0,1<<v[b+12>>2]);if(Dg(a)){while(1){g=A[Uk(a,c)>>3];mN(tc(e,c),g);c=c+1|0;if(Dg(a)>>>0>c>>>0){continue}break}}v[114578]=0;R(1215,b|0,e|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}h=d,i=bc(e),v[h>>2]=i;h=d,i=cc(e),v[h+24>>2]=i;b:{if(Jb(d,d+24|0)){while(1){c=v[d>>2];v[114578]=0;g=+la(1216,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}mN(c,vo(g));Tf(d);if(Jb(d,d+24|0)){continue}break}}v[114578]=0;R(1217,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;Z(1218,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}if(od(e)>>>0>3){c=1;while(1){vy(tc(e,c),2);vy(tc(e,(od(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<od(e)>>>1>>>0){continue}break}}v[114578]=0;R(1215,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}h=d,i=bc(e),v[h+24>>2]=i;h=d,i=cc(e),v[h+16>>2]=i;if(Jb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[114578]=0;R(1219,d|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}f=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=f;f=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=f;Tf(d+24|0);if(Jb(d+24|0,d+16|0)){continue}break}}v[114578]=0;R(1217,b|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;Z(1218,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}if(Dg(a)){c=0;while(1){g=A[tc(e,c)>>3];h=Uk(a,c),j=g,A[h>>3]=j;c=c+1|0;if(Dg(a)>>>0>c>>>0){continue}break}}ip(e);jb=d+48|0;return}}a=P()|0;O()|0;ip(e);S(a|0);L()}function Rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;b=jb-48|0;jb=b;s=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;g=v[a+52>>2];v[b+40>>2]=g;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+s|0;h=t[e|0]<<8;v[b+8>>2]=h;v[b+12>>2]=t[e+1|0]<<8;f=0;l=1;while(1){g=v[a+60>>2];k=g;i=(b+32|0)+(f<<3)|0;o=v[i>>2];e=Yb(o,-16777216,16776704);r=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];u=p;p=p>>31;v[i+4>>2]=o;o=v[a+72>>2];q=g>>31;h=h<<8;g=h;g=Fma(k,q,g,g>>31);k=mb;q=(b+8|0)+(f<<2)|0;f=g;g=Fma(r,r>>31,e,e>>31);f=f+g|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;j=Fma(u,p,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[q>>2]=(e|0)/256;v[i>>2]=e-(h&o);if(l){f=1;l=0;h=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];g=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}k=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=k;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function lY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){b=2;i=w[c|0];if(i>>>0>1114111){break b}m=a;d:{if(i<<24>>24>=0){u[f>>1]=i;b=c+1|0;break d}if(i>>>0<194){break b}if(i>>>0<=223){if((d-c|0)<2){break c}j=w[c+1|0];if((j&192)!=128){break a}i=j&63|i<<6&1984;if(i>>>0>1114111){break a}u[f>>1]=i;b=c+2|0;break d}if(i>>>0<=239){if((d-c|0)<3){break c}k=w[c+2|0];j=w[c+1|0];e:{f:{if((i|0)!=237){if((i|0)!=224){break f}if((j&224)==160){break e}break a}if((j&224)==128){break e}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}i=k&63|((j&63)<<6|i<<12);if((i&65535)>>>0>1114111){break a}u[f>>1]=i;b=c+3|0;break d}if(i>>>0>244){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];j=w[c+2|0];c=w[c+1|0];g:{h:{switch(i-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((j&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;k=k&63;l=j<<6;i=i&7;if((k|(l&4032|(c<<12&258048|i<<18)))>>>0>1114111){break a}b=c<<2;u[f>>1]=(j>>>4&3|(b&192|i<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=k|l&960|56320;b=v[a+12>>2]+4|0}v[m+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function W0(a){a=a|0;var b=0,c=0,d=0,e=0;c=v[13925];b=jb-16|0;jb=b;d=pr(461076);v[115279]=461132;v[115277]=c;v[115269]=55716;t[461128]=0;v[115281]=-1;sr(b+8|0,d);e=v[v[115269]+8>>2];v[114578]=0;R(e|0,461076,b+8|0);e=v[114578];v[114578]=0;a:{if((e|0)!=1){Ob(b+8|0);jb=b+16|0;break a}a=P()|0;O()|0;Ob(b+8|0);jl(d);S(a|0);L()}b=Tr(460400);v[115098]=58756;v[b>>2]=58776;v[115099]=0;v[114578]=0;R(2313,v[14686]+460392|0,461076);d=v[114578];v[114578]=0;b:{if((d|0)==1){break b}b=jb-16|0;jb=b;d=OF(461140);v[115295]=461196;v[115293]=c;v[115285]=55856;t[461192]=0;v[115297]=-1;sr(b+8|0,d);c=v[v[115285]+8>>2];v[114578]=0;R(c|0,461140,b+8|0);c=v[114578];v[114578]=0;c:{if((c|0)!=1){Ob(b+8|0);jb=b+16|0;break c}a=P()|0;O()|0;Ob(b+8|0);uo(d);S(a|0);L()}b=dG(460488);v[115120]=58804;v[b>>2]=58824;v[115121]=0;v[114578]=0;R(2314,v[14698]+460480|0,461140);c=v[114578];v[114578]=0;if((c|0)==1){break b}b=v[13926];gG(461204,b,461252);fw(460568,461204);fG(461260,b,461308);ew(460652,461260);b=v[13922];gG(461316,b,461364);fw(460736,461316);fw(460904,v[(v[v[115184]-12>>2]+460736|0)+24>>2]);fG(461372,b,461420);ew(460820,461372);ew(460988,v[(v[v[115205]-12>>2]+460820|0)+24>>2]);tr(v[v[115098]-12>>2]+460392|0,460568);tr(v[v[115120]-12>>2]+460480|0,460652);eG(v[v[115184]-12>>2]+460736|0);eG(v[v[115205]-12>>2]+460820|0);tr(v[v[115184]-12>>2]+460736|0,460568);tr(v[v[115205]-12>>2]+460820|0,460652);return a|0}a=P()|0;O()|0;ah(b);S(a|0);L()}function o3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-176|0;jb=b;d=Ub(b+8|0,38719);v[114578]=0;Q(85,b+20|0,38724)|0;e=v[114578];v[114578]=0;c=1;a:{b:{if((e|0)==1){break b}v[114578]=0;Q(85,b+32|0,38734)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=2;break b}v[114578]=0;Q(85,b+44|0,38747)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=3;break b}v[114578]=0;Q(85,b+56|0,38765)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=4;break b}v[114578]=0;Q(85,b+68|0,38775)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=5;break b}v[114578]=0;Q(85,b+80|0,38790)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=6;break b}v[114578]=0;Q(85,b+92|0,38798)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=7;break b}v[114578]=0;Q(85,b+104|0,38805)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=8;break b}v[114578]=0;Q(85,b+116|0,38811)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=9;break b}v[114578]=0;Q(85,b+128|0,38816)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=10;break b}v[114578]=0;Q(85,b+140|0,38824)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=11;break b}v[114578]=0;Q(85,b+152|0,38836)|0;c=v[114578];v[114578]=0;if((c|0)==1){c=12;break b}v[114578]=0;v[b+172>>2]=13;v[b+168>>2]=d;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2179,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){c=b+164|0;while(1){c=yb(c-12|0);if((d|0)!=(c|0)){continue}break}jb=b+176|0;return}c=b+164|0;break a}c=(b+8|0)+B(c,12)|0}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((d|0)!=(c|0)){continue}break}S(a|0);L()}function NG(a){var b=0,c=0,d=0,e=0;Xd(a,v[a+20>>2]);if(v[a+24>>2]>=1){while(1){Xd(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}Xd(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<1){break a}while(1){c=B(e,24)+b|0;b=v[c+16>>2];if(b){d=a;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=1){Xd(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){Xd(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}Xd(d,b)}Xd(a,v[c+20>>2]);e=e+1|0;if((e|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){d=a;if(v[a+120>>2]>=1){c=0;while(1){b=B(c,2096)+b|0;Xd(a,v[b+8>>2]);Xd(a,v[b+28>>2]);Xd(a,v[b+32>>2]);Xd(a,v[b+2084>>2]);b=v[b+2088>>2];Xd(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}Xd(d,b)}Xd(a,v[a+260>>2]);Xd(a,v[a+396>>2]);d=v[a+404>>2];if(d){b=1;c=a;if(v[a+400>>2]>=1){Xd(a,v[d+4>>2]);if(v[a+400>>2]>=2){while(1){Xd(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}d=v[a+404>>2]}Xd(c,d)}c=1;b:{if(v[a+4>>2]<1){break b}b=0;while(1){d=(b<<2)+a|0;Xd(a,v[d+800>>2]);Xd(a,v[d+928>>2]);Xd(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;Xd(a,v[b+1068>>2]);Xd(a,v[b+1076>>2]);Xd(a,v[b+1084>>2]);Xd(a,v[b+1092>>2]);Xd(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function Dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=jb-48|0;jb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;h=v[a+48>>2];v[e+36>>2]=h;l=v[a+52>>2];v[e+40>>2]=l;i=v[a+56>>2];v[e+44>>2]=i;p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;r=a;if(d){while(1){j=g>>>18|0;l=1;i=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;f=0;b=1;h=0;while(1){k=h<<1;g=u[k+i>>1];v[(e+8|0)+(h<<2)>>2]=g+((B(j,u[i+(k|4)>>1]-g|0)|0)/16384|0);g=b;b=0;h=1;if(g){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=v[h>>2];k=v[a+60>>2];g=(e+32|0)+(f<<3)|0;f=v[g>>2];b=Yb(f,-16777216,16776704);n=v[a+64>>2];i=Yb(v[g+4>>2],-16777216,16776704);m=v[a+68>>2];s=m;m=m>>31;v[g+4>>2]=f;t=v[a+72>>2];j=j<<8;f=j;f=Fma(k,k>>31,f,f>>31);k=mb;w=h;h=Fma(n,n>>31,b,b>>31);f=h+f|0;b=mb+k|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=Fma(s,m,i,i>>31);i=h+f|0;b=mb+b|0;b=f>>>0>i>>>0?b+1|0:b;i=i+8388608|0;if(i>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|i>>>24;v[w>>2]=(b|0)/256;v[g>>2]=b-(j&t);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];b=v[e+28>>2];continue}break}g=v[e+24>>2];b=v[e+28>>2];l=v[e+40>>2];h=v[e+36>>2];f=v[e+32>>2];i=v[e+44>>2]}v[r+56>>2]=i;v[a+52>>2]=l;v[a+48>>2]=h;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function Efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=jb-48|0;jb=e;q=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;l=v[a+56>>2];v[e+44>>2]=l;r=v[a+24>>2];s=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){k=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+q|0;i=0;l=1;b=1;f=0;while(1){h=t[g+f|0];v[(e+8|0)+(f<<2)>>2]=((B(k,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){f=(e+8|0)+(i<<2)|0;k=v[f>>2];j=v[a+60>>2];n=j;h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Yb(i,-16777216,16776704);p=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);m=v[a+68>>2];u=m;m=m>>31;v[h+4>>2]=i;i=v[a+72>>2];o=j>>31;k=k<<8;j=k;j=Fma(n,o,j,j>>31);n=mb;o=f;f=j;j=Fma(p,p>>31,b,b>>31);f=f+j|0;b=mb+n|0;b=f>>>0<j>>>0?b+1|0:b;j=f;f=Fma(u,m,g,g>>31);g=j+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;if(g>>>0<8388608){b=b+1|0}b=(b&16777215)<<8|g>>>24;v[o>>2]=(b|0)/256;v[h>>2]=b-(i&k);i=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],r);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=l;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;jb=e+48|0}function B_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=Xv(g);g=Iv(g);ng(k,g);a:{b:{if(Wc(k)){v[114578]=0;aa(2470,l|0,a|0,c|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114578]=0;j=Q(2482,l|0,h<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114578]=0;h=Q(2482,l|0,48)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[114578]=0;h=Q(2482,l|0,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}i=0;v[114578]=0;Wj(j,c);h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;o=T(2467,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114578]=0;qo((j-a<<2)+d|0,g);g=v[114578];v[114578]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[kc(k,h)|0]){break f}if(t[kc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114578]=0;n=Q(2482,l|0,n|0)|0;m=v[114578];v[114578]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;yb(k);jb=k+16|0}function Sja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-32|0;jb=h;v[h+28>>2]=d;a:{if(w[a+8|0]){d=a+12|0;r=h,s=Ac(d)-c|0,v[r+24>>2]=s;a=v[Lb(h+24|0,h+28|0)>>2];r=h,s=bc(d),v[r+24>>2]=s;f=cf(h+24|0,c);r=h,s=bc(d),v[r+8>>2]=s;r=h,s=cf(h+8|0,c),v[r+16>>2]=s;wj(f,cf(h+16|0,a),b);break a}f=jb-32|0;jb=f;v[f+28>>2]=d;b:{c:{if(w[a+24|0]){if(!d){break b}m=a+40|0;break c}n=nb[v[v[a>>2]+44>>2]](a,b,c,d)|0;break b}while(1){j=f;o=c;l=m;k=0;i=jb-16|0;jb=i;e=a;p=e+40|0;g=e+232|0;q=c-(c&4095)|0;d:{while(1){e:{d=v[Ve(g,k)>>2];if(!w[Ii(p,d)+8|0]){break e}if(v[Ii(p,d)>>2]!=(q|0)){break e}r=i,s=v[Ve(g,k)>>2],v[r+8>>2]=s;e=k<<2;Fp(g,e+g|0,(g+e|0)+4|0);e=v[i+8>>2];r=Ve(g,0),s=e,v[r>>2]=s;break d}k=k+1|0;if((k|0)!=16){continue}break}r=i,s=v[Ve(g,15)>>2],v[r+8>>2]=s;Fp(g,g+60|0,g- -64|0);d=v[i+8>>2];r=Ve(g,0),s=d,v[r>>2]=s;d=v[Ve(g,0)>>2];g=Ii(p,d);v[g>>2]=q;Lz(i+8|0,e,d);r=g,s=nb[v[v[e>>2]+44>>2]](e,v[i+8>>2],q,4096)|0,v[r+4>>2]=s;t[g+8|0]=1}jb=i+16|0;e=j;j=o-v[Ii(l,d)>>2]|0;v[e+8>>2]=4096-j;r=f,s=v[Lb(f+8|0,f+28|0)>>2],v[r+24>>2]=s;e=f;if(j>>>0<y[Ii(m,d)+4>>2]){l=v[Ii(m,d)+4>>2]-j|0}else{l=0}v[e+20>>2]=l;e=v[Lb(f+24|0,f+20|0)>>2];Lz(f+8|0,a,d);o=v[f+8>>2];Lz(f,a,d);gf(j+o|0,e+(j+v[f>>2]|0)|0,b);d=v[f+28>>2]-e|0;v[f+28>>2]=d;n=e+n|0;if(e>>>0<y[f+24>>2]){break b}c=c+e|0;b=b+e|0;if(d){continue}break}}jb=f+32|0;a=n}jb=h+32|0;return a|0}function N_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=ru(g);g=Lv(g);ng(k,g);a:{b:{if(Wc(k)){v[114578]=0;aa(2447,l|0,a|0,c|0,d|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114578]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114578]=0;h=Q(22,l|0,48)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[114578]=0;h=Q(22,l|0,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}i=0;v[114578]=0;Wj(j,c);h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;o=T(2438,g|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114578]=0;Wj((j-a|0)+d|0,g);g=v[114578];v[114578]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[kc(k,h)|0]){break f}if(t[kc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114578]=0;n=Q(22,l|0,n|0)|0;m=v[114578];v[114578]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;yb(k);jb=k+16|0}function IG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0);d=(b<<2)+a|0;g=d+1068|0;m=c<<1&-4;r=g,s=Td(a,m),v[r>>2]=s;j=d+1076|0;r=j,s=Td(a,m),v[r>>2]=s;k=Td(a,c&-4);v[d+1084>>2]=k;a:{g=v[g>>2];if(!g){break a}j=v[j>>2];if(!j|!k){break a}b:{d=c;if((d|0)<4){break b}l=d>>>2|0;l=l>>>0>1?l:1;n=C(d|0);i=C(C(1)/n);while(1){o=e<<2;f=+C(C(C(h<<2)*C(3.1415927410125732))*i);r=o+g|0,t=C(ze(f)),z[r>>2]=t;p=e|1;q=p<<2;r=q+g|0,t=C(-C(ii(f))),z[r>>2]=t;f=+C(C(C(p|0)*C(1.5707963705062866))*i);r=j+o|0,t=C(C(ze(f))*C(.5)),z[r>>2]=t;r=j+q|0,t=C(C(ii(f))*C(.5)),z[r>>2]=t;e=e+2|0;h=h+1|0;if((l|0)!=(h|0)){continue}break}if((d|0)<8){break b}d=d>>3;d=(d|0)>1?d:1;i=C(C(1)/n);e=0;h=1;while(1){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))*i);r=k+(e<<2)|0,t=C(ze(f)),z[r>>2]=t;r=k+(g<<2)|0,t=C(-C(ii(f))),z[r>>2]=t;if((d|0)==(h|0)){break b}e=e+2|0;h=h+1|0;continue}}e=(b<<2)+a|0;d=Td(a,m);v[e+1092>>2]=d;if(!d){break a}b=c;if((b|0)>=2){b=b>>1;h=(b|0)>1?b:1;f=1/+(b|0);b=0;while(1){i=C(ii((+(b|0)*1.5707963705062866+.7853981852531433)*f));r=d+(b<<2)|0,t=C(ii(+C(i*i)*1.5707963705062866)),z[r>>2]=t;b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=Td(a,c>>2&-2);v[e+1100>>2]=b;if(!b){break a}a=c;d=ml(a);if((a|0)>=8){c=36-d|0;a=a>>>3|0;d=a>>>0>1?a:1;a=0;while(1){r=b+(a<<1)|0,s=kl(a)>>>c<<2,u[r>>1]=s;a=a+1|0;if((d|0)!=(a|0)){continue}break}}return 1}dc(a,3);return 0}function mY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{b:{while(1){if(c>>>0>=d>>>0){f=0;break a}f=2;b=x[c>>1];if(b>>>0>1114111){break a}c:{d:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<1){break a}v[a+8>>2]=c+1;t[c|0]=b;break d}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break c}if((g-v[a+8>>2]|0)<4){break a}f=b&960;if((i&1023|(b<<10&64512|f<<10))+65536>>>0>1114111){break c}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;j=c;c=(f>>>6|0)+1|0;t[j|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break d}if(b>>>0<57344){break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=2;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return f|0}function Os(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{i=255;b:{c:{e=a;f=e+58|0;d=b;b=w[fc(f,d)|0];if((b|0)==255){break c}if(t[fc(f,d)|0]>-1){break b}g=e+22|0;b=b&127;if(x[ed(g,b)>>1]!=65535){if((d|0)!=x[ed(g,b)>>1]){break c}}k=ed(g,b),l=d,u[k>>1]=l;k=fc(f,d),l=b,t[k|0]=l;break b}j=e+4|0;h=e+22|0;b=0;g=255;while(1){if(x[ed(h,b)>>1]==65535){k=ed(h,b),l=d,u[k>>1]=l;k=fc(f,d),l=b,t[k|0]=l;break b}if(!(w[fc(j,b)|0]&32)){i=t[fc(f,x[ed(h,b)>>1])|0]>-1?i:b;g=b}b=b+1|0;if((b|0)!=18){continue}break}if((g&255)!=255){b=(i&255)==255?g:i;g=b&255;k=fc(f,x[ed(h,g)>>1]),l=255,t[k|0]=l;k=ed(h,g),l=d,u[k>>1]=l;k=fc(f,d),l=b,t[k|0]=l}b=vk(e,d)}g=b&255;if((g|0)==255){break a}b=0;if(qj(a)){break a}e=Ii(a+314|0,g);d=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[e+8|0]=d;t[e+9|0]=d>>>8;t[e+10|0]=d>>>16;t[e+11|0]=d>>>24;d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;t[e+4|0]=d;t[e+5|0]=d>>>8;t[e+6|0]=d>>>16;t[e+7|0]=d>>>24;f=xN(g);h=f+3|0;d=1;while(1){e=d;d=d?f:h;hh(v[a>>2],(d|32)&65535,w[fc(c,b)|0]);hh(v[a>>2],(d|64)&65535,w[fc(c,b|2)|0]);hh(v[a>>2],(d|96)&65535,w[fc(c,b|4)|0]);hh(v[a>>2],(d|128)&65535,w[fc(c,b|6)|0]);hh(v[a>>2],(d|224)&65535,w[fc(c,b|8)|0]);d=0;b=1;if(e){continue}break}hh(v[a>>2],Ps(g)|192,w[fc(c,10)|0])}}function n7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=C(0),s=0;g=jb-16|0;jb=g;m=a+44|0;if(rh(m)){j=Pd(m,0);k=Pd(m,1);h=jd(m,0);i=jd(m,1);r=z[a+4212>>2];v[g+12>>2]=d;if(d){e=v[a+4224>>2];while(1){s=a;f=v[a+4220>>2];a:{if(f>>>0>e>>>0){v[g+8>>2]=f-e;f=v[Lb(g+12|0,g+8|0)>>2];b:{if(!(r<C(1))){if(!f){break b}e=1;while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;if((e|0)==(f|0)){break b}e=e+1|0;continue}}e=v[a+4224>>2];l=f+e|0;if(e>>>0>=l>>>0){break b}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=n*z[j>>2];z[i>>2]=n*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+v[a+4224>>2]|0;break a}v[g+4>>2]=v[a+4216>>2]-e;f=v[Lb(g+12|0,g+4|0)>>2];c:{d:{if(!(r<C(1))){if(!f){break d}e=1;while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;if((e|0)==(f|0)){break d}e=e+1|0;continue}}p=v[a+4216>>2];q=v[a+4224>>2];e=p-q|0;l=e-f|0;if(e>>>0<=l>>>0){break c}o=C(C(1)/C(y[a+4220>>2]));while(1){n=C(C(e>>>0)*o);z[h>>2]=n*z[j>>2];z[i>>2]=n*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(l>>>0<e>>>0){continue}break}break c}e=f<<2;k=e+k|0;j=e+j|0;p=v[a+4216>>2];q=v[a+4224>>2]}l=v[g+12>>2]-f|0;v[g+12>>2]=l;e=f+q|0;e=e>>>0<p>>>0?e:0}v[s+4224>>2]=e;if(l){continue}break}}pi(a,b,c,jd(m,0),jd(m,1),d)}jb=g+16|0}function Fx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;h=eL(b,c);a:{if(!v[b+656>>2]|!(t[h|0]&1)){break a}g=v[h+4>>2];i=a+1074308|0;Eb(e+8|0,i,31);f=Cb(e+8|0);d=su(v[b+656>>2],c);if(nd(d)){break a}g=g+(f^1)|0;Eb(e+8|0,i,31);j=Cb(e+8|0);f=w[d+12|0];b:{c:{if(!j){d:{if(!(f&2)){break d}f=x[Pb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){Eb(e+8|0,i,70);k=Cb(e+8|0)}if((g|0)!=(f|0)|k){break d}g=x[Pb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Pb(d,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Pb(d,w[d+15|0])>>1];Eb(e+8|0,i,93);if(!Cb(e+8|0)|(c|0)!=1|v[b+88>>2]&2048){break b}t[h|0]=w[h|0]&254;break b}if(x[oj(d)>>1]>=g>>>0){break b}k=1;g=x[oj(d)>>1];break c}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(v[h+8>>2]==-1){break f}Eb(e+8|0,i,97);if(Cb(e+8|0)){break f}f=w[d+12|0]}if(f&2){f=x[Pb(d,w[d+13|0])>>1];j=x[Pb(d,w[d+14|0])>>1]+1|0;break e}f=x[oj(d)>>1];k=g>>>0>f>>>0;j=f;break e}f=x[Pb(d,w[d+15|0])>>1];j=x[Pb(d,w[d+16|0])>>1]+1|0}g=g>>>0<j>>>0?g:f}if(!k|c){break b}if(!(!(w[b+89|0]&8)|v[a+480180>>2]==16384?!(v[a+480180>>2]&16777248):0)){v[b+88>>2]=v[b+88>>2]|4096}if(w[oj(d)+2|0]|(v[a+480180>>2]&16777248?0:!x[b+808>>1])){break b}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}Eb(e+8|0,i,31);l=h,m=Cb(e+8|0)+g|0,v[l+4>>2]=m}jb=e+16|0}function afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-32|0;jb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;jb=g+32|0}function uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;l=v[a+16>>2];g=Qf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];n=g,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[g+16>>2];if(b){n=g,o=Pf(a+8|0,b),v[n>>2]=o;v[g+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;f=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=f;a:{if(d){while(1){f=0;i=h;v[e+40>>2]=h;v[e+44>>2]=m;h=((((b&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){f=(f&2147483647)<<1|i>>>31;Ad(v[g+8>>2],(u[(f<<1|2)+h>>1]+u[h+((f&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break b}b=b-1|0;i=v[e+40>>2];f=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Kf(b,v[g+12>>2]);h=v[a+32>>2];k=v[a+28>>2]+k|0;f=k>>12;v[c>>2]=v[c>>2]+B(b,f);j=h+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;f=k>>12}v[a+40>>2]=j;v[a+20>>2]=f;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function QU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){Fd(b,32);Qi(d,1,a+4|0);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}yb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;jg(b+30|0,256);u[b+32>>1]=w[a+17|0];jg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;jg(b+28|0,256);if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<=-1){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);nn(b);t[b+38|0]=w[(w[a+79|0]&7)+27872|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=d+32|0;return c|0}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-16|0;jb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Yb(k,-16777216,16776704);j=v[a+64>>2];f=Yb(f,-16777216,16776704);I=v[a+72>>2];J=v[c>>2];e=Fma(j,j>>31,e,e>>31);j=mb;K=e;e=v[a+68>>2];l=Fma(e,e>>31,f,f>>31);e=K+l|0;f=mb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=Fma(G,H,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=B(e,n)+J;v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&I)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=k;k=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function h8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;e=jb-16|0;jb=e;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[e+12>>2]=0;W(1761,a+8|0,e+12|0,e+8|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){jb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}v[114578]=0;e=a;R(1754,e|0,11);b=v[114578];v[114578]=0;b:{if((b|0)!=1){b=79888;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){d=Ig(44);if(d){h=v[b>>2];g=v[b+4>>2];v[114578]=0;g=Q(85,c+32|0,g|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break l}v[114578]=0;R(1755,c+48|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break k}f=v[b+8>>2];v[114578]=0;f=Q(85,c|0,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break j}v[114578]=0;R(1755,c+16|0,f|0);i=v[114578];v[114578]=0;if((i|0)==1){break i}v[114578]=0;ea(1756,d|0,h|0,1,c+48|0,c+16|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break h}Ib(c+16|0);yb(f);Ib(c+48|0);yb(g);v[114578]=0;v[c+60>>2]=d;R(1757,e|0,c+60|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=80152){continue}break}jb=c- -64|0;return a|0}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;Ib(c+16|0)}yb(f)}Ib(c+48|0)}yb(g)}Xb(d);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}cx(e);S(b|0);L()}function $f(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;v[f+12>>2]=d;e=b-1|0;g=0;a:{if(e>>>0>249){break a}h=Lp(a);g=v[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;g=x[((e-B(a,12)&255)<<1)+21424>>1]<<4>>>a|0;break a}if(!(v[a+480180>>2]!=64?!(w[a+480208|0]&16):0)){Eb(f,a+1074308|0,7);if(!(i=!Cb(f),j=0,k=v[a+480180>>2]!=64,k?i:j)){a=((e&255)>>>0)/12|0;b=Fma(v[f+12>>2],0,v[(e-B(a,12)<<6&960)+25312>>2]<<a,0);a=mb;c=a>>>21|0;g=id((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;g=x[((e-B(a,12)&255)<<1)+21424>>1]<<5>>>a|0;break a}if(!d){v[f+12>>2]=8363}a=((e&255)>>>0)/12|0;Cc(f+12|0,-1>>>a|0);g=id(Ima(Fma(x[((e-B(a,12)&255)<<1)+21424>>1],0,267616,0),mb,v[f+12>>2]<<a,0),mb);break a}if(g&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Eb(f,a+1074308|0,76);b=Cb(f)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;g=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;c=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[f>>2]=c+8;ce(f,0,103);c=c+((b|0)<0?-1:1)|0;c=(c|0)>-8?c:-8;d=b;b=b>>31;b=(d+b^b)&15;g=B(x[((((c|0)<95?c:95)<<1)+21904|0)+16>>1],b)+B(x[(v[f>>2]<<1)+21904>>1],16-b|0)<<1>>>a|0;break a}a=c>>>4&15;if(!(e>>>0<108?!(a|e>>>0<24):0)){b=B(a,12);a=((e&255)>>>0)/12|0;g=x[(b+(e-B(a,12)&255)<<1)+21024>>1]<<5>>>a|0;break a}g=x[(b<<1)+20798>>1]<<2}jb=f+16|0;return g}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=jb-16|0;jb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];k=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=k;k=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Yb(k,-16777216,16776704);j=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[c>>2];e=Fma(j,j>>31,e,e>>31);j=mb;L=e;e=v[a+68>>2];l=Fma(e,e>>31,f,f>>31);e=L+l|0;f=mb+j|0;f=e>>>0<l>>>0?f+1|0:f;j=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=Fma(H,I,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=B(e,n)+K;v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=k;k=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;f=v[a+48>>2];v[b+36>>2]=f;h=v[a+52>>2];v[b+40>>2]=h;k=v[a+56>>2];v[b+44>>2]=k;r=v[a+24>>2];s=v[a+20>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;if(d){while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+q|0;h=u[e>>1];v[b+8>>2]=h;v[b+12>>2]=u[e+2>>1];f=0;k=1;while(1){g=v[a+60>>2];n=g;i=(b+32|0)+(f<<3)|0;l=v[i>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);m=v[a+68>>2];t=m;m=m>>31;v[i+4>>2]=l;l=v[a+72>>2];o=g>>31;h=h<<8;g=h;g=Fma(n,o,g,g>>31);n=mb;o=(b+8|0)+(f<<2)|0;f=g;g=Fma(p,p>>31,e,e>>31);f=f+g|0;e=mb+n|0;e=f>>>0<g>>>0?e+1|0:e;j=Fma(t,m,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[o>>2]=(e|0)/256;v[i>>2]=e-(h&l);if(k){f=1;k=0;h=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],r);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];k=v[b+44>>2];h=v[b+40>>2];j=v[b+32>>2];f=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=h;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;jb=f+32|0}function Vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;f=v[a+48>>2];v[b+36>>2]=f;h=v[a+52>>2];v[b+40>>2]=h;k=v[a+56>>2];v[b+44>>2]=k;r=v[a+24>>2];s=v[a+20>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;if(d){while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+q|0;h=t[e|0]<<8;v[b+8>>2]=h;v[b+12>>2]=t[e+1|0]<<8;f=0;k=1;while(1){g=v[a+60>>2];n=g;i=(b+32|0)+(f<<3)|0;l=v[i>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);m=v[a+68>>2];u=m;m=m>>31;v[i+4>>2]=l;l=v[a+72>>2];o=g>>31;h=h<<8;g=h;g=Fma(n,o,g,g>>31);n=mb;o=(b+8|0)+(f<<2)|0;f=g;g=Fma(p,p>>31,e,e>>31);f=f+g|0;e=mb+n|0;e=f>>>0<g>>>0?e+1|0:e;j=Fma(u,m,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}e=(e&16777215)<<8|f>>>24;v[o>>2]=(e|0)/256;v[i>>2]=e-(h&l);if(k){f=1;k=0;h=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],s);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],r);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];k=v[b+44>>2];h=v[b+40>>2];j=v[b+32>>2];f=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=h;v[a+48>>2]=f;v[a+44>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function gla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=w[a+3|0];switch(b-14|0){case 2:case 3:case 4:case 5:break b;case 8:break f;case 6:case 7:break g;case 1:break h;case 0:break i;default:break j}}switch(b-31|0){case 2:break d;case 0:break e;default:break b}}k:{l:{b=w[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}t[a+3|0]=11;break a}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(b>>>0>=16){t[a+5|0]=b|15;break c}t[a+5|0]=b|240;break c}t[c+15|0]=w[a+5|0]>>>4;t[c+14|0]=15;e=a,f=w[pc(c+15|0,c+14|0)|0]|32,t[e+5|0]=f;break c}b=w[a+5|0];if(b>>>0>=16){t[c+13|0]=b>>>4;t[c+12|0]=15;e=a,f=w[pc(c+13|0,c+12|0)|0]|240,t[e+5|0]=f;break c}t[a+5|0]=b|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}e=a,f=zj(w[a+5|0]<<1),t[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=w[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}t[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}t[a+3|0]=0;break c}t[a+5|0]=119;break c}b=48}t[a+5|0]=d&15|b}b=w[a+3|0]}if(b>>>0>=36){t[a+3|0]=0;break a}t[a+3|0]=w[b+13344|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;b=w[a+5|0];t[a+5|0]=0;t[a+4|0]=b}jb=c+16|0}function LZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-496|0;jb=a;Bc(a+488|0,d);v[114578]=0;l=T(2456,a+488|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=v[hj(f,0)>>2];v[114578]=0;i=Q(2482,l|0,45)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}m=(g|0)==(i|0)}j=Wb(a+456|0);i=tf(a+440|0);g=tf(a+424|0);v[114578]=0;na(2510,c|0,m|0,a+488|0,a+480|0,a+476|0,a+472|0,j|0,i|0,g|0,a+420|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[a+4>>2]=2427;k=Rd(a+8|0,0,a+4|0);h:{if((Fb(f)|0)>v[a+420>>2]){c=Fb(f);h=v[a+420>>2];h=(Fb(g)+(c-h<<1)|0)+1|0;break h}h=Fb(g)+2|0}c=a+16|0;h=(Fb(i)+h|0)+v[a+420>>2]|0;if(h>>>0<101){break e}ye(k,pd(h<<2));c=v[k>>2];if(c){break e}v[114578]=0;Y(2428);b=v[114578];v[114578]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}h=v[d+4>>2];n=Tb(f);o=Tb(f);f=Fb(f);v[114578]=0;sa(2511,c|0,a+4|0,a|0,h|0,n|0,(f<<2)+o|0,l|0,m|0,a+480|0,v[a+476>>2],v[a+472>>2],j|0,i|0,g|0,v[a+420>>2]);f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;b=ka(2486,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Gc(k)}Lc(g);Lc(i);yb(j)}Ob(a+488|0);S(f|0);L()}Gc(k);Lc(g);Lc(i);yb(j);Ob(a+488|0);jb=a+496|0;return b|0}function UZ(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-448|0;jb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2489;h=Rd(a+24|0,a+32|0,a+20|0);v[114578]=0;Bc(a+16|0,e);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){v[114578]=0;i=T(2456,a+16|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[114578]=0;b=ta(2500,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}if(!b){break c}c=jb-16|0;jb=c;b=g;e:{if(Fe(b)){d=v[b>>2];v[c+12>>2]=0;Te(d,c+12|0);we(b,0);break e}v[c+8>>2]=0;Te(b,c+8|0);of(b,0)}jb=c+16|0;if(!w[a+15|0]){break d}v[114578]=0;b=Q(2482,i|0,45)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(112,g|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114578]=0;b=Q(2482,i|0,48)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;while(1){if(!((b|0)!=v[e>>2]|d>>>0<=e>>>0)){e=e+4|0;continue}break}v[114578]=0;W(2506,g|0,e|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break c}break b}v[114578]=0;b=Q(2462,a+440|0,a+432|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Ob(a+16|0);Gc(h);jb=a+448|0;return b|0}e=P()|0;O()|0;Ob(a+16|0)}Gc(h);S(e|0);L()}function PZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-192|0;jb=a;Bc(a+184|0,d);v[114578]=0;l=T(21,a+184|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=w[kc(f,0)|0];v[114578]=0;i=Q(22,l|0,45)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}m=(g|0)==(i&255)}j=Wb(a+160|0);i=Wb(a+144|0);g=Wb(a+128|0);v[114578]=0;na(2508,c|0,m|0,a+184|0,a+176|0,a+175|0,a+174|0,j|0,i|0,g|0,a+124|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[a+4>>2]=2427;k=Rd(a+8|0,0,a+4|0);h:{if((Fb(f)|0)>v[a+124>>2]){c=Fb(f);h=v[a+124>>2];h=(Fb(g)+(c-h<<1)|0)+1|0;break h}h=Fb(g)+2|0}c=a+16|0;h=(Fb(i)+h|0)+v[a+124>>2]|0;if(h>>>0<101){break e}ye(k,pd(h));c=v[k>>2];if(c){break e}v[114578]=0;Y(2428);b=v[114578];v[114578]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}h=v[d+4>>2];n=Tb(f);o=Tb(f);f=Fb(f);v[114578]=0;sa(2509,c|0,a+4|0,a|0,h|0,n|0,f+o|0,l|0,m|0,a+176|0,t[a+175|0],t[a+174|0],j|0,i|0,g|0,v[a+124>>2]);f=v[114578];v[114578]=0;if((f|0)!=1){v[114578]=0;b=ka(17,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Gc(k)}yb(g);yb(i);yb(j)}Ob(a+184|0);S(f|0);L()}Gc(k);yb(g);yb(i);yb(j);Ob(a+184|0);jb=a+192|0;return b|0}function daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;v[h+24>>2]=b;b=v[a>>2];q=h,r=bc(a),v[q>>2]=r;b=b+B(ks(h+24|0,h),6)|0;a:{b:{if(!c){break b}g=v[zb(a)>>2];e=v[a+4>>2];if((g-e|0)/6>>>0>=c>>>0){f=c;i=e-b|0;g=(i|0)/6|0;if(g>>>0<c>>>0){Qz(a,c-g|0,d);f=g;if(!i){break b}}k=jb-16|0;jb=k;n=a;o=e;i=b;m=v[a+4>>2];g=B((m-(B(c,6)+b|0)|0)/6|0,6)+b|0;j=Qp(k,a,(e-g|0)/6|0);c:{d:{if(e>>>0>g>>>0){e=g;while(1){l=zb(n);p=v[j+4>>2];v[114578]=0;U(1567,l|0,p|0,e|0);l=v[114578];v[114578]=0;if((l|0)==1){break d}v[j+4>>2]=v[j+4>>2]+6;e=e+6|0;if(o>>>0>e>>>0){continue}break}}Mb(j);e=g-i|0;if(e){$i(m+B((e|0)/-6|0,6)|0,i,e)}jb=k+16|0;break c}a=P()|0;O()|0;Mb(j);S(a|0);L()}d=b>>>0<=d>>>0?y[a+4>>2]>d>>>0?B(c,6)+d|0:d:d;a=b;if(f){while(1){c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[a+4|0]=c;t[a+5|0]=c>>>8;a=a+6|0;f=f-1|0;if(f){continue}break}}break b}f=zb(a);f=JR(h,Fz(a,bg(a)+c|0),(b-v[a>>2]|0)/6|0,f);v[114578]=0;U(708,f|0,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;b=W(1566,a|0,f|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}xt(f)}a=Ng(b);jb=h+32|0;return a|0}a=P()|0;O()|0;xt(f);S(a|0);L()}function vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;l=v[a+16>>2];g=Qf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];n=g,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[g+16>>2];if(b){n=g,o=Pf(a+8|0,b),v[n>>2]=o;v[g+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;f=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=f;a:{if(d){while(1){f=0;i=h;v[e+40>>2]=h;v[e+44>>2]=m;h=(((b&2147483647)<<1|h>>>31)&-2)+l|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){f=(f&2147483647)<<1|i>>>31;Ad(v[g+8>>2],t[(f|1)+h|0]+t[h+(f&-2)|0]<<5);zd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break b}b=b-1|0;i=v[e+40>>2];f=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);zd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Kf(b,v[g+12>>2]);h=v[a+32>>2];k=v[a+28>>2]+k|0;f=k>>12;v[c>>2]=v[c>>2]+B(b,f);j=h+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;f=k>>12}v[a+40>>2]=j;v[a+20>>2]=f;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function aw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;g=jb-1040|0;jb=g;s=v[114552];m=g+16|0;a:{b:{c:{n=g+16|0;e=b;h=v[21203];d:{e:{while(1){if((e|0)!=w[d+56160|0]){c=87;d=d+1|0;if((d|0)!=87){continue}break e}break}c=d;if(c){break e}e=56256;break d}d=56256;while(1){i=w[d|0];e=d+1|0;d=e;if(i){continue}d=e;c=c-1|0;if(c){continue}break}}c=v[h+20>>2];if(c){k=v[c+4>>2];d=e;f=v[c>>2];j=v[f>>2]+1794895138|0;l=dl(v[f+8>>2],j);h=dl(v[f+12>>2],j);i=dl(v[f+16>>2],j);f:{if(k>>>2>>>0<=l>>>0){break f}c=k-(l<<2)|0;if((h|i)&3|(c>>>0<=h>>>0|c>>>0<=i>>>0)){break f}u=i>>>2|0;x=h>>>2|0;while(1){o=l>>>1|0;h=o+p|0;i=h<<1;c=(i+x<<2)+f|0;q=dl(v[c>>2],j);c=dl(v[c+4>>2],j);if(c>>>0>=k>>>0|k-c>>>0<=q>>>0|w[(c+q|0)+f|0]){break f}c=ji(d,c+f|0);if(!c){d=(i+u<<2)+f|0;c=dl(v[d>>2],j);d=dl(v[d+4>>2],j);if(d>>>0>=k>>>0|c>>>0>=k-d>>>0){break f}r=w[(c+d|0)+f|0]?0:d+f|0;break f}if((l|0)==1){break f}c=(c|0)<0;l=c?o:l-o|0;p=c?p:h;continue}}}d=r?r:e;e=$e(d);g:{if(e>>>0>=1024){lc(n,d,1023);t[n+1023|0]=0;e=68;break g}lc(n,d,e+1|0);e=0}switch(e+1|0){case 1:break a;case 0:break c;default:break b}}e=v[114552]}m=58392;if((e|0)==28){break a}Xa();L()}if(!w[m|0]){v[g>>2]=b;bw(g+16|0,1024,58596,g);m=g+16|0}v[114552]=s;Ub(a,m);jb=g+1040|0}function Dma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{g=b;if(g){e=c;if(!e){break j}f=d;if(!f){break i}f=E(f)-E(g)|0;if(f>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;kb=a-B(b,c)|0;lb=0;mb=0;return b}e=d;if(!a){break g}if(!e){break f}f=e-1|0;if(f&e){break f}kb=a;lb=f&g;a=g>>>Ema(e)|0;mb=0;return a}f=e-1|0;if(!(f&e)){break e}j=(E(e)+33|0)-E(g)|0;h=0-j|0;break c}j=f+1|0;h=63-f|0;break c}kb=0;a=(g>>>0)/(e>>>0)|0;lb=g-B(a,e)|0;mb=0;return a}f=E(e)-E(g)|0;if(f>>>0<31){break d}break b}kb=a&f;lb=0;if((e|0)==1){break a}c=a;a=Ema(e);d=a&31;if((a&63)>>>0>=32){f=0;a=b>>>d|0}else{f=b>>>d|0;a=((1<<d)-1&b)<<32-d|c>>>d}mb=f;return a}j=f+1|0;h=63-f|0}e=b;g=a;f=j&63;i=f&31;if((f&63)>>>0>=32){f=0;l=e>>>i|0}else{f=e>>>i|0;l=((1<<i)-1&e)<<32-i|g>>>i}a=h&63;h=a&31;if((a&63)>>>0>=32){e=g<<h;a=0}else{e=(1<<h)-1&g>>>32-h|b<<h;a=g<<h}b=e;if(j){g=d-1|0;e=c-1|0;g=(e|0)!=-1?g+1|0:g;h=e;while(1){e=l;f=f<<1|e>>>31;e=e<<1;k=f;f=b>>>31|e;m=k;e=k;k=f;i=g-((f>>>0>h>>>0)+e|0)|0;e=i>>31;i=i>>31;f=c&i;l=k-f|0;f=m-((d&e)+(f>>>0>k>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;e=0;m=e;k=i&1;n=k;j=j-1|0;if(j){continue}break}}kb=l;lb=f;e=b<<1|a>>>31;a=k|a<<1;mb=e|m;return a}kb=a;lb=b;a=0;b=0}mb=b;return a}function iY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){i=v[a+12>>2];if(!(i>>>0>=d>>>0|f>>>0>=g>>>0)){b=t[i|0];c=b&255;c:{if((b|0)>=0){b=2;if(c>>>0>1114111){break a}b=i+1|0;break c}b=2;if(c>>>0<194){break a}if(c>>>0<=223){if((d-i|0)<2){break b}j=w[i+1|0];if((j&192)!=128){break a}c=j&63|c<<6&1984;if(c>>>0>1114111){break a}b=i+2|0;break c}if(c>>>0<=239){if((d-i|0)<3){break b}k=w[i+2|0];j=w[i+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((j&224)==160){break d}break a}if((j&224)==128){break d}break a}if((j&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(j&63)<<6);if(c>>>0>1114111){break a}b=i+3|0;break c}if(c>>>0>244){break a}if((d-i|0)<4){break b}k=w[i+3|0];l=w[i+2|0];j=w[i+1|0];f:{g:{switch(c-240|0){case 0:if((j+112&255)>>>0<48){break f}break a;case 4:if((j&240)==128){break f}break a;default:break g}}if((j&192)!=128){break a}}if((l&192)!=128|(k&192)!=128){break a}c=k&63|(l<<6&4032|(c<<18&1835008|(j&63)<<12));if(c>>>0>1114111){break a}b=i+4|0}v[f>>2]=c;v[a+12>>2]=b;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>i>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function ZU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-1072|0;jb=f;e=Yh(f+16|0);h=hm(a,e);Bb(e);v[a+1060>>2]=0;v[a+1064>>2]=0;v[a+1056>>2]=c;e=a+1068|0;v[e>>2]=0;v[e+4>>2]=0;e=0;v[a+1076>>2]=0;t[a+1080|0]=d;a:{b:{if(ue(c)){i=a+1060|0;while(1){v[a+1060>>2]=0;v[a+1064>>2]=0;c:{if(!v[c>>2]){break c}while(1){v[114578]=0;d=Q(258,b|0,2)|0;g=v[114578];v[114578]=0;d:{e:{f:{g:{if((g|0)!=1){if(!d){break c}v[114578]=0;d=T(359,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}if(!d){break d}v[114578]=0;U(343,f|0,b|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break f}d=hm(f+16|0,f);Wd(h,d);lc(h+16|0,d+16|0,1040);Bb(f+16|0);Bb(f);v[a+1072>>2]=0;v[a+1076>>2]=0;g=sq(v[a+1056>>2]);d=v[a+1056>>2];if(g>>>0>=2){d=v[d+20>>2];v[114578]=0;R(360,a|0,d+(e<<1)|0);d=v[114578];v[114578]=0;if((d|0)!=1){break d}break e}d=v[d+20>>2];v[114578]=0;R(361,a|0,d+e|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(76880)|0;if((O()|0)!=(ga(76880)|0)){break a}_(d|0)|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)==1){break b}}if(y[i>>2]<y[c>>2]){continue}break}}e=e+1|0;if(ue(v[a+1056>>2])>>>0>e>>>0){continue}break}}jb=f+1072|0;return a|0}d=P()|0;O()|0}Bb(a);S(d|0);L()}function N9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-144|0;jb=c;e=al(c+40|0,a);v[114578]=0;d=Q(683,c+24|0,32325)|0;a=v[114578];v[114578]=0;a:{b:{c:{d:{if((a|0)!=1){v[114578]=0;v[c+16>>2]=19466496;v[c+20>>2]=0;U(684,e|0,d|0,c+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}Ib(d);if(!(v[e>>2]&1073741824)){break c}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(d);break b}a=Ce(b);v[114578]=0;u[c+16>>1]=a;u[c+14>>1]=65535;d=Q(683,c+24|0,32331)|0;a=v[114578];v[114578]=0;e:{if((a|0)!=1){v[114578]=0;a=W(1183,e|0,c+14|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}Ib(d);if((a|0)!=1){u[c+16>>1]=x[c+14>>1]}jg(c+16|0,x[v[19811]+10>>1]);f:{if(x[c+16>>1]<=Ce(b)>>>0){break f}v[114578]=0;R(403,b|0,x[c+16>>1]);a=v[114578];v[114578]=0;if((a|0)!=1){break f}a=P()|0;O()|0;break b}u[c+12>>1]=0;if(!x[c+16>>1]){break a}a=0;g:{while(1){h:{a=_b(b,a);v[114578]=0;R(1588,c+24|0,c+12|0);d=v[114578];v[114578]=0;if((d|0)==1){break h}v[114578]=0;aa(1570,e|0,a|0,c+24|0,1589)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}Ib(c+24|0);a=x[c+12>>1]+1|0;u[c+12>>1]=a;a=a&65535;if(a>>>0<x[c+16>>1]){continue}break a}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(c+24|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(d)}vg(e);S(a|0);L()}vg(e);jb=c+144|0}function Cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-432|0;jb=d;Jc(b);zz(b,d+376|0,d+296|0,d+8|0);e=d;if(w[d+408|0]|w[d+409|0]<<8|(w[d+410|0]<<16|w[d+411|0]<<24)){f=w[d+427|0]+1|0}else{f=1}k=e,l=zj(f),t[k+4|0]=l;e=w[pc(15087,d+4|0)|0];t[d+7|0]=e;u[d+4>>1]=4;a:{b:{if(!e){break b}while(1){e=w[d+8|0]|w[d+9|0]<<8;c:{d:{if(w[d+291|0]>63){break d}f=(e<<8|e>>>8)<<16>>16;if((f|0)<0){break d}if(e){e=f&65535;i=e>>>0>1?e:1;f=0;while(1){e=w[d+392|0]|w[d+393|0]<<8|(w[d+394|0]<<16|w[d+395|0]<<24);e:{if(!Pc(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+(f<<2)|0)){break e}if(!Pc(b,rA(b))){break e}e=d;f:{if(!c){h=Gd(b);break f}h=Wp(b)}u[e+2>>1]=h;k=d,l=x[Si(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;if((i|0)!=(f|0)){continue}break}}e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0>j>>>0){e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if(Pc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))){break c}}t[d+7|0]=g+1;break b}SB(a);break a}e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);zz(b,d+376|0,d+296|0,d+8|0);j=e<<8&16711680|e<<24|(e>>>8&65280|e>>>24);g=g+1|0;if(w[d+7|0]>(g&255)>>>0){continue}break}}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}jb=d+432|0}function lia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;e=b;f=Dg(e);d=c;a:{if(f>>>0<d>>>0){l=jb-32|0;jb=l;b:{c:{k=d-f|0;d:{if(k>>>0<=v[zb(e)>>2]-v[e+4>>2]>>3>>>0){f=jb-16|0;jb=f;e:{d=zq(f,e,k);if(v[d+4>>2]!=v[d+8>>2]){while(1){g=zb(e);h=v[d+4>>2];v[114578]=0;R(926,g|0,h|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}g=v[d+4>>2]+8|0;v[d+4>>2]=g;if((g|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=f+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}m=zb(e);g=l+8|0;i=Dg(e)+k|0;h=jb-16|0;jb=h;v[h+12>>2]=i;f=e;f:{d=Qu(e);if(i>>>0<=d>>>0){f=Ui(f);if(f>>>0<d>>>1>>>0){v[h+8>>2]=f<<1;d=v[bd(h+8|0,h+12|0)>>2]}jb=h+16|0;break f}fd();L()}i=Dg(e);f=0;h=jb-16|0;jb=h;v[h+12>>2]=0;Tc(g+12|0,m);if(d){f=d;if(d>>>0>536870911){Fc(16520);L()}f=sc(f<<3,1)}v[g>>2]=f;i=(i<<3)+f|0;v[g+8>>2]=i;v[g+4>>2]=i;n=ec(g),o=(d<<3)+f|0,v[n>>2]=o;jb=h+16|0;v[114578]=0;R(924,g|0,k|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(925,e|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}YP(g)}jb=l+32|0;break b}a=P()|0;O()|0;YP(g);S(a|0);L()}break a}if(d>>>0<f>>>0){d=v[e>>2]+(d<<3)|0;Dg(e);ZP(e,d);Ui(e);Dg(e)}}c=Qb(a,c<<3);if(c){e=jb-16|0;jb=e;gc(j+8|0,v[b>>2],Dg(b)<<3);jb=e+16|0;Bd(a,j+8|0)}jb=j+16|0;return c|0}function Rka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{if(!Qb(b,9)){break b}h=a+484344|0;i=a+480280|0;while(1){An(b,c+28|0);d=Cf(b);c:{if(!((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1229999433|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1397771593|((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110104|(w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1297110099))){if(Qb(b,d)){break c}}fg(b,8);break b}ud(c+8|0,b,d);d=i;d:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1481001027){while(1){v[114578]=0;e=T(392,c+8|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}t[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}e:{if(w[c+28|0]!=70){break e}d=w[c+29|0];e=(d|0)==88;if((d-48&255)>>>0>9?!e:0){break e}f=w[c+30|0];if((f-48&255)>>>0>9){break e}g=w[c+31|0];if((g-48&255)>>>0>9){break e}d=(B(f,10)+(e?-16:B(d,100)+48|0)|0)+g&255;if(d>>>0>249){break d}v[114578]=0;R(666,c+8|0,(B(d,160)+a|0)+906300|0);d=v[114578];v[114578]=0;if((d|0)!=1){break d}break a}if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1430540109){break d}v[a+1074304>>2]=0;j=1}Bb(c+8|0);if(Qb(b,9)){continue}break}}jb=c+32|0;return j|0}a=P()|0;O()|0;Bb(c+8|0);S(a|0);L()}function H9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);h=jb-16|0;jb=h;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Kb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}i=u[d+2>>1];if((i|0)<(g|0)){break a}if((Kb(b)-1&65535)>>>0>(i-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Kb(b)){break b}while(1){if(!(z[Pb(b,f)>>2]<C(0))){f=f+1|0;if(Kb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=dK(Kb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;pl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=bc(b);f=cc(b);l=h,m=bc(g),v[l+8>>2]=m;i=pp(h+8|0,u[e>>1]-u[d>>1]|0);b=jb-16|0;jb=b;Qc(b+8|0,Az(Il(c),Il(f),Il(i)));jb=b+16|0;b=u[e>>1];f=u[a+28>>1];c:{if((b|0)<=(f|0)){c=b;break c}while(1){b=b-1|0;j=z[Pb(g,u[a+30>>1]+(b-f|0)|0)>>2];k=z[a+32>>2];l=Pb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;c=u[e>>1];f=u[a+28>>1];if((f|0)>=(b|0)){break c}if((c|0)!=-32768){continue}break}}f=u[a+30>>1];b=f+c|0;d:{if((b|0)>u[d+2>>1]|(32767-f|0)<(c|0)){break d}while(1){j=z[a+32>>2];k=z[Pb(g,b-(u[a+28>>1]+f|0)|0)>>2];l=Pb(g,b-u[a+28>>1]|0),n=C(k*j),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}b=b+1|0;f=u[a+30>>1];if(u[e>>1]<=(32767-f|0)){continue}break}}Mo(a);f=1}jb=h+16|0;return f|0}function aF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;k=jb-16|0;jb=k;a:{b:{c:{if((c|0)<=36){h=w[a|0];if(h){break c}f=a;break b}v[114552]=28;d=0;e=0;break a}f=a;d:{while(1){if(!fl(h<<24>>24)){break d}h=w[f+1|0];g=f+1|0;f=g;if(h){continue}break}f=g;break b}e:{g=w[f|0];switch(g-43|0){case 0:case 2:break e;default:break b}}m=(g|0)==45?-1:0;f=f+1|0}f:{if(!(c&-17|w[f|0]!=48)){o=1;if((w[f+1|0]&223)==88){f=f+2|0;l=16;break f}f=f+1|0;l=c?c:8;break f}l=c?c:10}p=l;q=l>>31;c=0;while(1){g:{g=t[f|0];h=g-48|0;h:{if((h&255)>>>0<=9){break h}if((g-97&255)>>>0<=25){h=g-87|0;break h}if((g-65&255)>>>0>25){break g}h=g-55|0}if((h|0)>=(l|0)){break g}$g(k,p,q,j,i);g=1;i:{if(v[k+8>>2]|v[k+12>>2]){break i}r=Fma(j,i,p,q);n=mb;s=h>>31;u=s^-1;if((n|0)==(u|0)&(h^-1)>>>0<r>>>0|n>>>0>u>>>0){break i}i=n+s|0;g=h+r|0;i=g>>>0<h>>>0?i+1|0:i;j=g;o=1;g=c}f=f+1|0;c=g;continue}break}if(b){v[b>>2]=o?f:a}j:{k:{if(c){v[114552]=68;a=d&1;m=a?0:m;j=d;i=e;break k}if((e|0)==(i|0)&d>>>0>j>>>0|e>>>0>i>>>0){break j}a=d&1}if(!(a|m)){v[114552]=68;a=d;d=a-1|0;e=e-(a>>>0<1)|0;break a}if((e|0)==(i|0)&d>>>0>=j>>>0|e>>>0>i>>>0){break j}v[114552]=68;break a}a=m;c=a^j;d=c-a|0;b=a>>31;e=(b^i)-((a>>>0>c>>>0)+b|0)|0}jb=k+16|0;mb=e;return d}function AQ(a,b){var c=0;a:{b:{c:{d:{if($d(a,15629)){break d}if($d(a,15656)){break d}if($d(a,15661)){break d}if($d(a,16153)){break d}if(!$d(a,16158)){break c}}u[b+8>>1]=4;v[b>>2]=16163;break b}e:{f:{if($d(a,15634)){break f}if($d(a,15639)){break f}if(!$d(a,16196)){break e}}t[b+10|0]=1;u[b+8>>1]=4;v[b>>2]=16201;return 1}g:{if(!$d(a,16214)){if(!$d(a,16219)){break g}}u[b+8>>1]=8;v[b>>2]=16224;break b}h:{if(!$d(a,16234)){if(!$d(a,16239)){break h}}v[b>>2]=16244;u[b+8>>1]=t[a+2|0]-48;break b}i:{if(!$d(a,15619)){if(!$d(a,15624)){break i}}v[b+4>>2]=1;v[b>>2]=16262;u[b+8>>1]=w[a|0]==56?8:4;return 1}if(!(qd(a,16293,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=16297;u[b+8>>1]=t[a+3|0]-48;break b}j:{if(qd(a,16313,3)){if(qd(a,16317,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+13|0]=1;t[b+11|0]=1;v[b>>2]=16321;u[b+8>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!qd(a+1|0,16333,3)){t[b+12|0]=1;v[b>>2]=16337;u[b+8>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9|((w[a+2|0]|w[a+3|0]<<8)!=20035?(w[a+2|0]|w[a+3|0]<<8)!=18499:0)){break k}t[b+12|0]=1;v[b>>2]=16337;u[b+8>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}if(qd(a,16368,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=16372;u[b+8>>1]=t[a+3|0]-48}c=1}return c}function n8(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=jb-32|0;jb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=nb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[de(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[114578]=0;R(508,d+4|0,b+4|0);b=v[114578];v[114578]=0;c:{d:{e:{f:{if((b|0)!=1){b=v[a+20>>2];v[114578]=0;R(698,c+8|0,b+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;v[c>>2]=0;v[c+4>>2]=0;U(1739,c+16|0,c+8|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;Q(1740,c+16|0,0)|0;b=v[114578];v[114578]=0;g:{if((b|0)==1){break g}d=v[v[a>>2]+176>>2];b=0;v[114578]=0;R(d|0,a|0,-1);d=v[114578];v[114578]=0;if((d|0)==1){break g}if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[114578]=0;f=C(pa(d|0,a|0,b|0));d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;z[c+8>>2]=f;Q(1741,c+16|0,c+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+180>>2];v[114578]=0;Z(b|0,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(71204)|0;break c}b=V(71204)|0;break c}b=V(71204)|0;break c}b=V(71204)|0;break c}b=V(71204)|0}if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;Gs(v[a+20>>2]+4|0);$()}jb=c+32|0;return}S(b|0);L()}function PT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-32|0;jb=i;t[i+12|0]=0;l=KA(i+16|0,d,i+12|0);h=v[l>>2];v[i+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){n=i;g=b-1|0;f=w[a|0];b:{c:{if(!(!g|(f|0)!=(e&255))){f=w[a+1|0];v[114578]=0;v[i+8>>2]=f;f=Q(33,i+8|0,i+12|0)|0;g=v[114578];v[114578]=0;d:{if((g|0)!=1){k=a+2|0;g=b-2|0;if(!g){break d}j=v[f>>2];if(!(j&255)){break d}g=w[k|0];while(1){t[h|0]=g;f=v[i+12>>2]-1|0;v[i+12>>2]=f;h=h+1|0;j=j-1|0;if(j&255){continue}break}g=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;qq(l);S(a|0);L()}t[h|0]=e;f=v[i+12>>2]-1|0;break c}k=a+1|0;t[h|0]=f;f=v[i+12>>2]-1|0}v[n+12>>2]=f;h=h+1|0}if(!g){break a}a=k;b=g;if(f){continue}break}}k=v[l>>2];e=d-f|0;e:{if(!e){break e}h=128;g=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+g|0;t[a|0]=w[a|0]|(B(b&h,257)&65535)>>>(f-j&7);a=g+1|0;g=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;h=(h<<8|h)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}h=(h<<8|h)>>>f&255;k=k+1|0;m=m+1|0;if((m|0)!=(e|0)){continue}break}if(!e){break e}j=0;while(1){d=c;f=d;g=j<<24>>24;b=t[d|0];d=128;f:{if((b|0)==-128){break f}a=b;d=a;if((a|0)>-1){break f}d=0-(b&127)|0}j=g-(d&255)|0;t[f|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}qq(l);jb=i+32|0}function Vo(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=bc(a),v[f+8>>2]=g;f=c,g=cc(a),v[f>>2]=g;a=1;j:{if(!Jb(c+8|0,c)){break j}while(1){b=v[c+8>>2];if(!(!mh(b)|v[b+12>>2]==64)){a=4;break j}sy(c+8|0);if(Jb(c+8|0,c)){continue}break}}jb=c+16|0;return a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}jb=c+16|0;return d}function yla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;Fd(b,32);e=a+4|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=a+10|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+4>>2]=e;g=e;e=a+14|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b+8>>2]=g+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));e=b;if(!(d?0:c)){c=a+46|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}v[e+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;if(!(w[d|0]|w[d+1|0]<<8)|(w[d|0]|w[d+1|0]<<8)==12288){break a}e=c;c=w[d|0]|w[d+1|0]<<8;c=(e-(((c<<8|c>>>8)&65535)<<7)|0)+6144|0}Ys(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[pc(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}jb=f+16|0}function AR(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{d=w[a|0];b:{if(d>>>0>21){break b}t[a|0]=w[d+14784|0];c:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break b;case 4:t[b|0]=w[b|0]+1>>>1;break b;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break b;case 6:d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 10:break e;case 9:break f;case 8:break g;case 6:break h;case 5:break i;case 3:break j;case 1:break k;case 0:break l;case 11:case 12:case 13:break b;case 14:break d;default:break m}}t[a|0]=0;break b}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[pc(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break b}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[pc(c+13|0,c+12|0)|0]|240,t[e|0]=f;break b}t[b|0]=d&15|48;break b}t[b|0]=d&15|176;break b}t[b|0]=d&15|64;break b}t[a|0]=15;t[b|0]=w[b|0]&15;break b}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break b}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break b}t[a|0]=10;break b;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break b}if(a>>>0<=239){t[b|0]=a<<2&48|15;break b}t[b|0]=a<<4|15;break b;case 9:break c;default:break b}}a=w[b|0];if(a>>>0<=223){break a}if(a>>>0>239){break b}t[b|0]=a>>>2&3|240}jb=c+16|0;return}t[b|0]=a>>>0>63?15:a>>>2|0;jb=c+16|0}function lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=e+p|0;j=t[g+2|0];n=t[g+1|0];q=t[g|0];r=t[g-1|0];g=v[a+60>>2];s=g;w=g>>31;e=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);x=v[a+72>>2];y=v[a+32>>2];g=c;z=v[g>>2];e=Fma(k,k>>31,e,e>>31);k=mb;A=e;e=v[a+68>>2];o=Fma(e,e>>31,f,f>>31);e=A+o|0;f=mb+k|0;f=e>>>0<o>>>0?f+1|0:f;k=e;e=(i>>>21&2040)+27888|0;i=(((B(q,u[e+2>>1])+B(r,u[e>>1])|0)+B(n,u[e+4>>1])|0)+B(j,u[e+6>>1])<<8)/16384<<8;e=i;j=Fma(s,w,e,e>>31);e=k+j|0;f=mb+f|0;f=e>>>0<j>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(f,j)+z;l=l+y|0;n=l>>12;v[c+4>>2]=v[c+4>>2]+B(f,n);g=e-(i&x)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=b;b=g;continue}break}i=v[h+8>>2];e=v[h+12>>2];f=b;break a}n=l>>12;j=m>>12;g=b}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=g;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function AL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b:{d=a+484360|0;if(oc(Vb(d))>>>0<=b>>>0){break b}if(np(Vb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(oc(Vb(d))>>>0<=c>>>0){break a}if(!np(Vb(d),b&65535)){continue}break}break a}c=b}if(oc(Vb(d))>>>0>c>>>0){d=a+1074308|0;f=a+1304360|0;c=a+1074984|0;while(1){t[c+819|0]=0;v[c+700>>2]=0;t[c+861|0]=0;t[c+827|0]=0;v[c+708>>2]=0;t[c+841|0]=0;v[c+804>>2]=0;t[c+839|0]=0;t[c+840|0]=0;Eb(e+8|0,d,23);if(Cb(e+8|0)){u[c+798>>1]=0;u[c+800>>1]=1}t[c+859|0]=0;c=c+896|0;if((f|0)!=(c|0)){continue}break}zL(a);c:{if(!(b&65535)){b=a;c=0;while(1){pn((b+B(c,896)|0)+1074984|0,b,c&65535);c=c+1|0;if((c|0)!=256){continue}break}pj(b+1304360|0,1);v[b+1074444>>2]=v[b+480200>>2];v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+480208>>2]=v[b+480208>>2]&-769;fy(b+1074376|0);u[b+1074440>>1]=0;v[b+1074392>>2]=-2;c=b+1074428|0;v[c>>2]=0;v[c+4>>2]=0;c=b+1074396|0;v[c>>2]=0;v[c+4>>2]=0;v[b+1074376>>2]=0;v[b+1074380>>2]=0;break c}u[a+1074440>>1]=b;u[a+1074436>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}jb=e+16|0}function uY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!v[i>>2]){break a}i=i+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((f|0)==(g|0)|(c|0)==(d|0))){k=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=k;m=1;l=jb-16|0;jb=l;v[l+12>>2]=v[a+8>>2];n=Ah(l+8|0,l+12|0);v[114578]=0;k=fF(f,e,i-c>>2,g-f|0,b);o=v[114578];v[114578]=0;d:{if((o|0)!=1){Ie(n);jb=l+16|0;break d}a=P()|0;O()|0;Ie(n);S(a|0);L()}e:{f:{g:{h:{switch(k+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=Bv(f,v[c>>2],j+8|0,v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=k+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((d|0)==(i|0)){c=v[e>>2];i=d;continue}i=Bv(j+4|0,0,b,v[a+8>>2]);if((i|0)!=-1){break f}}m=2;break c}c=j+4|0;if(g-v[h>>2]>>>0<i>>>0){break c}while(1){if(i){f=w[c|0];k=v[h>>2];v[h>>2]=k+1;t[k|0]=f;i=i-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!v[i>>2]){break b}i=i+4|0;continue}}c=v[e>>2]}m=(c|0)!=(d|0)}jb=j+16|0;return m|0}f=v[h>>2];continue}}function kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;h=jb-16|0;jb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];k=v[a>>2];v[h+8>>2]=k;v[h+12>>2]=f;g=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=g;a:{if(d){while(1){g=(f<<1)+p|0;i=u[g>>1];q=u[g-2>>1];r=u[g+2>>1];s=u[g+4>>1];o=v[a+60>>2];f=Yb(b,-16777216,16776704);n=v[a+64>>2];j=Yb(e,-16777216,16776704);t=v[a+72>>2];w=v[a+32>>2];g=c;x=v[g>>2];e=Fma(n,n>>31,f,f>>31);n=mb;f=e;e=(k>>>21&2040)+27888|0;k=(((B(i,u[e+2>>1])+B(q,u[e>>1])|0)+B(r,u[e+4>>1])|0)+B(s,u[e+6>>1])|0)/16384<<8;e=k;i=Fma(o,o>>31,e,e>>31);f=f+i|0;e=mb+n|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];j=Fma(f,f>>31,j,j>>31);f=i+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;j=m>>12;v[g>>2]=B(e,j)+x;l=l+w|0;i=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);g=f-(k&t)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;k=v[h+8>>2];f=v[h+12>>2];e=b;b=g;continue}break}k=v[h+8>>2];f=v[h+12>>2];e=b;break a}i=l>>12;j=m>>12;g=b}v[a+40>>2]=l;v[a+20>>2]=j;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=g;v[a+24>>2]=i;v[a>>2]=k;v[a+4>>2]=f;jb=h+16|0}function efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-32|0;jb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=g+32|0}function dda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-32|0;jb=g;v[g+24>>2]=b;b=v[a>>2];n=g,o=bc(a),v[n>>2]=o;b=b+(Vp(g+24|0,g)<<1)|0;a:{f=py(c,d);b:{if((f|0)<1){break b}h=v[zb(a)>>2];e=v[a+4>>2];if((f|0)<=h-e>>1){v[g>>2]=d;i=e-b|0;h=i>>1;if((h|0)<(f|0)){v[g>>2]=c;v[g>>2]=v[g>>2]+(h<<1);LN(a,v[g>>2],d,f-h|0);if((i|0)<1){break b}}k=jb-16|0;jb=k;h=e;i=b;j=a;l=v[a+4>>2];a=(l-((f<<1)+b|0)|0)+b|0;f=Xh(k,j,e-a>>1);c:{d:{if(a>>>0<e>>>0){d=a;while(1){e=zb(j);m=v[f+4>>2];v[114578]=0;U(1248,e|0,m|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[f+4>>2]=v[f+4>>2]+2;d=d+2|0;if(h>>>0>d>>>0){continue}break}}Mb(f);Fp(i,a,l);jb=k+16|0;break c}a=P()|0;O()|0;Mb(f);S(a|0);L()}gf(c,v[g>>2],b);break b}k=zb(a);h=Ri(a,oc(a)+f|0);f=b-v[a>>2]>>1;j=jb-16|0;jb=j;v[j+12>>2]=0;e=g;Tc(e+12|0,k);if(h){i=h;if(h>>>0>2147483647){Fc(11736);L()}i=sc(i<<1,2)}v[e>>2]=i;f=(f<<1)+i|0;v[e+8>>2]=f;v[e+4>>2]=f;n=ec(e),o=(h<<1)+i|0,v[n>>2]=o;jb=j+16|0;v[114578]=0;U(1246,e|0,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;b=W(1247,a|0,e|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}bC(e)}a=Ng(b);jb=g+32|0;return a|0}a=P()|0;O()|0;bC(e);S(a|0);L()}function _Z(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-160|0;jb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=2489;b=Rd(a+24|0,a+32|0,a+20|0);v[114578]=0;Bc(a+16|0,e);h=v[114578];v[114578]=0;a:{b:{c:{d:{if((h|0)!=1){v[114578]=0;h=T(21,a+16|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break b}t[a+15|0]=0;e=v[e+4>>2];v[114578]=0;c=ta(2490,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(!c){break c}Le(g);if(!w[a+15|0]){break d}v[114578]=0;c=Q(22,h|0,45)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(110,g|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114578]=0;h=Q(22,h|0,48)|0;c=v[114578];v[114578]=0;if((c|0)!=1){e=v[b>>2];i=v[a+20>>2];c=i-1|0;d=c>>>0<e>>>0?e:c;h=h&255;while(1){e:{if(c>>>0>e>>>0){if((h|0)==w[e|0]){break e}d=e}v[114578]=0;W(2498,g|0,d|0,i|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break c}break b}e=e+1|0;continue}}break b}v[114578]=0;c=Q(2430,a+152|0,a+144|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Ob(a+16|0);Gc(b);jb=a+160|0;return c|0}e=P()|0;O()|0;Ob(a+16|0)}Gc(b);S(e|0);L()}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b&63;if(Bk(c)>>>0>d>>>0){g=CR(c,d);h=jb-16|0;jb=h;c=a;t[c+12|0]=0;vR(c);f=jb-32|0;jb=f;a:{b:{d=c;if(yd(d)>>>0<15){e=zb(d);e=Un(f+8|0,15,Kb(d),e);v[114578]=0;R(370,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}Wh(e)}jb=f+32|0;break a}a=P()|0;O()|0;Wh(e);S(a|0);L()}d=w[g+1|0];c:{if(!d){break c}f=0-d|0;while(1){t[h+7|0]=64;f=(f<<16>>16)+d|0;j=Cp(h+8|0,f&65535,w[pc(((i<<1)+g|0)+2|0,h+7|0)|0]);d=c;d:{if(y[d+4>>2]<y[zb(d)>>2]){tR(d,j);break d}k=jb-32|0;jb=k;e=d;l=zb(d);d=Un(k+8|0,Be(d,Kb(d)+1|0),Kb(d),l);m=v[d+8>>2];v[114578]=0;U(767,l|0,m|0,j|0);j=v[114578];v[114578]=0;e:{f:{if((j|0)==1){break f}v[d+8>>2]=v[d+8>>2]+4;v[114578]=0;R(370,e|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break f}Wh(d);jb=k+32|0;break e}a=P()|0;O()|0;Wh(d);S(a|0);L()}}i=i+1|0;if((i|0)==15){break c}d=w[((i<<1)+g|0)+1|0];if(d){continue}break}}d=w[g+32|0];t[c+14|0]=d>>>4;t[c+13|0]=d&15;d=w[g+31|0];e=d&15;t[c+15|0]=e;t[c+16|0]=e;if(d&16){t[c+12|0]=w[c+12|0]|4}if(d&32){t[c+12|0]=w[c+12|0]|2}jb=h+16|0}g:{h:{if(b<<24>>24>=0){b=a+12|0;break h}c=a;b=c+12|0;if(nd(c)){break h}a=w[c+12|0]|1;break g}a=w[a+12|0]&-2}t[b|0]=a}function zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;j=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=Pf(a+8|0,b),v[n>>2]=o;v[f+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){h=0;i=g;v[e+40>>2]=g;v[e+44>>2]=m;g=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+j|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){h=(h&2147483647)<<1|i>>>31;Ad(v[f+8>>2],(u[(h<<1|2)+g>>1]+u[g+((h&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,(u[(b<<1|2)+g>>1]+u[g+((b&2147483646)<<1)>>1]|0)/8<<16>>16);zd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function nga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=jb-16|0;jb=g;a:{if(w[d|0]){e=Od(g+8|0,b);b=Ci(c,b);d=jb-16|0;jb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Lb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){Uc(a,c,Ema(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){Ny(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){Uc(a,c,Ema(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}Uc(a,c,Ema(e));break b}Uc(a,c,b)}break a}e=Od(g,b);b=Ci(c,b);d=jb-16|0;jb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Lb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){Uc(a,c,Ema(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){Ny(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){Uc(a,c,Ema(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}Uc(a,c,Ema(e));break d}Uc(a,c,b)}}jb=d+16|0;jb=g+16|0}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(v[a+4>>2]!=v[zb(a)>>2]){h=jb-16|0;jb=h;c=h;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+56;a=zb(a);d=v[c+4>>2];v[114578]=0;U(977,a|0,d|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;Mb(c);jb=h+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}i=jb-32|0;jb=i;h=a;j=zb(a);e=i+8|0;c=wk(a)+1|0;f=jb-16|0;jb=f;v[f+12>>2]=c;d=c;c=jb-16|0;jb=c;g=a;zb(a);v[c+12>>2]=76695844;v[114578]=0;v[c+8>>2]=2147483647;k=Q(33,c+12|0,c+8|0)|0;l=v[114578];v[114578]=0;b:{if((l|0)!=1){jb=c+16|0;c=v[k>>2];break b}V(0)|0;O()|0;Ab();L()}c:{if(c>>>0>=d>>>0){d=sn(g);if(d>>>0<c>>>1>>>0){v[f+8>>2]=d<<1;c=v[bd(f+8|0,f+12|0)>>2]}jb=f+16|0;break c}fd();L()}g=wk(a);a=0;d=jb-16|0;jb=d;v[d+12>>2]=0;Tc(e+12|0,j);if(c){a=c;if(a>>>0>76695844){Fc(16924);L()}a=sc(B(a,56),4)}v[e>>2]=a;g=B(g,56)+a|0;v[e+8>>2]=g;v[e+4>>2]=g;m=ec(e),n=B(c,56)+a|0,v[m>>2]=n;jb=d+16|0;a=v[e+8>>2];v[114578]=0;U(977,j|0,a|0,b|0);a=v[114578];v[114578]=0;d:{e:{if((a|0)==1){break e}v[e+8>>2]=v[e+8>>2]+56;v[114578]=0;R(978,h|0,e|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}tP(e);jb=i+32|0;break d}a=P()|0;O()|0;tP(e);S(a|0);L()}}function tma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-32|0;jb=h;v[h+24>>2]=b;b=v[a>>2];o=h,p=bc(a),v[o>>2]=p;b=b+(Vp(h+24|0,h)<<1)|0;a:{b:{if(y[a+4>>2]<y[zb(a)>>2]){j=v[a+4>>2];if((j|0)==(b|0)){f=jb-16|0;jb=f;e=Xh(f,a,1);d=zb(a);a=v[e+4>>2];v[114578]=0;U(521,d|0,a|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[e+4>>2]=v[e+4>>2]+2;Mb(e);jb=f+16|0;break b}a=P()|0;O()|0;Mb(e);S(a|0);L()}l=jb-16|0;jb=l;d=a;e=b;k=v[a+4>>2];g=(k-(b+2|0)|0)+b|0;i=Xh(l,a,j-g>>1);c:{d:{if(g>>>0<j>>>0){f=g;while(1){n=zb(d);m=v[i+4>>2];v[114578]=0;U(522,n|0,m|0,f|0);m=v[114578];v[114578]=0;if((m|0)==1){break d}v[i+4>>2]=v[i+4>>2]+2;f=f+2|0;if(j>>>0>f>>>0){continue}break}}Mb(i);if((e|0)!=(g|0)){while(1){k=k-2|0;g=g-2|0;rT(k,g);if((e|0)!=(g|0)){continue}break}}jb=l+16|0;break c}a=P()|0;O()|0;Mb(i);S(a|0);L()}c=b>>>0<=c>>>0?y[a+4>>2]>c>>>0?c+2|0:c:c;t[b|0]=w[c|0];t[e+1|0]=w[c+1|0];break b}d=zb(a);d=wT(h,Ri(a,oc(a)+1|0),b-v[a>>2]>>1,d);v[114578]=0;R(515,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;b=W(516,a|0,d|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}Yt(d)}a=Ng(b);jb=h+32|0;return a|0}a=P()|0;O()|0;Yt(d);S(a|0);L()}function cp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;f=a+1074308|0;Eb(e+8|0,f,96);d=Cb(e+8|0);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[a+480180>>2]==16384?v[b+88>>2]&1:0)|0;b:{if(cg(b+810|0)){d=v[b+656>>2];if(d){d=x[ed(d+236|0,w[b+810|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if(!(w[b+88|0]&2)|y[b+84>>2]>c>>>0?y[b+76>>2]>c>>>0:0){break b}Eb(e+8|0,f,57);if(!(h=!Cb(e+8|0),i=0,j=v[a+480180>>2]!=16,j?h:i)){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){Eb(e+8|0,f,27);if(Cb(e+8|0)){if(w[a+480208|0]&4){d=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=d;break b}v[b>>2]=0;v[b+4>>2]=0;break b}d=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=d;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}jb=e+16|0}function M3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;b=jb-2144|0;jb=b;Rb(b+96|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[114578]=0;b=Q(85,b+80|0,38648)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}g=v[c>>2];d=v[c+12>>2];e=v[c+8>>2];v[b+72>>2]=e;v[b+76>>2]=d;c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;v[b+68>>2]=f;v[b+64>>2]=g;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;c=b;i=b;h=$P(b+16|0);if(h){v[b+48>>2]=e;v[b+52>>2]=d;d=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=d;v[b+44>>2]=f;v[b+40>>2]=g;d=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=d;d=VP(b)}else{d=0}v[i+56>>2]=d;v[c+60>>2]=0;c=0;d=2048;while(1){d:{e=nb[f|0](g,(b+96|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}a=ps(a,Kl(b+32|0,Db(b+96|0),c),h?b+56|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b+80|0,38633)|0;c=v[114578];v[114578]=0;if((c|0)!=1){mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0);break b}jb=b+2144|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function Hd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;v[a+480180>>2]=b;b=Vo(a);FL(d,b);e=v[d+12>>2];c=a+1074316|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074308>>2]=v[d>>2];v[a+1074312>>2]=c;qs(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Xb(ut(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074300>>2]=0;v[a+1074304>>2]=0;u[a+480192>>1]=0;Tx(a,4);e=jb+-64|0;jb=e;b=a+484344|0;rK(b);f=jf(b);c=ox(e+8|0,b);v[114578]=0;U(1581,b|0,f|0,c|0);b=v[114578];v[114578]=0;a:{if((b|0)!=1){vl(c);jb=e- -64|0;break a}a=P()|0;O()|0;vl(c);S(a|0);L()}WN(a+484360|0);Le(a+1304400|0);Le(a+1304412|0);Le(a+1304424|0);c=a+1304436|0;d=Rb(d,0,64);b=NL(d);Gb(c,b);Gb(c+12|0,b+12|0);Gb(c+24|0,b+24|0);Gb(c+36|0,b+36|0);Gb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];ts(b);iA(a+1304500|0);Ms(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}jb=d- -64|0}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=jb-32|0;jb=e;a:{b:{c:{f=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?f>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?f>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?f>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?f>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;jb=e+32|0}function Vba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0;h=jb-16|0;jb=h;s=h,t=B(v[a>>2],ue(a)),v[s+4>>2]=t;Cc(h+4|0,c>>>3|0);c=Db(b);j=A[e+8>>3];i=v[h+4>>2];a:{if(!i){break a}e=i;while(1){k=0;f=c;m=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);q=g<<24|g<<8&16711680;o=k;k=m<<24|g>>>8;f=m<<8|g>>>24;o=o|0;k=k&65280|f&255|q;f=m;l(0,((f&255)<<24|g>>>8)&-16777216|((f&16777215)<<8|g>>>24)&16711680|(f>>>8&65280|f>>>24)|o);l(1,k&2147483647);j=G(+n(),j);c=c+8|0;e=e-1|0;if(e){continue}break}if(!i|j==0){break a}r=1/j;c=v[a+20>>2];while(1){e=b;a=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);g=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=g<<24;q=0;m=g<<8&16711680|f;o=a<<24|g>>>8;f=a<<8|g>>>24;e=a;l(0,((e&255)<<24|g>>>8)&-16777216|((e&16777215)<<8|g>>>24)&16711680|(e>>>8&65280|e>>>24)|q);l(1,m|(o&65280|f&255));s=h,x=+n()*r,A[s+8>>3]=x;Rf(h+8|0,-1,1);p=A[h+8>>3]*32768;A[h+8>>3]=p;a=c;p=Sd(p);b:{if(D(p)<2147483648){e=~~p;break b}e=-2147483648}s=a,t=Vc(e),u[s>>1]=t;b=b+8|0;c=c+2|0;i=i-1|0;if(i){continue}break}}if(d){A[d>>3]=j}jb=h+16|0;return v[h+4>>2]<<3}function p3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-80|0;jb=d;a:{b:{c:{if(ni(a)){Fo(d+72|0);break c}Pm(d+32|0,a);v[114578]=0;R(2175,d+72|0,d+32|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}rf(d+32|0)}c=a+36|0;d:{if(ni(a)){break d}c=v[d+72>>2]}e=v[a+8>>2];e:{if((e|0)==-1){e=Ut(c);f:{if(!Id(c)){break f}while(1){if(!(A[Rc(c,f)>>3]+h<=b)){e=Rc(c,f);break f}h=A[e>>3]+h;f=f+1|0;if(Id(c)>>>0>f>>>0){continue}break}}b=b-h;break e}e=Rc(c,e)}f=a+24|0;c=v[f>>2];g=x[e+12>>1];v[114578]=0;R(2178,c|0,g|0);c=v[114578];v[114578]=0;if((c|0)!=1){g:{g=v[f>>2];i=w[a+64|0];c=jI(vQ(d+32|0,b),w[e+16|0],x[e+12>>1],v[e+8>>2]);v[114578]=0;e=v[c+12>>2];v[d+16>>2]=v[c+8>>2];v[d+20>>2]=e;e=v[c+20>>2];v[d+24>>2]=v[c+16>>2];v[d+28>>2]=e;e=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=e;X(2129,d+56|0,g|0,(i?7:1)|0,d+8|0);c=v[114578];v[114578]=0;if((c|0)==1){break g}c=Tg(d+56|0);e=t[c+26|0]&1;g=v[(e?c+8|0:c+12|0)>>2];e=x[(e?c+20|0:c+22|0)>>1];b=A[c>>3];Hl(d+56|0);u[v[f>>2]+1074438>>1]=e;u[v[f>>2]+1074440>>1]=e;v[v[f>>2]+1074428>>2]=g;v[v[f>>2]+1074392>>2]=-2;b=b+h;A[a+16>>3]=b;gk(d+72|0);jb=d+80|0;return+b}}f=P()|0;O()|0;gk(d+72|0);break a}f=P()|0;O()|0;rf(d+32|0)}S(f|0);L()}function nF(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{c=v[a+4>>2];d:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break d}c=$c(a)}switch(c-43|0){case 0:case 2:break b;default:break c}}b=c-48|0;break a}f=(c|0)==45;d=!b;b=v[a+4>>2];e:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break e}c=$c(a)}b=c-48|0;if(!(d|b>>>0<10|!v[a+104>>2])){v[a+4>>2]=v[a+4>>2]-1}}f:{if(b>>>0<=9){b=0;while(1){d=(b+c|0)-48|0;g=(d|0)>214748363;b=v[a+4>>2];g:{if(b>>>0<y[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break g}c=$c(a)}e=c-48|0;if(!(g|e>>>0>9)){b=B(d,10);continue}break}b=d;d=b>>31;h:{if(e>>>0>=10){break h}while(1){d=Fma(b,d,10,0);b=d+c|0;c=mb;c=b>>>0<d>>>0?c+1|0:c;d=b;b=b-48|0;d=c-(d>>>0<48)|0;c=v[a+4>>2];i:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=$c(a)}e=c-48|0;if(e>>>0>9){break h}if((d|0)<21474836?1:(d|0)<=21474836?b>>>0<2061584302:0){continue}break}}if(e>>>0<10){while(1){c=v[a+4>>2];j:{if(c>>>0<y[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=$c(a)}if(c-48>>>0<10){continue}break}}if(v[a+104>>2]){v[a+4>>2]=v[a+4>>2]-1}a=b;b=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break f}b=0;d=-2147483648;if(!v[a+104>>2]){break f}v[a+4>>2]=v[a+4>>2]-1;mb=-2147483648;return 0}mb=d;return b}function vma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=jb-144|0;jb=g;l=Wp(a);if(l){p=g+8|4;q=g+8|6;r=g+8|5;k=g+8|2;m=g+8|3;while(1){h=jb-16|0;jb=h;e=jb-16|0;jb=e;i=g+8|0;gc(h+8|0,i,136);jb=e+16|0;f=Hb(h+8|0);e=a;j=nc(e,ac(h,h+8|0));if((f|0)==(j|0)){$b(e,Hb(h+8|0))}jb=h+16|0;if((f|0)!=(j|0)){e=jb-16|0;jb=e;Rb(i,0,136);jb=e+16|0}e=w[g+8|0]|w[g+9|0]<<8;a:{if(!e){break a}e=(e<<8|e>>>8)&65535;if(e>>>0>x[c+480192>>1]){break a}e=v[((e<<2)+c|0)+900380>>2];if(!e){break a}e=uu(e,b);b:{if(!w[m|0]){break b}if(t[k|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[k|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[k|0]&4)){break b}t[e+12|0]=w[e+12|0]|2}t[g+4|0]=w[m|0];t[g+7|0]=31;f=w[pc(g+4|0,g+7|0)|0]+1|0;i=f&255;gg(e,i);t[e+13|0]=w[r|0];t[e+14|0]=w[q|0];h=w[p|0];t[e+15|0]=h;t[e+16|0]=h;h=0;if((f|0)!=(i|0)){break a}while(1){j=h<<2;n=g+16|0;f=j+n|0;f=w[f|0]|w[f+1|0]<<8;s=Pb(e,h),y=f<<8|f>>>8,u[s>>1]=y;f=n+(j|2)|0;f=w[f|0]|w[f+1|0]<<8;f=f<<8|f>>>8;u[g+4>>1]=d?(f&65535)+128>>>2|0:f;jg(g+4|0,64);f=w[g+4|0];s=Pb(e,h),y=f,t[s+2|0]=y;h=h+1|0;if((i|0)!=(h|0)){continue}break}}o=o+1|0;if((o&65535)>>>0<l>>>0){continue}break}}jb=g+144|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;Fd(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=zk(Vg(+(f+1408|0)*.0006510416666666666)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[pc(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+27872|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[pc(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);jb=e+16|0}function Pm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-80|0;jb=c;g=Sw(a);e=b+24|0;a:{b:{if(Nh(v[e>>2]+484360|0)){if(Nh(v[e>>2]+484360|0)){a=0;while(1){f=v[e>>2];b=jI(wQ(c+40|0,1),a&255,0,0);v[114578]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+20>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;X(2129,c- -64|0,f|0,0,c|0);b=v[114578];v[114578]=0;c:{d:{if((b|0)!=1){i=c,j=bc(c- -64|0),v[i+32>>2]=j;i=c,j=cc(c- -64|0),v[i+24>>2]=j;if(Jb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{b=v[c+32>>2];f=x[b+24>>1];h=A[b>>3];d=v[b+16>>2];b=c+40|0;v[b+16>>2]=a;v[b+12>>2]=f;v[b+8>>2]=d;A[b>>3]=h;v[114578]=0;R(2130,g|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}By(c+32|0);if(Jb(c+32|0,c+24|0)){continue}break c}break}a=P()|0;O()|0;Hl(c- -64|0);break b}Hl(c- -64|0);a=a+1|0;if(Nh(v[e>>2]+484360|0)>>>0>a>>>0){continue}break}}jb=c+80|0;return}b=ba(8)|0;v[114578]=0;c=Q(85,c+40|0,38586)|0;a=v[114578];v[114578]=0;if((a|0)!=1){mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0)}rf(g);S(a|0)}L()}function tY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!w[i|0]){break a}i=i+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((f|0)==(g|0)|(c|0)==(d|0)){break d}l=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=l;k=jb-16|0;jb=k;v[k+12>>2]=v[a+8>>2];m=Ah(k+8|0,k+12|0);v[114578]=0;l=eF(f,e,i-c|0,g-f>>2,b);n=v[114578];v[114578]=0;e:{if((n|0)!=1){Ie(m);jb=k+16|0;break e}a=P()|0;O()|0;Ie(m);S(a|0);L()}f:{g:{h:{i:{if((l|0)==-1){while(1){j:{v[h>>2]=f;if(v[e>>2]==(c|0)){break j}k:{l:{m:{n:{b=bE(f,c,i-c|0,j+8|0,v[a+8>>2]);switch(b+2|0){case 1:break m;case 2:break n;case 0:break g;default:break l}}c=c+1|0;break k}v[e>>2]=c;break i}c=b+c|0}f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(l<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break f}c=v[e>>2];if((d|0)==(i|0)){i=d;continue}if(!bE(f,c,1,b,v[a+8>>2])){break h}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!w[i|0]){break b}i=i+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}jb=j+16|0;return a|0}f=v[h>>2];continue}}function SW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;if(kg(a,v[b+8>>2],e)){nv(b,c,d);return}a:{if(kg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;i=f+(v[a+12>>2]<<3)|0;j=b;b:{c:{while(1){d:{if(f>>>0>=i>>>0){break d}u[b+52>>1]=0;mv(f,b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}h=1;g=1;if(w[a+8|0]&2){break e}break c}h=1;d=g;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}d=g;a=4;if(!h){break b}}a=3}v[j+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];f=a+16|0;Rq(f,b,c,d,e);if((g|0)<2){break a}g=f+(g<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(v[b+36>>2]!=1?!(a&2):0)){while(1){if(w[b+54|0]){break a}Rq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Rq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|(v[b+24>>2]==1?v[b+36>>2]==1:0)){break a}Rq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function sc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(iD(b)){h=jb-16|0;jb=h;i=b>>>0>4?b:4;j=a?a:1;a:{while(1){a=j;e=i;b:{c:{d:{if((e|0)==8){a=pd(a);break d}d=e>>>2|0;c=0;while(1){b=c;if(d){d=d-1&d;c=c+1|0;continue}break}c=28;if(e&3|(b|0)!=1){break c}c=48;if(a>>>0>-64-e>>>0){break c}d=a;b=16;a=e>>>0>16?e:16;c=a>>>0>16?a:16;e:{if(!(c-1&c)){a=c;break e}while(1){a=b;b=a<<1;if(a>>>0<c>>>0){continue}break}}f:{if(d>>>0>=-64-a>>>0){v[114552]=48;b=0;break f}f=d>>>0<11?16:d+11&-8;d=pd((f+a|0)+12|0);b=0;if(!d){break f}b=d-8|0;g:{if(!(d&a-1)){a=b;break g}e=d-4|0;c=v[e>>2];d=((a+d|0)-1&0-a)-8|0;a=d-b>>>0>15?d:a+d|0;g=a-b|0;d=(c&-8)-g|0;if(!(c&3)){b=v[b>>2];v[a+4>>2]=d;v[a>>2]=b+g;break g}v[a+4>>2]=d|v[a+4>>2]&1|2;c=a+d|0;v[c+4>>2]=v[c+4>>2]|1;v[e>>2]=g|v[e>>2]&1|2;c=b+g|0;v[c+4>>2]=v[c+4>>2]|1;Pq(b,g)}c=v[a+4>>2];h:{if(!(c&3)){break h}b=c&-8;if(b>>>0<=f+16>>>0){break h}v[a+4>>2]=f|c&1|2;d=a+f|0;c=b-f|0;v[d+4>>2]=c|3;b=a+b|0;v[b+4>>2]=v[b+4>>2]|1;Pq(d,c)}b=a+8|0}a=b}c=48;if(!a){break b}v[h+12>>2]=a;c=0}}if(!c){break a}a=v[115885];if(a){nb[a|0]();continue}break}a=ba(4)|0;Zk(a);ja(a|0,71204,2008);L()}jb=h+16|0;return v[h+12>>2]}return Pe(a)}function $8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=mf(a);if(c>>>0<b>>>0){f=jb-32|0;jb=f;a:{b:{e=b-c|0;c:{if(e>>>0<=v[zb(a)>>2]-v[a+4>>2]>>11>>>0){c=jb-16|0;jb=c;g=a;b=c;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);d:{if(v[b+4>>2]!=v[b+8>>2]){while(1){a=zb(g);d=v[b+4>>2];v[114578]=0;R(1651,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}a=v[b+4>>2]+2048|0;v[b+4>>2]=a;if((a|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=c+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}h=zb(a);i=f+8|0;b=mf(a)+e|0;d=jb-16|0;jb=d;v[d+12>>2]=b;c=b;b=jb-16|0;jb=b;g=a;zb(a);v[b+12>>2]=2097151;v[114578]=0;v[b+8>>2]=2147483647;j=Q(33,b+12|0,b+8|0)|0;k=v[114578];v[114578]=0;e:{if((k|0)!=1){jb=b+16|0;b=v[j>>2];break e}V(0)|0;O()|0;Ab();L()}f:{if(b>>>0>=c>>>0){c=jk(g);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[bd(d+8|0,d+12|0)>>2]}jb=d+16|0;break f}fd();L()}b=FJ(i,b,mf(a),h);v[114578]=0;R(1649,b|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1645,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}fs(b)}jb=f+32|0;break a}a=P()|0;O()|0;fs(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<11)|0;mf(a);CJ(a,b);GJ(a)}}function uH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+40>>2]){case 0:Ir(c,b);break a;case 2:Ir(c,zb(b));break a;case 3:i=Ug(b);b=jb-80|0;jb=b;d=v[c>>2];g=v[d+4>>2];f=v[d+24>>2];v[b+40>>2]=v[d+20>>2];v[b+44>>2]=f;f=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=f;Eh(b- -64|0,b+32|0,g);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);g=v[v[c+12>>2]>>2];f=v[v[c+8>>2]>>2];c=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=c;c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(g){while(1){d=0;if(f){while(1){k=v[Of(c,d,h)>>2];Ve(i,d);l=qn(j,d,h),m=C(C(k|0)*C(7.450580596923828e-9)),z[l>>2]=m;d=d+1|0;if((f|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=b+80|0;break a;case 1:Ir(c,zb(b));break a;default:break b}}Ir(c,zb(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function Mo(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0),j=0,k=0,l=0,m=C(0);c=v[a+36>>2];if(!c){ui(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:e=a+16|0;if(c>>>0>=1001){ui(e);return}pl(e,c);c=x[a+28>>1];b=a+4|0;Kb(b);g=ql(a,(c<<16)+65536>>16);c=u[a+28>>1];Kb(b);b=1;g=ne(C(g/ql(a,c)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){i=ne(g,C(b>>>0));l=Pb(e,b-1|0),m=i,z[l>>2]=m;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:e=a+16|0;h=x[a+30>>1];if(h>>>0>1e3/(c>>>0)>>>0){ui(e);return}pl(e,B(c,h));c=u[a+28>>1];Kb(a+4|0);b=x[a+30>>1];if((c|0)>=0){c=(c|0)%(b|0)|0}else{c=((c^-1)%(b|0)^-1)+b|0}if(!h){break b}while(1){d=b&65535;k=a;f=c+j<<16>>16;d:{if((f|0)>=0){b=(f|0)%(d|0)|0;break d}b=d+((f^-1)%(d|0)^-1)|0}b=b<<16;f=b>>16;g=ne(C(ql(k,b+65536>>16)/ql(a,f)),C(C(1)/C(v[a+36>>2]+1>>>0)));e:{if(!v[a+36>>2]){break e}b=1;d=0;while(1){i=ne(g,C((b&65535)>>>0));l=Pb(e,B(v[a+36>>2],f)+d|0),m=i,z[l>>2]=m;b=b+1|0;d=b&65535;if(d>>>0>y[a+36>>2]){break e}d=d-1|0;continue}}j=j+1|0;if(h>>>0<=(j&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}ui(a+16|0);v[a+36>>2]=0}return}ui(a+16|0)}function Ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=a+808|0;c=a+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+40|0]=1;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((d|0)!=(c|0)){continue}break}d=a+3832|0;c=a+808|0;while(1){v[c>>2]=0;v[c+4>>2]=0;v[c+68>>2]=0;v[c+72>>2]=0;v[c+24>>2]=0;v[c+28>>2]=0;u[c+20>>1]=511;v[c+16>>2]=-1;u[c+14>>1]=1;u[c+6>>1]=0;u[c+8>>1]=0;u[c+10>>1]=0;u[c+12>>1]=0;t[c+73|0]=0;t[c+74|0]=0;t[c+75|0]=0;t[c+76|0]=0;t[c+77|0]=0;t[c+78|0]=0;t[c+79|0]=0;t[c+80|0]=0;c=c+84|0;if((d|0)!=(c|0)){continue}break}c=a;v[c+3832>>2]=0;v[c+3836>>2]=0;d=c+3837|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;while(1){Ef((c+B(f,84)|0)+808|0,c);f=f+1|0;if((f|0)!=36){continue}break}while(1){v[(c+B(e,44)|0)+32>>2]=c;e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){d=v[(e<<2)+19808>>2];f=(c+B(e,44)|0)+16|0;a:{if(!(!(1<<e&3591)|e>>>0>11)){d=c+B(d,84)|0;HN(f,d+808|0,d+1060|0,d+1312|0,d+1564|0);break a}d=c+B(d,84)|0;HN(f,d+808|0,d+1060|0,0,0)}e=e+1|0;if((e|0)!=18){continue}break}e=0;while(1){ln((c+B(e,84)|0)+808|0);e=e+1|0;if((e|0)!=36){continue}break}GN(c,b);return a|0}function xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){k=0;g=k;v[e+40>>2]=h;v[e+44>>2]=g;h=(b<<1)+l|0;b:{b=v[f+16>>2];if((b|0)<=0){break b}while(1){Ad(v[f+8>>2],u[(g<<1)+h>>1]/4<<16>>16);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);h=v[a+32>>2];j=v[a+28>>2]+j|0;g=j>>12;v[c>>2]=v[c>>2]+B(b,g);i=h+i|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}k=i>>12;g=j>>12}v[a+40>>2]=i;v[a+20>>2]=g;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;if(!w[a+4242|0]){fx(a);a:{if(!w[a+4240|0]){break a}e=BL(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;cs(a)}g=a+4256|0;b:{if(w[a+4244|0]){if(!(A[g>>3]<=1)){A[g>>3]=1}break b}i=(v[a+4232>>2]&-2)!=4;e=A[g>>3];c:{if(D(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(i|(f|0)<1)){ex(a);e=A[a+4256>>3]}A[g>>3]=e-+(f|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=ii(A[a+4256>>3]*6.283185307179586);break d;case 1:e=D(A[a+4256>>3]+-.5)*-4+1;break d;case 2:e=A[a+4256>>3];e=e+e+-1;break d;case 3:e=A[a+4256>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];j=e*e*e*((e*6+-15)*e+10);e=A[a+4272>>3];e=j*(A[a+4280>>3]-e)+e}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];Rf(h+8|0,0,1);f=jj(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|st(A[h+8>>3]*127)<<16,k=v[v[f>>2]+68>>2],nb[k](l|0,m|0)|0;break f}nb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;pi(f,b,c,Pd(a,0),Pd(a,1),d);jb=h+16|0}function Ic(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{f=w[b+8|0];c=v[b>>2];d=v[b+4>>2];b=jb-48|0;jb=b;e=Wb(a);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((f|0)!=1){if(!d|(f|0)!=4){break k}break l}if(d){break l}a=c;break j}d=d-1|0}m:{switch(f-1|0){case 0:case 1:break m;case 2:case 3:break i;default:break h}}a=c+d|0}t[b+32|0]=0;a=Sm(c,a,b+32|0);v[114578]=0;W(119,e|0,c|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}v[114578]=0;W(119,e|0,c|0,c+d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break g}c=Ed(e);d=sf(e);f=Ed(e);a=jb-32|0;jb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=f;if(Jb(a+24|0,a+16|0)){while(1){c=t[v[a+24>>2]];t[v[a+8>>2]]=c?c:32;qg(a+24|0);qg(a+8|0);if(Jb(a+24|0,a+16|0)){continue}break}}jb=a+32|0;v[114578]=0;c=Q(120,b+16|0,e|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break f}v[114578]=0;d=Q(85,b|0,6640)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;U(121,b+32|0,c|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}Gb(e,b+32|0);yb(b+32|0);yb(d);yb(c)}jb=b+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d)}yb(c)}yb(e);S(a|0);L()}}function aia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=jb+-64|0;jb=d;o=d,p=nf(a)>>>5|0,u[o+32>>1]=p;u[d+16>>1]=3999;o=c,p=x[lf(d+32|0,d+16|0)>>1],u[o+480190>>1]=p;cz(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=d+62|0;k=d+58|0;l=d+56|0;n=d+52|0;m=d+60|0;i=1;j=1;while(1){f=vp(c,j&65535);lt(a,d+32|0);Fd(f,0);Hn(d,2,d+32|0);Ic(d+16|0,d);v[114578]=0;Q(371,((i<<5)+c|0)+946300|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}yb(d+16|0);u[f+32>>1]=64;v[f+24>>2]=8287;e=w[m|0]|w[m+1|0]<<8;u[d+16>>1]=e<<8|e>>>8;u[d>>1]=64;o=f,p=x[lf(d+16|0,d)>>1]<<2,u[o+30>>1]=p;e=n;e=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))&-16777217;v[f>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=w[l|0]|w[l+1|0]<<8;g=w[k|0]|w[k+1|0]<<8;g=(g<<8|g>>>8)&65535;b:{if(g>>>0<2){break b}e=(e<<8|e>>>8)&65535;g=e+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=e<<1;u[f+34>>1]=x[f+34>>1]|8}if(w[h|0]|w[h+1|0]<<8){e=(w[h|0]|w[h+1|0]<<8)==512}else{e=1}ee(d+16|0,b,i-1|0);ge(d+16|0,e);j=j+1|0;i=j&65535;if(i>>>0<=x[c+480190>>1]){continue}break}}jb=d- -64|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;i=jb-16|0;jb=i;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];j=v[a>>2];v[i+8>>2]=j;v[i+12>>2]=f;h=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=h;a:{if(d){while(1){h=f+p|0;n=t[h+1|0];f=t[h|0];h=v[a+60>>2];q=h;r=h>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];u=v[a+32>>2];h=c;w=v[h>>2];g=Fma(k,k>>31,g,g>>31);k=mb;x=g;g=v[a+68>>2];o=Fma(g,g>>31,e,e>>31);g=x+o|0;e=mb+k|0;e=g>>>0<o>>>0?e+1|0:e;k=g;j=((B(n-f|0,j>>>10&4194048)|0)/16384|0)+(f<<8)<<8;f=j;g=Fma(q,r,f,f>>31);f=k+g|0;e=mb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;g=m>>12;v[h>>2]=B(e,g)+w;l=l+u|0;n=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,n);h=f-(j&s)|0;Sb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;j=v[i+8>>2];f=v[i+12>>2];e=b;b=h;continue}break}j=v[i+8>>2];f=v[i+12>>2];e=b;break a}n=l>>12;g=m>>12;h=b}v[a+40>>2]=l;v[a+20>>2]=g;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=h;v[a+24>>2]=n;v[a>>2]=j;v[a+4>>2]=f;jb=i+16|0}function Aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;j=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];n=f,o=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[n+12>>2]=o;b=v[f+16>>2];if(b){n=f,o=Pf(a+8|0,b),v[n>>2]=o;v[f+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){h=0;i=g;v[e+40>>2]=g;v[e+44>>2]=m;g=(((b&2147483647)<<1|g>>>31)&-2)+j|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){h=(h&2147483647)<<1|i>>>31;Ad(v[f+8>>2],t[(h|1)+g|0]+t[g+(h&-2)|0]<<5);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;i=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];h=v[b+4>>2];if(h){i=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;Ad(i,t[(b|1)+g|0]+t[g+(b&-2)|0]<<5);zd(v[f+8>>2],h);b=v[f+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;v[f+8>>2]=c>>>4;v[f+4>>2]=v[a>>2];d=v[Lb(f+8|0,f+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){e=b;g=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=g;j=h<<8&16711680|h<<24;k=e<<24|h>>>8;g=e<<8|h>>>24;j=k&65280|g&255|j;v[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|l;v[f+12>>2]=j;Rf(f+8|0,-1,1);i=A[f+8>>3]*32768;A[f+8>>3]=i;e=a;i=Sd(i);a:{if(D(i)<2147483648){g=~~i;break a}g=-2147483648}m=e,n=Vc(g),u[m>>1]=n;e=b;g=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);h=w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24);e=g;j=h<<8&16711680|h<<24;k=e<<24|h>>>8;g=e<<8|h>>>24;j=k&65280|g&255|j;v[f+8>>2]=((e&255)<<24|h>>>8)&-16777216|((e&16777215)<<8|h>>>24)&16711680|(e>>>8&65280|e>>>24)|l;v[f+12>>2]=j;Rf(f+8|0,-1,1);i=A[f+8>>3]*32768;A[f+8>>3]=i;e=a;i=Sd(i);b:{if(D(i)<2147483648){g=~~i;break b}g=-2147483648}m=e,n=Vc(g),u[m+2>>1]=n;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=f+16|0;return d<<4}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;i=jb-16|0;jb=i;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];j=v[a>>2];v[i+8>>2]=j;v[i+12>>2]=f;h=v[a+12>>2];v[i>>2]=v[a+8>>2];v[i+4>>2]=h;a:{if(d){while(1){h=(f<<1)+p|0;n=u[h+2>>1];f=u[h>>1];h=v[a+60>>2];q=h;r=h>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];t=v[a+32>>2];h=c;w=v[h>>2];g=Fma(k,k>>31,g,g>>31);k=mb;x=g;g=v[a+68>>2];o=Fma(g,g>>31,e,e>>31);g=x+o|0;e=mb+k|0;e=g>>>0<o>>>0?e+1|0:e;k=g;j=f+((B(n-f|0,j>>>18|0)|0)/16384|0)<<8;f=j;g=Fma(q,r,f,f>>31);f=k+g|0;e=mb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;g=m>>12;v[h>>2]=B(e,g)+w;l=l+t|0;n=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,n);h=f-(j&s)|0;Sb(i+8|0,i);d=d-1|0;if(d){c=c+8|0;j=v[i+8>>2];f=v[i+12>>2];e=b;b=h;continue}break}j=v[i+8>>2];f=v[i+12>>2];e=b;break a}n=l>>12;g=m>>12;h=b}v[a+40>>2]=l;v[a+20>>2]=g;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=h;v[a+24>>2]=n;v[a>>2]=j;v[a+4>>2]=f;jb=i+16|0}function lc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Pa(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if((c|0)<1){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function tba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb+-64|0;jb=g;e=g;h=e+16|0;while(1){l=(i<<2)+h|0;f=0;c=0;j=jb-16|0;jb=j;d=b;Qc(j+8|0,d);a:{b:{c:{d:{e:{if(rd(d+16|0)){while(1){f:{k=v[d+16>>2];v[114578]=0;k=T(98,k|0)|0;m=v[114578];v[114578]=0;if((m|0)==1){break f}f=f|k;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(71180)|0;if((O()|0)!=(ga(71180)|0)){break b}_(c|0)|0;t[d+20|0]=0;v[114578]=0;Z(82,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break b}t[d+20|0]=0}if(!w[d+20|0]){d=v[d+24>>2];v[114578]=0;d=T(99,d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}f=d^f}jb=j+16|0;break a}c=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break b}V(0)|0;O()|0;Ab();L()}c=P()|0;O()|0}S(c|0);L()}v[l>>2]=f;i=i+1|0;if((i|0)!=12){continue}break}b=hn(e);v[114578]=0;U(109,e|0,h|0,h+48|0);d=v[114578];v[114578]=0;g:{if((d|0)==1){break g}v[114578]=0;b=e;W(106,a|0,e|0,0)|0;a=v[114578];v[114578]=0;h:{if((a|0)!=1){oe(b);jb=g- -64|0;break h}break g}return}a=P()|0;O()|0;oe(b);S(a|0);L()}function qO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;h=jb-16|0;jb=h;if(tj(a)){f=w[(be(w[a+819|0])?a+819|0:a+821|0)|0];Eb(h+8|0,d+1074308|0,34);a:{if(!Cb(h+8|0)){break a}d=f;if(f){if(d>>>0>120){break a}f=w[fc(v[a+656>>2]+108|0,d-1|0)|0];break a}f=0}d=a;k=C(C(v[a+704>>2]<<4)*b);e=v[v[a+656>>2]+44>>2];c=(c+f<<16)-3997696>>16;b:{c:{a=v[a+876>>2]+v[a+768>>2]|0;if(a){i=v[e+36>>2];if(i){break c}}b=ql(e,a+c<<16>>16);break b}g=i+1|0;d:{if((a|0)>=0){f=a;a=(a|0)/(g|0)|0;f=f-B(g,a)|0;break d}f=i-((a^-1)%(g|0)|0)|0;a=((a+1|0)/(g|0)|0)-1|0}l=u[e+28>>1];j=e+4|0;Kb(j);b=C(1);c=a+c<<16>>16;e:{if((c|0)<(l|0)){break e}if((c|0)>(x[e+28>>1]+Kb(j)<<16)-65536>>16){break e}if(!f){b=z[Pb(j,c-u[e+28>>1]|0)>>2];break b}a=x[e>>1];f:{if((a|0)==3){a=e+16|0;if(Kb(a)){b=z[Pb(a,f-1|0)>>2];break f}a=x[e>>1]}g:{if((a&65535)!=1){break g}a=e+16|0;if(!Kb(a)){break g}g=x[e+30>>1];if((c|0)>=0){g=(c|0)%(g|0)|0}else{g=g+((c^-1)%(g|0)^-1)|0}b=z[Pb(a,(B(g<<16>>16,i)+f|0)-1|0)>>2];break f}b=ne(C(ql(e,(c<<16)+65536>>16)/ql(e,c)),C(C(f|0)/C(g|0)))}b=C(z[Pb(j,c-u[e+28>>1]|0)>>2]*b)}}m=d,n=Ai(C(k*b)),v[m+700>>2]=n}jb=h+16|0}function yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){k=0;g=k;v[e+40>>2]=h;v[e+44>>2]=g;h=b+l|0;b:{b=v[f+16>>2];if((b|0)<=0){break b}while(1){Ad(v[f+8>>2],t[h+g|0]<<6);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,t[h+v[e+44>>2]|0]<<6);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);h=v[a+32>>2];j=v[a+28>>2]+j|0;g=j>>12;v[c>>2]=v[c>>2]+B(b,g);i=h+i|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2];break a}k=i>>12;g=j>>12}v[a+40>>2]=i;v[a+20>>2]=g;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function Q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,t=0,u=C(0);a:{if(!v[a+4272>>2]){break a}h=a+44|0;if(!rh(h)){break a}k=Pd(h,0);l=Pd(h,1);m=jd(h,0);n=jd(h,1);if(d){j=a+4256|0;e=v[a+4268>>2];o=d;while(1){f=z[l>>2];g=z[k>>2];t=Pb(j,e<<1),u=g,z[t>>2]=u;t=Pb(j,v[a+4268>>2]<<1|1),u=f,z[t>>2]=u;f=C(D(ZI(C(C(C(D(g))+C(D(f)))*C(536870912)),31,5)));g=z[a+4276>>2];f=C(f*C(4.656612873077393e-10));f=C(C(C(g-f)*z[(f<g?4240:4236)+a>>2])+f);z[a+4276>>2]=f;p=m;q=C(z[a+4232>>2]*C(4.656612873077393e-10));g=z[a+4244>>2];f=C(C(C(z[a+4248>>2]*C(2147483648))*C(g-C(G(f,g))))+C(2147483392));b:{if(f<C(4294967296)&f>=C(0)){i=~~f>>>0;break b}i=0}e=i<<5;r=e|-2147483648;s=e;e=i>>>26|0;f=C(q*C((e?r:s)>>>(e?32-e|0:31)>>>0));e=v[a+4272>>2];e=(((e+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(e|0)<<1;t=p,u=C(f*z[Pb(j,e)>>2]),z[t>>2]=u;t=n,u=C(f*z[Pb(j,e|1)>>2]),z[t>>2]=u;i=v[a+4268>>2];e=i-1|0;v[a+4268>>2]=e;if(!i){e=v[a+4272>>2]+e|0;v[a+4268>>2]=e}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}pi(a,b,c,jd(h,0),jd(h,1),d)}}function hl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;v[a+4>>2]=0;if(w[gj(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+24>>2];d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;b=T(2384,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}if(ve(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!ve(b,c)){continue}break}d=0;break a}while(1){if(v[a+4>>2]>=(b|0)){break a}e=v[v[a>>2]-12>>2];v[114578]=0;e=v[(a+e|0)+24>>2];g=v[114578];v[114578]=0;d:{if((g|0)==1){break d}v[114578]=0;e=T(2384,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}if(ve(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!ve(e,c)){continue}break a}break}}b=V(0)|0;O()|0;_(b|0)|0;ej(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];c=v[114578];v[114578]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break f}S(a|0);L()}$();d=1;break a}V(0)|0;O()|0;Ab()}L()}d=2}Ag(v[v[a>>2]-12>>2]+a|0,d)}jb=f+16|0;return a|0}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-16|0;jb=g;a:{b:{c:{h=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?h>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?h>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?h>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?h>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;jb=g+16|0}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-32|0;jb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;jb=f+32|0}function qH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;c=e;a:{b:{switch(v[b+40>>2]){case 0:Hr(c,b);break a;case 2:Hr(c,zb(b));break a;case 3:i=Ug(b);b=jb-80|0;jb=b;d=v[c>>2];f=v[d+4>>2];v[b+40>>2]=v[d+20>>2];g=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=g;Do(b- -64|0,b+32|0,f);d=me(b+48|0,v[v[c+4>>2]>>2],v[v[c+8>>2]>>2],v[v[c+12>>2]>>2]);f=v[v[c+12>>2]>>2];g=v[v[c+8>>2]>>2];v[b+24>>2]=v[b+72>>2];c=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=c;v[b+8>>2]=v[d+8>>2];c=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=c;j=b+16|0;c=b;if(f){while(1){d=0;if(g){while(1){k=v[Of(c,d,h)>>2];Ve(i,d);l=Of(j,d,h),m=C(C(k|0)*C(7.450580596923828e-9)),z[l>>2]=m;d=d+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((f|0)!=(h|0)){continue}break}}jb=b+80|0;break a;case 1:Hr(c,zb(b));break a;default:break b}}Hr(c,zb(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+8>>2];e=v[a+12>>2];d:{if((e|0)<1?1:(e|0)<=1?g>>>0<=805306368:0){if((e|0)>-2?1:(e|0)>=-2?g>>>0>=3489660928:0){break c}if((e|0)>-2?1:(e|0)>=-2?g>>>0>2147483647:0){break d}break b}if((e|0)>1?1:(e|0)>=1?g>>>0>2147483648:0){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;jb=f+16|0}function GG(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>=1){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){dk(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=ll(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<=-1){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}dc(a,21);return 0}k=B(d,l);m=((k+m|0)+j|0)>(p|0)?(p-k|0)+j|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(z[v[b+28>>2]+(g+k<<2)>>2]+n);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+z[v[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}dc(a,21);return 0}ha(50752,50496,1872,50788);L()}function VH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;a:{j=$P(e);b:{if(j){i=e+24|0;g=jb-48|0;jb=g;d=sc(324,4);h=Uc(g+16|0,g+40|0,1);f=jb-16|0;jb=f;v[f+12>>2]=d;v[114578]=0;d=g+24|0;W(2202,d|0,f+12|0,h|0)|0;h=v[114578];v[114578]=0;c:{if((h|0)!=1){jb=f+16|0;break c}break a}f=v[d>>2];v[114578]=0;Q(2163,f|0,b|0)|0;b=v[114578];v[114578]=0;d:{if((b|0)!=1){co(i,ec(v[d>>2]),Nd(d));HH(d);jb=g+48|0;break d}a=P()|0;O()|0;HH(d);S(a|0);L()}Lu(e+32|0,e+24|0);break b}i=e+16|0;g=jb-48|0;jb=g;d=sc(56,4);h=Uc(g+16|0,g+40|0,1);f=jb-16|0;jb=f;v[f+12>>2]=d;v[114578]=0;d=g+24|0;W(2204,d|0,f+12|0,h|0)|0;h=v[114578];v[114578]=0;e:{if((h|0)!=1){jb=f+16|0;break e}break a}f=v[d>>2];v[114578]=0;Q(2164,f|0,b|0)|0;b=v[114578];v[114578]=0;f:{if((b|0)!=1){co(i,ec(v[d>>2]),Nd(d));GH(d);jb=g+48|0;break f}a=P()|0;O()|0;GH(d);S(a|0);L()}Lu(e+32|0,e+16|0)}b=a;a=em(e+40|0,e+32|0);yC(b,a,c);Bb(a);Bb(e+32|0);g:{if(!j){Bb(e+16|0);break g}Bb(e+24|0)}jb=e+48|0;return}V(0)|0;O()|0;Ab();L()}function vx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;e=a+2|0;if(!(w[e|0]==255|!w[e|0])){v[f+12>>2]=w[e|0]+1;v[f+8>>2]=10;gg(b,v[de(f+12|0,f+8|0)>>2]);e=w[a+3|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=511;e=0;a:{b:{switch(c-1|0){case 1:e=4096;g=128;break a;case 0:break b;default:break a}}e=32768;g=1024}if(Kb(b)){i=g>>>1|e;while(1){h=(d<<2)+a|0;c=h+6|0;c=w[c|0]|w[c+1|0]<<8;j=Pb(b,d),k=c>>>4|0,u[j>>1]=k;c:{d:{if(!d){e=0;c=0;break d}c=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,c)>>1]){break c}e=d;c=x[Pb(b,c)>>1]+1|0}j=Pb(b,e),k=c,u[j>>1]=k}c=h+8|0;v[f+12>>2]=(i+((w[c|0]|w[c+1|0]<<8)<<16>>16)|0)/(g|0);v[f+8>>2]=0;v[f+4>>2]=64;c=v[Ls(f+12|0,f+8|0,f+4|0)>>2];j=Pb(b,d),k=c,t[j+2|0]=k;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;c=b;e:{f:{if(!(w[a|0]&2)){break f}d=w[b+15|0];if(Kb(b)>>>0<d>>>0){break f}d=w[b+12|0]|4;break e}d=w[b+12|0]&-5}t[c+12|0]=d;c=b;g:{h:{if(!(w[a|0]&4)){break h}a=w[b+13|0];if(a>>>0>w[b+14|0]){break h}if(Kb(b)>>>0<a>>>0){break h}a=w[b+12|0]|2;break g}a=w[b+12|0]&-3}t[c+12|0]=a}jb=f+16|0}function V5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{c=u[b>>1];b=jb-32|0;jb=b;v[114578]=0;h=Q(15,b+24|0,a|0)|0;d=v[114578];v[114578]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[h|0]){break e}d=v[(v[v[a>>2]-12>>2]+a|0)+4>>2];Bc(b+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;f=T(2392,b+16|0)|0;e=v[114578];v[114578]=0;f:{g:{if((e|0)!=1){Ob(b+16|0);e=Sk(b+8|0,a);g=v[v[a>>2]-12>>2];v[114578]=0;g=a+g|0;j=T(16,g|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}e=v[e>>2];v[114578]=0;k=f;f=c&65535;i=c;c=d&74;c=ea(2393,k|0,e|0,g|0,j|0,((c|0)==64?f:(c|0)==8?f:i)|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Qk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+c|0,5);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Hf(h);break d}Hf(h);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=b+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb+-64|0;jb=e;g=Wm(a);a:{if(b-1>>>0>1023){break a}f=v[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break a}f=v[a+12>>2]}f=B(lk(a),b>>>0>f>>>0?b-f|0:f-b|0);b:{c:{if(y[a+12>>2]<b>>>0){c=e;d:{if(d){d=cc(a);break d}d=bc(a)}v[c+48>>2]=d;c=Md(e+56|0,e+48|0);Qh(e+40|0);c=v[c>>2];v[114578]=0;aa(1564,a|0,c|0,f|0,e+40|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}a=V(71204)|0;break c}if(d){i=e,j=cc(a),v[i+48>>2]=j;i=e,j=xK(e+48|0,0-f|0),v[i+40>>2]=j;c=Md(e+32|0,e+40|0);i=e,j=cc(a),v[i+16>>2]=j;d=v[Md(e+24|0,e+16|0)>>2];c=v[c>>2];v[114578]=0;W(1565,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}a=V(71204)|0;break c}i=e,j=bc(a),v[i+40>>2]=j;c=Md(e+8|0,e+40|0);i=e,j=bc(a),v[i+16>>2]=j;i=e,j=xK(e+16|0,f),v[i+48>>2]=j;d=v[Md(e,e+48|0)>>2];c=v[c>>2];v[114578]=0;W(1565,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}a=V(71204)|0}if((O()|0)==(ga(71204)|0)){_(a|0)|0;$();break a}S(a|0);L()}v[a+12>>2]=b;h=1}jb=e- -64|0;return h|0}function FQ(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Je(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Je(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Je(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Je(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Je(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}jb=f+16|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-16|0;jb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=h+n|0;h=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Yb(b,-16777216,16776704);j=v[a+64>>2];f=Yb(f,-16777216,16776704);w=v[a+72>>2];x=v[c>>2];e=Fma(j,j>>31,e,e>>31);j=mb;y=e;e=v[a+68>>2];k=Fma(e,e>>31,f,f>>31);e=y+k|0;f=mb+j|0;f=e>>>0<k>>>0?f+1|0:f;j=e;e=(i>>>21&2040)+27888|0;h=(((B(u[e+2>>1],p)+B(q,u[e>>1])|0)+B(u[e+4>>1],o)|0)+B(h,u[e+6>>1])<<8)/16384<<8;e=h;i=Fma(r,s,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=B(e,m)+x;v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(h&w)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;g=jb-16|0;jb=g;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(h<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(f,-16777216,16776704);s=v[a+72>>2];f=v[c>>2];e=Fma(k,k>>31,e,e>>31);k=mb;t=c;w=f;f=(i>>>21&2040)+27888|0;i=(((B(j,u[f+2>>1])+B(u[f>>1],p)|0)+B(u[f+4>>1],q)|0)+B(r,u[f+6>>1])|0)/16384<<8;f=i;j=Fma(l,l>>31,f,f>>31);e=j+e|0;f=mb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];h=Fma(e,e>>31,h,h>>31);e=j+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[t>>2]=w+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(i&s)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function Kd(a){var b=0,c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;v[c+12>>2]=0;v[c+8>>2]=2555;d=v[c+12>>2];v[c>>2]=v[c+8>>2];v[c+4>>2]=d;d=v[c+4>>2];b=c+16|0;v[b+4>>2]=v[c>>2];v[b+8>>2]=d;v[b>>2]=a;e=jb-16|0;jb=e;d=a;if(v[a>>2]!=-1){f=e+8|0;Qc(f,b);Qc(e,f);b=e;while(1){if(v[d>>2]==1){continue}break}a:{b:{c:{if(!v[d>>2]){Ef(d,1);v[114578]=0;f=v[114578];v[114578]=0;d:{if((f|0)==1){break d}v[114578]=0;Z(2564,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[d>>2]=-1;v[114578]=0;b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;a=v[114578];v[114578]=0;e:{if((a|0)==1){break e}Ef(d,0);v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)==1){break c}S(a|0);L()}break a}V(0)|0;O()|0;Ab()}L()}}jb=e+16|0;jb=c+32|0;return v[a+4>>2]-1|0}function Nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;jb=f+32|0}function mz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;uQ(a,b);i=jb-16|0;jb=i;Fd(c,1);a=b+22|0;a=w[a|0]|w[a+1|0]<<8;v[c>>2]=((a<<8|a>>>8)&65535)<<1;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[pc(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;a=w[a|0]|w[a+1|0]<<8;j=(a<<8|a>>>8)&65535;a=j<<1;f=b+28|0;f=w[f|0]|w[f+1|0]<<8;g=(f<<8|f>>>8)&65535;f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(f-a>>>0>3?!(f>>>0<4|a>>>0>f>>>0):0)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}jb=i+16|0;Tl(h,3,b);Ic(h+16|0,h);v[114578]=0;Q(371,d|0,h+16|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){a=d+32|0;yb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=nz(b);jb=h+32|0;return a}a=P()|0;O()|0;yb(h+16|0);S(a|0);L()}function uJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=jb+-64|0;jb=c;d=fo(c+48|0,Od(c+40|0,b),0);v[114578]=0;b=T(332,d|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;b=W(1702,d|0,c|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}b:{if(!b|v[c>>2]!=542066252){break b}b=c|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}b=c+8|0;f=a,g=gn((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4220>>2]=g;b=c+12|0;f=a,g=gn((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4224>>2]=g;b=c+16|0;f=a,g=gn((l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q()),C(0),C(1)),z[f+4228>>2]=g;b=c+20|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+24|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+28|0]!=0;t[a+4241|0]=w[c+29|0]!=0;t[a+4242|0]=w[c+30|0]!=0;t[a+4243|0]=w[c+31|0]!=0;t[a+4244|0]=w[c+32|0]!=0;ds(a)}Bb(d);jb=c- -64|0;return}a=P()|0;O()|0;Bb(d);S(a|0);L()}function s$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;a=Hv(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((dr(b,c,0)|0)!=-1){while(1){f=dr(b,c,e);v[114578]=0;X(199,d|0,b|0,e|0,f-e|0);f=v[114578];v[114578]=0;if((f|0)==1){break j}v[114578]=0;R(200,d+16|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break i}v[114578]=0;R(201,a|0,d+16|0);f=v[114578];v[114578]=0;if((f|0)==1){break h}yb(d+16|0);yb(d);e=dr(b,c,e)+Fb(c)|0;if((dr(b,c,e)|0)!=-1){continue}break}}k:{if(nd(a)){v[114578]=0;X(199,d+16|0,b|0,e|0,-1);c=v[114578];v[114578]=0;if((c|0)==1){break f}c=Fb(d+16|0);yb(d+16|0);if(!c){break k}}v[114578]=0;X(199,d|0,b|0,e|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;R(200,d+16|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;R(201,a|0,d+16|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+16|0);yb(d)}jb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;yb(d+16|0)}yb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(d+16|0)}yb(d)}cl(a);S(e|0);L()}function r6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=UM(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(Js(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!Js(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(40,4);i=Ck(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1258,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(1256,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(2109,h|0,c|0,38127,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;TM(b);S(a|0);L()}Dk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;TM(d+8|0)}Ei(f+24|0,Qc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+12|0}function bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-32|0;jb=d;t[d+16|0]=44;v[d+8>>2]=-1;v[d+12>>2]=0;v[d>>2]=1042;v[d+4>>2]=2;h=a;g=d;a=jb-16|0;jb=a;i=a;c=jb-176|0;jb=c;e=dh(c+40|0);f=v[v[e>>2]-12>>2];v[114578]=0;j=da(122)|0;k=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{if((k|0)==1){break f}v[114578]=0;U(123,c+32|0,(c+40|0)+f|0,j|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}Ob(c+32|0);v[114578]=0;R(148,e|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;R(132,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;R(125,c|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break f}v[114578]=0;U(140,c+16|0,c|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(141,i|0,c+16|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}yb(c+16|0);yb(c);Yd(e);jb=c+176|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(c+16|0)}yb(c)}Yd(e);S(a|0);L()}v[114578]=0;U(13,h|0,0,a|0);b=v[114578];v[114578]=0;g:{if((b|0)!=1){yb(a);jb=a+16|0;break g}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+32|0}function Iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=UM(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{zb(c);h=b+14|0;e:{if(SL(g,h)){if(!v[b>>2]){break b}e=b;break e}zb(c);if(!SL(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(20,4);i=Ck(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1386,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(1382,c+14|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(1385,h|0,c|0,20485,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;TL(b);S(a|0);L()}Dk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;TL(d+8|0)}Ei(f+24|0,Qc(d+8|0,b),d+27|0);jb=d+32|0;a=wt(f+24|0);jb=f+32|0;return a+4|0}function bK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(hs(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!hs(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(32,4);i=Ck(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1624,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(733,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(1623,h|0,c|0,32530,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;VJ(b);S(a|0);L()}Dk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;VJ(d+8|0)}Ei(f+24|0,Qc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+4|0}function Qw(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=jb-96|0;jb=g;h=a+24|0;So(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=YH(g+32|0,g+80|0,ZH(g+80|0),b);e=v[a+32>>2];i=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;c=jb-16|0;jb=c;d=v[g+12>>2];v[c+8>>2]=v[g+8>>2];v[c+12>>2]=d;d=v[g+4>>2];v[c>>2]=v[g>>2];v[c+4>>2]=d;f=g+48|0;d=f;Nr(d);v[d+8>>2]=e;v[d+4>>2]=0;v[d>>2]=83888;e=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=e;e=v[c+12>>2];v[d+20>>2]=v[c+8>>2];v[d+24>>2]=e;z[d+28>>2]=i;v[d>>2]=83832;jb=c+16|0;a:{b:{if(b){e=0;while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114578]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=Q(2153,g+24|0,g+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}d=v[d>>2];v[114578]=0;c=W(2154,c|0,d|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}e=c+e|0;if(c){b=b-c|0;if(b){continue}}break}if(e){break b}}e=0;if(v[a+52>>2]!=1){break b}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+96|0;return e}a=P()|0;O()|0;S(a|0);L()}function Pw(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=jb-96|0;jb=g;h=a+24|0;So(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=YH(g+32|0,g+80|0,ZH(g+80|0),b);e=v[a+32>>2];i=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;c=jb-16|0;jb=c;d=v[g+12>>2];v[c+8>>2]=v[g+8>>2];v[c+12>>2]=d;d=v[g+4>>2];v[c>>2]=v[g>>2];v[c+4>>2]=d;f=g+48|0;d=f;Nr(d);v[d+8>>2]=e;v[d+4>>2]=0;v[d>>2]=83984;e=v[c+4>>2];v[d+12>>2]=v[c>>2];v[d+16>>2]=e;e=v[c+12>>2];v[d+20>>2]=v[c+8>>2];v[d+24>>2]=e;z[d+28>>2]=i;v[d>>2]=83936;jb=c+16|0;a:{b:{if(b){e=0;while(1){c=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114578]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=Q(2153,g+24|0,g+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}d=v[d>>2];v[114578]=0;c=W(2154,c|0,d|0,f|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}e=c+e|0;if(c){b=b-c|0;if(b){continue}}break}if(e){break b}}e=0;if(v[a+52>>2]!=1){break b}a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+96|0;return e}a=P()|0;O()|0;S(a|0);L()}function rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+14|0;e:{if(yn(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!yn(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(20,4);i=Ck(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(830,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(823,c+14|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(829,h|0,c|0,15166,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;RQ(b);S(a|0);L()}Dk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;RQ(d+8|0)}Ei(f+24|0,Qc(d+8|0,b),d+27|0);jb=d+32|0;a=wt(f+24|0);jb=f+32|0;return a+2|0}function lka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(yn(zb(c),g,h)){if(!v[b>>2]){break b}e=b;break e}if(!yn(zb(c),h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=sc(32,4);i=Ck(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(731,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(729,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(730,h|0,c|0,14646,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;ZR(b);S(a|0);L()}Dk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;ZR(d+8|0)}Ei(f+24|0,Qc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+4|0}function ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=Db(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)!=4){break c}c=0;while(1){f:{g:{h:{d=w[c+h|0];switch(d-10|0){case 3:break h;case 0:break g;default:break f}}e=e+1|0;break f}f=f+1|0}i=((g&255)==13&(c|0)!=0&(d|0)==10)+i|0;g=d;c=c+1|0;if((c|0)!=(b|0)){continue}break}c=(e|0)==(i|0);break d}if((d|0)!=4){break b}b=0;c=1}i:{if((e|0)==(f|0)){d=2;if(c){break i}}if(e){d=0;if(!f){break i}}d=e?3:f?1:3}if(!b){break b}}g=0;f=(d|0)!=2;c=0;e=0;while(1){e=(f|w[c+h|0]!=10)+e|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}break a}b=0;g=1;e=0}Co(a,e);if(!g){g=(d|0)==2;f=d&-3;i=(d|0)==1?32:13;c=0;e=0;while(1){j:{k:{l:{m:{n:{o:{d=t[c+h|0];switch(d-10|0){case 1:case 2:break l;case 0:break n;case 3:break o;default:break m}}j=om(a,e),k=i,t[j|0]=k;c=c+g|0;break j}d=om(a,e);if(f){t[d|0]=13;break j}t[d|0]=32;break j}if(!d){break k}}j=om(a,e),k=d,t[j|0]=k;break j}j=om(a,e),k=32,t[j|0]=k}e=e+1|0;c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function Eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-32|0;jb=f;l=f,m=uh(b),v[l+16>>2]=m;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;g=b;c=a;b=Ke(c);e=hc(c);a:{b:{if(b){c:{while(1){d:{zb(c);h=b+16|0;e:{if(QL(g,h)){if(!v[b>>2]){break b}e=b;break e}zb(c);if(!QL(h,g)){break c}e=b+4|0;if(!v[b+4>>2]){break d}b=e;e=b}b=v[b>>2];continue}break}v[d+28>>2]=b;b=e;break a}v[d+28>>2]=b;b=e;break a}b=hc(c)}v[d+28>>2]=b}e=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=hc(a);b=VL(1);i=Ck(g+8|0,h);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=d+8|0;W(1390,b|0,c+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=c+16|0;break f}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;c=T(1387,c+16|0)|0;i=v[114578];v[114578]=0;g:{h:{if((i|0)==1){break h}v[114578]=0;fa(1389,h|0,c|0,20485,j|0,k|0);c=v[114578];v[114578]=0;if((c|0)==1){break h}l=hc(b),m=1,t[l+4|0]=m;jb=g+16|0;break g}a=P()|0;O()|0;RL(b);S(a|0);L()}Dk(a,v[d+28>>2],e,v[d+8>>2]);b=Nd(d+8|0);t[d+27|0]=1;RL(d+8|0)}Ei(f+24|0,Qc(d+8|0,b),d+27|0);jb=d+32|0;a=jh(f+24|0);jb=f+32|0;return a+8|0}function uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=oc(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>1>>>0){g=jb-16|0;jb=g;e:{d=Xh(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(828,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+2|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Ri(f,oc(f)+h|0);m=oc(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>2147483647){Fc(15088);L()}g=sc(g<<1,1)}v[e>>2]=g;j=(m<<1)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<1)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(826,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(827,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}SQ(e)}jb=k+32|0;break b}a=P()|0;O()|0;SQ(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<1)|0;oc(f);UQ(f,d);Nn(f)}}c=Qb(a,c<<1);if(c){_A(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function Vka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=Kb(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>2>>>0){g=jb-16|0;jb=g;e:{d=qe(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(741,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+4|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Be(f,Kb(f)+h|0);m=Kb(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>1073741823){Fc(14480);L()}g=sc(g<<2,1)}v[e>>2]=g;j=(m<<2)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<2)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(739,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(740,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}OR(e)}jb=k+32|0;break b}a=P()|0;O()|0;OR(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<2)|0;Kb(f);PR(f,d);Qg(f)}}c=Qb(a,c<<2);if(c){Hz(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function Bja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=Kb(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>2>>>0){g=jb-16|0;jb=g;e:{d=qe(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(821,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+4|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Be(f,Kb(f)+h|0);m=Kb(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>1073741823){Fc(15088);L()}g=sc(g<<2,1)}v[e>>2]=g;j=(m<<2)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<2)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(819,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(820,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}ZQ(e)}jb=k+32|0;break b}a=P()|0;O()|0;ZQ(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<2)|0;Kb(f);_Q(f,d);Qg(f)}}c=Qb(a,c<<2);if(c){Hz(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function uU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;i=jb-16|0;jb=i;f=b;e=oc(f);d=c;a:{if(e>>>0<d>>>0){k=jb-32|0;jb=k;b:{c:{h=d-e|0;d:{if(h>>>0<=v[zb(f)>>2]-v[f+4>>2]>>1>>>0){g=jb-16|0;jb=g;e:{d=Xh(g,f,h);if(v[d+4>>2]!=v[d+8>>2]){while(1){e=zb(f);h=v[d+4>>2];v[114578]=0;R(427,e|0,h|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=v[d+4>>2]+2|0;v[d+4>>2]=e;if((e|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=g+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(f);d=Ri(f,oc(f)+h|0);m=oc(f);l=jb-16|0;jb=l;v[l+12>>2]=0;e=k+8|0;Tc(e+12|0,j);if(d){g=d;if(d>>>0>2147483647){Fc(12065);L()}g=sc(g<<1,1)}v[e>>2]=g;j=(m<<1)+g|0;v[e+8>>2]=j;v[e+4>>2]=j;n=ec(e),o=(d<<1)+g|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(425,e|0,h|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(426,f|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}ZA(e)}jb=k+32|0;break b}a=P()|0;O()|0;ZA(e);S(a|0);L()}break a}if(d>>>0<e>>>0){d=v[f>>2]+(d<<1)|0;oc(f);$A(f,d);Nn(f)}}c=Qb(a,c<<1);if(c){_A(i+8|0,b);Bd(a,i+8|0)}jb=i+16|0;return c|0}function AA(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b:{if((w[a|0]-1&255)>>>0>14){break b}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<=-2){break b}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){c=B(d,13)+a|0;if(w[c+14|0]){break a}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break a}b=e+422|0;if(w[c+942|0]|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>=1048576){break a}c=B(d,11)+a|0;g=c+1346|0;if(w[g|0]>=16|w[c+1351|0]>=4|w[c+1356|0]>=4){break a}c:{if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break c}c=e+430|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048574){break c}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break a}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break a}}d:{e:{if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)|f){break e}if(qd(g,12323,11)){break e}f=0;break d}f=1}d=d+1|0;if((d|0)!=32){continue}break}}return f}return 0}function FG(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[d>>2];j=z[a>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=z[b>>2]+f;i=C(j-i);f=C(f-g);z[d>>2]=C(z[e>>2]*i)-C(z[e+4>>2]*f);z[b>>2]=C(z[e+4>>2]*i)+C(z[e>>2]*f);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=j+f;h=a-12|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+32>>2]*f)-C(z[e+36>>2]*g);z[b>>2]=C(z[e+36>>2]*f)+C(z[e+32>>2]*g);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=j+f;h=a-20|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+64>>2]*f)-C(z[e+68>>2]*g);z[b>>2]=C(z[e+68>>2]*f)+C(z[e+64>>2]*g);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=j+f;h=a-28|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+96>>2]*f)-C(z[e+100>>2]*g);z[b>>2]=C(z[e+100>>2]*f)+C(z[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=(k|0)>1;k=k-1|0;if(b){continue}break}}return}ha(51904,50496,2408,51917);L()}function cha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-144|0;jb=f;Sy(a);a:{b:{if(!Df(a,64)){break b}c:{d:{e:{if(!yk(a,60)){break e}if(!fP(a,17212)){break e}b=15;break d}Sy(a);if(!Df(a,128)){break b}b=0;c=1;if(!yk(a,124)){break d}e=31;if(fP(a,17217)){break c}}e=b;if(c){break a}}Sy(a);b=1;while(1){c=0;d=jb-16|0;jb=d;if(cP(a,d+8|0)){c=d+8|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}jb=d+16|0;if(c>>>0>131072){break a}if((b&65535)>>>0<e>>>0){b=b+1|0;continue}break}Xc(a,4);if(!Df(a,2)){break b}c=0;g=jb-16|0;jb=g;d=jb-16|0;jb=d;Pk(d+8|0,g+8|0);b=a;i=Hb(d+8|0);j=md(a,ac(d,d+8|0));if((i|0)==(j|0)){Xc(b,Hb(d+8|0))}jb=d+16|0;jb=g+16|0;if((i|0)==(j|0)){b=g+8|0;b=w[b|0]|w[b+1|0]<<8;c=b<<8|b>>>8}if((c&65535)>>>0<178){break a}h=-1;b=B(e,30);if(!Df(a,b)){break a}Xc(a,b);b=jb-16|0;jb=b;e=f+8|0;lQ(b+8|0,e);c=Hb(b+8|0);d=md(a,ac(b,b+8|0));if((c|0)==(d|0)){Xc(a,Hb(b+8|0))}jb=b+16|0;a=(c|0)==(d|0);if(!a){mQ(e)}if(!a){break a}h=eP(f+8|0);break a}h=-1}jb=f+144|0;return h|0}function Sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-16|0;jb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;j=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=j;a:{if(d){while(1){k=u[(f<<1)+p>>1];g=v[a+60>>2];f=Yb(b,-16777216,16776704);n=v[a+64>>2];i=Yb(e,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];j=c;s=v[c>>2];o=k<<8;e=o;e=Fma(g,g>>31,e,e>>31);k=mb;g=Fma(n,n>>31,f,f>>31);f=g+e|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=v[a+68>>2];i=Fma(f,f>>31,i,i>>31);f=g+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;k=m>>12;v[j>>2]=B(e,k)+s;l=l+r|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,g);j=f-(o&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;f=v[h+12>>2];e=b;b=j;continue}break}i=v[h+8>>2];f=v[h+12>>2];e=b;break a}g=l>>12;k=m>>12;j=b}v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=j;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function yda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;g=Wb(a+4|0);c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=0;e=a+16|0;W(83,e|0,c+12|0,c+8|0)|0;b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){jb=c+16|0;break b}break a}c=e;t[a+20|0]=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;e=a+24|0;W(84,e|0,b+12|0,b+8|0)|0;f=v[114578];v[114578]=0;c:{if((f|0)!=1){jb=b+16|0;break c}break a}v[114578]=0;Z(80,d+8|0);b=v[114578];v[114578]=0;d:{e:{f:{if((b|0)!=1){oy(c,Nd(d+8|0));wf(d+8|0);t[a+20|0]=0;b=0;break f}b=Ca(71204,71180)|0;f=O()|0;if((ga(71204)|0)==(f|0)){_(b|0)|0;v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)==1){b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){break e}V(0)|0;O()|0;Ab()}L()}if((ga(71180)|0)!=(f|0)){break e}_(b|0)|0;t[a+20|0]=0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){b=P()|0;O()|0;break e}b=w[a+20|0]}if(b&255){break d}v[114578]=0;Z(82,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=P()|0;O()|0}wf(e);wf(c);yb(g);S(b|0);L()}jb=d+16|0;return a|0}V(0)|0;O()|0;Ab();L()}function iw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;i=c;a:{if((f|0)==(e|0)&c>>>0>c>>>0|e>>>0>f>>>0){e=d<<4|c>>>28;c=c<<4|b>>>28;b=b&268435455;h=b;if((b|0)==134217728&a>>>0>=1|b>>>0>134217728){e=e+1073741824|0;a=c+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}f=c;e=e+1073741824|0;if(a|h^134217728){break a}b=c&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!i&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){f=c;c=d<<4|c>>>28;f=f<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;qf(g+16|0,a,b,c,e,h-15233|0);Fm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;c=a;b=v[g>>2]|((v[g+16>>2]|v[g+24>>2])!=0|(v[g+20>>2]|v[g+28>>2])!=0);if((a|0)==134217728&b>>>0>=1|a>>>0>134217728){a=f+1|0;e=a>>>0<1?e+1|0:e;f=a;break a}if(b|c^134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}jb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-16|0;jb=h;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;j=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=j;a:{if(d){while(1){k=t[f+p|0];g=v[a+60>>2];f=Yb(b,-16777216,16776704);n=v[a+64>>2];i=Yb(e,-16777216,16776704);q=v[a+72>>2];r=v[a+32>>2];j=c;s=v[c>>2];o=k<<16;e=o;e=Fma(g,g>>31,e,e>>31);k=mb;g=Fma(n,n>>31,f,f>>31);f=g+e|0;e=mb+k|0;e=f>>>0<g>>>0?e+1|0:e;g=f;f=v[a+68>>2];i=Fma(f,f>>31,i,i>>31);f=g+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;if(f>>>0<8388608){e=e+1|0}f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;k=m>>12;v[j>>2]=B(e,k)+s;l=l+r|0;g=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,g);j=f-(o&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;f=v[h+12>>2];e=b;b=j;continue}break}i=v[h+8>>2];f=v[h+12>>2];e=b;break a}g=l>>12;k=m>>12;j=b}v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=j;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function uL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-560|0;jb=e;u[e+558>>1]=b;a:{b:{if((b-1&65535)>>>0>254){break b}d=((b<<2)+a|0)+900380|0;f=v[d>>2];c:{if(f){c=lO(e,c);d=v[c+4>>2];b=f;v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);g=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=g;t[b+8|0]=g>>>8;t[b+9|0]=g>>>16;t[b+10|0]=g>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;Ox(b+48|0,c+48|0);Ox(b+68|0,c+68|0);Ox(b+88|0,c+88|0);lc(b+108|0,c+108|0,448);ut(c);break c}b=Ig(556);if(!b){f=0;v[d>>2]=0;break b}v[114578]=0;f=Q(1436,b|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[((x[e+558>>1]<<2)+a|0)+900380>>2]=b}h=a,i=x[Si(a+480192|0,e+558|0)>>1],u[h+480192>>1]=i}jb=e+560|0;return f|0}a=P()|0;O()|0;Xb(b);S(a|0);L()}function er(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Fb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Fv(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+64400|0];d:{e:{switch(Jma(f-88|0,30)|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Bc(g,d);v[114578]=0;b=T(2456,g|0)|0;a=v[114578];v[114578]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Bc(g,d);v[114578]=0;a=T(2457,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}Ob(g);v[114578]=0;R(2458,g|0,a|0);d=v[114578];v[114578]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114578]=0;R(2459,g|12,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;d=g+24|0;a=ua(2460,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Lc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;while(1){d=Lc(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;Lc(g)}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function vL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{switch(v[a+480224>>2]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Fma(c,c>>31,5e4,0);f=mb;b=v[bd(d+12|0,d+8|0)>>2];c=yc(Gma(c,f,b,b>>31),mb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Fma(c,c>>31,1e4,0);f=mb;b=v[bd(d+12|0,d+8|0)>>2];c=yc(Gma(c,f,b,b>>31),mb);break a;case 1:break b}}e=+y[a+24620>>2]*60/(+y[b+44>>2]*1e-4*(+(Fma(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(mb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!dg(c,x[b+60>>1])){break d}if(!(nd(_b(c,x[b+60>>1])+24|0)^1)){break d}c=_b(c,x[b+60>>1])+24|0;break c}c=a+480248|0}if(!nd(c)){e=e*5.960464477539063e-8*+y[Pb(c,y[b+48>>2]%(Kb(c)>>>0)|0)>>2]}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+A[b+8>>3];A[b+8>>3]=e;if(!(e<1)){A[b+8>>3]=e+-1;c=c+1|0;break a}if(A[a+1074384>>3]>-1){break a}A[b+8>>3]=e+1;c=c-1|0}b=Fma(v[a+480244>>2],0,c,0)+32768|0;a=mb;a=b>>>0<32768?a+1|0:a;a=id((a&65535)<<16|b>>>16,a>>>16|0);jb=d+16|0;return(a?a:1)|0}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Bc(g,d);v[114578]=0;b=T(21,g|0)|0;a=v[114578];v[114578]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Bc(g,d);v[114578]=0;a=T(2423,g|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}Ob(g);v[114578]=0;R(2424,g|0,a|0);d=v[114578];v[114578]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114578]=0;R(2425,g|12,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}v[114578]=0;d=g+24|0;a=ua(2426,g+24|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114578];v[114578]=0;if((b|0)==1){break f}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;yb(g)}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function f5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{f=v[b>>2];b=v[b+4>>2];c=jb-32|0;jb=c;v[114578]=0;g=Q(15,c+24|0,a|0)|0;h=v[114578];v[114578]=0;b:{c:{d:{if((h|0)!=1){e:{if(!w[g|0]){break e}Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;h=T(2392,c+16|0)|0;d=v[114578];v[114578]=0;f:{g:{if((d|0)!=1){Ob(c+16|0);d=Sk(c+8|0,a);e=v[v[a>>2]-12>>2];v[114578]=0;e=a+e|0;i=T(16,e|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break g}d=v[d>>2];v[114578]=0;b=Ea(2395,h|0,d|0,e|0,i|0,f|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[c+16>>2]=b;if(!Qk(c+16|0)){break e}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,5);b=v[114578];v[114578]=0;if((b|0)!=1){break e}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;Ob(c+16|0);break f}b=V(0)|0;O()|0}Hf(g);break d}Hf(g);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=c+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function gr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Fb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Sm(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+64400|0];d:{e:{switch(f-22|0){case 2:case 3:b=v[e>>2];if((w[b-1|0]&95)!=(w[c|0]&127)?(b|0)!=(d|0):0){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:case 1:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function zo(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[d>>2];k=z[a>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=z[c>>2]+g;j=C(k-j);g=C(g-h);z[d>>2]=C(z[e>>2]*j)-C(z[e+4>>2]*g);z[c>>2]=C(z[e+4>>2]*j)+C(z[e>>2]*g);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=k+g;i=a-12|0;h=z[i>>2];z[i>>2]=z[f>>2]+h;i=c;c=b+e|0;g=C(g-k);h=C(h-j);z[i>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[f>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=k+g;i=a-20|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=k+g;i=a-28|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=(l|0)>1;l=l-1|0;if(c){continue}break}}}function kY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=g>>>0|a>>>0>=d>>>0){break a}b=w[a|0];if(b>>>0>1114111){break a}f=a+1|0;b:{if(b<<24>>24>=0){break b}if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=w[a+1|0];if((f&192)!=128|(f&63|b<<6&1984)>>>0>1114111){break a}f=a+2|0;break b}c:{d:{if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((b|0)==237){break d}if((b|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if(e-g>>>0<2|b>>>0>244|(d-a|0)<4){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break a}g=g+1|0;f=a+4|0;break b}if((f&224)!=128){break a}}if((h&192)!=128|(h&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break a}f=a+3|0}a=f;g=g+1|0;continue}break}return a-c|0}function XV(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb+-64|0;jb=c;a=gd(a);v[114578]=0;b=da(228)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[114578]=0;d=Q(2,c+32|0,10984)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;b=da(228)|0;e=v[114578];v[114578]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[114578]=0;v[c+12>>2]=b;R(234,c+16|0,c+12|0);b=v[114578];v[114578]=0;if((b|0)==1){break h}v[114578]=0;U(3,c+48|0,d|0,c+16|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}Gb(a,c+48|0);yb(c+48|0);yb(c+16|0);yb(d);v[114578]=0;b=da(230)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(!b){break e}v[114578]=0;Q(235,a|0,10987)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(c+16|0)}yb(d);break a}v[114578]=0;b=da(229)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}if(!b){break d}v[114578]=0;Q(235,a|0,10989)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}}jb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}yb(a);S(b|0);L()}function QH(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{f:{g:{if(ni(a)){Fo(d+24|0);break g}Pm(d+8|0,a);v[114578]=0;R(2175,d+24|0,d+8|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}rf(d+8|0)}c=a+36|0;h:{if(ni(a)){break h}c=v[d+24>>2]}if((b|0)==-1){e=4194304;break d}if((b|0)>=0){f=b;if((Id(c)|0)>(b|0)){break d}}b=ba(8)|0;v[114578]=0;c=Q(85,d+8|0,38703)|0;a=v[114578];v[114578]=0;if((a|0)==1){break e}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break c}a=P()|0;O()|0;rf(d+8|0);break b}a=P()|0;O()|0;ca(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|e;b=v[b>>2];e=w[Rc(c,f)+16|0];v[114578]=0;R(489,b+484360|0,e|0);b=v[114578];v[114578]=0;i:{if((b|0)==1){break i}b=v[Rc(c,f)+12>>2];c=v[Rc(c,f)+8>>2];v[114578]=0;+oa(2025,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break i}v[a+16>>2]=0;v[a+20>>2]=0;gk(d+24|0);jb=d+32|0;return}a=P()|0;O()|0}gk(d+24|0)}S(a|0)}L()}function Bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;i=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}j=v[a+24>>2];k=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;if(d){while(1){g=0;v[e+40>>2]=h;v[e+44>>2]=l;h=(b<<1)+i|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){Ad(v[f+8>>2],u[(g<<1)+h>>1]/4<<16>>16);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,u[h+(v[e+44>>2]<<1)>>1]/4<<16>>16);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function rM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=B(b,896)+a|0;a:{if(c){Eb(e+8|0,a+1074308|0,90);if(!Cb(e+8|0)){t[(B(b,896)+a|0)+1075815|0]=c}t[(B(b,896)+a|0)+1075816|0]=c;break a}c=w[g+1075816|0]}f=g+1074984|0;h=c&255;j=0-h|0;i=d?i:!(v[a+480180>>2]&204473357);lM(a,b,j,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}g=v[(B(b,896)+a|0)+1075640>>2];if(!g|!v[g+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){kM(a,f,240-h|0);break b}if(!(b>>>0<224|d)){jM(f,224-h|0);break b}iM(f,j);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=65535}if(!(!i|(c&255)>>>0<224)){d:{d=h&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}fM(a,f,d);break b}if(v[a+480180>>2]==524288){break d}oM(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){Eb(e+8|0,a+1074308|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}gM(a,f,h<<2)}jb=e+16|0}function Pla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-2608|0;jb=f;d=f+8|0;hm(d,a);v[d+1056>>2]=0;v[d+1060>>2]=0;Rb(d+1064|0,0,1536);v[114578]=0;Z(565,d|0);a=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((a|0)!=1){if(!c){break d}f:{while(1){v[114578]=0;j=Q(260,d|0,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break f}a=0;g:{while(1){v[114578]=0;e=Q(260,d|0,1)|0;k=v[114578];v[114578]=0;if((k|0)==1){break g}a=B(a,6)+d|0;a=u[(e?a+1066|0:a+1064|0)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1068|0];if(u[e+1064>>1]<0){break h}if(u[e+1066>>1]>-1){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break d}break}b=V(76880)|0;break e}b=V(76880)|0;break e}b=V(76880)|0}if((O()|0)!=(ga(76880)|0)){break a}_(b|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break c}}v[114578]=0;a=T(566,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}Bb(d);jb=f+2608|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0}Bb(d);S(b|0);L()}function Haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;f=Wb(e+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[114578]=0;c=T(341,b|0)|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){v[e+12>>2]=c;if((c|0)>0){break d}v[114578]=0;Q(85,a|0,30880)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break b}}break a}v[114578]=0;c=T(332,b|0)|0;d=v[114578];v[114578]=0;e:{if((d|0)==1){break e}v[114578]=0;c=T(857,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;v[e+8>>2]=c;c=Q(464,e+12|0,e+8|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break e}c=v[c>>2];v[114578]=0;R(111,f|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[114578]=0;c=T(389,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}if(!c){break f}v[114578]=0;W(1532,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}break a}v[114578]=0;Q(340,b|0,4)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}cd(a,f)}yb(f);jb=e+32|0;return}a=P()|0;O()|0;yb(f);S(a|0);L()}function r8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{d=jb-16|0;jb=d;f=gd(a);b:{if(Fb(b)){while(1){c=v[hj(b,i)>>2];c:{if(c>>>0>=2097152){v[114578]=0;R(118,f|0,63);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}e=0;d:{e:{f:{while(1){h=c&63;t[(d+10|0)+e|0]=h;a=e+1|0;c=c>>>6|0;if(!c){break f}e=a;if((a|0)!=6){continue}break}a=7;c=1;break e}if(!e){v[114578]=0;R(118,f|0,t[d+10|0]);a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}c=7-e|0;if((a|0)!=2){break e}if((h|0)==1){break d}a=2;c=6}e=a+d|0;h=(-1<<a^-1)<<c;c=a;while(1){g:{h:{if((a|0)==(c|0)){g=w[e+9|0];v[114578]=0;R(118,f|0,(g|h)<<24>>24);g=v[114578];v[114578]=0;if((g|0)==1){break g}c=c-1|0;break h}v[114578]=0;c=c-1|0;R(118,f|0,t[c+(d+10|0)|0]|-128);g=v[114578];v[114578]=0;if((g|0)==1){break g}}if(c){continue}break c}break}break b}v[114578]=0;R(118,f|0,t[d+10|0]|64);a=v[114578];v[114578]=0;if((a|0)==1){break b}}i=i+1|0;if(Fb(b)>>>0>i>>>0){continue}break}}jb=d+16|0;break a}a=P()|0;O()|0;yb(f);S(a|0);L()}}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;h=jb-16|0;jb=h;g=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=f+o|0;p=t[e+1|0];e=t[e|0];f=v[a+60>>2];q=f;r=f>>31;f=Yb(b,-16777216,16776704);j=v[a+64>>2];g=Yb(g,-16777216,16776704);s=v[a+72>>2];u=v[c>>2];f=Fma(j,j>>31,f,f>>31);j=mb;k=f;f=v[a+68>>2];l=Fma(f,f>>31,g,g>>31);f=k+l|0;g=mb+j|0;g=f>>>0<l>>>0?g+1|0:g;k=f;f=((B(p-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=f;i=Fma(q,r,e,e>>31);e=k+i|0;g=mb+g|0;g=e>>>0<i>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;v[c>>2]=B(e,n)+u;v[c+4>>2]=v[c+4>>2]+B(e,m);e=g-(f&s)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];f=v[h+12>>2];g=b;b=e;continue}break}i=v[h+8>>2];f=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function Baa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-32|0;jb=f;e=jb-16|0;jb=e;d=b;c=a+33|0;v[d>>2]=w[c+206|0]|w[c+207|0]<<8;NK(c,d+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);NK(c,d+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);i=d+236|0;while(1){j=w[c+g|0];k=ed(i,g+12|0),l=j,u[k>>1]=l;g=g+1|0;if((g|0)!=96){continue}break}if(w[c+208|0]){t[d+31|0]=w[c+209|0]+1;g=w[d+31|0];a:{if(g>>>0<1){t[d+31|0]=1;break a}if(g>>>0<=16){break a}t[d+31|0]=16}u[e+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[e+12>>1]=127;k=d,l=w[lf(e+14|0,e+12|0)|0]+1|0,t[k+30|0]=l}t[d+33|0]=w[c+212|0];jb=e+16|0;c=b+236|0;while(1){d=0;e=a+h|0;if(w[e+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){d=w[e+33|0]}k=ed(c,h+12|0),l=d,u[k>>1]=l;h=h+1|0;if((h|0)!=96){continue}break}Tl(f,3,a+4|0);Ic(f+16|0,f);v[114578]=0;Q(371,b+492|0,f+16|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){yb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}jb=f+32|0;return}a=P()|0;O()|0;yb(f+16|0);S(a|0);L()}function z6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=v[b>>2];b=jb-32|0;jb=b;v[114578]=0;g=Q(15,b+24|0,a|0)|0;d=v[114578];v[114578]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[g|0]){break e}Bc(b+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;d=T(2392,b+16|0)|0;e=v[114578];v[114578]=0;f:{g:{if((e|0)!=1){Ob(b+16|0);e=Sk(b+8|0,a);f=v[v[a>>2]-12>>2];v[114578]=0;f=a+f|0;h=T(16,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}e=v[e>>2];v[114578]=0;c=ea(2393,d|0,e|0,f|0,h|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Qk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+c|0,5);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Hf(g);break d}Hf(g);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=b+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function W4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{g=A[b>>3];b=jb-32|0;jb=b;v[114578]=0;f=Q(15,b+24|0,a|0)|0;c=v[114578];v[114578]=0;b:{c:{d:{if((c|0)!=1){e:{if(!w[f|0]){break e}Bc(b+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;c=T(2392,b+16|0)|0;d=v[114578];v[114578]=0;f:{g:{if((d|0)!=1){Ob(b+16|0);d=Sk(b+8|0,a);e=v[v[a>>2]-12>>2];v[114578]=0;e=a+e|0;h=T(16,e|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break g}d=v[d>>2];v[114578]=0;c=Ya(2396,c|0,d|0,e|0,h|0,+g)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Qk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+c|0,5);c=v[114578];v[114578]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Hf(f);break d}Hf(f);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$()}jb=b+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function Ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=jb-16|0;jb=h;g=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];f=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=f;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=g;break a}while(1){e=(f<<1)+o|0;p=u[e+2>>1];e=u[e>>1];f=v[a+60>>2];q=f;r=f>>31;f=Yb(b,-16777216,16776704);j=v[a+64>>2];g=Yb(g,-16777216,16776704);s=v[a+72>>2];t=v[c>>2];f=Fma(j,j>>31,f,f>>31);j=mb;k=f;f=v[a+68>>2];l=Fma(f,f>>31,g,g>>31);f=k+l|0;g=mb+j|0;g=f>>>0<l>>>0?g+1|0:g;k=f;f=e+((B(p-e|0,i>>>18|0)|0)/16384|0)<<8;e=f;i=Fma(q,r,e,e>>31);e=k+i|0;g=mb+g|0;g=e>>>0<i>>>0?g+1|0:g;e=e+8388608|0;if(e>>>0<8388608){g=g+1|0}g=(g&16777215)<<8|e>>>24;e=(g|0)/256|0;v[c>>2]=B(e,n)+t;v[c+4>>2]=v[c+4>>2]+B(e,m);e=g-(f&s)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];f=v[h+12>>2];g=b;b=e;continue}break}i=v[h+8>>2];f=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=f;jb=h+16|0}function sM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;h=B(b,896)+a|0;a:{if(c){Eb(e+8|0,a+1074308|0,90);if(!Cb(e+8|0)){t[(B(b,896)+a|0)+1075816|0]=c}t[(B(b,896)+a|0)+1075815|0]=c;break a}c=w[h+1075815|0]}f=h+1074984|0;g=c&255;i=d?i:!(v[a+480180>>2]&204473357);lM(a,b,g,i);b:{c:{if(v[a+480180>>2]!=16777216){break c}h=v[(B(b,896)+a|0)+1075640>>2];if(!h|!v[h+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){kM(a,f,g-240|0);break b}if(!(b>>>0<224|d)){jM(f,g-224|0);break b}iM(f,g);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=1}if(!(!i|(c&255)>>>0<224)){d:{d=g&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}hM(a,f,d);break b}if(v[a+480180>>2]==524288){break d}nM(a,f,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){Eb(e+8|0,a+1074308|0,6);if(Cb(e+8|0)){break e}}if(v[a+480180>>2]==64){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}gM(a,f,0-(g<<2)|0)}jb=e+16|0}function hY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=h>>>0|a>>>0>=d>>>0){break a}f=t[a|0];b=f&255;b:{if((f|0)>=0){if(b>>>0>1114111){break a}a=a+1|0;break b}if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=w[a+1|0];if((f&192)!=128|(f&63|b<<6&1984)>>>0>1114111){break a}a=a+2|0;break b}c:{d:{if(b>>>0<=239){if((d-a|0)<3){break a}g=w[a+2|0];f=w[a+1|0];if((b|0)==237){break d}if((b|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>244){break a}g=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(g&192)!=128|(g&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break a}a=a+4|0;break b}if((f&224)!=128){break a}}if((g&192)!=128|(g&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break a}a=a+3|0}h=h+1|0;continue}break}return a-c|0}function nG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;v[d+8>>2]=1;v[d+12>>2]=0;a:{h=b<<2;if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(g+4|0)+b|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}b:{f=(a+h|0)-4|0;if(f>>>0<=a>>>0){e=1;b=1;break b}e=1;b=1;while(1){c:{if((e|0)==3){lw(a,c,b,d+16|0);Ar(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){zr(a,c,d+8|0,b,0,d+16|0);break d}lw(a,c,b,d+16|0)}if((b|0)==1){yr(d+8|0,1);b=0;break c}yr(d+8|0,g);b=1}e=v[d+8>>2]|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0<=a>>>0){break b}e=e&3;continue}}zr(a,c,d+8|0,b,0,d+16|0);while(1){e:{f:{g:{if(!((b|0)!=1|(e|0)!=1)){if(v[d+12>>2]){break g}break a}if((b|0)>1){break f}}f=mG(d+8|0);Ar(d+8|0,f);e=v[d+8>>2];b=b+f|0;break e}yr(d+8|0,2);v[d+8>>2]=v[d+8>>2]^7;Ar(d+8|0,1);g=a-4|0;f=b-2|0;zr(g-v[(d+16|0)+(f<<2)>>2]|0,c,d+8|0,b-1|0,1,d+16|0);yr(d+8|0,1);e=v[d+8>>2]|1;v[d+8>>2]=e;zr(g,c,d+8|0,f,1,d+16|0);b=f}a=a-4|0;continue}}jb=d+208|0}function kaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;Fd(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[lf(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[lf(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+31850|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}jb=e+16|0}function bj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;Bc(i+8|0,d);v[114578]=0;j=T(2456,i+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Ob(i+8|0);v[e>>2]=0;c=1;a:{while(1){if(!(c&1)|(g|0)==(h|0)){break a}b:{if(_j(i+24|0,i+16|0)){break b}c:{if((um(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}k=0;b=um(j,v[c>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=um(j,v[g+8>>2])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if($j(j,8192,v[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if($j(j,8192,v[g>>2])){continue}}break}while(1){if(!lr(i+24|0,i+16|0)){break c}if(!$j(j,8192,gl(i+24|0))){break c}Bm(i+24|0);continue}}if((Nk(j,gl(i+24|0))|0)==(Nk(j,v[g>>2])|0)){g=g+4|0;Bm(i+24|0);break c}v[e>>2]=4}c=!v[e>>2];continue}break}v[e>>2]=4}if(_j(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Ob(i+8|0);S(a|0);L()}function fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;An(b,f+44|0);a:{if(!zO(f+44|0)){break a}c=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;d=(h|0)!=3;i=e>>>1&3;e=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(d,6)+18424|0)+(e<<1)>>1]<<g;e=B(B(w[e+(B(d,3)+18201|0)|0],x[((B(d,90)+18208|0)+B(e,30)|0)+(c>>>3&30)>>1]),1e3);c=c>>>1|0;c=B(((e>>>0)/x[(B(h,6)+18400|0)+(c&6)>>1]|0)+(c&1)|0,(i|0)==3?4:1);u[a>>1]=c;e=w[g+((d<<1)+18436|0)|0];if(e+8>>>0>(c&65535)>>>0){break a}d=f;c=jb-16|0;jb=c;v[c+12>>2]=e+4;v[c>>2]=36;g=v[Lb(c+12|0,c)>>2];if(!Qb(b,g)){g=nf(b)}uq(c,d);xg(b,v[c>>2],g);uq(c,d);Rb(v[c>>2]+g|0,0,36-g|0);$b(b,v[c+12>>2]);jb=c+16|0;b=2;if(e>>>0>2){while(1){if(w[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=a;d=e+f|0;c=1;b:{if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1868983881){break b}c=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))==1735289176}t[b+5|0]=c}jb=f+48|0;return a|0}function gI(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){v[114578]=0;b=c;T(1404,b|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){c=v[b+4>>2];if(c){a=c;vf(a);if(v[a>>2]){f=a;g=v[a>>2];d=v[a+4>>2];b:{while(1){if((d|0)==(g|0)){break b}e=zb(f);v[114578]=0;d=d-4|0;R(1440,e|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[f+4>>2]=g;Re(zb(a),v[a>>2],yd(a))}Xb(c)}v[b+4>>2]=0;Vx(b+1304500|0);ts(b+1304436|0);yb(b+1304424|0);yb(b+1304412|0);yb(b+1304400|0);ss(b+1304396|0);rs(b+1304392|0);$o(b+1304360|0);a=b+946300|0;c=b+906300|0;while(1){a=$m(a-160|0);if((c|0)!=(a|0)){continue}break}Vs(b+484360|0);Ux(b+484344|0);oe(b+480248|0);break a}V(0)|0;O()|0;Vx(b+1304500|0);ts(b+1304436|0);yb(b+1304424|0);yb(b+1304412|0);yb(b+1304400|0);ss(b+1304396|0);rs(b+1304392|0);$o(b+1304360|0);a=b+946300|0;c=b+906300|0;while(1){a=$m(a-160|0);if((c|0)!=(a|0)){continue}break}Vs(b+484360|0);Ux(b+484344|0);oe(b+480248|0);Ab();L()}Xb(b)}}}function Mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-80|0;jb=d;c=v[a+28>>2];Dn(v[v[c>>2]-12>>2]+c|0,0);if(!xd(a,4)){iv(a)}a:{if(!v[a+4>>2]){break a}if(xd(a,6)){break a}if(xd(a,7)){break a}g=v[a+28>>2];h=v[a+84>>2];f=B(v[a+20>>2],v[a+4>>2]);e=f+v[a+80>>2]|0;e=Og(d- -64|0,e,e>>>0<f>>>0?h+1|0:h);f=v[e+12>>2];v[d+24>>2]=v[e+8>>2];v[d+28>>2]=f;c=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=c;dj(g,d+16|0)}c=0;b:{if(!xd(a,5)){break b}h=0;i=a+44|0;e=od(i);c=0;if(!e){break b}g=a+32|0;while(1){c:{j=(v[a+96>>2]+h>>>0)%(e>>>0)|0;if(y[tc(i,j)>>2]>=Ac(g)>>>0){break c}f=mm(d+48|0,xc(g,v[tc(i,j)>>2]),x[tc(i,j)+12>>1]);c=kv(b,f);Ib(f);if(!c){break c}v[a+96>>2]=(j+1>>>0)%(e>>>0);if(v[tc(i,j)+4>>2]){f=v[a+28>>2];c=v[a+12>>2];b=v[a+8>>2];a=v[tc(i,j)+4>>2];g=b+a|0;c=Og(d+32|0,g,a>>>0>g>>>0?c+1|0:c);a=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=a;a=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=a;dj(f,d)}c=tc(i,j);break b}h=h+1|0;if((e|0)!=(h|0)){continue}break}c=0}jb=d+80|0;return c}function Cea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;i=v[a+16>>2];f=Qf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Lf(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Pf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}j=v[a+24>>2];k=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+8>>2]=h;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;if(d){while(1){g=0;v[e+40>>2]=h;v[e+44>>2]=l;h=b+i|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){Ad(v[f+8>>2],t[h+g|0]<<6);zd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;g=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){Ad(b,t[h+v[e+44>>2]|0]<<6);zd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Kf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,k);v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);if(d){c=c+8|0;h=v[e+8>>2];b=v[e+12>>2];continue}break}h=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=h;v[a+4>>2]=b;jb=e+48|0}function cj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;Bc(i+8|0,d);v[114578]=0;j=T(21,i+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Ob(i+8|0);v[e>>2]=0;c=1;a:{while(1){if(!(c&1)|(g|0)==(h|0)){break a}b:{if(fj(i+24|0,i+16|0)){break b}c:{if((vm(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}k=0;b=vm(j,t[c|0]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=vm(j,t[g+2|0])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(Kg(j,8192,t[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Kg(j,8192,t[g|0])){continue}}break}while(1){if(!to(i+24|0,i+16|0)){break c}if(!Kg(j,8192,bk(i+24|0))){break c}il(i+24|0);continue}}if((Kv(j,bk(i+24|0))|0)==(Kv(j,t[g|0])|0)){g=g+1|0;il(i+24|0);break c}v[e>>2]=4}c=!v[e>>2];continue}break}v[e>>2]=4}if(fj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Ob(i+8|0);S(a|0);L()}function Ty(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?42:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=33;return;case 27:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function Qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-32|0;jb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];i=v[a+4>>2];e=i;g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;jb=f+32|0}function Uv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;v[114578]=0;g=Q(15,c+24|0,a|0)|0;d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)!=1){d:{if(!w[g|0]){break d}Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;d=T(2392,c+16|0)|0;e=v[114578];v[114578]=0;e:{f:{if((e|0)!=1){Ob(c+16|0);e=Sk(c+8|0,a);f=v[v[a>>2]-12>>2];v[114578]=0;f=a+f|0;h=T(16,f|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break f}e=v[e>>2];v[114578]=0;b=ea(2394,d|0,e|0,f|0,h|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break f}v[c+16>>2]=b;if(!Qk(c+16|0)){break d}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,5);b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Ob(c+16|0);break e}b=V(0)|0;O()|0}Hf(g);break c}Hf(g);break b}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=c+32|0;return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;jb=f+16|0}function jY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if((b&-2048)==55296|b>>>0>1114111){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<1){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return c|0}function vj(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=42;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function aV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-80|0;jb=d;Jc(b);Gq(a);a:{if(!Ju(b,d+40|0)){break a}if(!mC(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(!Qb(b,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))-28|0)){break a}ev(a);dv(d+24|0);cv(Tg(a)+28|0,d+24|0);Fq(d+24|0);e=v[Tg(a)+28>>2];v[114578]=0;f=T(352,b|0)|0;b=v[114578];v[114578]=0;c:{if((b|0)==1){break c}c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);b=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);v[114578]=0;c=aa(353,f|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))-28|0,e|0,b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}f=0;if(!c){break a}Vi(d+8|0,e);_u(d+16|0,d+8|0);b=fo(d+24|0,d+16|0,0);Wd(Tg(a)+12|0,b);Bb(b);break b}b=Ca(71204,77224)|0;a=O()|0;d:{if((ga(71204)|0)==(a|0)){break d}if((ga(77224)|0)==(a|0)){break d}S(b|0);L()}_(b|0)|0;$();f=0;break a}f=1}jb=d+80|0;return f|0}function Xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);c=0;while(1){if((l|0)>=1){i=(k<<1)+b|0;m=i+(l<<1)|0;while(1){n=c;u[e+6>>1]=0;FQ(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{h=w[e+15|0];if(!h){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;g=(f&65534)>>>0>255;t[e+14|0]=g;f=e;if(!c){if(!Je(a,e+5|0)){break b}g=w[e+5|0];c=g<<1&254|1;u[e+12>>1]=c;g=g>>>7|0}j=x[e+6>>1]<<1|g;u[f+6>>1]=j;h=h-1|0;if(h&255){continue}break}break a}j=x[e+6>>1]}c=1;g=j&65535;c:{if(g>>>0<4){break c}h=15;while(1){c=h;f=c&255;if(f>>>0<2){break c}h=c-1|0;if(!(1<<f&g)){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;f=c-1^(j&65534)>>>1;c=f+x[e+8>>1]|0;u[e+6>>1]=c;u[i>>1]=c;v[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);ce(e+8|0,-32768,32767);i=(d<<1)+i|0;if(m>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function MG(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[a+32>>2];a:{b:{c:{b=v[a+1380>>2];d:{if((b|0)==-1){h=1;b=-1;break d}d=v[a+1116>>2];e:{if((d|0)<=(b|0)){break e}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break e}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){break c}b=(b|0)==(d|0)?-1:b}while(1){if((b|0)!=-1){return 1}g=v[a+40>>2];if(g>>>0<=c+26>>>0){dc(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[84480]|w[84481]<<8|(w[84482]<<16|w[84483]<<24))){dc(a,21);break a}if(w[c+4|0]){dc(a,21);break a}f:{if(h){if(!v[a+992>>2]|!(t[c+5|0]&1)){break f}dc(a,21);break a}if(t[c+5|0]&1){break f}dc(a,21);break a}d=c+27|0;e=w[c+26|0];c=d+e|0;if(g>>>0<c>>>0){break b}h=0;b=0;f=0;g:{if(!e){break g}while(1){i=w[b+d|0];c=i+c|0;f=b;if((i|0)!=255){break g}b=b+1|0;if((e|0)!=(b|0)){continue}break}f=e}d=f;b=(d|0)==(e|0)?-1:d;if(c>>>0<=g>>>0){continue}break}dc(a,1);break a}dc(a,1);break a}dc(a,1)}return 0}function hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{h=v[a+8>>2];g=v[a+12>>2];d:{if((g|0)<1?1:(g|0)<=1?h>>>0<=805306368:0){if((g|0)>-2?1:(g|0)>=-2?h>>>0>=3489660928:0){break c}if((g|0)>-2?1:(g|0)>=-2?h>>>0>2147483647:0){break d}break b}if((g|0)>1?1:(g|0)>=1?h>>>0>2147483648:0){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;jb=f+16|0}function nR(a){var b=0,c=0,d=0,e=0;b=jb-48|0;jb=b;c=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+8>>2]=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))+788;v[b+12>>2]=0;c=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b+16>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);v[b+20>>2]=0;c=b;e=b;if(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24)){d=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}else{d=52}v[e+24>>2]=d;v[c+28>>2]=0;c=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[b+44>>2]=4;v[b+40>>2]=b+8;a=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=a;v[b+32>>2]=(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+80;v[b+36>>2]=0;c=jb-16|0;jb=c;a=v[b>>2];d=v[b>>2]+(v[b+4>>2]<<3)|0;a:{if((a|0)==(d|0)){break a}e=a+8|0;if((d|0)==(e|0)){break a}while(1){a=ou(a,e)?e:a;e=e+8|0;if((d|0)!=(e|0)){continue}break}}jb=c+16|0;jb=b+48|0;b=v[a>>2];c=b-52|0;mb=v[a+4>>2]-(b>>>0<52)|0;return c}function pn(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;t[a+861|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+819|0]=0;v[a+804>>2]=0;v[a+824>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;Eb(e+8|0,b+1074308|0,23);if(Cb(e+8|0)){u[a+798>>1]=0;u[a+800>>1]=1}t[a+866|0]=0;t[a+859|0]=0;t[a+871|0]=255;v[a+660>>2]=0;t[a+872|0]=w[a+872|0]&252;jt(a+810|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+865|0]=0;t[a+858|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+840>>1]=0;t[a+839|0]=0;u[a+856>>1]=32512;u[a+862>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+876>>2]=0;v[a+880>>2]=0;t[a+872|0]=w[a+872|0]&243;a:{if(c>>>0>126){c=64;b=128;d=0;break a}d=(c<<5)+b|0;c=x[d+480286>>1];b=x[d+480284>>1];d=v[d+480280>>2]}u[a+796>>1]=0;v[a+760>>2]=c;v[a+692>>2]=b;v[a+88>>2]=d;t[a+817|0]=0;t[a+818|0]=0;jb=e+16|0}function lO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=Ey(a+48|0);e=Ey(a+68|0);f=Ey(a+88|0);v[114578]=0;T(1162,a+492|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;T(1162,a+524|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;U(909,a|0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;U(910,a|0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[114578]=0;R(777,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=fc(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;tn(f);tn(e);tn(d);S(a|0);L()}function bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;e=a;c=jb-16|0;jb=c;z[c+8>>2]=2;u[c+14>>1]=12;v[c+4>>2]=15;d=Pe(64);v[114578]=0;g=T(1428,d|0)|0;h=v[114578];v[114578]=0;a:{b:{c:{if((h|0)!=1){d=Qx(c,g);g=v[d>>2];v[114578]=0;R(1429,g|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=v[d>>2];v[114578]=0;b=W(1430,b|0,c+14|0,c+8|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break c}d:{if(!b){Px(e);break d}b=v[d>>2];v[114578]=0;R(1431,b|0,c+4|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Gp(e,d)}ag(d);jb=c+16|0;break a}a=P()|0;O()|0;Xb(d);break b}a=P()|0;O()|0;ag(d)}S(a|0);L()}b=0;e:{f:{g:{while(1){c=v[a>>2];v[114578]=0;u[f+14>>1]=b;e=Q(2,f|0,(b<<2)+20768|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;U(1427,c|0,f+14|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}yb(e);b=b+1|0;if((b|0)!=12){continue}break}jb=f+16|0;return}b=P()|0;O()|0;break e}b=P()|0;O()|0;yb(e)}ag(a);S(b|0);L()}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-16|0;jb=f;v[f+12>>2]=b;a:{if(th(a)>>>0>=b>>>0){n=f,o=xe(a),v[n+8>>2]=o;b=v[a>>2];d=c;l=v[Lb(f+12|0,f+8|0)>>2];if(l){while(1){g=d;if((d|0)!=(b|0)){i=bc(g);j=cc(g);h=jb-16|0;jb=h;k=lA(i,j);e=b;b:{if(k>>>0<=Uf(e)>>>0){v[h+8>>2]=j;if(oc(e)>>>0<k>>>0){v[h+8>>2]=i;m=oc(e);v[h+8>>2]=v[h+8>>2]+(m<<1);wj(i,v[h+8>>2],v[e>>2]);$N(e,v[h+8>>2],j,k-oc(e)|0);break b}Pn(e,wj(i,j,v[e>>2]));break b}_N(e);dz(e,Ri(e,k));$N(e,i,j,k)}jb=h+16|0;Wi(b+12|0,g+12|0);u[b+28>>1]=x[g+28>>1]}b=b+32|0;l=l-1|0;if(l){continue}break}}b=v[f+12>>2];d=v[f+8>>2];if(b>>>0>d>>>0){Ay(a,b-d|0,c);break a}VN(a,v[a>>2]+(b<<5)|0);break a}d=a;if(v[d>>2]){xe(d);PN(d);Zu(d);sh(zb(d),v[d>>2],th(d));n=zb(d),o=0,v[n>>2]=o;v[d>>2]=0;v[d+4>>2]=0}e=dm(a,b);if(FC(a)>>>0<e>>>0){fd();L()}g=NN(zb(d),e);v[d>>2]=g;v[d+4>>2]=g;n=zb(d),o=g+(e<<5)|0,v[n>>2]=o;Bq(d,0);Ay(a,b,c)}jb=f+16|0}function Rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];i=h;e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;h=a;if(d){while(1){g=(((i&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;i=a;a=0;e=1;if(i){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];i=v[f+28>>2];continue}break}e=v[f+24>>2];i=v[f+28>>2]}v[h>>2]=e;v[h+4>>2]=i;jb=f+32|0}function lJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);b=jb-32|0;jb=b;d=v[a+20>>2];a:{if(!d){break a}if(Ac(d+4|0)>>>0<4){break a}Vi(b+8|0,v[a+20>>2]+4|0);c=jb-16|0;jb=c;XJ(c+8|0,ac(c,b+8|0));d=b+16|0;Xu(d,c+8|0);v[d+12>>2]=0;v[d+8>>2]=0;jb=c+16|0;v[114578]=0;c=T(392,d|0)|0;f=v[114578];v[114578]=0;b:{if((f|0)!=1){if(c){break b}c=v[v[a>>2]+40>>2];v[114578]=0;c=T(c|0,a|0)|0;f=v[114578];v[114578]=0;c:{if((f|0)==1){break c}if(Ac(v[a+20>>2]+4|0)-4>>>0<c<<2>>>0){break b}e=v[v[a>>2]+168>>2];f=0;v[114578]=0;R(e|0,a|0,-1);e=v[114578];v[114578]=0;if((e|0)==1){break c}if(c){while(1){v[114578]=0;g=C(Aa(701,d|0));e=v[114578];v[114578]=0;if((e|0)==1){break c}e=v[v[a>>2]+44>>2];v[114578]=0;ya(e|0,a|0,f|0,C(g));e=v[114578];v[114578]=0;if((e|0)==1){break c}f=f+1|0;if((c|0)!=(f|0)){continue}break}}c=v[v[a>>2]+172>>2];v[114578]=0;Z(c|0,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;Bb(d);S(a|0);L()}Bb(d)}jb=b+32|0}function Z8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=0,y=C(0);if(v[a+4220>>2]){f=a+44|0;i=Pd(f,0);j=Pd(f,1);k=jd(f,0);l=jd(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[j>>2];o=z[i>>2];w=h;e=e-v[a+4228>>2]|0;if((e|0)<=-1){e=e+v[a+4220>>2]|0}e=e<<1;p=z[Pb(w,e)>>2];e=Pb(h,e|1);r=z[a+4248>>2];s=z[a+4256>>2];t=z[a+4252>>2];u=z[a+4244>>2];q=z[e>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(u*q));x=Pb(h,v[a+4224>>2]<<1),y=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[x>>2]=y;g=C(C(C(C(r*o)+C(s*n))+C(t*q))+C(u*p));x=Pb(h,v[a+4224>>2]<<1|1),y=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[x>>2]=y;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(p*z[a+4236>>2])+C(o*z[a+4240>>2]);z[l>>2]=C(q*z[a+4236>>2])+C(n*z[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}pi(a,b,c,jd(f,0),jd(f,1),d)}}function hV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-48|0;jb=b;c=-1;a:{if(!rC(a,b+8|0)){break a}c=0;if(!OK(b+8|0)){break a}d=b+8|0;h=$e(11555);if(h){m=v[a+12>>2];if(yk(a,w[d+16|0]|w[d+17|0]<<8|(w[d+18|0]<<16|w[d+19|0]<<24))){b:{if(!(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))){break b}while(1){if(!Df(a,4)){break b}c:{if((w[d+4|0]|w[d+5|0]<<8)>>>0>=64){c=a;g=$p(a);e=g&63;d:{if(!(g&64)){break d}f=6;while(1){i=$p(c);e=(i&127)<<f|e;if(f>>>0>24){break d}f=f+7|0;if(i&128){continue}break}}if(((g&128?0-e|0:e)|0)<1){break c}}f=$p(a);e:{if(f){g=1;e=0;while(1){i=Io(f<<24>>24);j=e>>>0>=h>>>0;f=j&g;c=f;f:{if(j){break f}c=f;if(!(g&1)){break f}c=w[e+11555|0]==(i&255)}g=c;e=e+1|0;f=$p(a);if(f){continue}break}c=(e|0)==(h|0)&g;break e}c=!h}Xc(a,4);k=c?1:k}l=l+1|0;if(l>>>0<(w[d+12|0]|w[d+13|0]<<8|(w[d+14|0]<<16|w[d+15|0]<<24))>>>0){continue}break}}e=k&1}yk(a,m)}c=e}a=c;jb=b+48|0;return a|0}function dj(a,b){var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;d=v[(v[v[a>>2]-12>>2]+a|0)+16>>2]&-3;Dn(v[v[a>>2]-12>>2]+a|0,d);a:{b:{if(w[gj(c+56|0,a,1)|0]){e=v[v[a>>2]-12>>2];v[114578]=0;e=v[(a+e|0)+24>>2];f=v[114578];v[114578]=0;c:{d:{if((f|0)==1){break d}v[114578]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;X(2387,c+40|0,e|0,c+8|0,8);b=v[114578];v[114578]=0;if((b|0)==1){break d}b=Og(c+24|0,-1,-1);v[114578]=0;b=MS(c+40|0,b);e=v[114578];v[114578]=0;if((e|0)==1){break d}b=b?d|4:d;break c}b=V(0)|0;O()|0;_(b|0)|0;b=d|1;ej(v[v[a>>2]-12>>2]+a|0,b);d=v[v[a>>2]-12>>2];v[114578]=0;d=v[(a+d|0)+20>>2];e=v[114578];v[114578]=0;e:{if((e|0)!=1){if(!(d&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,b)}jb=c- -64|0;return}V(0)|0;O()|0;Ab()}L()}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-16|0;jb=h;f=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];b=v[a+44>>2];p=v[a+16>>2];i=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=i;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){j=u[(i<<1)+p>>1];g=v[a+60>>2];k=g;e=Yb(b,-16777216,16776704);m=v[a+64>>2];i=Yb(f,-16777216,16776704);q=v[a+72>>2];f=v[c>>2];l=g>>31;j=j<<8;g=j;g=Fma(k,l,g,g>>31);k=mb;l=c;r=f;f=g;g=Fma(m,m>>31,e,e>>31);e=f+g|0;f=mb+k|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=v[a+68>>2];i=Fma(e,e>>31,i,i>>31);e=g+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[l>>2]=r+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=f-(j&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+12>>2];f=b;b=e;continue}break}j=v[h+8>>2];i=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=i;jb=h+16|0}function zga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;v[f>>2]=c;v[f+8>>2]=b;if(Jb(f+8|0,f)){while(1){b=d;g=jb-16|0;jb=g;c=v[f+8>>2];if(!(w[c+3|0]!=4|w[c+5|0])){ee(g+8|0,b,x[b+14>>1]);ge(g+8|0,0);t[c+3|0]=0}e=w[c+2|0];a:{if((e|0)!=11){break a}e=11;if(w[c+4|0]){break a}ee(g+8|0,b,x[b+14>>1]);e=0;ge(g+8|0,0);t[c+2|0]=0}b:{c:{d:{if(!w[c|0]){ee(g+8|0,b,x[b+14>>1]);if(Cb(g+8|0)){break d}e=w[c+2|0]}h=w[c+3|0];ee(g+8|0,b,x[b+14>>1]);ge(g+8|0,(h|0)==4|(e|0)==11);e=w[c+3|0];break c}e=w[c+3|0];h=w[c+2|0];if(!(e|(h|0)==11)){t[c+5|0]=0;t[c+3|0]=4;break b}if(h|(e|0)==4){break c}t[c+4|0]=0;t[c+2|0]=11}e:{if(!(!w[b+16|0]|e)){t[c+5|0]=125;t[c+3|0]=17;break e}f:{switch(e-16|0){case 1:break e;case 0:break f;default:break b}}if(w[c+5|0]){break b}t[c+5|0]=6;t[b+16|0]=1;break b}t[b+16|0]=0}u[b+14>>1]=(x[b+14>>1]+1>>>0)%x[b+12>>1];jb=g+16|0;Cj(f+8|0);if(Jb(f+8|0,f)){continue}break}}NO(a,d);jb=f+16|0}function mF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-32|0;jb=h;f=d&2147483647;g=f;e=f-1065418752|0;i=f-1082064896|0;f=c;a:{if((e|0)==(i|0)&f>>>0<f>>>0|e>>>0<i>>>0){g=(d&33554431)<<7|c>>>25;f=0;j=f;i=c&33554431;if(!(!f&(i|0)==16777216?!(a|b):!f&i>>>0<16777216)){e=g+1073741825|0;break a}e=g+1073741824|0;if(i^16777216|a|(b|j)){break a}e=(g&1)+e|0;break a}if(!(!f&(g|0)==2147418112?!(a|b):g>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(g>>>0>1082064895){break a}e=0;f=g>>>16|0;if(f>>>0<16145){break a}g=c;e=d&65535|65536;qf(h+16|0,a,b,g,e,f-16129|0);Fm(h,a,b,g,e,16257-f|0);b=v[h+8>>2];e=(v[h+12>>2]&33554431)<<7|b>>>25;g=v[h+4>>2];f=g;a=0;i=a;j=v[h>>2]|((v[h+16>>2]|v[h+24>>2])!=0|(v[h+20>>2]|v[h+28>>2])!=0);b=b&33554431;if(!(!a&(b|0)==16777216?!(f|j):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|j|(f|i)){break a}e=(e&1)+e|0}jb=h+32|0;return l(2,d&-2147483648|e),q()}function Kw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];g=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=g;g=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=g;Eh(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);g=v[v[a+12>>2]>>2];j=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;k=c+16|0;a=c;d=jb-16|0;jb=d;if(g){l=b+4|0;while(1){e=0;if(j){while(1){f=A[ch(a,e,h)>>3];fc(b,e);m=d,n=+(sj(Sd(f*134217728))-1024+((Kr(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,A[m+8>>3]=n;Rf(d+8|0,-1,1);f=A[d+8>>3]*32768;A[d+8>>3]=f;f=Sd(f);a:{if(D(f)<2147483648){i=~~f;break a}i=-2147483648}i=Vc(i);m=Mm(k,e,h),o=i,u[m>>1]=o;e=e+1|0;if((j|0)!=(e|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=d+16|0;jb=c+80|0}function Xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-16|0;jb=h;f=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];b=v[a+44>>2];p=v[a+16>>2];i=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=i;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){j=t[i+p|0];g=v[a+60>>2];k=g;e=Yb(b,-16777216,16776704);m=v[a+64>>2];i=Yb(f,-16777216,16776704);q=v[a+72>>2];f=v[c>>2];l=g>>31;j=j<<16;g=j;g=Fma(k,l,g,g>>31);k=mb;l=c;r=f;f=g;g=Fma(m,m>>31,e,e>>31);e=f+g|0;f=mb+k|0;f=e>>>0<g>>>0?f+1|0:f;g=e;e=v[a+68>>2];i=Fma(e,e>>31,i,i>>31);e=g+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;if(e>>>0<8388608){f=f+1|0}f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[l>>2]=r+B(e,o);v[c+4>>2]=v[c+4>>2]+B(e,n);e=f-(j&q)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+12>>2];f=b;b=e;continue}break}j=v[h+8>>2];i=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=i;jb=h+16|0}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=4;u[e+12>>1]=0;v[e+8>>2]=0;if(d){l=B(c,d);m=(l|0)<1;c=0;while(1){if(!m){i=b+k|0;n=l+i|0;while(1){o=c;t[e+7|0]=0;EQ(a,e+14|0,e+12|0,e+7|0);a:{b:{h=w[e+15|0];if(!h){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;g=(f&65534)>>>0>255;t[e+14|0]=g;f=e;if(!c){if(!Je(a,e+6|0)){break b}g=w[e+6|0];c=g<<1&254|1;u[e+12>>1]=c;g=g>>>7|0}j=w[e+7|0]<<1|g;t[f+7|0]=j;h=h-1|0;if(h&255){continue}break}break a}j=w[e+7|0]}c=1;g=j&255;c:{if(g>>>0<4){break c}h=7;while(1){c=h;f=c&255;if(f>>>0<2){break c}h=c-1|0;if(!(1<<f&g)){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;f=c-1^(j&254)>>>1;c=f+w[e+8|0]|0;t[e+7|0]=c;t[i|0]=c;v[e+8>>2]=((f>>1)-(o<<24>>24)|0)+(c<<24>>24<<1);ce(e+8|0,-128,127);i=d+i|0;if(n>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-80|0;jb=d;Le(b);a:{b:{if(Qb(a,1)){c:{d:{e:{f:{g:{h:{while(1){v[114578]=0;e=W(602,a|0,d+16|0,64)|0;f=v[114578];v[114578]=0;if((f|0)==1){break e}v[d+8>>2]=e;e=Fb(b);v[114578]=0;v[d+4>>2]=c-e;e=Q(33,d+8|0,d+4|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break h}e=v[e>>2];if(!e){break c}t[d+8|0]=0;f=e+(d+16|0)|0;e=Sm(d+16|0,f,d+8|0);h=d,i=sf(b),v[h+8>>2]=i;Md(d,d+8|0);v[114578]=0;aa(603,b|0,v[d>>2],d+16|0,e|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break g}v[114578]=0;Q(340,a|0,e-(d+16|0)|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}if(e>>>0>=f>>>0){continue}break}v[114578]=0;Q(340,a|0,1)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break c}a=V(71204)|0;break d}a=V(71204)|0;break d}a=V(71204)|0;break d}a=V(71204)|0;break d}a=V(71204)|0}if((O()|0)!=(ga(71204)|0)){break b}_(a|0)|0;$()}e=(Fb(b)|0)!=0}jb=d+80|0;break a}S(a|0);L()}return e|0}function NK(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;t[k+15|0]=c;t[k+14|0]=12;gg(b,w[pc(k+15|0,k+14|0)|0]);if(Kb(b)){c=0;l=a+96|0;a=a+144|0;while(1){a:{b:{c:{switch(h|0){case 0:i=c<<2;j=i+l|0;j=w[j|0]|w[j+1|0]<<8;n=Pb(b,c),o=j,u[n>>1]=o;i=(i|2)+l|0;break b;case 1:break c;default:break a}}i=c<<2;j=i+a|0;j=w[j|0]|w[j+1|0]<<8;n=Pb(b,c),o=j,u[n>>1]=o;i=a+(i|2)|0}i=w[i|0];n=Pb(b,c),o=i,t[n+2|0]=o}d:{if(!c){break d}i=c-1|0;if(x[Pb(b,c)>>1]>=x[Pb(b,i)>>1]){break d}if(x[Pb(b,c)>>1]>255){break d}j=w[Pb(b,i)+1|0];m=Pb(b,c);u[m>>1]=x[m>>1]|j<<8;if(x[Pb(b,c)>>1]>=x[Pb(b,i)>>1]){break d}i=Pb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Kb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(nd(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}jb=k+16|0}function PO(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+17520|0];a:{b:{c:{switch(d|0){case 0:if(w[b|0]?c>>>0>=51:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&240)!=32?(d&15)!=2:0)){t[a|0]=20;t[b|0]=159;d=159}if(!((d&15)==12|(d&240)==192)|c>>>0<51){break b}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:d:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break d;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;k=c;e=jb-32|0;jb=e;j=b;f=b;b=Ke(b);d=hc(f);a:{b:{if(b){c:{while(1){d:{g=b+14|0;e:{if(Xn(zb(f),c,g)){if(!v[b>>2]){break b}d=b;break e}if(!Xn(zb(f),g,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=hc(f)}v[e+28>>2]=b}c=b;b=v[b>>2];t[e+27|0]=0;if(!b){f=jb-16|0;jb=f;g=hc(j);b=sc(16,4);i=Ck(f+8|0,g);d=jb-16|0;jb=d;v[d+12>>2]=b;v[114578]=0;b=e+8|0;W(1168,b|0,d+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=d+16|0;break f}V(0)|0;O()|0;Ab();L()}d=v[b>>2]+14|0;v[114578]=0;U(1167,g|0,d|0,k|0);d=v[114578];v[114578]=0;g:{if((d|0)!=1){l=hc(b),m=1,t[l+4|0]=m;jb=f+16|0;break g}a=P()|0;O()|0;gO(b);S(a|0);L()}Dk(j,v[e+28>>2],c,v[e+8>>2]);b=Nd(e+8|0);t[e+27|0]=1;gO(e+8|0)}Ei(h+8|0,Qc(e+8|0,b),e+27|0);jb=e+32|0;iO(a,h+8|0);jb=h+16|0}function XH(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=jb-80|0;jb=e;g=a+24|0;So(v[g>>2]);t[v[g>>2]+1304512|0]=v[a+52>>2]!=0;c=me(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;h=e+48|0;c=h;Nr(c);v[c+8>>2]=f;v[c+4>>2]=0;v[c>>2]=84056;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=84008;jb=d+16|0;a:{b:{if(b){c=0;while(1){d=v[g>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114578]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;f=Q(2153,e+24|0,e+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}f=v[f>>2];v[114578]=0;d=W(2154,d|0,f|0,h|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}c=c+d|0;if(d){b=b-d|0;if(b){continue}}break}if(c){break b}}c=0;if(v[a+52>>2]!=1){break b}a=v[g>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=e+80|0;return c}a=P()|0;O()|0;S(a|0);L()}function WH(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=jb-80|0;jb=e;g=a+24|0;So(v[g>>2]);t[v[g>>2]+1304512|0]=v[a+52>>2]!=0;c=me(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;h=e+48|0;c=h;Nr(c);v[c+8>>2]=f;v[c+4>>2]=0;v[c>>2]=84128;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=84080;jb=d+16|0;a:{b:{if(b){c=0;while(1){d=v[g>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114578]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;f=Q(2153,e+24|0,e+16|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break a}f=v[f>>2];v[114578]=0;d=W(2154,d|0,f|0,h|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}c=c+d|0;if(d){b=b-d|0;if(b){continue}}break}if(c){break b}}c=0;if(v[a+52>>2]!=1){break b}a=v[g>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=e+80|0;return c}a=P()|0;O()|0;S(a|0);L()}function Oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;k=c;e=jb-32|0;jb=e;j=b;f=b;b=Ke(b);d=hc(f);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(RK(zb(f),c,g)){if(!v[b>>2]){break b}d=b;break e}if(!RK(zb(f),g,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d;d=b}b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=hc(f)}v[e+28>>2]=b}c=b;b=v[b>>2];t[e+27|0]=0;if(!b){f=jb-16|0;jb=f;g=hc(j);b=sc(28,4);i=Ck(f+8|0,g);d=jb-16|0;jb=d;v[d+12>>2]=b;v[114578]=0;b=e+8|0;W(1528,b|0,d+12|0,i|0)|0;i=v[114578];v[114578]=0;f:{if((i|0)!=1){jb=d+16|0;break f}V(0)|0;O()|0;Ab();L()}d=v[b>>2]+16|0;v[114578]=0;U(1527,g|0,d|0,k|0);d=v[114578];v[114578]=0;g:{if((d|0)!=1){l=hc(b),m=1,t[l+4|0]=m;jb=f+16|0;break g}a=P()|0;O()|0;QK(b);S(a|0);L()}Dk(j,v[e+28>>2],c,v[e+8>>2]);b=Nd(e+8|0);t[e+27|0]=1;QK(e+8|0)}Ei(h+8|0,Qc(e+8|0,b),e+27|0);jb=e+32|0;iO(a,h+8|0);jb=h+16|0}function $J(a,b,c){var d=0;a:{b:{switch(b|0){case 0:LJ(a,c);return;case 1:b=0;a=tf(a);d=Fb(c);v[114578]=0;R(113,a|0,d|0);d=v[114578];v[114578]=0;c:{if((d|0)!=1){d:{if(Fb(c)){while(1){d=t[kc(c,b)|0];e:{if((d|0)>=0){v[114578]=0;R(112,a|0,d&255);d=v[114578];v[114578]=0;if((d|0)!=1){break e}break d}v[114578]=0;R(112,a|0,65533);d=v[114578];v[114578]=0;if((d|0)==1){break d}}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break c}}break a}return;case 2:b=0;a=tf(a);d=Fb(c);v[114578]=0;R(113,a|0,d|0);d=v[114578];v[114578]=0;f:{if((d|0)!=1){g:{if(Fb(c)){while(1){d=w[kc(c,b)|0];v[114578]=0;R(112,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}b=b+1|0;if(Fb(c)>>>0>b>>>0){continue}break}}break f}}break a}return;case 3:Jo(a,c,1520);return;case 4:Jo(a,c,2544);return;case 5:Jo(a,c,3568);return;case 6:Jo(a,c,4592);return;case 7:Jo(a,c,5616);return;default:break b}}tf(a);return}b=P()|0;O()|0;Lc(a);S(b|0);L()}function Q4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114578]=0;Z(2088,a|0);e=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[114578]=0;Z(2041,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break e}e=0;v[114578]=0;Z(2089,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}a=Rb(c,0,d);if(!w[b|0]){break b}if(ji(b,37350)|(d|0)!=8){break d}v[a+4>>2]=2090;v[a>>2]=2091;break c}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37374,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();return 0}if(ji(b,37362)|(d|0)!=64){break b}v[a+60>>2]=2092;v[a+56>>2]=2093;v[a+52>>2]=2094;v[a+48>>2]=2095;v[a+44>>2]=2096;v[a+40>>2]=2097;v[a+36>>2]=2098;v[a+32>>2]=2099;v[a+28>>2]=2100;v[a+24>>2]=2101;v[a+20>>2]=2102;v[a+16>>2]=2103;v[a+12>>2]=2104;v[a+8>>2]=2105;v[a+4>>2]=2106;v[a>>2]=2107}e=1}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function $3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;iI(c+24|0);gI(a+24|0,Nd(c+24|0));Gh(c+24|0);u[a+28>>1]=0;e=c+24|0;f=UL();d=Pe(44);v[114578]=0;f=Q(2135,d|0,f|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){d=jb-16|0;jb=d;v[114578]=0;v[d+12>>2]=f;W(2139,e|0,d+12|0,d+8|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;Xb(d);S(a|0);L()}Hs(a+32|0,c+24|0);wf(c+24|0);hI(c+24|0,v[a>>2]);tI(a+4|0,Nd(c+24|0));Yc(c+24|0);Om(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;h=c,i=vn(b),v[h+24>>2]=i;h=c,i=Hi(b),v[h+16>>2]=i;b:{if(Gi(c+24|0,c+16|0)){while(1){d=jh(c+24|0);b=Af(c,d);v[114578]=0;X(2081,a|0,b|0,d+12|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break b}yb(b);Bp(c+24|0);if(Gi(c+24|0,c+16|0)){continue}break}}jb=c+32|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function m2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f>>2]=c;v[f+8>>2]=b;Dq(v[f+8>>2]);c=jb-32|0;jb=c;v[c+24>>2]=v[f>>2];b=v[c+24>>2];d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=jb-16|0;jb=e;b=v[c+20>>2];v[e+8>>2]=v[c+16>>2];v[e+12>>2]=b;b=v[c+12>>2];v[e>>2]=v[c+8>>2];v[e+4>>2]=b;d=VP(e);b=a;Kp(b);t[b+8|0]=0;v[b+4>>2]=d;v[b>>2]=76256;d=Oi(b+12|0);t[b+24|0]=0;v[114578]=0;Q(35,b+28|0,0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){d=b+40|0;g=d+192|0;while(1){v[d>>2]=0;v[d+4>>2]=0;t[d+8|0]=0;d=d+12|0;if((g|0)!=(d|0)){continue}break}if(w[b+24|0]){b=b+232|0;d=0;while(1){h=Ve(b,d),i=d,v[h>>2]=i;d=d+1|0;if((d|0)!=16){continue}break}}break a}a=P()|0;O()|0;Pg(d);S(a|0);L()}v[a>>2]=76372;b=v[c+12>>2];v[a+296>>2]=v[c+8>>2];v[a+300>>2]=b;b=v[c+20>>2];v[a+304>>2]=v[c+16>>2];v[a+308>>2]=b;jb=e+16|0;jb=c+32|0;jb=f+16|0;return a|0}function aG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[zf(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;b:{while(1){if((d|0)!=(h|0)){f=ur(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(_F(v[a+36>>2],g,c+24|0,d,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=ur(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((vr(Cg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}j=a,k=Cg(t[c+23|0]),v[j+48>>2]=k}d=Cg(t[c+23|0]);break a}d=-1}jb=c+32|0;return d}function B7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=C(0),s=C(0),t=C(0),u=0,x=0,y=C(0);f=jb-16|0;jb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!rh(g)){break a}t=z[a+4220>>2];u=f,x=Pd(g,0),v[u+8>>2]=x;u=f,x=Pd(g,1),v[u+12>>2]=x;u=f,x=jd(g,0),v[u>>2]=x;u=f,x=jd(g,1),v[u+4>>2]=x;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;e=v[a+4244>>2]-v[((n<<2)+a|0)+4248>>2]|0;if((e|0)<=-1){e=v[a+4240>>2]+e|0}o=h<<2;p=o+(f+8|0)|0;q=v[p>>2];v[p>>2]=q+4;l=z[q>>2];r=z[Pb(m,(e<<1)+n|0)>>2];s=C(C(z[a+4224>>2]*r)+C(l*z[a+4260>>2]));u=Pb(m,v[a+4244>>2]<<1|h),y=C(D(s))<C(1.0000000195414814e-24)?C(0):s,z[u>>2]=y;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l+C(C(r-l)*t);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}pi(a,b,c,jd(g,0),jd(g,1),d)}jb=f+16|0}function aM(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=b;f=0;a:{if(!b){break a}if(v[a+480180>>2]&20){b=a+1074308|0;Eb(e,b,73);if(Cb(e)){v[e+12>>2]=x[e+12>>1]}if(w[a+480208|0]&16){Eb(e,b,73);b=Cb(e);a=v[e+12>>2];f=v[((a>>>0)%768<<2)+22112>>2]<<6>>>(b?14-((9983-a>>>0)/768|0)&31:((a>>>0)/768|0)+2|0)|0;break a}a=v[e+12>>2];if(!a){v[e+12>>2]=1;a=1}f=229079296/(a>>>0)|0;break a}f=227001280/(b>>>0)|0;if(Lp(a)){break a}f=(b+c<<4)-133808|0;if(v[a+480180>>2]==64){break a}b=v[a+480180>>2];Cc(e+12|0,16777215);if(b&17408){f=id(Ima(Fma(c?c:8363,0,3506176,0),mb,(v[e+12>>2]<<8)+d|0,0),mb);break a}if(w[a+480208|0]&16){Eb(e,a+1074308|0,7);if(Cb(e)){c=d>>31;b=d;a=v[e+12>>2];d=a>>>24|0;f=a<<8;b=b+f|0;a=c+d|0;a=b>>>0<f>>>0?a+1|0:a;f=(a&15)<<28|b>>>4;break a}f=id(Ima(Fma(c?c:8363,0,7012352,0),mb,(v[e+12>>2]<<8)+d|0,0),mb);break a}f=id(Ima(-1485242368,13,(v[e+12>>2]<<8)+d|0,0),mb)}jb=e+16|0;return f}function LJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=tf(a);f=d,g=Ed(b),v[f+8>>2]=g;f=d,g=sf(b),v[f>>2]=g;a:{b:{if(!Jb(d+8|0,d)){break b}a=0;b=0;while(1){c=w[v[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;v[114578]=0;R(112,e|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;v[114578]=0;R(112,e|0,65533);c=v[114578];v[114578]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){v[114578]=0;R(112,e|0,65533);a=v[114578];v[114578]=0;if((a|0)==1){break a}b=c&63;a=-1;break c}c=c&63|b<<6;a=a-1|0;if(a){b=c;break c}b=0;v[114578]=0;R(112,e|0,c|0);c=v[114578];v[114578]=0;a=0;if((c|0)==1){break a}}qg(d+8|0);if(Jb(d+8|0,d)){continue}break}if(!a){break b}v[114578]=0;R(112,e|0,65533);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}jb=d+16|0;return}a=P()|0;O()|0;Lc(e);S(a|0);L()}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=(g>>>21&2040)+27888|0;g=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;jb=e+32|0}function b0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[gj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;d=T(2377,c+16|0)|0;e=v[114578];v[114578]=0;d:{e:{f:{g:{if((e|0)==1){break g}e=Cm(c+8|0,a);f=Gk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114578]=0;ka(2380,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break g}Ob(c+16|0);break f}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ej(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];d=v[114578];v[114578]=0;if((d|0)!=1){if(!(b&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function fW(){var a=0,b=0,c=0,d=0;c=jb-32|0;jb=c;a:{a=Ub(c+16|0,10940);if(!Fb(a)){break a}b:{if((Yf(a,10946)|0)!=-1){b=Yf(a,10946);v[114578]=0;X(232,c|0,a|0,b+1|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Yf(a,10948)|0)!=-1){b=Yf(a,10948);v[114578]=0;X(232,c|0,a|0,b+1|0,-1);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Yf(a,10950)|0)!=-1){b=Yf(a,10950);v[114578]=0;X(232,c|0,a|0,0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Yf(a,10952)|0)!=-1){b=Yf(a,10952);v[114578]=0;X(232,c|0,a|0,0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if((Yf(a,10954)|0)!=-1){b=Yf(a,10954);v[114578]=0;X(232,c|0,a|0,0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}v[114578]=0;b=T(233,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;yb(a);S(c|0);L()}yb(a);jb=c+32|0;return b|0}function c5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){d=Wb(b+32|0);c=v[a+24>>2];v[114578]=0;R(2075,b+16|0,c|0);c=v[114578];v[114578]=0;d:{if((c|0)!=1){e=b,f=bc(b+16|0),v[e+8>>2]=f;e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[114578]=0;Q(1250,d|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}zn(b+8|0);e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}v[114578]=0;Q(1995,d|0,34201)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;ld(b+16|0);break d}c=V(0)|0;O()|0}yb(d);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[114578]=0;X(1989,36905,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}c=Zd(Tb(d));ld(b+16|0);yb(d)}jb=b+48|0;return c|0}function L5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)!=1){d=Wb(b+32|0);c=v[a+24>>2];v[114578]=0;R(2040,b+16|0,c|0);c=v[114578];v[114578]=0;d:{if((c|0)!=1){e=b,f=bc(b+16|0),v[e+8>>2]=f;e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}while(1){e:{c=v[b+8>>2];v[114578]=0;Q(1250,d|0,c|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break e}zn(b+8|0);e=b,f=cc(b+16|0),v[e>>2]=f;if(!Jb(b+8|0,b)){break b}v[114578]=0;Q(1995,d|0,34201)|0;c=v[114578];v[114578]=0;if((c|0)!=1){continue}}break}c=V(0)|0;O()|0;ld(b+16|0);break d}c=V(0)|0;O()|0}yb(d);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[114578]=0;X(1989,35662,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}c=Zd(Tb(d));ld(b+16|0);yb(d)}jb=b+48|0;return c|0}function ll(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;dk(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){d=v[b+2084>>2];if(d){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}d=v[b+2084>>2];if(!d){break c}}h=v[a+1392>>2];j=kl(h);e=v[b+2092>>2];if((e|0)>=2){while(1){f=e>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+d>>2];c=g?c:i;e=g?f:e-f|0;if((e|0)>1){continue}break}}e=a;d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;a=0;break e}v[a+1392>>2]=h>>>b;a=d-b|0}v[e+1396>>2]=a;return c}if(w[b+23|0]){break a}if((f|0)>=1){d=v[b+8>>2];while(1){f:{e=w[c+d|0];if((e|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<e^-1))){break f}d=v[a+1396>>2];if((d|0)>=(e|0)){v[a+1392>>2]=h>>>e;v[a+1396>>2]=d-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}dc(a,21);v[a+1396>>2]=0}return-1}ha(50714,50496,1690,50725);L()}function YF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[zf(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;b:{while(1){if((d|0)!=(h|0)){f=ur(v[a+32>>2]);if((f|0)==-1){break b}t[(c+24|0)+d|0]=f;d=d+1|0;continue}break}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];f=v[d>>2];i=v[d+4>>2];e:{g=d;d=(c+24|0)+e|0;switch(_F(v[a+36>>2],g,c+24|0,d,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}g=v[a+40>>2];v[g>>2]=f;v[g+4>>2]=i;if((e|0)==8){break b}f=ur(v[a+32>>2]);if((f|0)==-1){break b}t[d|0]=f;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<1){break f}e=e-1|0;if((vr(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}jb=c+32|0;return d}function Oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=jb-112|0;jb=j;a:{b:{if(!De(a)){break b}if(wc(b)>>>0<2){break b}f=Oy(j+8|0,a);v[f+20>>2]=0;v[f>>2]=0;d=wc(b);c:{if(!d){break c}while(1){c=sd(b,g);e=v[a>>2];h=v[c>>2];if(e>>>0<=h>>>0){break c}c=v[c+4>>2];if(c>>>0>e-h>>>0){break c}e=v[f>>2];if(e>>>0>268435456-c>>>0){break c}v[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!Zs(f)){break b}if(g){d=0;c=0;while(1){e=sd(b,d);h=v[f+20>>2];v[114578]=0;h=T(467,h|0)|0;i=v[114578];v[114578]=0;if((i|0)==1){break a}i=v[a+20>>2];v[114578]=0;i=T(467,i|0)|0;k=v[114578];v[114578]=0;if((k|0)==1){break a}lc(c+h|0,i+v[e>>2]|0,v[e+4>>2]);v[e>>2]=c;if(!(!d|d>>>0>9)){v[((d<<2)+f|0)- -64>>2]=c}c=v[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}}on(a);Oy(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}jb=j+112|0;return}V(0)|0;O()|0;Ab();L()}function rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=(h>>>21&2040)+27888|0;h=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;jb=e+32|0}function z9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+24>>2]=d;i=Mj(a,c);pf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!i){if(xd(a,5)){break a}}k=v[e+24>>2];d=jb-48|0;jb=d;h=v[a+28>>2];Nj(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>256|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){xf(h,d+38|0);f=Wb(d+24|0);v[114578]=0;W(724,h|0,f|0,255)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[114578]=0;U(13,d+8|0,k|0,f|0);g=v[114578];v[114578]=0;if((g|0)==1){break e}v[114578]=0;g=Q(1618,b|0,d+38|0)|0;l=v[114578];v[114578]=0;if((l|0)==1){break d}Gb(g,d+8|0);yb(d+8|0);yb(f);f=v[d+44>>2];j=j+1|0;if(!f&j>>>0<y[d+40>>2]|f){continue}break}}jb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+8|0)}yb(f);S(a|0);L()}}Zi(a,i,c,e+16|0);jb=e+32|0}function ey(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=B(d,896)+a|0;c=e+1075060|0;b:{if(v[c>>2]){break b}if(!nj(e+1074984|0)){break a}if(v[c>>2]){break b}if(w[e+1075073|0]&24){break a}}if(w[e+1075073|0]&2){if(!rd(f)){break a}if(!xM(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,896)+a|0;if(!v[b+1075680>>2]){d=65535;if(v[b+1075060>>2]){break a}}g=v[b+1075672>>2]|v[b+1075664>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,896)+a|0;if(!(v[c+1075680>>2]?0:v[c+1075060>>2])){f=(v[c+1075672>>2]|v[c+1075664>>2]<<9)>>>(v[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075712>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function Hw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];g=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=g;Lm(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);g=v[v[a+12>>2]>>2];j=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;k=c+16|0;a=c;d=jb-16|0;jb=d;if(g){l=b+4|0;while(1){e=0;if(j){while(1){f=A[ch(a,e,h)>>3];fc(b,e);m=d,n=+(sj(Sd(f*134217728))-1024+((Kr(l)^-2147483648)>>>21)|0)*7.450580596923828e-9,A[m+8>>3]=n;Rf(d+8|0,-1,1);f=A[d+8>>3]*32768;A[d+8>>3]=f;f=Sd(f);a:{if(D(f)<2147483648){i=~~f;break a}i=-2147483648}i=Vc(i);m=Km(k,e,h),o=i,u[m>>1]=o;e=e+1|0;if((j|0)!=(e|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=d+16|0;jb=c+80|0}function Sv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=$e(a);a:{if(!v[115363]|!w[a|0]){break a}b=a;b:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break b}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];c:{if((c^-1)&c-16843009&-2139062144){break c}while(1){c=c^1027423549;if((c^-1)&c-16843009&-2139062144){break c}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;d=w[b|0];if(d){b=c+1|0;if((d|0)!=61){continue}}break}b=c}if(w[b|0]==61?b:0){break a}e=v[v[115363]>>2];if(!e){break a}d:{while(1){h=v[115363];b=a;c=g;d=0;e:{if(!c){break e}d=w[b|0];f:{if(d){while(1){c=c-1|0;if(!c){break f}i=w[e|0];if(!i){break f}g:{if((d|0)==(i|0)){break g}break f}e=e+1|0;d=w[b+1|0];b=b+1|0;if(d){continue}break}}d=0}d=d-w[e|0]|0}if(!d){b=v[(f<<2)+h>>2]+g|0;if(w[b|0]==61){break d}}f=f+1|0;e=v[(f<<2)+h>>2];if(e){continue}break}return 0}f=b+1|0}return f}function mr(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;c=v[v[a>>2]-12>>2];v[114578]=0;c=v[(a+c|0)+24>>2];b=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[114578]=0;c=Q(15,d+8|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+24>>2];e=v[114578];v[114578]=0;f:{if((e|0)==1){break f}v[114578]=0;b=T(2376,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Hf(c);break c}b=V(0)|0;O()|0;break c}Hf(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function QG(a,b,c,d){var e=0,f=0,g=0,h=C(0),i=0,j=C(0),k=0,l=C(0),m=C(0),n=C(0),o=0;e=jb-96|0;jb=e;if((d|0)>=1){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){g=f<<3;i=f<<4;j=z[(i|8)+a>>2];h=z[(i|4)+a>>2];z[(e+48|0)+(g|4)>>2]=j+h;k=f<<1;z[(8-k<<2)+e>>2]=h-j;j=z[(a+i|0)+16>>2];h=z[(i|12)+a>>2];z[(7-k<<2)+e>>2]=j-h;z[(e+g|0)+56>>2]=-C(h+j);f=f+1|0;if((f|0)!=4){continue}break}PG(e+48|0);PG(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=z[g>>2];k=g;h=z[f+48928>>2];l=z[f+(e+48|0)>>2];m=z[e+f>>2];g=f+36|0;n=z[g+48928>>2];z[k>>2]=C(h*l)-C(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=C(C(h*m)+C(n*l));z[k>>2]=C(j*z[f>>2])-C(z[g>>2]*h);z[(17-i<<2)+a>>2]=C(z[f>>2]*h)+C(j*z[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}jb=e+96|0}function q5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2061,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(wc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2062,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2009,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((wc(d)|0)<=(b|0)){break j}a=Tb(sd(d,b))}b=Zd(a);ld(d);break d}b=V(0)|0;O()|0;ca(c|0)}ld(d)}_(b|0)|0;b=0;v[114578]=0;X(1989,36407,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function p5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2063,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(wc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2062,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2009,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((wc(d)|0)<=(b|0)){break j}a=Tb(sd(d,b))}b=Zd(a);ld(d);break d}b=V(0)|0;O()|0;ca(c|0)}ld(d)}_(b|0)|0;b=0;v[114578]=0;X(1989,36439,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function o5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2064,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(wc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2062,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2009,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((wc(d)|0)<=(b|0)){break j}a=Tb(sd(d,b))}b=Zd(a);ld(d);break d}b=V(0)|0;O()|0;ca(c|0)}ld(d)}_(b|0)|0;b=0;v[114578]=0;X(1989,36471,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function n5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2065,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(wc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2062,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2009,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((wc(d)|0)<=(b|0)){break j}a=Tb(sd(d,b))}b=Zd(a);ld(d);break d}b=V(0)|0;O()|0;ca(c|0)}ld(d)}_(b|0)|0;b=0;v[114578]=0;X(1989,36501,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function m5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2066,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(wc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2062,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2009,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((wc(d)|0)<=(b|0)){break j}a=Tb(sd(d,b))}b=Zd(a);ld(d);break d}b=V(0)|0;O()|0;ca(c|0)}ld(d)}_(b|0)|0;b=0;v[114578]=0;X(1989,36533,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function l5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2067,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break i}if(wc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114578]=0;Q(2062,c|0,36392)|0;b=v[114578];v[114578]=0;if((b|0)==1){break g}v[114578]=0;U(2009,c|0,71532,265);b=v[114578];v[114578]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=34181;j:{if((b|0)<0){break j}a=34181;if((wc(d)|0)<=(b|0)){break j}a=Tb(sd(d,b))}b=Zd(a);ld(d);break d}b=V(0)|0;O()|0;ca(c|0)}ld(d)}_(b|0)|0;b=0;v[114578]=0;X(1989,36568,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break c}$()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[114578]=0;Z(2041,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;Z(2041,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}d=v[a+24>>2];v[114578]=0;b=Q(85,e+16|0,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break g}v[114578]=0;c=Q(85,e|0,c|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;X(2081,d|0,b|0,c|0,1);d=v[114578];v[114578]=0;if((d|0)==1){break e}yb(c);yb(b);b=1;break b}d=V(0)|0;O()|0;break c}d=V(0)|0;O()|0;break d}d=V(0)|0;O()|0;yb(c)}yb(b)}_(d|0)|0;b=0;v[114578]=0;X(1989,37079,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=e+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function LF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;v[114578]=0;g=Q(15,d+24|0,a|0)|0;e=v[114578];v[114578]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=Sk(d+8|0,a);h=v[(v[v[a>>2]-12>>2]+a|0)+4>>2];f=v[v[a>>2]-12>>2];v[114578]=0;f=a+f|0;i=T(16,f|0)|0;j=v[114578];v[114578]=0;if((j|0)==1){break d}e=v[e>>2];v[114578]=0;c=b+c|0;b=ka(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Qk(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,5);b=v[114578];v[114578]=0;if((b|0)!=1){break e}break d}Hf(g);break b}b=V(0)|0;O()|0;Hf(g);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}$()}jb=d+32|0;return a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){V(0)|0;O()|0;Ab();L()}S(a|0);L()}function hM(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)|!(c&255)){break b}d=v[b+700>>2];if(!d){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}c=_x(a,c&15);f=Fma(c,c>>31,d,d>>31)+32768|0;c=mb;c=yc(Gma(f,f>>>0<32768?c+1|0:c,65536,0),mb);v[b+700>>2]=c;if((c|0)!=(d|0)){break b}a=a+1074308|0;Eb(e+8|0,a,7);if(!(!Cb(e+8|0)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break b}Eb(e+8|0,a,7);if(Cb(e+8|0)){break b}a=v[b+700>>2];if((a|0)<2){break b}v[b+700>>2]=a-1;break b}c=d-((c&255)<<2)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=e+16|0}function FL(a,b){var c=0;c=jb-16|0;jb=c;a=Wx(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(a,7,1);Nb(a,9,1);Nb(a,10,1);Nb(a,13,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,20,1);Nb(a,21,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,28,1);Nb(a,30,1);Nb(a,31,1);Nb(a,33,1);Nb(a,34,1);Nb(a,39,1);Nb(a,41,1);Nb(a,44,1);Nb(a,46,1);Nb(a,45,1);Nb(a,47,1);Nb(a,48,1);Nb(a,50,1);Nb(a,99,1);Nb(a,102,1);Nb(a,104,1);Nb(a,105,1);Nb(a,108,1);break a;case 1:Sx(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;wg(a,107);break a;case 3:Sx(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;wg(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}Sx(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}jb=c+16|0}function tQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}b=w[d+42|0]|w[d+43|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>32768){break a}b=w[d+42|0]|w[d+43|0]<<8;h=((b<<8|b>>>8)&65535)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}e=jb-16|0;jb=e;b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}jb=e+16|0;b=w[b|0];if(b>>>0>63|(b|w[a+470|0]?0:!w[a+471|0])){break a}k=1}return k}function d0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[gj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2377,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Cm(c+8|0,a);f=Gk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2378,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ej(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function Zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);while(1){if((l|0)>=1){i=(k<<1)+b|0;n=i+(l<<1)|0;while(1){u[e+10>>1]=0;FQ(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){h=c<<1;c=h&254;u[e+12>>1]=c;f=(h&65534)>>>0>255;t[e+14|0]=f;h=e;if(!c){if(!Je(a,e+9|0)){break b}f=w[e+9|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}j=x[e+10>>1]<<1|f;u[h+10>>1]=j;g=g-1|0;if(g&255){continue}break}break a}j=x[e+10>>1]}c=1;g=j&65535;c:{if(g>>>0<4){break c}h=15;while(1){c=h;f=c&255;if(f>>>0<2){break c}h=c-1|0;if(!(g&1<<f)){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;m=(c-1^(j&65534)>>>1)+m|0;u[i>>1]=m;i=(d<<1)+i|0;if(n>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function Z$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[gj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2377,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Cm(c+8|0,a);f=Gk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2382,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ej(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function Y$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[gj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2377,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Cm(c+8|0,a);f=Gk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2383,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ej(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function $$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[gj(c+24|0,a,0)|0]){Bc(c+16|0,v[v[a>>2]-12>>2]+a|0);v[114578]=0;e=T(2377,c+16|0)|0;d=v[114578];v[114578]=0;d:{e:{if((d|0)==1){break e}d=Cm(c+8|0,a);f=Gk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];d=v[d>>2];v[114578]=0;ka(2381,e|0,d|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}Ob(c+16|0);break d}b=V(0)|0;O()|0;Ob(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;ej(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];e=v[114578];v[114578]=0;f:{if((e|0)!=1){if(!(b&1)){break f}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break c}S(a|0);L()}$()}Ag(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function kq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;a:{if(!b){break a}if(c){c=Od(f+8|0,a);a=jb-16|0;jb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Lb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Rb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}jb=a+16|0;break a}c=Od(f,a);a=jb-16|0;jb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Lb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Rb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}jb=a+16|0}jb=f+16|0}function qw(a){var b=0,c=0,d=0,e=0,f=0,g=0;o(+a);e=j(1)|0;j(0)|0;b=e;e=b>>>31|0;a:{b:{c:{d:{d=a;e:{f:{b=b&2147483647;g:{if(b>>>0>=1082532651){o(+a);b=j(1)|0;b=b&2147483647;if((b|0)==2146435072&(j(0)|0)!=0|b>>>0>2146435072){return a}if(a>709.782712893384){return a*8.98846567431158e307}if(!(a<-708.3964185322641)|!(a<-745.1332191019411)){break g}break b}if(b>>>0<1071001155){break d}if(b>>>0<1072734898){break f}}a=a*1.4426950408889634+A[(e<<3)+52256>>3];if(D(a)<2147483648){b=~~a;break e}b=-2147483648;break e}b=!e-e|0}c=+(b|0);a=d+c*-.6931471803691238;f=c*1.9082149292705877e-10;d=a-f;break c}if(b>>>0<=1043333120){break a}b=0;d=a}c=d;g=a;c=c*c;a=d-c*(c*(c*(c*(c*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);c=g+(d*a/(2-a)-f)+1;if(!b){break b}c=$h(c,b)}return c}return a+1}function cz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-80|0;jb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){g=Qf(d+72|0);f=b-e|0;b=it(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){xk(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}zb(a);b=bz(d+56|0);e=v[a+4>>2];v[114578]=0;e=Q(932,a|0,e+f|0)|0;h=v[114578];v[114578]=0;c:{if((h|0)==1){break c}v[114578]=0;R(933,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;uj(d+40|0,a);xk(d+32|0,a);uj(d+24|0,b);v[114578]=0;e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;X(934,d+48|0,d+8|0,d|0,d+24|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;az(a,b);ke(b);break b}a=P()|0;O()|0;ke(b);S(a|0);L()}v[a+4>>2]=b;break a}kq(Od(d+16|0,g),f,c)}jb=d+80|0}function lma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Wb(a);h=Fb(b);v[114578]=0;R(524,f|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[kc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[kc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114578]=0;d=Q(533,e|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){V(0)|0;O()|0;Ab();L()}if(d>>>0<=g>>>0){d=a;break b}v[114578]=0;d=Q(525,c|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;Q(526,f|0,d|0)|0;e=v[114578];v[114578]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114578]=0;W(527,f|0,1,37)|0;g=v[114578];v[114578]=0;d=a;if((g|0)==1){break a}}v[114578]=0;W(527,f|0,1,e<<24>>24)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;yb(f);S(a|0);L()}function rP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-48|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;zb(b);Zc(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){lq(a,v[b+4>>2]);uj(c+32|0,b);xk(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=jb-80|0;jb=b;i=a;f=v[a+4>>2];d=v[c+20>>2];j=d;g=v[c+16>>2];v[b+72>>2]=g;v[b+76>>2]=d;e=v[c+12>>2];k=e;h=v[c+8>>2];v[b+64>>2]=h;v[b+68>>2]=e;v[b+24>>2]=g;v[b+28>>2]=d;v[b+16>>2]=h;v[b+20>>2]=e;d=pP(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^f-1)>>>0<32?f:0)){e=v[i>>2];v[(d>>>0<33?e:(d-1>>>3&536870908)+e|0)>>2]=0}v[b+48>>2]=h;v[b+52>>2]=k;v[b+56>>2]=g;v[b+60>>2]=j;Tn(b+40|0,i,f);d=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=d;d=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=d;TP(b+32|0,b+8|0,b,b+40|0);jb=b+80|0}jb=c+48|0;return a|0}function O2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;e=gh(a);f=b+24|0;a=v[f>>2];v[114578]=0;a=T(2194,a+484344|0)|0;c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)==1){break c}v[114578]=0;R(1533,e|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[114578]=0;c=T(2194,c+484344|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=_b(v[f>>2]+484344|0,a);v[114578]=0;R(2191,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(2185,d+16|0,b|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break g}v[114578]=0;R(1535,e|0,d+16|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}a=a+1|0;yb(d+16|0);yb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(d+16|0)}yb(d);break a}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}ld(e);S(a|0);L()}function wI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb+-64|0;jb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[114578]=0;v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[j+20>>2]=d?d:1997;U(1998,j+24|0,j+20|0,j+60|0);a=v[114578];v[114578]=0;a:{b:{c:{d:{if((a|0)!=1){b=Ho(j+32|0,j+24|0);v[114578]=0;a=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=a;a=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=a;c=+xa(1999,j|0,+c,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}Yc(b);Yc(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Yc(b);Yc(j+24|0)}_(a|0)|0;v[114578]=0;ia(2e3,34536,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}jb=j- -64|0;return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb-4112|0;jb=c;i=nb[v[v[a>>2]+112>>2]](a)|0;if(!i){nb[v[v[a>>2]+116>>2]](a)}v[c+12>>2]=0;d=jb-16|0;jb=d;h=a+44|0;if(mf(h)){while(1){f=Yl(h,e);g=Yl(h,e);v[d+12>>2]=0;g=(g+2048|0)-f>>2;if((g|0)>=1){while(1){z[f>>2]=z[d+12>>2];f=f+4|0;j=(g|0)>1;g=g-1|0;if(j){continue}break}}e=e+1|0;if(mf(h)>>>0>e>>>0){continue}break}}jb=d+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;Cc(c+8|0,512);sp(c+16|0);nb[v[v[a>>2]+60>>2]](a,c+16|0,f,v[c+8>>2]);e=0;if(v[c+8>>2]){while(1){d=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[d>>2]);k=c,l=z[dx(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[d+2048>>2]);k=c,l=z[dx(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=e+1|0;d=v[c+8>>2];if(e>>>0<d>>>0){continue}break}b=b-d|0}if(b){continue}break}}if(!i){nb[v[v[a>>2]+120>>2]](a)}jb=c+4112|0;return C(z[c+12>>2])}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;a:{if(d){while(1){k=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(h,e);i=i+k|0;k=i>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function V6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=jb-16|0;jb=i;j=a+44|0;if(rh(j)){h=Pd(j,0);v[i+8>>2]=h;k=Pd(j,1);v[i+12>>2]=k;e=jd(j,0);v[i>>2]=e;f=jd(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4228>>2];r=z[a+4224>>2];s=z[a+4220>>2];t=z[a+4236>>2];u=z[a+4232>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(n*r)+C(s*l))+C(p*q))-C(C(w*t)+C(o*u)));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;lc(e,g,h);lc(f,k,h)}pi(a,b,c,jd(j,0),jd(j,1),d)}jb=i+16|0}function wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=gd(a);h=Fb(b);v[114578]=0;R(73,f|0,h|0);a=v[114578];v[114578]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[kc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[kc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114578]=0;d=Q(79,e|0,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){V(0)|0;O()|0;Ab();L()}if(d>>>0<=g>>>0){d=a;break b}v[114578]=0;d=Q(74,c|0,g|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;Q(75,f|0,d|0)|0;e=v[114578];v[114578]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114578]=0;W(76,f|0,1,37)|0;g=v[114578];v[114578]=0;d=a;if((g|0)==1){break a}}v[114578]=0;W(76,f|0,1,e<<24>>24)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;yb(f);S(a|0);L()}function ET(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+12560|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function Mka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-48|0;jb=e;i=e+24|0;f=jb-144|0;jb=f;g=dh(f+8|0);h=v[v[g>>2]-12>>2];v[114578]=0;j=da(122)|0;k=v[114578];v[114578]=0;a:{b:{if((k|0)==1){break b}v[114578]=0;U(123,f|0,h+(f+8|0)|0,j|0);h=v[114578];v[114578]=0;if((h|0)==1){break b}Ob(f);v[114578]=0;R(134,g|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(125,i|0,g|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}Yd(g);jb=f+144|0;break a}a=P()|0;O()|0;Yd(g);S(a|0);L()}v[114578]=0;U(667,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;c:{d:{if((c|0)!=1){v[114578]=0;R(668,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(518,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break c}}c=P()|0;O()|0;ef(e+24|0);break d}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function a9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((mf(a)|0)==(b|0)){if((mf(a+12|0)|0)==(c|0)){break b}}v[114578]=0;R(1642,a|0,b|0);d=v[114578];v[114578]=0;c:{d:{if((d|0)==1){break d}v[114578]=0;e=a+12|0;R(1642,e|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}v[114578]=0;f=a+24|0;R(1643,f|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}v[114578]=0;g=a+36|0;R(1643,g|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=Yl(a,d);i=Pb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;PJ(a);OJ(a);b=a+12|0;PJ(b);OJ(b);b=a+24|0;NJ(b);MJ(b);a=a+36|0;NJ(a);MJ(a);$();return 0}a=0;while(1){b=Yl(e,a);i=Pb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function Yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=4;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);n=(l|0)<1;while(1){if(!n){i=b+k|0;o=l+i|0;while(1){t[e+11|0]=0;EQ(a,e+14|0,e+12|0,e+11|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){h=c<<1;c=h&254;u[e+12>>1]=c;f=(h&65534)>>>0>255;t[e+14|0]=f;h=e;if(!c){if(!Je(a,e+10|0)){break b}f=w[e+10|0];c=f<<1&254|1;u[e+12>>1]=c;f=f>>>7|0}j=w[e+11|0]<<1|f;t[h+11|0]=j;g=g-1|0;if(g&255){continue}break}break a}j=w[e+11|0]}c=1;g=j&255;c:{if(g>>>0<4){break c}h=7;while(1){c=h;f=c&255;if(f>>>0<2){break c}h=c-1|0;if(!(g&1<<f)){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=j&1;t[e+14|0]=c;m=(c-1^(j&254)>>>1)+m|0;t[i|0]=m;i=d+i|0;if(o>>>0>i>>>0){continue}break}}k=k+1|0;if((k|0)!=(d|0)){continue}break}}jb=e+16|0}function To(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{b:{switch(v[a+480224>>2]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=Fma(b,d,5e4,0);e=mb;b=v[bd(c+8|0,c)>>2];b=yc(Gma(d,e,b,b>>31),mb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Fma(v[a+1074420>>2],0,Fma(v[a+1074408>>2],0,v[a+1074416>>2],0),mb),v[g>>2]=h;v[c+4>>2]=mb;d=jb-16|0;jb=d;e=c+8|0;f=ou(e,c);jb=d+16|0;d=Fma(b,0,6e5,0);b=f?c:e;b=Ima(d,mb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=Fma(b,d,1e4,0);e=mb;b=v[bd(c+8|0,c)>>2];b=yc(Gma(d,e,b,b>>31),mb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=Fma(a,a>>31,b,b>>31)+32768|0;a=mb;a=yc(Gma(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[d>>2]=a?a:1;jb=c+16|0}function Oba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;v[a>>2]=b;c=FM(Pe(229984),b+1074376|0);b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;f=a+4|0;W(1377,f|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){jb=b+16|0;break b}break a}d=jb-16|0;jb=d;e=d+8|0;b=jb-16|0;jb=b;v[114578]=0;g=a+8|0;c=g;T(1378,c+4|0)|0;h=v[114578];v[114578]=0;c:{if((h|0)!=1){v[114578]=0;v[b+12>>2]=0;W(1379,c+8|0,b+12|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}break a}break a}i=c,j=hc(c),v[i>>2]=j;jb=b+16|0;jb=d+16|0;b=jb-16|0;jb=b;c=a+20|0;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1380,c+8|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){jb=b+16|0;break d}break a}v[114578]=0;Z(1340,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;DM(c);$L(g);wf(f);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function eF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;g=jb-1040|0;jb=g;h=v[b>>2];v[g+12>>2]=h;j=a?a:g+16|0;a:{b:{c:{d=a?d:256;if(!d|!h){break c}f=c>>>2|0;k=f>>>0>=d>>>0;if(d>>>0>f>>>0?c>>>0<=131:0){break b}while(1){f=k?d:f;c=c-f|0;f=Pv(j,g+12|0,f,e);if((f|0)==-1){d=0;h=v[g+12>>2];i=-1;break c}h=(g+16|0)==(j|0);j=h?j:(f<<2)+j|0;i=f+i|0;d=d-(h?0:f)|0;h=v[g+12>>2];if(!d|!h){break c}f=c>>>2|0;k=f>>>0>=d>>>0;if(d>>>0<=f>>>0|c>>>0>131){continue}break}break b}if(!h){break a}}if(!d|!c){break a}f=i;while(1){d:{i=so(j,h,c,e);e:{if(i+2>>>0<=2){f:{switch(i+1|0){case 1:v[g+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}h=v[g+12>>2]+i|0;v[g+12>>2]=h;f=f+1|0;d=d-1|0;if(d){break d}}i=f;break a}j=j+4|0;c=c-i|0;i=f;if(c){continue}break}}if(a){v[b>>2]=v[g+12>>2]}jb=g+1040|0;return i|0}function $la(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(y[a+4>>2]<y[zb(a)>>2]){g=jb-16|0;jb=g;e=Kk(g,a,1);f=zb(a);d=v[e+4>>2];v[114578]=0;X(559,f|0,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[e+4>>2]=v[e+4>>2]+24;Mb(e);jb=g+16|0;break a}a=P()|0;O()|0;Mb(e);S(a|0);L()}i=jb-32|0;jb=i;g=a;k=zb(a);e=Jk(a,Id(a)+1|0);h=Id(a);j=jb-16|0;jb=j;v[j+12>>2]=0;d=i+8|0;Tc(d+12|0,k);if(e){f=e;if(e>>>0>178956970){Fc(12706);L()}f=sc(B(f,24),4)}v[d>>2]=f;h=B(h,24)+f|0;v[d+8>>2]=h;v[d+4>>2]=h;l=ec(d),m=B(e,24)+f|0,v[l>>2]=m;jb=j+16|0;e=v[d+8>>2];v[114578]=0;X(559,k|0,e|0,b|0,c|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[d+8>>2]=v[d+8>>2]+24;v[114578]=0;R(560,g|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}US(d);jb=i+32|0;break b}a=P()|0;O()|0;US(d);S(a|0);L()}}return Ut(a)|0}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;Fd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;f=c,g=w[pc(d+16|0,d)|0]<<2,u[f+30>>1]=g;e=b+14|0;v[c+24>>2]=(w[e|0]|w[e+1|0]<<8)<<1;Hk(d,2,b+1|0);Ic(d+16|0,d);v[114578]=0;Q(372,c+43|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){yb(d+16|0);e=ad(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}bA(e);Gj(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function QT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;Fd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=aq(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=aq(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(_s(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[pc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}jb=d+16|0}function t3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb+-64|0;jb=d;a:{b:{if((b|0)>=0){e=a+24|0;if((rj(Vb(v[e>>2]+484360|0))|0)>(b|0)){break b}}a=a+16|0;break a}f=x[rc(Vb(v[e>>2]+484360|0),b)>>1];c:{if(!Kn(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[_b(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074438>>1]=b;c=b&65535;AL(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;Es(d+48|0,e,f?7:1,d);h=a,i=A[Tg(d+48|0)>>3],A[h+16>>3]=i;Hl(d+48|0);a=a+16|0}jb=d- -64|0;return+A[a>>3]}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;xf(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=v[19811];if(x[c+62>>1]>x[e+12>>1]){f=v[b+12>>2];qA(c+16|0,18533);v[114578]=0;X(1181,c+32|0,c+16|0,c+62|0,e+12|0);d=v[114578];v[114578]=0;if((d|0)==1){break g}v[114578]=0;d=Q(649,c+48|0,c+32|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break f}v[114578]=0;R(624,f|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}yb(d);yb(c+32|0);Ib(c+16|0);u[c+62>>1]=x[e+12>>1]}eg(Di(b,0),x[c+62>>1]);b=Di(b,0);h=c,i=bc(b),v[h+48>>2]=i;h=c,i=cc(b),v[h+16>>2]=i;if(Jb(c+48|0,c+16|0)){break b}break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d)}yb(c+32|0)}Ib(c+16|0);S(b|0);L()}while(1){b=v[c+48>>2];xf(a,c+14|0);u[b>>1]=x[c+14>>1];te(c+48|0);if(Jb(c+48|0,c+16|0)){continue}break}}jb=c- -64|0}function Yba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=C(0),j=C(0),k=0,m=0;f=jb-16|0;jb=f;k=f,m=B(v[a>>2],ue(a)),v[k+8>>2]=m;Cc(f+8|0,c>>>2|0);c=Db(b);h=z[e+4>>2];e=v[f+8>>2];if(e){while(1){g=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);h=C(G(C(D((l(2,g<<24|g<<8&16711680|(g>>>8&65280|g>>>24)),q()))),h));c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[f+8>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[f+12>>2]=j*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());ae(f+12|0,C(-1));i=C(z[f+12>>2]*C(32768));z[f+12>>2]=i;a=c;i=je(i);b:{if(C(D(i))<C(2147483648)){g=~~i;break b}g=-2147483648}k=a,m=Vc(g),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}jb=f+16|0;return v[f+8>>2]<<2}function jF(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=Sv(60416);if(w[b|0]?b:0){break a}b=Sv(B(a,12)+60432|0);if(w[b|0]?b:0){break a}b=Sv(60504);if(w[b|0]?b:0){break a}b=60509}b:{while(1){e=w[b+c|0];if(!(!e|(e|0)==47)){e=15;c=c+1|0;if((c|0)!=15){continue}break b}break}e=c}d=60509;c:{d:{c=w[b|0];e:{f:{if(!(w[b+e|0]|(c|0)==46)){d=b;if((c|0)!=67){break f}}if(!w[d+1|0]){break e}}if(!ji(d,60509)){break e}if(ji(d,60517)){break d}}if(!a){c=60340;if(w[d+1|0]==46){break c}}return 0}c=v[115366];if(c){while(1){if(!ji(d,c+8|0)){break c}c=v[c+24>>2];if(c){continue}break}}c=v[115366];if(c){while(1){if(!ji(d,c+8|0)){return c}c=v[c+24>>2];if(c){continue}break}}c=pd(28);g:{if(!c){c=0;break g}b=v[15086];v[c>>2]=v[15085];v[c+4>>2]=b;b=c+8|0;lc(b,d,e);t[b+e|0]=0;v[c+24>>2]=v[115366];v[115366]=c}c=a|c?c:60340}return c}function Wba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0;f=jb-16|0;jb=f;m=f,o=B(v[a>>2],ue(a)),v[m+4>>2]=o;Cc(f+4|0,c>>>3|0);c=Db(b);h=A[e+8>>3];g=v[f+4>>2];a:{if(!g){break a}e=g;while(1){j=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&2147483647;l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,j|0);h=G(+n(),h);c=c+8|0;e=e-1|0;if(e){continue}break}if(!g|h==0){break a}k=1/h;c=v[a+20>>2];while(1){a=b;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);l(0,w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24));l(1,e|0);m=f,p=+n()*k,A[m+8>>3]=p;Rf(f+8|0,-1,1);i=A[f+8>>3]*32768;A[f+8>>3]=i;a=c;i=Sd(i);b:{if(D(i)<2147483648){e=~~i;break b}e=-2147483648}m=a,o=Vc(e),u[m>>1]=o;b=b+8|0;c=c+2|0;g=g-1|0;if(g){continue}break}}if(d){A[d>>3]=h}jb=f+16|0;return v[f+4>>2]<<3}function Aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;Fd(b,4);u[b+30>>1]=w[a+12|0]<<2;jg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Ub(d,31680);v[114578]=0;Q(372,b+43|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){yb(a);jb=d+16|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function K3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-48|0;jb=e;h=Go(a,c);i=UH(a+4|0);j=TH(a+24|0);k=SH(a+32|0);l=Sw(a+36|0);v[a+56>>2]=3;m=gh(a+68|0);v[114578]=0;R(2165,a|0,d|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{if((c|0)!=1){c=v[b>>2];f=v[b+4>>2];g=v[b+12>>2];b=v[b+8>>2];v[e+8>>2]=b;v[e+12>>2]=g;v[114578]=0;v[e+24>>2]=b;v[e+28>>2]=g;v[e+16>>2]=c;v[e+20>>2]=f;v[e>>2]=c;v[e+4>>2]=f;U(2166,e+32|0,e|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(2167,a|0,e+32|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Bb(e+32|0);v[114578]=0;Z(2168,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}jb=e+48|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bb(e+32|0);break a}a=P()|0;O()|0}ld(m);rf(l);wf(k);Gh(j);Yc(i);Yc(h);S(a|0);L()}function $T(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Wf(a,d+8|0)){v[d+4>>2]=w[d+8|0];g=v[Lb(d+4|0,d+12|0)>>2];c=jb+-64|0;jb=c;Me(c+40|0,a,g);a=v[c+40>>2];v[114578]=0;e=T(414,c+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,c+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,c+24|0,c+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(470,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,c|0,c+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(c+24|0);Ec(c+40|0);jb=c- -64|0;c=!g|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+24|0)}Ec(c+40|0);S(a|0);L()}}jb=d+16|0;return c|0}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Kk(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1562,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Jk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(31753);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1562,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(1563,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}GK(c);jb=f+32|0;break b}a=P()|0;O()|0;GK(c);S(a|0);L()}}function c4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Kk(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(2132,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Jk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(39501);L()}h=sc(B(a,24),8)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(2132,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(2133,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}yH(c);jb=f+32|0;break b}a=P()|0;O()|0;yH(c);S(a|0);L()}}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];h=v[Lb(e+12|0,e+8|0)>>2];i=z[d>>2];b=Db(b);if(h){a=v[a+20>>2];c=h;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;d=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=d,k=Vc(g),u[j>>1]=k;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);z[e+12>>2]=i*(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;d=a;f=je(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=d,k=Vc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return h<<3}function yha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Kk(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(986,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Jk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(16924);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(986,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(987,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}vP(c);jb=f+32|0;break b}a=P()|0;O()|0;vP(c);S(a|0);L()}}function sla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Kk(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(605,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Jk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(12852);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(605,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(606,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}NS(c);jb=f+32|0;break b}a=P()|0;O()|0;NS(c);S(a|0);L()}}function nma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Kk(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(529,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Jk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(12489);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(529,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(530,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}tT(c);jb=f+32|0;break b}a=P()|0;O()|0;tT(c);S(a|0);L()}}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Kk(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(769,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Jk(a,Id(a)+1|0);j=Id(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>178956970){Fc(14703);L()}h=sc(B(a,24),4)}v[c>>2]=h;a=B(j,24)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=B(d,24)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(769,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114578]=0;R(770,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}qR(c);jb=f+32|0;break b}a=P()|0;O()|0;qR(c);S(a|0);L()}}function xda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;b=A[a+8>>3];d=jb-32|0;jb=d;o(+A[a>>3]);a=j(1)|0;e=j(0)|0;o(+b);f=j(1)|0;i=j(0)|0;f=f&2147483647;c=f;g=a&2147483647;k=(c|0)==(g|0)&e>>>0<i>>>0|c>>>0>g>>>0;a=k?e:i;c=k?g:c;p=c;l(0,a|0);l(1,c|0);b=+n();c=c>>>20|0;a:{if((c|0)==2047){break a}k=e;e=(f|0)==(g|0)&e>>>0>i>>>0|f>>>0<g>>>0;i=e?k:i;f=e?g:f;e=f;l(0,i|0);l(1,e|0);h=+n();b:{if(!(a|p)){break b}a=e>>>20|0;if((a|0)==2047){break b}if((a-c|0)>=65){b=h+b;break a}c:{if(a>>>0>=1534){b=b*1.90109156629516e-211;h=h*1.90109156629516e-211;m=5.260135901548374e210;break c}m=1;if(c>>>0>572){break c}b=b*5.260135901548374e210;h=h*5.260135901548374e210;m=1.90109156629516e-211}vG(d+24|0,d+16|0,h);vG(d+8|0,d,b);b=m*K(A[d>>3]+A[d+16>>3]+A[d+8>>3]+A[d+24>>3]);break a}b=h}jb=d+32|0;return+b}function Xr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-176|0;jb=d;e=dh(d+40|0);f=v[v[e>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114578]=0;U(123,d+32|0,f+(d+40|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}Ob(d+32|0);v[114578]=0;R(142,e|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;R(133,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;R(125,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(140,d+16|0,d|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(141,a|0,d+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}yb(d+16|0);yb(d);Yd(e);jb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(d+16|0)}yb(d)}Yd(e);S(c|0);L()}function Paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(v[a+4>>2]!=v[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1519,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(30794);L()}h=sc(a<<2,4)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1519,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1520,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}TK(c);jb=f+32|0;break b}a=P()|0;O()|0;TK(c);S(a|0);L()}}function rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1057,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(17993);L()}h=sc(a<<2,1)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1057,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1058,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}EO(c);jb=f+32|0;break b}a=P()|0;O()|0;EO(c);S(a|0);L()}}function jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1422,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(20588);L()}h=sc(a<<2,4)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1422,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1423,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}nL(c);jb=f+32|0;break b}a=P()|0;O()|0;nL(c);S(a|0);L()}}function SJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=qe(e,a,1);a=zb(a);c=v[d+4>>2];v[114578]=0;U(1636,a|0,c|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}f=jb-32|0;jb=f;e=a;i=zb(a);d=Be(a,Kb(a)+1|0);j=Kb(a);g=jb-16|0;jb=g;v[g+12>>2]=0;c=f+8|0;Tc(c+12|0,i);if(d){a=d;if(a>>>0>1073741823){Fc(32555);L()}h=sc(a<<2,4)}v[c>>2]=h;a=(j<<2)+h|0;v[c+8>>2]=a;v[c+4>>2]=a;k=ec(c),l=(d<<2)+h|0,v[k>>2]=l;jb=g+16|0;a=v[c+8>>2];v[114578]=0;U(1636,i|0,a|0,b|0);a=v[114578];v[114578]=0;b:{c:{if((a|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114578]=0;R(1637,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}QJ(c);jb=f+32|0;break b}a=P()|0;O()|0;QJ(c);S(a|0);L()}}function Pja(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}AR(g+15|0,g+13|0);AR(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}sx(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){rx(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(Xm(c)>>>0<=Xm(w[g+14|0])>>>0){break b}lh(g+15|0,g+14|0);lh(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];jb=g+16|0}function VY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Kb(a);if(c>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{g=b-c|0;c:{if(g>>>0<=v[Uq(a)>>2]-v[a+4>>2]>>2>>>0){uE(a,g);break c}i=$k(a);d=h+8|0;f=Kb(a)+g|0;e=jb-16|0;jb=e;v[e+12>>2]=f;b=a;d:{c=XD(a);if(f>>>0<=c>>>0){b=_k(b);if(b>>>0<c>>>1>>>0){v[e+8>>2]=b<<1;c=v[bd(e+8|0,e+12|0)>>2]}jb=e+16|0;break d}fd();L()}f=Kb(a);b=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(d+12|0,i);if(c){b=WD(v[d+16>>2],c)}v[d>>2]=b;f=(f<<2)+b|0;v[d+8>>2]=f;v[d+4>>2]=f;j=ec(d),k=(c<<2)+b|0,v[j>>2]=k;jb=e+16|0;v[114578]=0;R(2559,d|0,g|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(2560,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}QD(d)}jb=h+32|0;break a}a=P()|0;O()|0;QD(d);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Kb(a);SD(a,b);rE(a)}}function I3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-32|0;jb=f;d=Go(a,d);h=UH(a+4|0);i=TH(a+24|0);j=SH(a+32|0);k=Sw(a+36|0);v[a+56>>2]=3;l=gh(a+68|0);v[114578]=0;R(2165,a|0,e|0);g=v[114578];v[114578]=0;a:{b:{c:{d:{if((g|0)!=1){v[114578]=0;b=T(2172,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;U(2173,f+8|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(2174,f+16|0,f+8|0,0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(2167,a|0,f+16|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Bb(f+16|0);v[114578]=0;Z(2168,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Bb(f+16|0)}ld(l);rf(k);wf(j);Gh(i);Yc(h);Yc(d);S(a|0);L()}jb=f+32|0;return a|0}function oi(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-48|0;jb=d;e=a+24|0;f=v[v[e>>2]+24620>>2];a:{if(!((f|0)!=(b|0)|v[v[e>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}lL(v[e>>2],1);break a}lc(d+8|0,v[e>>2]+24604|0,40);g=v[d+40>>2];h=v[d+44>>2];v[d+28>>2]=c;v[d+24>>2]=b;ul(d+8|0,g);kn(d+8|0,h);Kx(v[e>>2],d+8|0);if((b|0)==(f|0)){break a}b=v[e>>2];f=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(nb[v[v[b>>2]+112>>2]](b)|0)){break b}nb[v[v[b>>2]+104>>2]](b,0);nb[v[v[b>>2]+92>>2]](b);nb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((f|0)!=(c|0)){continue}break}b=v[e>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(nb[v[v[b>>2]+112>>2]](b)|0){break c}nb[v[v[b>>2]+104>>2]](b,1);nb[v[v[b>>2]+116>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}}t[a+29|0]=1;jb=d+48|0}function _ba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-16|0;jb=i;m=i,n=B(v[a>>2],ue(a)),v[m+12>>2]=n;Cc(i+12|0,c>>>2|0);c=Db(b);h=v[e+4>>2];f=v[i+12>>2];a:{if(!f){g=h;break a}while(1){e=Db(w[c+3|0]);e=e|Db(w[c+2|0])<<8|Db(w[c+1|0])<<16|Db(w[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+4|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[i+12>>2];if(!e){break c}j=g-1|0;k=g>>>1|0;l=g;c=v[a+20>>2];while(1){a=Db(w[b+3|0]);a=a|Db(w[b+2|0])<<8|Db(w[b+1|0])<<16|Db(w[b|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=yc(Gma(f-a|0,h-(a>>>0>f>>>0)|0,l,0),mb)>>>16|0,u[m>>1]=n;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=i+16|0;return v[i+12>>2]<<2}function $ba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-16|0;jb=i;m=i,n=B(v[a>>2],ue(a)),v[m+12>>2]=n;Cc(i+12|0,c>>>2|0);c=Db(b);h=v[e+4>>2];f=v[i+12>>2];a:{if(!f){g=h;break a}while(1){e=Db(w[c|0]);e=e|Db(w[c+1|0])<<8|Db(w[c+2|0])<<16|Db(w[c+3|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+4|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[i+12>>2];if(!e){break c}j=g-1|0;k=g>>>1|0;l=g;c=v[a+20>>2];while(1){a=Db(w[b|0]);a=a|Db(w[b+1|0])<<8|Db(w[b+2|0])<<16|Db(w[b+3|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=yc(Gma(f-a|0,h-(a>>>0>f>>>0)|0,l,0),mb)>>>16|0,u[m>>1]=n;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=i+16|0;return v[i+12>>2]<<2}function gM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;a:{if(!v[b+700>>2]){break a}f=v[a+480180>>2]==64?B(c,-20):c;b:{if(!(!(w[a+480208|0]&16)|v[a+480180>>2]==4)){g=v[b+700>>2];c=f>>31;v[e+12>>2]=(c+f^c)>>>2;Cc(e+12|0,255);d=v[e+12>>2];c:{if(!d){break c}h=b;c=v[b+700>>2];i=c;c=c>>31;d:{if((f|0)<=-1){d=_x(a,d);break d}d=Zx(a,d)}d=Fma(i,c,d,d>>31)+32768|0;c=mb;c=yc(Gma(d,d>>>0<32768?c+1|0:c,65536,0),mb);v[h+700>>2]=c;if((c|0)!=(g|0)){break c}Eb(e,a+1074308|0,7);d=Cb(e);c=v[b+700>>2];if((d|0)==(f>>>31|0)){if((c|0)==2147483647){break c}v[b+700>>2]=v[b+700>>2]+1;break c}if((c|0)<2){break c}v[b+700>>2]=c-1}c=v[b+700>>2];break b}c=f+v[b+700>>2]|0;v[b+700>>2]=c}if((c|0)>0){break a}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=e+16|0}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;jb=e+32|0}function eI(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-176|0;jb=d;e=dh(d+40|0);f=v[v[e>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114578]=0;U(123,d+32|0,f+(d+40|0)|0,g|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}Ob(d+32|0);v[114578]=0;R(147,e|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break e}v[114578]=0;R(130,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;R(125,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(140,d+16|0,d|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}v[114578]=0;U(141,a|0,d+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}yb(d+16|0);yb(d);Yd(e);jb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(d+16|0)}yb(d)}Yd(e);S(c|0);L()}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;c=lk(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((bg(a)|0)!=(c|0)){break b}b=jb-16|0;jb=b;c=bc(a);d=cc(a);Qh(b+8|0);a=jb-16|0;jb=a;v[a>>2]=d;v[a+8>>2]=c;d=ks(a,a+8|0);g=jb-16|0;jb=g;v[g+8>>2]=c;if((d|0)>=1){while(1){c=v[g+8>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=(d|0)>1;Cj(g+8|0);d=d-1|0;if(c){continue}break}}jb=g+16|0;jb=a+16|0;jb=b+16|0;break a}Qh(f+8|0);c=oS(f+16|0,c,f+8|0);tK(a);El(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[zb(c)>>2];h=zb(a),i=d,v[h>>2]=i;h=zb(c),i=0,v[h>>2]=i;v[c>>2]=0;v[c+4>>2]=0;Ll(c);v[a+12>>2]=b}a=1}else{a=0}jb=f+32|0;return a|0}function E6(){var a=0,b=0,c=0,d=0,e=0;a=jb-48|0;jb=a;c=Wb(a+32|0);v[114578]=0;Z(1994,a+16|0);b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){d=a,e=bc(a+16|0),v[d+8>>2]=e;d=a,e=cc(a+16|0),v[d>>2]=e;if(!Jb(a+8|0,a)){break c}while(1){e:{b=v[a+8>>2];v[114578]=0;Q(1250,c|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}zn(a+8|0);d=a,e=cc(a+16|0),v[d>>2]=e;if(!Jb(a+8|0,a)){break c}v[114578]=0;Q(1995,c|0,34201)|0;b=v[114578];v[114578]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;ld(a+16|0);break d}b=V(0)|0;O()|0}yb(c);_(b|0)|0;b=0;v[114578]=0;X(1989,34203,0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$();break b}b=Zd(Tb(c));ld(a+16|0);yb(c)}jb=a+48|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);t[e+15|0]=w[a+4|0];t[e+14|0]=64;f=b,g=w[pc(e+15|0,e+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);a=a+10|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);d=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24);a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=d+(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))|0;v[b+8>>2]=a;d=v[b+4>>2];c=v[b>>2];if(d>>>0>=c>>>0){d=c-1|0;v[b+4>>2]=d}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<d>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}v[b+68>>2]=d;u[b+34>>1]=x[b+34>>1]|2}jb=e+16|0}function yo(a){var b=C(0),c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=Ch(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-Ch(((e|0)>-1?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<=-1){b=Dh(f+1.5707963267948966);break a}b=Dh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Ch(((e|0)>-1?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<=-1){b=Dh(-4.71238898038469-+a);break a}b=Dh(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(pw(a,c+8|0)&3){case 0:b=Ch(A[c+8>>3]);break a;case 1:b=Dh(-A[c+8>>3]);break a;case 2:b=C(-Ch(A[c+8>>3]));break a;default:break b}}b=Dh(A[c+8>>3])}a=b;jb=c+16|0;return a}function TJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-16|0;jb=d;a:{if(Kb(a)>>>0>511){break a}if(!Gf(v[v[b>>2]-12>>2]+b|0)){break a}j=d+8|0;f=b;g=c;h=jb-16|0;jb=h;e=Pe(64);v[114578]=0;i=T(1428,e|0)|0;k=v[114578];v[114578]=0;b:{c:{if((k|0)!=1){e=Qx(h+8|0,i);i=v[e>>2];v[114578]=0;f=W(1634,i|0,f|0,g|0)|0;g=v[114578];v[114578]=0;d:{e:{if((g|0)!=1){if((f|0)==1){break e}Px(j);break d}a=P()|0;O()|0;ag(e);break c}Gp(j,e)}ag(e);jb=h+16|0;break b}a=P()|0;O()|0;Xb(e)}S(a|0);L()}f:{g:{if(!rd(d+8|0)){v[114578]=0;U(1632,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break g}aS(d+8|0,Nd(d));ag(d)}f=0;if(!rd(d+8|0)){break f}f=v[d+8>>2];v[114578]=0;R(1633,a|0,d+8|0);a=v[114578];v[114578]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;ag(d+8|0);S(a|0);L()}ag(d+8|0)}jb=d+16|0;return f}function k3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;i=Wb(a);a=Wb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!x[v[g>>2]+480192>>1]){break d}b=0;f=1;while(1){c=v[g>>2];v[114578]=0;c=Q(2183,c|0,f&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;c=Q(85,e|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}d=Wc(c);v[114578]=0;Q(1250,a|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;Q(1995,a|0,38845)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}b=d^1|b;yb(c);f=f+1|0;if(x[v[g>>2]+480192>>1]>=(f&65535)>>>0){continue}break}if(!(b&1)){break d}v[114578]=0;Q(450,i|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}yb(a);jb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(a);yb(i);S(b|0);L()}function j3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;i=Wb(a);a=Wb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!x[v[g>>2]+480190>>1]){break d}b=0;f=1;while(1){c=v[g>>2];v[114578]=0;c=Q(2184,c|0,f&65535)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;c=Q(85,e|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break c}d=Wc(c);v[114578]=0;Q(1250,a|0,c|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}v[114578]=0;Q(1995,a|0,38845)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}b=d^1|b;yb(c);f=f+1|0;if(x[v[g>>2]+480190>>1]>=(f&65535)>>>0){continue}break}if(!(b&1)){break d}v[114578]=0;Q(450,i|0,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}yb(a);jb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(a);yb(i);S(b|0);L()}function Zj(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Fb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=Sm(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+64400|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+64400|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=k+16|0;return a|0}function Yj(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=jb-16|0;jb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Fb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=Fv(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+64400|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+64400|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=k+16|0;return a|0}function LL(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;f=jb-16|0;jb=f;g=a+128e3|0;while(1){d=jb-32|0;jb=d;kO(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;jb=d+32|0;a=a+32|0;if((g|0)!=(a|0)){continue}break}jb=f+16|0;jb=e+16|0}function Hf(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114578]=0;b=v[(b+c|0)+24>>2];c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114578]=0;b=Gf(b+c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(ED()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114578]=0;b=v[(b+c|0)+24>>2];c=v[114578];v[114578]=0;c:{if((c|0)==1){break c}v[114578]=0;b=T(2376,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114578]=0;R(18,a+b|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function Iq(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a=gd(a);a:{b:{c:{switch(b|0){case 0:v[114578]=0;b=Q(2,d|0,7167)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}Gb(a,b);yb(b);break b;case 1:v[114578]=0;b=Q(2,d|0,7192)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 2:v[114578]=0;b=Q(2,d|0,7237)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 3:v[114578]=0;b=Q(2,d|0,7264)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 4:v[114578]=0;b=Q(2,d|0,7290)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 5:break c;default:break b}}v[114578]=0;b=Q(2,d|0,7319)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}Gb(a,b);yb(b)}jb=d+16|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function bca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-16|0;jb=i;m=i,n=B(v[a>>2],ue(a)),v[m+12>>2]=n;Cc(i+12|0,(c>>>0)/3|0);c=Db(b);h=v[e+4>>2];f=v[i+12>>2];a:{if(!f){g=h;break a}while(1){e=Db(w[c|0]);e=Db(w[c+1|0])<<16|e<<8|Db(w[c+2|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+3|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[i+12>>2];if(!e){break c}j=g-1|0;k=g>>>1|0;l=g;c=v[a+20>>2];while(1){a=Db(w[b|0]);a=Db(w[b+1|0])<<16|a<<8|Db(w[b+2|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=yc(Gma(f-a|0,h-(a>>>0>f>>>0)|0,l,0),mb)>>>16|0,u[m>>1]=n;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=i+16|0;return B(v[i+12>>2],3)|0}function aca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-16|0;jb=i;m=i,n=B(v[a>>2],ue(a)),v[m+12>>2]=n;Cc(i+12|0,(c>>>0)/3|0);c=Db(b);h=v[e+4>>2];f=v[i+12>>2];a:{if(!f){g=h;break a}while(1){e=Db(w[c+2|0]);e=Db(w[c+1|0])<<16|e<<8|Db(w[c|0])<<24;b:{if((e|0)<=-1){g=-2147483648;if((e|0)==-2147483648){break b}e=0-e|0}g=e>>>0>h>>>0?e:h}c=c+3|0;h=g;f=f-1|0;if(f){continue}break}}c:{if(!g){break c}e=v[i+12>>2];if(!e){break c}j=g-1|0;k=g>>>1|0;l=g;c=v[a+20>>2];while(1){a=Db(w[b+2|0]);a=Db(w[b+1|0])<<16|a<<8|Db(w[b|0])<<24;h=a>>31;f=a;a=h;h=a<<31|f>>>1;f=k|f<<31;a=j&a>>31;m=c,n=yc(Gma(f-a|0,h-(a>>>0>f>>>0)|0,l,0),mb)>>>16|0,u[m>>1]=n;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=i+16|0;return B(v[i+12>>2],3)|0}function I7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;g=jb-16|0;jb=g;j=a+44|0;if(rh(j)){r=g,s=Pd(j,0),v[r+8>>2]=s;r=g,s=Pd(j,1),v[r+12>>2]=s;r=g,s=jd(j,0),v[r>>2]=s;r=g,s=jd(j,1),v[r+4>>2]=s;if(d){p=w[a+4273|0];q=w[a+4272|0];k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=v[f>>2];v[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=C(C(z[a+4236>>2]*z[m>>2])+C(z[a+4240>>2]*z[e>>2]));z[m>>2]=i;i=C(z[a+4260>>2]*ZI(C(i*C(1073741824)),q,p));e=f+4244|0;n=z[a+4264>>2];f=f+4252|0;o=z[f>>2];i=C(i-C(C(z[a+4268>>2]*z[e>>2])+C(n*o)));z[f>>2]=i;z[e>>2]=o+C(i*n);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=i*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}pi(a,b,c,jd(j,0),jd(j,1),d)}jb=g+16|0}function Lw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-80|0;jb=c;d=v[a>>2];g=v[d+4>>2];f=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=f;f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Eh(c- -64|0,c+32|0,g);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);g=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;a=c;if(g){j=b+4|0;while(1){d=0;if(f){while(1){e=v[Of(a,d,h)>>2];fc(b,d);e=(e+((Kr(j)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;e=e>>>0>491520?e:491520;k=Mm(i,d,h),l=(e|0)<557055?e:557055,u[k>>1]=l;d=d+1|0;if((f|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=c+80|0}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;jb=e+32|0}function HK(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-16|0;jb=h;t[h+15|0]=b;t[h+14|0]=10;gg(g,w[pc(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Kb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Pb(g,c),j=d>>>4|0,u[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(x[Pb(g,c)>>1]>=x[Pb(g,d)>>1]){break a}e=c;d=x[Pb(g,d)>>1]+1|0}i=Pb(g,e),j=d,u[i>>1]=j}b=Cd(w[b+2|0],0,64);i=Pb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Kb(g)>>>0>c>>>0){continue}break}}c=w[g+12|0]&-2|a&1;t[g+12|0]=c;b=g;c:{d:{if(!(a&2)){break d}d=w[g+15|0];e=Kb(g);c=w[g+12|0];if(d>>>0>e>>>0){break d}c=c|4;break c}c=c&251}t[b+12|0]=c;b=g;e:{f:{if(!(a&4)){break f}a=w[g+13|0];if(a>>>0>w[g+14|0]){break f}d=Kb(g);c=w[g+12|0];if(a>>>0>d>>>0){break f}a=c|2;break e}a=c&253}t[b+12|0]=a;jb=h+16|0}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>4;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[e+8>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=g;Rf(e+8|0,-1,1);f=A[e+8>>3]*32768;A[e+8>>3]=f;g=a;f=Sd(f);a:{if(D(f)<2147483648){h=~~f;break a}h=-2147483648}i=g,j=Vc(h),u[i>>1]=j;g=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);v[e+8>>2]=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);v[e+12>>2]=g;Rf(e+8|0,-1,1);f=A[e+8>>3]*32768;A[e+8>>3]=f;g=a;f=Sd(f);b:{if(D(f)<2147483648){h=~~f;break b}h=-2147483648}i=g,j=Vc(h),u[i+2>>1]=j;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function zG(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Dh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<=-1){a=C(-Ch(d+1.5707963267948966));break a}a=Ch(d+-1.5707963267948966);break a}a=Dh(-(((e|0)>-1?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<=-1){a=Ch(d+4.71238898038469);break a}a=C(-Ch(d+-4.71238898038469));break a}a=Dh(((e|0)>-1?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(pw(a,b+8|0)&3){case 0:a=Dh(A[b+8>>3]);break a;case 1:a=Ch(A[b+8>>3]);break a;case 2:a=Dh(-A[b+8>>3]);break a;default:break b}}a=C(-Ch(A[b+8>>3]))}jb=b+16|0;return a}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=qi(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=81440;c=a+4960|0;e=a+4504|0;b=e;while(1){kk(b);b=b+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[114578]=0;W(1640,a+44|0,2,2)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){v[114578]=0;Z(1641,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;Sf(c);if((c|0)!=(e|0)){continue}break}bf(d);S(a|0);L()}return a|0}function pf(a,b){var c=0,d=0,e=0;d=jb-32|0;jb=d;a=Og(a,-1,-1);a:{b:{if(w[gj(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[114578]=0;c=v[(b+c|0)+24>>2];e=v[114578];v[114578]=0;c:{d:{if((e|0)==1){break d}v[114578]=0;Oa(2386,d+8|0,c|0,0,0,1,8);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;_(a|0)|0;ej(v[v[b>>2]-12>>2]+b|0,1);a=v[v[b>>2]-12>>2];v[114578]=0;a=v[(a+b|0)+20>>2];c=v[114578];v[114578]=0;e:{if((c|0)!=1){if(!(a&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}$();a=1}Ag(v[v[b>>2]-12>>2]+b|0,a)}jb=d+32|0;return}V(0)|0;O()|0;Ab()}L()}function Du(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;g=a+1|0;gg(b,w[pc(g,f+15|0)|0]);d=w[pc(a+2|0,f+15|0)|0];t[b+13|0]=d;j=b,k=Cd(w[a+3|0],d,w[f+15|0]),t[j+14|0]=k;d=w[pc(a+4|0,f+15|0)|0];t[b+15|0]=d;j=b,k=Cd(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[pc(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Yb(w[e+6|0]+c<<24>>24,0,64);j=Pb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Pb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}if(x[Pb(b,d)>>1]>255){break a}h=w[Pb(b,e)+1|0];i=Pb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}e=Pb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[pc(f+14|0,g)|0]){continue}break}}jb=f+16|0}function gL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=-1;a:{if(!Gx(a,b,2)){break a}h=v[b+656>>2];f=a+1074308|0;Eb(e+8|0,f,31);b:{if(Cb(e+8|0)){d=v[b+752>>2];if(d){break b}break a}d=v[b+752>>2]}Eb(e+8|0,f,31);f=d-Cb(e+8|0)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=qp(h+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+748|0]&16){g=fp(a,b,!(v[b+88>>2]&32768),d);break a}if(tj(b)){if((d|0)==v[b+768>>2]){break a}v[b+768>>2]=d;t[b+872|0]=w[b+872|0]|8;break a}b=Zo(a);v[e+8>>2]=d;f=c;c:{if((d|0)<=-1){v[e+8>>2]=0-d;Ak(e+8|0,255);a=(v[e+8>>2]<<2)+(b?26336:25312)|0;break c}Ak(e+8|0,255);a=(v[e+8>>2]<<2)+(b?25312:26336)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];i=f,j=yc(Gma(Fma(b,d,a,a>>31),mb,65536,0),mb),v[i>>2]=j}jb=e+16|0;return g}function fM(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{c:{if(!(t[b+872|0]&1)|!(c&255)){break c}d=v[b+700>>2];if(!d){break c}if(!(w[a+480208|0]&16)){break b}d=v[b+700>>2];if(v[a+480180>>2]==4){break b}c=Zx(a,c&15);f=Fma(c,c>>31,d,d>>31)+32768|0;c=mb;c=yc(Gma(f,f>>>0<32768?c+1|0:c,65536,0),mb);v[b+700>>2]=c;if((c|0)!=(d|0)){break c}a=a+1074308|0;Eb(e+8|0,a,7);if(!(Cb(e+8|0)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break c}Eb(e+8|0,a,7);if(!Cb(e+8|0)){break c}a=v[b+700>>2];if((a|0)<2){break c}v[b+700>>2]=a-1}jb=e+16|0;return}a=((c&255)<<2)+d|0;v[b+700>>2]=(a|0)<65535?a:65535;jb=e+16|0}function PG(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);b=z[a+32>>2];c=z[a+8>>2];e=z[a+16>>2];f=C(C(b-c)+e);i=z[a>>2];j=z[a+24>>2];k=C(i-j);z[a+16>>2]=f+k;d=z[a+4>>2];g=z[a+20>>2];h=z[a+28>>2];l=C(C(d-C(g+h))*C(.8660253882408142));k=C(k-C(f*C(.5)));z[a+4>>2]=l+k;m=C(C(g+d)*C(.9848077297210693));f=C(z[a+12>>2]*C(.8660253882408142));n=C(C(h+d)*C(-.6427876353263855));o=C(C(m-f)+n);d=C(i+C(j*C(.5)));i=C(C(b+c)*C(.7660444378852844));b=C(C(e-b)*C(.1736481785774231));j=C(C(d-i)+b);z[a+12>>2]=o+j;z[a+20>>2]=j-o;z[a+28>>2]=k-l;g=C(C(g-h)*C(.3420201539993286));h=C(g-C(f+m));c=C(C(e+c)*C(.9396926164627075));b=C(C(d+c)-b);z[a+32>>2]=h+b;e=C(C(g+f)+n);c=C(C(d-c)+i);z[a+24>>2]=e+c;z[a+8>>2]=c-e;z[a>>2]=b-h}function cn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;e=v[b+656>>2];if(!(!e|t[b+724|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}f=x[c+34>>1];if(f&2){v[b+88>>2]=(f&4?d|4:d&-135)|2;d=v[c>>2];v[b+76>>2]=d;f=v[c+4>>2];v[b+80>>2]=f;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<d>>>0){v[b+76>>2]=c;g=c}else{g=d}d=v[b+4>>2];if(g>>>0>=d>>>0){break b}v[b>>2]=0;v[b+4>>2]=((d-f>>>0)%(c-f>>>0)|0)+f;break b}v[b+88>>2]=d&-135;v[b+76>>2]=v[c>>2]}if(!e){break a}if(!(!v[e>>2]|(v[a+480180>>2]&1064964?0:!(w[e+60|0]&2)))){v[b+88>>2]=v[b+88>>2]|4096}if(w[e+65|0]==255|v[b+732>>2]!=-1){break a}a=e+48|0;h=b,i=qp(a,v[b+728>>2],256,64),v[h+732>>2]=i;h=b,i=x[Pb(a,w[e+65|0])>>1],v[h+728>>2]=i}}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;g=gh(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[114578]=0;R(1533,g|0,a|0);c=v[114578];v[114578]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[114578]=0;c=Q(2183,c|0,a&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;c=Q(85,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;U(2185,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(1535,g|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}yb(d+16|0);yb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+16|0)}yb(c);break a}a=P()|0;O()|0}ld(g);S(a|0);L()}function M2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;g=gh(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[114578]=0;R(1533,g|0,a|0);c=v[114578];v[114578]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[114578]=0;c=Q(2184,c|0,a&65535)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;c=Q(85,d|0,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break e}v[114578]=0;U(2185,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(1535,g|0,d+16|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}yb(d+16|0);yb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+16|0)}yb(c);break a}a=P()|0;O()|0}ld(g);S(a|0);L()}function NZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=BE(c);b:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break b}Zq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}bi(i,k);Lc(k);l=e,m=fi(a),v[l>>2]=m;l=f,m=ei(a),v[l>>2]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);bi(h,k);Lc(k);a=Qj(a);break a}a=AE(c);c:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break c}Zq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}bi(i,k);Lc(k);l=e,m=fi(a),v[l>>2]=m;l=f,m=ei(a),v[l>>2]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);bi(h,k);Lc(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=(f>>>21&2040)+27888|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);ae(e+12|0,C(-1));g=C(z[e+12>>2]*C(32768));z[e+12>>2]=g;f=a;g=je(g);a:{if(C(D(g))<C(2147483648)){h=~~g;break a}h=-2147483648}i=f,j=Vc(h),u[i>>1]=j;f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);ae(e+12|0,C(-1));g=C(z[e+12>>2]*C(32768));z[e+12>>2]=g;f=a;g=je(g);b:{if(C(D(g))<C(2147483648)){h=~~g;break b}h=-2147483648}i=f,j=Vc(h),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function oR(a){var b=0,c=0;a:{if(qd(a,15083,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<52){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}}a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return 0}function paa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;Fd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<5){t[c+38|0]=w[w[d|0]+31850|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function RZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=GE(c);b:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break b}Zq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}Gb(i,k);yb(k);l=e,m=fi(a),t[l|0]=m;l=f,m=ei(a),t[l|0]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);Gb(h,k);yb(k);a=Qj(a);break a}a=EE(c);c:{if(b){Sj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Rj(k,a);break c}Zq(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Zg(k,a)}Gb(i,k);yb(k);l=e,m=fi(a),t[l|0]=m;l=f,m=ei(a),t[l|0]=m;ng(k,a);Gb(g,k);yb(k);_g(k,a);Gb(h,k);yb(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function HI(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=Se(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-9965.784284662086/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(Vg(d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(Vg(d*+y[a+4292>>2])),z[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=Vg(l*+(j+v[(e+h|0)+16>>2]>>>0));b=Vg(d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=f*.5;z[e+12>>2]=b*(.5-f);z[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=Vg(+GI(z[a+4208>>2])*.16609640474436813);b=Vg(+GI(z[a+4212>>2])*.33219280948873625);z[a+4228>>2]=d*4*K(b)/K(k);z[a+4224>>2]=d*K(1-b)}function d2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-80|0;jb=d;a=v[a+4>>2];Ru(d+16|0,b);v[114578]=0;b=Q(2,d|0,38630)|0;e=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[114578]=0;U(3,d+32|0,d+16|0,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break h}v[114578]=0;U(721,d+48|0,d+32|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break g}v[114578]=0;U(9,d- -64|0,0,d+48|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[114578]=0;R(c|0,a|0,d- -64|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}yb(d- -64|0);yb(d+48|0);yb(d+32|0);yb(b);yb(d+16|0);jb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(d- -64|0)}yb(d+48|0)}yb(d+32|0)}yb(b)}yb(d+16|0);S(a|0);L()}function b$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;a:{if((b|0)!=(c|0)){j=v[114552];v[114552]=0;f=jb-16|0;jb=f;le();g=jb-16|0;jb=g;h=jb-16|0;jb=h;Mv(h,b,e+28|0,2);b=v[h+4>>2];v[g>>2]=v[h>>2];v[g+4>>2]=b;b=v[h+12>>2];v[g+8>>2]=v[h+8>>2];v[g+12>>2]=b;jb=h+16|0;b=v[g+4>>2];v[f>>2]=v[g>>2];v[f+4>>2]=b;b=v[g+12>>2];v[f+8>>2]=v[g+8>>2];v[f+12>>2]=b;jb=g+16|0;b=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=b;b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;jb=f+16|0;i=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];b=v[114552];b:{if(b){if(v[e+28>>2]!=(c|0)){break b}if((b|0)!=68){break a}v[d>>2]=4;break a}v[114552]=j;if(v[e+28>>2]==(c|0)){break a}}}v[d>>2]=4;g=0;h=0;i=0;f=0}v[a>>2]=g;v[a+4>>2]=h;v[a+8>>2]=i;v[a+12>>2]=f;jb=e+32|0}function Kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=$n(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1373,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+32;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}g=jb-32|0;jb=g;d=a;i=zb(a);c=dm(a,xe(a)+1|0);f=xe(a);e=jb-16|0;jb=e;v[e+12>>2]=0;a=g+8|0;Tc(a+12|0,i);if(c){h=VL(c)}v[a>>2]=h;f=(f<<5)+h|0;v[a+8>>2]=f;v[a+4>>2]=f;j=ec(a),k=(c<<5)+h|0,v[j>>2]=k;jb=e+16|0;c=v[a+8>>2];v[114578]=0;U(1373,i|0,c|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+32;v[114578]=0;R(1374,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}WL(a);jb=g+32|0;break b}b=P()|0;O()|0;WL(a);S(b|0);L()}}function ux(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function i4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=lm(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(2127,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+16;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}g=jb-32|0;jb=g;d=a;i=zb(a);c=Mq(a,od(a)+1|0);f=od(a);e=jb-16|0;jb=e;v[e+12>>2]=0;a=g+8|0;Tc(a+12|0,i);if(c){h=CH(c)}v[a>>2]=h;f=(f<<4)+h|0;v[a+8>>2]=f;v[a+4>>2]=f;j=ec(a),k=(c<<4)+h|0,v[j>>2]=k;jb=e+16|0;c=v[a+8>>2];v[114578]=0;U(2127,i|0,c|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+16;v[114578]=0;R(2128,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}AH(a);jb=g+32|0;break b}b=P()|0;O()|0;AH(a);S(b|0);L()}}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-80|0;jb=c;h=nN(a,1<<b-1);v[a+12>>2]=b;a:{b=1<<b;f=b>>>2|0;if(f){i=1/+(b>>>0);b=f;e=1;while(1){v[114578]=0;A[c+40>>3]=+(b>>>0)*-6.283185307179586*i;U(1530,c+48|0,30864,c+40|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1219,c- -64|0,c+48|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=tc(h,e);g=v[c+76>>2];v[d+8>>2]=v[c+72>>2];v[d+12>>2]=g;g=v[c+68>>2];v[d>>2]=v[c+64>>2];v[d+4>>2]=g;e=e<<1;b=b>>>1|0;if(b){continue}break}}b=Bl(c+24|0,1,0);v[114578]=0;e=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=e;e=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=e;X(1531,a|0,0,f|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}jb=c+80|0;return a|0}a=P()|0;O()|0;ip(h);S(a|0);L()}function mma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-48|0;jb=e;a:{b:{if(v[a+8>>2]!=v[ec(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];f=v[a>>2];if(c>>>0>f>>>0){i=((c-f>>1)+1|0)/-2<<1;f=i+c|0;d=g;g=v[d>>2];if((g|0)!=(c|0)){while(1){rT(f,c);f=f+2|0;c=c+2|0;if((g|0)!=(c|0)){continue}break}}v[d>>2]=f;v[h>>2]=i+v[h>>2];break b}j=e,k=v[ec(a)>>2]-v[a>>2]|0,v[j+24>>2]=k;v[e+44>>2]=1;d=v[bd(e+24|0,e+44|0)>>2];d=wT(e+24|0,d,d>>>2|0,v[a+16>>2]);c=Qc(e+16|0,v[a+4>>2]);f=v[Qc(e+8|0,v[a+8>>2])>>2];c=v[c>>2];v[114578]=0;U(523,d|0,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}Zb(a,d);Zb(h,d+4|0);Zb(g,d+8|0);Zb(ec(a),ec(d));Yt(d)}mA(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+2;jb=e+48|0;return}a=P()|0;O()|0;Yt(d);S(a|0);L()}function t2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}k=-1;l=-1;h=f&24;a:{if(!h|((h|0)==24?(e|0)==1:0)){break a}h=v[b+44>>2];if(h){g=h-Tb(b+32|0)|0;m=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;i=e;j=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;i=e;j=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=m;j=g}d=d+j|0;c=c+i|0;d=i>>>0>c>>>0?d+1|0:d;e=c;c=d;if((d|0)<0|((d|0)>(g|0)?1:(g|0)<=(d|0)?e>>>0>m>>>0:0)){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(d){Nm(b,v[b+8>>2],e+v[b+8>>2]|0,v[b+44>>2])}if(f&16){Mw(b,v[b+20>>2],v[b+28>>2]);Mr(b,e)}k=e;l=c}Og(a,k,l)}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-16|0;jb=g;e=b;f=Kb(e);d=c;a:{if(f>>>0<d>>>0){j=jb-32|0;jb=j;b:{c:{h=d-f|0;d:{if(h>>>0<=v[zb(e)>>2]-v[e+4>>2]>>2>>>0){NP(e,h);break d}i=zb(e);k=Be(e,Kb(e)+h|0);m=Kb(e);f=0;l=jb-16|0;jb=l;v[l+12>>2]=0;d=j+8|0;Tc(d+12|0,i);if(k){f=JP(k)}v[d>>2]=f;i=(m<<2)+f|0;v[d+8>>2]=i;v[d+4>>2]=i;n=ec(d),o=(k<<2)+f|0,v[n>>2]=o;jb=l+16|0;v[114578]=0;R(950,d|0,h|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;R(951,e|0,d|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}HP(d)}jb=j+32|0;break b}a=P()|0;O()|0;HP(d);S(a|0);L()}break a}if(d>>>0<f>>>0){d=v[e>>2]+(d<<2)|0;Kb(e);IP(e,d);Qg(e)}}c=Qb(a,c<<2);if(c){Hz(g+8|0,b);Bd(a,g+8|0)}jb=g+16|0;return c|0}function uha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;Fd(b,0);Qi(d,1,a);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;Ys(b,+((w[a+60|0]^8)-120|0)*.005208333333333333);t[d+16|0]=w[a+61|0];t[d|0]=64;e=b,f=w[pc(d+16|0,d)|0]<<2,u[e+30>>1]=f;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<=-1){u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function pN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=ns(b);d=jb-16|0;jb=d;e=a;f=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1226,a+8|0,d+12|0,d+8|0)|0;h=v[114578];v[114578]=0;a:{if((h|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}v[114578]=0;R(1220,a|0,2048);a=v[114578];v[114578]=0;b:{if((a|0)!=1){v[114578]=0;R(1222,e|0,2048);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;ty(f);S(a|0);L()}a=0;c:{while(1){c=1;if((a|0)!=1024){v[114578]=0;c=+(a-1024|0);i=+hb(1214,+(K(c*c*-9.5367431640625e-7+1)*b));f=v[114578];v[114578]=0;if((f|0)==1){break c}c=c*.0372006759294457;c=i*ii(c)/(c*g)}j=Uk(e,a),k=c*.011841342921061943,A[j>>3]=k;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Mf(e);S(a|0);L()}function iW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-96|0;jb=g;Bi(g+48|0,g+40|0,c);v[114578]=0;c=g+60|0;U(224,c|0,g+32|0,d|0);d=v[114578];v[114578]=0;a:{b:{h=g+48|0;c:{d:{e:{f:{if((d|0)!=1){v[114578]=0;U(224,g+72|0,g+24|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}v[114578]=0;U(224,g+84|0,g+16|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break e}v[114578]=0;R(225,g+8|0,g+48|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,g+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}gD(g+48|0);jb=g+96|0;return}a=P()|0;O()|0;break c}a=P()|0;O()|0;b=2;break d}a=P()|0;O()|0;b=3}c=h+B(b,12)|0}while(1){c=yb(c-12|0);if((c|0)!=(g+48|0)){continue}break}break a}a=P()|0;O()|0;gD(g+48|0)}S(a|0);L()}function T3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;b=v[a+4>>2];c=f;a=v[a>>2];v[c>>2]=a;v[c+4>>2]=b;v[c+8>>2]=a;v[c+12>>2]=b;b=jb+-64|0;jb=b;a:{b:{e=v[c+4>>2];if(!e){break b}d=78208;while(1){a=v[c+4>>2];v[b+56>>2]=v[c>>2];v[b+60>>2]=a;a=qc(b+48|0,v[d+8>>2]);g=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=g;g=v[a+4>>2];v[b+16>>2]=v[a>>2];v[b+20>>2]=g;if(YK(b+24|0,b+16|0)){break b}d=d+12|0;if((d|0)!=78724){continue}break}d=78736;while(1){c:{a=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=a;a=qc(b+32|0,v[d+8>>2]);e=v[b+44>>2];v[b+8>>2]=v[b+40>>2];v[b+12>>2]=e;e=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=e;a=YK(b+8|0,b);if(a){break c}d=d+12|0;if((d|0)!=78784){continue}}break}jb=b- -64|0;break a}jb=b- -64|0;a=(e|0)!=0}jb=f+16|0;return a|0}function Uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=wc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/12>>>0){e=jb-16|0;jb=e;d:{b=bl(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(1024,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+12|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=Qy(d+8|0,tm(a,wc(a)+c|0),wc(a),b);v[114578]=0;R(1019,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1020,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}TO(b)}jb=d+32|0;break a}a=P()|0;O()|0;TO(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,12)|0;wc(a);UO(a,b);ft(a)}}function ZK(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Qo(a,C(1));Po(a,C(3.725290298461914e-9));Oo(a,C(268435456));No(a,0);break b;case 1:Qo(a,C(32));Po(a,C(4.656612873077393e-10));Oo(a,C(2147483648));No(a,0);break b;case 2:Qo(a,C(2));Po(a,C(7.450580596923828e-9));Oo(a,C(134217728));No(a,1);break b;default:Qo(a,C(1));Po(a,C(7.450580596923828e-9));Oo(a,C(134217728));No(a,1);Dx(a,0);ul(a,1);Cx(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Qo(a,C(.75));Po(a,C(7.450580596923828e-9));Oo(a,C(134217728));No(a,1);Dx(a,0);b=(b|0)==4;ul(a,b?2:3);Cx(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Dx(a,1);ul(a,0);Cx(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function vo(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;e=j(0)|0;a:{b:{c:{d:{if((b|0)>0?1:(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|e)){return-1/(a*a)}if((b|0)>-1){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(e){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;e=j(0)|0;g=-1077}b=b+614242|0;d=+((b>>>20|0)+g|0);l(0,e|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);h=d*.6931471803691238;i=a;k=d*1.9082149292705877e-10;m=c;d=a*(a*.5);c=c*c;a=c*c;a=h+(i+(k+m*(d+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))-d))}return a}function V4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{c:{if((e|0)==1){break c}v[114578]=0;Z(2041,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Z(2041,c|0);f=v[114578];v[114578]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);v[114578]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;X(2085,f|0,d+8|0,d|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37201,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}jb=d+32|0;return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Ni(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=jb-16|0;jb=e;d:{b=_S(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(742,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+48|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=YS(d+8|0,ZS(a,Ni(a)+c|0),Ni(a),b);v[114578]=0;R(697,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(558,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Nt(b)}jb=d+32|0;break a}a=P()|0;O()|0;Nt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Ni(a);$S(a,b);iT(a)}}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=(f>>>21&2040)+27888|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function _8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=qe(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(1653,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=DJ(d+8|0,Be(a,Kb(a)+c|0),Kb(a),b);v[114578]=0;R(1650,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1647,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}es(b)}jb=d+32|0;break a}a=P()|0;O()|0;es(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Kb(a);yJ(a,b);Qg(a)}}function bH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}b=ba(8)|0;v[114578]=0;c=Q(85,f|0,40657)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,896)|0)+1075072|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,896);if((b|0)==x[(e+v[d>>2]|0)+1075792>>1]){e=(e+v[d>>2]|0)+1075072|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}jb=f+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function KS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+24>>2]=b;k=e,l=Ed(a),v[k+8>>2]=l;g=$l(e+24|0,e+8|0);b=Pi(c,d);a:{b:{if(!b){break b}if(Zz(c,Tb(a),Tb(a)+Fb(a)|0)){b=ri(e+8|0,c,d);c=v[e+24>>2];d=Tb(b);g=Tb(b);h=Fb(b);v[114578]=0;c=aa(610,a|0,c|0,d|0,g+h|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}h=Fb(a);f=Kc(a);c:{if(b>>>0<=f-h>>>0){f=Tb(a);i=h-g|0;if(!i){break c}j=g+f|0;_l(b+j|0,j,i);break c}Rl(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;Sg(a,b);t[e+8|0]=0;he(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){he(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=Ed(a),v[k+8>>2]=l;c=cf(e+8|0,g)}jb=e+32|0;return c|0}function Zba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=C(0),i=0,j=C(0),k=0,m=0;f=jb-16|0;jb=f;k=f,m=B(v[a>>2],ue(a)),v[k+8>>2]=m;Cc(f+8|0,c>>>2|0);c=Db(b);g=z[e+4>>2];e=v[f+8>>2];if(e){while(1){g=C(G(C(D((l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q()))),g));c=c+4|0;e=e-1|0;if(e){continue}break}}c=g==C(0);a:{if(c){break a}e=v[f+8>>2];if(!e){break a}j=c?C(1):C(C(1)/g);c=v[a+20>>2];while(1){z[f+12>>2]=j*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());ae(f+12|0,C(-1));h=C(z[f+12>>2]*C(32768));z[f+12>>2]=h;a=c;h=je(h);b:{if(C(D(h))<C(2147483648)){i=~~h;break b}i=-2147483648}k=a,m=Vc(i),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=g}jb=f+16|0;return v[f+8>>2]<<2}function rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;v[d+28>>2]=0;Fi(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Wb(d+16|0);v[114578]=0;u[d+14>>1]=0;f=W(722,a|0,e|0,255)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!f){break d}v[114578]=0;Q(713,a|0,d+14|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;U(13,d|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;f=Q(723,b|0,d+14|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}Gb(f,d);yb(d);yb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}Gf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}yb(e)}jb=d+32|0;return}a=P()|0;O()|0}yb(e);S(a|0);L()}function qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;u[d+30>>1]=0;xf(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Wb(d+16|0);v[114578]=0;u[d+14>>1]=0;f=W(724,a|0,e|0,255)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(!f){break d}v[114578]=0;Q(713,a|0,d+14|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}v[114578]=0;U(13,d|0,c|0,e|0);f=v[114578];v[114578]=0;if((f|0)==1){break f}v[114578]=0;f=Q(723,b|0,d+14|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break e}Gb(f,d);yb(d);yb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}Gf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}yb(e)}jb=d+32|0;return}a=P()|0;O()|0}yb(e);S(a|0);L()}function eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{if(mj(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[lf(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){ee(d+8|0,b,c);if(!Cb(d+8|0)){v[114578]=0;e=Q(1426,a|0,c&65535)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(e){v[114578]=0;e=Q(85,d+8|0,20525)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;Q(371,((c<<5)+a|0)+946300|0,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}yb(e);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}jb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(e);break a}c=P()|0;O()|0}S(c|0);L()}function $i(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){lc(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}t[a|0]=w[b|0];b=b+1|0;c=c-1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[a>>2]=v[b>>2];b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[a|0]=w[b|0];a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}}function io(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Ac(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){e=jb-16|0;jb=e;d:{b=Mi(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(218,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+1|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=nh(d+8|0,Ki(a,Ac(a)+c|0),Ac(a),b);v[114578]=0;R(213,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(209,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}nm(b)}jb=d+32|0;break a}a=P()|0;O()|0;nm(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+b|0;Ac(a);jD(a,b);tp(a)}}function _0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;b=d+16|0;a:{b:{c:{if(!wr(wa(v[a+60>>2],d+16|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<=-1){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!wr(wa(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}jb=d+32|0;return a|0}function Iw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];v[c+40>>2]=v[d+20>>2];g=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=g;Lm(c- -64|0,c+32|0,f);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];g=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;a=c;if(f){j=b+4|0;while(1){d=0;if(g){while(1){e=v[Of(a,d,h)>>2];fc(b,d);e=(e+((Kr(j)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;e=e>>>0>491520?e:491520;k=Km(i,d,h),l=(e|0)<557055?e:557055,u[k>>1]=l;d=d+1|0;if((g|0)!=(d|0)){continue}break}}h=h+1|0;if((f|0)!=(h|0)){continue}break}}jb=c+80|0}function Jw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Eh(c- -64|0,c+32|0,f);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(f){while(1){d=0;if(e){while(1){i=A[ch(a,d,g)>>3];fc(b,d);j=sj(Sd(i*134217728));k=qn(h,d,g),l=C(+(j|0)*7.450580596923828e-9),z[k>>2]=l;d=d+1|0;if((e|0)!=(d|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];c=v[Lb(e+12|0,e+8|0)>>2];i=z[d>>2];b=Db(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=i*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=h,k=Vc(g),u[j>>1]=k;z[e+12>>2]=i*(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}j=h,k=Vc(g),u[j+2>>1]=k;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return c<<3}function b5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114578]=0;Z(2041,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114578]=0;c=Q(85,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;X(2076,d+16|0,e|0,c|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break d}b=Zd(Tb(d+16|0));yb(d+16|0);yb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(c)}_(b|0)|0;b=0;v[114578]=0;X(1989,36929,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=d+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Rb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}f=a+c|0;t[f-1|0]=b;t[a|0]=b;if(c>>>0<3){break a}t[f-2|0]=b;t[a+1|0]=b;t[f-3|0]=b;t[a+2|0]=b;if(c>>>0<7){break a}t[f-4|0]=b;t[a+3|0]=b;if(c>>>0<9){break a}f=0-a&3;e=f+a|0;d=B(b&255,16843009);v[e>>2]=d;b=c-f&-4;c=b+e|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[e+8>>2]=d;v[e+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[e+24>>2]=d;v[e+20>>2]=d;v[e+16>>2]=d;v[e+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=e&4|24;c=c-b|0;if(c>>>0<32){break a}d=Fma(d,0,1,1);f=mb;b=b+e|0;while(1){v[b+24>>2]=d;e=f;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function qF(a,b,c,d,e,f){var g=0;g=jb-80|0;jb=g;a:{if((f|0)>=16384){td(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if((f|0)<32767){f=f-16383|0;break a}td(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}td(g- -64|0,b,c,d,e,0,0,0,65536);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if((f|0)>-32765){f=f+16382|0;break a}td(g+48|0,b,c,d,e,0,0,0,65536);f=((f|0)>-49146?f:-49146)+32764|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}td(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;jb=g+80|0}function K5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114578]=0;Z(2041,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114578]=0;c=Q(85,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break e}v[114578]=0;U(2042,d+16|0,e|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break d}b=Zd(Tb(d+16|0));yb(d+16|0);yb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(c)}_(b|0)|0;b=0;v[114578]=0;X(1989,35695,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=d+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Dk(a,b,c,d){var e=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}d=v[hc(a)>>2];b=v[c>>2];c=(d|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}e=ug(v[b+8>>2]);c=v[b+8>>2];b:{c:{if(e){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){c=c+12|0;b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];break c}if(!ug(b)){b=v[b+8>>2];Ep(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Dp(b);break a}c=v[v[c+8>>2]>>2];if(!c|w[c+12|0]){break b}c=c+12|0;b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2]}t[b+12|0]=(b|0)==(d|0);t[c|0]=1;if((b|0)!=(d|0)){continue}break a}break}if(ug(b)){b=v[b+8>>2];Dp(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Ep(b)}a=zb(a);v[a>>2]=v[a>>2]+1}function B6(a){a=a|0;var b=0;b=34280;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=34317;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=34181;break a}b=34294;break a}b=34336;break a}b=34350;break a}b=34364;break a}b=34376;break a}b=34396;break a}b=34417;break a}b=34429;break a}b=34448;break a}b=34480;break a}b=34502;break a}if((a|0)!=357){break a}b=34519}return Zd(b)|0}function gg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=qe(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(373,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=Un(d+8|0,Be(a,Kb(a)+c|0),Kb(a),b);v[114578]=0;R(369,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(370,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Wh(b)}jb=d+32|0;break a}a=P()|0;O()|0;Wh(b);S(a|0);L()}return}if(b>>>0<c>>>0){Cu(a,v[a>>2]+(b<<2)|0)}}function ak(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;v[a+4>>2]=0;a:{b:{d=4;c:{if(!w[gj(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[114578]=0;d=v[(a+d|0)+24>>2];f=v[114578];v[114578]=0;d:{if((f|0)==1){break d}v[114578]=0;b=W(2385,d|0,b|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;ej(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114578]=0;b=v[(a+b|0)+20>>2];c=v[114578];v[114578]=0;e:{if((c|0)!=1){if(!(b&1)){break e}v[114578]=0;Y(81);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)==1){break b}S(a|0);L()}$();d=1}Ag(v[v[a>>2]-12>>2]+a|0,d);jb=e+16|0;return}V(0)|0;O()|0;Ab()}L()}function dn(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+829|0]=c;break a}c=w[b+829|0]}d=v[a+480180>>2]&202376205?c&240?c&-16:c&15:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){bp(a,b,(d&240)>>>4|0,0);return}if(!(t[b+872|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){ap(a,b,f,0);return}if(!(t[b+872|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288?!(!(t[b+872|0]&1)|w[a+480208|0]&2):0){break c}e=d&255;d=d&15;d:{if(d){if(v[a+480180>>2]&16777248?e&240:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Yb(c,0,256),v[g+688>>2]=h}function dN(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c;if(x[a+28>>1]!=(b|0)){Ms(a+12|0);u[a+28>>1]=b}c=a+12|0;if(nd(c)){fN(c,ry(a,x[rc(hp(a),b)>>1]))}f=e+12|0;a:{if(v[c+4>>2]!=v[zb(c)>>2]){b=jb-16|0;jb=b;a=qe(b,c,1);c=zb(c);d=v[a+4>>2];v[114578]=0;U(413,c|0,d|0,f|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+4;Mb(a);jb=b+16|0;break a}b=P()|0;O()|0;Mb(a);S(b|0);L()}d=jb-32|0;jb=d;a=c;g=zb(a);b=ms(d+8|0,Be(a,Kb(a)+1|0),Kb(a),g);c=v[b+8>>2];v[114578]=0;U(413,g|0,c|0,f|0);c=v[114578];v[114578]=0;b:{c:{if((c|0)==1){break c}v[b+8>>2]=v[b+8>>2]+4;v[114578]=0;R(96,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}nk(b);jb=d+32|0;break b}a=P()|0;O()|0;nk(b);S(a|0);L()}}jb=e+16|0}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=(e<<1)+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=jb-16|0;jb=g;v[g+8>>2]=c>>>3;v[g+4>>2]=v[a>>2];d=v[Lb(g+8|0,g+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){k=0;e=b;h=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);i=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);f=h<<24|i>>>8;e=0;l=f&65280;f=e;e=h<<8|i>>>24;f=f|k;k=e&255|l|(i<<24|i<<8&16711680);e=g;v[e+8>>2]=((h&255)<<24|i>>>8)&-16777216|((h&16777215)<<8|i>>>24)&16711680|(h>>>8&65280|h>>>24)|f;v[e+12>>2]=k;Rf(e+8|0,-1,1);j=A[e+8>>3]*32768;A[e+8>>3]=j;e=a;j=Sd(j);a:{if(D(j)<2147483648){f=~~j;break a}f=-2147483648}m=e,n=Vc(f),u[m>>1]=n;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=g+16|0;return d<<3}function pG(a,b,c,d){a:{if(b>>>0>20){break a}b:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 1:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return;case 4:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 5:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 6:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 8:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 9:break b;default:break a}}nb[d|0](a,c)}}function pz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;gg(b,w[pc(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Kb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Pb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}e=x[Pb(b,e)>>1];h=Pb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Yb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Pb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=g+16|0}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;e=(e<<1)+k|0;f=(f>>>21&2040)+27888|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(g,e);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function pl(a,b){var c=0,d=0,e=0,f=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=qe(e,a,c);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);f=v[b+4>>2];v[114578]=0;R(1622,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=kx(d+8|0,Be(a,Kb(a)+c|0),Kb(a),b);v[114578]=0;R(1599,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1598,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Vm(b)}jb=d+32|0;break a}a=P()|0;O()|0;Vm(b);S(a|0);L()}return}if(b>>>0<c>>>0){lx(a,v[a>>2]+(b<<2)|0)}}function GF(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[114578]=0;c=Q(2389,d+8|0,a|0)|0;b=v[114578];v[114578]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[114578]=0;b=T(2390,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[114578]=0;R(2391,a+b|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;EF(c);break c}EF(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[114578]=0;Z(19,a+c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(762,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,d|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(519,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,d|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function jS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(512,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;Q(471,d|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];h=v[a+4>>2];e=h;f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;h=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=h;if(d){while(1){e=e+k|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,j);v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function J9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;sL(a);zb(a);i=b+4|0;g=i;f=v[a+4>>2];j=v[a>>2];if((f|0)!=(j|0)){c=v[g>>2];while(1){d=c-52|0;f=f-52|0;c=f;e=gK(d,zb(c));v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];h=v[zb(c)>>2];l=zb(e),m=h,v[l>>2]=m;l=zb(c),m=0,v[l>>2]=m;v[c>>2]=0;v[c+4>>2]=0;v[d+20>>2]=v[c+20>>2];e=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=e;e=c+24|0;h=mB(d+24|0,zb(e));v[d+24>>2]=v[e>>2];v[d+28>>2]=v[e+4>>2];k=v[zb(e)>>2];l=zb(h),m=k,v[l>>2]=m;l=zb(e),m=0,v[l>>2]=m;v[e>>2]=0;v[e+4>>2]=0;cd(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];c=v[g>>2]-52|0;v[g>>2]=c;if((f|0)!=(j|0)){continue}break}}Zb(a,i);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];hK(a,jf(a))}function x1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;a:{b:{if(!ve(b,-1)){f=v[a+12>>2];g=v[a+8>>2];if(v[a+24>>2]==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}h=v[a+24>>2];i=v[a+20>>2];j=v[a+44>>2];k=v[a+20>>2];v[114578]=0;c=a+32|0;R(110,c|0,0);d=v[114578];v[114578]=0;if((d|0)==1){break b}d=Kc(c);v[114578]=0;R(149,c|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}d=Tb(c);Mw(a,d,Fb(c)+d|0);Mr(a,h-i|0);v[a+44>>2]=v[a+20>>2]+(j-k|0)}v[e+12>>2]=v[a+24>>2]+1;l=a,m=v[bd(e+12|0,a+44|0)>>2],v[l+44>>2]=m;if(w[a+48|0]&8){c=Tb(a+32|0);Nm(a,c,c+(f-g|0)|0,v[a+44>>2])}c=VG(a,Jm(b));break a}c=Gr(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$();c=-1}jb=e+16|0;return c|0}function dU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;Fd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=aq(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=aq(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[pc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(_s(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}jb=d+16|0}function tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];g=v[a+4>>2];b=g;f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;g=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=g;a:{if(d){while(1){j=v[a+32>>2];i=v[a+28>>2]+i|0;g=i>>12;b=b+k|0;f=(f>>>21&2040)+27888|0;b=(((B(t[b|0],u[f+2>>1])+B(t[b-1|0],u[f>>1])|0)+B(t[b+1|0],u[f+4>>1])|0)+B(t[b+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(g,b);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=h>>12;g=i>>12}v[a+40>>2]=h;v[a+20>>2]=g;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;jb=e+16|0}function Ir(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Eh(c- -64|0,c+32|0,f);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(f){while(1){d=0;if(e){while(1){i=v[Of(a,d,g)>>2];fc(b,d);j=qn(h,d,g),k=C(C(i|0)*C(7.450580596923828e-9)),z[j>>2]=k;d=d+1|0;if((e|0)!=(d|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function vJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-48|0;jb=c;v[c+8>>2]=542066252;d=c+8|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Fk(b,33);lc(v[b>>2],c+8|0,33);Vi(c,b);Od(a,c);jb=c+48|0}function E2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-32|0;jb=b;e=gh(a);Dd(b+24|0);v[114578]=0;a=Q(2200,v[b+24>>2],v[b+28>>2])|0;c=v[114578];v[114578]=0;a:{b:{if((c|0)==1){break b}v[114578]=0;R(1533,e|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}a=0;c:{while(1){v[114578]=0;c=Q(2200,v[b+24>>2],v[b+28>>2])|0;d=v[114578];v[114578]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}jb=b+32|0;return}a=P()|0;O()|0;break a}c=v[v[b+24>>2]+(a<<3)>>2];v[114578]=0;c=Q(85,b+8|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(1535,e|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}yb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0}ld(e);S(a|0);L()}function YJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;f=Wb(e+32|0);v[114578]=0;Q(1620,a|0,e+24|0)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){g=v[e+28>>2];d=v[e+24>>2];Le(f);v[114578]=0;g=!g&d>>>0<255?d:255;R(149,f|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=kc(f,d);v[114578]=0;Q(1621,a|0,h|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((JD(f)|0)!=-1){a=JD(f);v[114578]=0;R(149,f|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}}v[114578]=0;U(13,e+8|0,c|0,f|0);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}break a}Gb(b,e+8|0);yb(e+8|0);yb(f);jb=e+48|0;return}a=P()|0;O()|0;yb(f);S(a|0);L()}function Aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-48|0;jb=c;d=c+24|0;f=Oi(d+8|0);v[114578]=0;e=T(332,b|0)|0;g=v[114578];v[114578]=0;a:{b:{if((g|0)==1){break b}v[114578]=0;U(423,d|0,b|0,e|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}d=v[d>>2];v[114578]=0;Q(340,b|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Pg(f);S(a|0);L()}v[114578]=0;R(703,c+8|0,c+24|0);b=v[114578];v[114578]=0;c:{if((b|0)==1){break c}v[114578]=0;R(704,c+16|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=v[c+16>>2];d=v[c+20>>2];v[114578]=0;W(705,a|0,b|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}Ec(c+24|0);jb=c+48|0;return}a=P()|0;O()|0;Ec(c+24|0);S(a|0);L()}function Fea(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;f=TE(v[v[a>>2]-12>>2]+a|0,10);e=jb-16|0;jb=e;v[114578]=0;c=a;d=Q(15,e+8|0,c|0)|0;b=v[114578];v[114578]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[d|0]){break e}b=Sk(e,c);v[114578]=0;Q(2397,b|0,f|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){if(!Qk(b)){break e}b=v[v[c>>2]-12>>2];v[114578]=0;R(18,b+c|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Hf(d);break d}Hf(d);break c}b=V(0)|0;O()|0}_(b|0)|0;d=v[v[c>>2]-12>>2];v[114578]=0;Z(19,c+d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}$()}jb=e+16|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}mr(a);return a|0}function Fia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-528|0;jb=d;c=-1;a:{if(!Df(a,1468)){break a}yk(a,1464);CQ(a,d+524|0);if(!$d(d+524|0,16026)){c=0;if(!$d(d+524|0,16031)){break a}}yk(a,20);b=1;while(1){c=-1;if(!zQ(a,d)){break a}e=nz(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}e=d+520|0;c=jb-16|0;jb=c;b=a;b:{if(Df(a,2)){Pk(c+8|0,e);fz(b,c+8|0);break b}t[c+7|0]=0;fB(e,c+7|0)}jb=c+16|0;e=dd(d+520|0);c=0;if(w[d+520|0]>128){break a}b=d;c=jb-16|0;jb=c;c:{if(Df(a,512)){_t(c+8|0,b);fz(a,c+8|0);break c}iQ(b)}jb=c+16|0;a=d+512|0;c=w[e|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}jb=d+528|0;return c|0}function cK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=C(0),j=0,k=C(0);f=jb-16|0;jb=f;if(!(!x[b>>1]|u[d>>1]>u[d+2>>1]|(!(z[c>>2]>C(0))|(u[d+2>>1]-u[d>>1]|0)>32766))){u[a>>1]=3;g=a+4|0;ui(g);u[a+28>>1]=65472;v[f+12>>2]=1065353216;eK(g,128,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;ui(a+16|0);u[a+28>>1]=x[d>>1];e=jb-16|0;jb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[lf(e+14|0,e+12|0)>>1];jb=e+16|0;u[a+30>>1]=b;h=C(D(z[c>>2]));z[a+32>>2]=h;h=ne(h,C(C(1)/C(u[a+30>>1])));e=1;pl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){i=ne(h,C(b|0));j=Pb(g,b-u[a+28>>1]|0),k=i,z[j>>2]=k;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}Mo(a)}jb=f+16|0;return e|0}function Ko(a,b,c){var d=0,e=0,f=0;d=Wb(a);a=Fb(b);v[114578]=0;R(111,d|0,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){a:{if(Fb(b)){while(1){f=v[hj(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[114578]=0;R(110,d|0,a<<24>>24);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[114578]=0;R(110,d|0,63);a=v[114578];v[114578]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Fb(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;yb(d);S(a|0);L()}function I9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-16|0;jb=c;u[a>>1]=0;e=kk(a+4|0);h=kk(a+16|0);v[a+36>>2]=0;j=gd(a+40|0);f=jb-16|0;jb=f;g=f+8|0;b=jb-16|0;jb=b;v[114578]=0;i=a+52|0;d=i;T(1595,d+4|0)|0;k=v[114578];v[114578]=0;a:{b:{c:{if((k|0)!=1){v[114578]=0;v[b+12>>2]=0;W(1596,d+8|0,b+12|0,g|0)|0;g=v[114578];v[114578]=0;if((g|0)!=1){break c}break b}break b}l=d,m=hc(d),v[l>>2]=m;jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=f+16|0;ui(e);u[a+28>>1]=65472;v[114578]=0;v[c+12>>2]=1065353216;U(1593,e|0,128,c+12|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;ui(h);jb=c+16|0;return a|0}a=P()|0;O()|0;YR(i);yb(j);Sf(h);Sf(e);S(a|0);L()}function so(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;f=d?d:461448;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[21203]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+60112>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[114552]=25;e=-1;break a}v[f>>2]=d}jb=h+16|0;return e|0}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){v[e+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=h,j=Vc(g),u[i>>1]=j;v[e+12>>2]=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);b:{if(C(D(f))<C(2147483648)){g=~~f;break b}g=-2147483648}i=h,j=Vc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function dH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=jb-16|0;jb=d;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114578]=0;d=Q(85,d|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,d);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}if(!(c<=1?!(c<0):0)){a=ba(8)|0;v[114578]=0;d=Q(85,d|0,40635)|0;b=v[114578];v[114578]=0;if((b|0)!=1){mc(a,d);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=mn(c*64);v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]=e;jb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function kea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-48|0;jb=d;a:{b:{if(v[a+8>>2]!=v[ec(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];e=v[a>>2];if(c>>>0>e>>>0){f=c;c=((c-e>>2)+1|0)/-2<<2;i=g,j=gf(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=d,j=v[ec(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[d+44>>2]=1;c=v[bd(d+24|0,d+44|0)>>2];c=Un(d+24|0,c,c>>>2|0,v[a+16>>2]);e=Qc(d+16|0,v[a+4>>2]);f=v[Qc(d+8|0,v[a+8>>2])>>2];e=v[e>>2];v[114578]=0;U(1161,c|0,e|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Zb(a,c);Zb(h,c+4|0);Zb(g,c+8|0);Zb(ec(a),ec(c));Wh(c)}sR(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;jb=d+48|0;return}a=P()|0;O()|0;Wh(c);S(a|0);L()}function by(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{if(!d){break a}if(c){t[b+835|0]=c;break a}c=w[b+835|0]}c=v[a+480180>>2]&1048580?c&240?c&-16:c&15:c;b:{c:{d:{if(!(v[a+480180>>2]&1048580)){d=c&240;c=c&15;if(!(!d|(c|0)!=15)){if(!(w[a+480209|0]&16)){break b}c=0-(d>>>2|0)|0;break d}f=v[a+480208>>2]&4096;if(!(!c|(d|0)!=240)){if(!f){break b}c=c<<2;break c}if(f){break b}if(c){c=c<<2;if(!d|!(v[a+480180>>2]&16777248)){break c}break b}c=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Eb(e+8|0,a+1074308|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;c=a;if(!Cb(e+8|0)){break d}c=(a|0)/4<<24>>24}if(!c){break b}}a=Yb(v[b+692>>2]+c|0,0,256);u[b+796>>1]=0;v[b+692>>2]=a}jb=e+16|0}function sQ(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Qb(a,1024)){gz(c+24|0,b);Bd(a,c+24|0);break a}v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;a=64;while(1){d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}jb=c+32|0}function M9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{f=jb-16|0;jb=f;d=c;zb(c);a=b;h=gK(a,f+8|0);b:{g=bg(c);if(!g){break b}v[114578]=0;R(680,a|0,g|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[d+4>>2];d=v[d>>2];v[114578]=0;X(1591,a|0,d|0,e|0,g|0);d=v[114578];v[114578]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;Dt(h);S(a|0);L()}jb=f+16|0;d=a;v[b+20>>2]=v[c+20>>2];a=v[c+16>>2];v[b+12>>2]=v[c+12>>2];v[b+16>>2]=a;v[114578]=0;e=Q(1590,b+24|0,c+24|0)|0;a=v[114578];v[114578]=0;c:{d:{if((a|0)!=1){v[114578]=0;Q(120,b+36|0,c+36|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break d}v[b+48>>2]=v[c+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;oe(e)}Ll(d);S(a|0);L()}}function H8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=qi(a,b,c,d);v[a>>2]=79476;c=Oi(a+4208|0);d=a+4288|0;v[d>>2]=0;v[d+4>>2]=0;v[a+4280>>2]=0;v[a+4284>>2]=0;v[114578]=0;d=da(1395)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;d=T(1396,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[a+4296>>2]=d;t[a+4244|0]=0;v[a+4236>>2]=2147483647;v[a+4240>>2]=0;ds(a);cs(a);v[114578]=0;W(1640,a+44|0,2,2)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;Z(1641,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Pg(c);bf(b);S(a|0);L()}function zia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;Le(b);Me(e+56|0,a,d);a=v[e+56>>2];v[114578]=0;f=T(414,e+56|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114578]=0;f=T(415,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;X(416,e+8|0,2,f|0,a|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;R(417,e+24|0,e+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;U(13,e+40|0,c|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Gb(b,e+40|0);yb(e+40|0);yb(e+24|0);Ec(e+56|0);jb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e+24|0)}Ec(e+56|0);S(a|0);L()}return a|0}function Ria(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;Le(b);Me(e+56|0,a,d);a=v[e+56>>2];v[114578]=0;f=T(414,e+56|0)|0;g=v[114578];v[114578]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114578]=0;f=T(415,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break d}v[114578]=0;X(416,e+8|0,3,f|0,a|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;R(417,e+24|0,e+8|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;U(13,e+40|0,c|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Gb(b,e+40|0);yb(e+40|0);yb(e+24|0);Ec(e+56|0);jb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e+24|0)}Ec(e+56|0);S(a|0);L()}return a|0}function Gw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Do(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(e){while(1){d=0;if(f){while(1){i=A[ch(a,d,g)>>3];fc(b,d);j=sj(Sd(i*134217728));k=Of(h,d,g),l=C(+(j|0)*7.450580596923828e-9),z[k>>2]=l;d=d+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function YK(a,b){var c=0,d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;if(v[a+4>>2]==v[b+4>>2]){c=v[a+4>>2];g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=c;d=v[b+4>>2];a=f;b=v[b>>2];v[a+16>>2]=b;v[a+20>>2]=d;v[a+8>>2]=g;v[a+12>>2]=c;v[a>>2]=b;v[a+4>>2]=d;c=jb-16|0;jb=c;d=a+8|0;v[c+12>>2]=v[d+4>>2];b=a;v[c+8>>2]=v[a+4>>2];a:{b:{if(!v[Lb(c+12|0,c+8|0)>>2]){break b}while(1){a=Io(t[xc(d,e)|0]);g=Io(t[xc(b,e)|0]);if((a|0)!=(g|0)){a=(a&255)>>>0<(g&255)>>>0?-1:1;break a}if(a){v[c+12>>2]=v[d+4>>2];v[c+8>>2]=v[b+4>>2];e=e+1|0;if(e>>>0>=y[Lb(c+12|0,c+8|0)>>2]){break b}continue}break}a=0;break a}a=0;if(v[d+4>>2]==v[b+4>>2]){break a}a=y[d+4>>2]<y[b+4>>2]?-1:1}jb=c+16|0;e=!a}jb=f+32|0;return e}function Nx(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-16|0;jb=c;if(!nd(a)){l=c,m=bc(a),v[l+8>>2]=m;l=c,m=cc(a),v[l>>2]=m;if(Jb(c+8|0,c)){while(1){b=v[c+8>>2];Yn(b,4194304,67108864);e=v[b>>2];f=e+f|0;b=g;b=f>>>0<e>>>0?b+1|0:b;g=b;_d(c+8|0);if(Jb(c+8|0,c)){continue}break}}b=Kb(a);h=Kb(a);l=c,m=bc(a),v[l+8>>2]=m;l=c,m=cc(a),v[l>>2]=m;b=Ima(f,g,b,0);e=mb;f=h<<24;g=0;if(Jb(c+8|0,c)){h=b;e=((e&1)<<31|b>>>1)&2147483647;while(1){b=v[c+8>>2];i=b;d=v[b>>2];b=d>>>8|0;d=e+(d<<24)|0;b=b+j|0;b=id(Ima(d,e>>>0>d>>>0?b+1|0:b,h,k),mb);v[i>>2]=b;d=f;f=d-b|0;g=g-(b>>>0>d>>>0)|0;_d(c+8|0);if(Jb(c+8|0,c)){continue}break}}a=Dc(a,0);v[a>>2]=f+v[a>>2]}jb=c+16|0}function E$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-32|0;jb=e;a:{if(iF(c)){while(1){if(a>>>d&1){j=(d<<2)+c|0,k=jF(d,b),v[j>>2]=k}d=d+1|0;if((d|0)!=6){continue}break}break a}while(1){i=(e+8|0)+(d<<2)|0;f=1<<d&a;g=v[(d<<2)+c>>2];b:{if(!(f|!c)){break b}g=jF(d,f?b:60523)}f=g;v[i>>2]=f;h=((f|0)!=0)+h|0;d=d+1|0;if((d|0)!=6){continue}break}c=60368;c:{d:{switch(h|0){case 0:break a;case 1:break d;default:break c}}if(v[e+8>>2]!=60340){break c}c=60392;break a}c=pd(24);if(!c){break a}a=v[e+12>>2];v[c>>2]=v[e+8>>2];v[c+4>>2]=a;a=v[e+28>>2];v[c+16>>2]=v[e+24>>2];v[c+20>>2]=a;a=v[e+20>>2];v[c+8>>2]=v[e+16>>2];v[c+12>>2]=a}jb=e+32|0;return c|0}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb+-64|0;jb=d;e=v[a+28>>2];Dn(v[v[e>>2]-12>>2]+e|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];e=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;f=Og(d+48|0,f,f>>>0<g>>>0?e+1|0:e);g=v[f+12>>2];v[d+16>>2]=v[f+8>>2];v[d+20>>2]=g;e=v[f+4>>2];v[d+8>>2]=v[f>>2];v[d+12>>2]=e;dj(h,d+8|0)}pf(d+24|0,v[a+28>>2]);e=v[d+36>>2];v[d+40>>2]=v[d+32>>2];v[d+44>>2]=e;nb[1186](v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];e=mm(d+24|0,xc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114578]=0;a=aa(1631,a|0,c|0,e|0,d+40|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){Ib(e);jb=d- -64|0;break a}a=P()|0;O()|0;Ib(e);S(a|0);L()}return a|0}function cW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-32|0;jb=c;a:{b:{c:{d:{if(!(i=!Wc(b),j=0,k=v[b+12>>2],k?i:j)){gd(a);break d}e=jb-16|0;jb=e;f=$E(c+16|0,e+8|0);d=Fb(b);g=$e(7063);h=Tb(b);v[114578]=0;X(195,f|0,h|0,d|0,d+g|0);d=v[114578];v[114578]=0;e:{if((d|0)!=1){v[114578]=0;W(196,f|0,7063,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;yb(f);S(a|0);L()}jb=e+16|0;v[114578]=0;R(234,c|0,b+12|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}v[114578]=0;U(3,a|0,c+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}yb(c);yb(c+16|0)}jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(c+16|0);S(b|0);L()}function mJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-16|0;jb=f;vh(f+8|0,b);e=jb-16|0;jb=e;ho(e+8|0,wh(e,f+8|0));c=e+8|0;g=jb-16|0;jb=g;d=v[a+8>>2];b=v[a+12>>2];a:{if((b|0)<0){break a}if(k=1,l=(n=Hb(a)>>>0<d>>>0,o=0,p=(b|0)>=0,p?n:o),m=(b|0)>0,m?k:l){break a}d=Hb(a);h=v[a+8>>2];i=0-((d>>>0<h>>>0)+v[a+12>>2]|0)|0;b=g;v[b+8>>2]=d-h;v[b+12>>2]=i;k=b,l=oh(c),v[k>>2]=l;v[b+4>>2]=0;b=xz(b+8|0,b);b=bR(v[b>>2],v[b+4>>2]);if((b|0)!=(oh(c)|0)){break a}gf(v[c>>2],v[c>>2]+b|0,Db(v[a>>2]+v[a+8>>2]|0));c=a;d=b+v[a+8>>2]|0;a=v[a+12>>2];v[c+8>>2]=d;v[c+12>>2]=b>>>0>d>>>0?a+1|0:a;j=1}jb=g+16|0;jb=e+16|0;jb=f+16|0;return j|0}function AP(a,b){var c=0,d=0,e=0;a:{c=jb+-64|0;jb=c;Me(c+40|0,a,4);a=v[c+40>>2];v[114578]=0;d=T(414,c+40|0)|0;e=v[114578];v[114578]=0;b:{c:{d:{if((e|0)==1){break d}v[114578]=0;d=T(415,d|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;X(416,c+8|0,3,d|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(417,c+24|0,c+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(985,c|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}v[114578]=0;Q(471,c|0,c+24|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}yb(c+24|0);Ec(c+40|0);jb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+24|0)}Ec(c+40|0);S(a|0);L()}}function $c(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=v[a+112>>2];d=v[a+116>>2];b:{if(c|d){b=c>>>0<=y[a+120>>2];c=v[a+124>>2];if((d|0)<(c|0)?1:(d|0)<=(c|0)?b:0){break b}}g=hw(a);if((g|0)>-1){break a}}v[a+104>>2]=0;return-1}h=a;b=v[a+116>>2];i=b;d=v[a+8>>2];c=d;f=v[a+112>>2];c:{if(!(b|f)){break c}c=d;e=v[a+120>>2]^-1;f=e+f|0;b=(v[a+124>>2]^-1)+i|0;b=f>>>0<e>>>0?b+1|0:b;i=v[a+4>>2];e=d-i|0;j=f>>>0>=e>>>0;e=e>>31;if((b|0)>(e|0)?1:(e|0)<=(b|0)?j:0){break c}c=f+i|0}v[h+104>>2]=c;h=v[a+4>>2];if(d){c=a;b=(d-h|0)+1|0;d=b+v[a+120>>2]|0;a=v[a+124>>2]+(b>>31)|0;v[c+120>>2]=d;v[c+124>>2]=d>>>0<b>>>0?a+1|0:a}a=h-1|0;if(w[a|0]!=(g|0)){t[a|0]=g}return g}function Mg(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0);d=z[a+4268>>2];f=MI(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));e=ne(C(10),C(C(C(v[((b<<2)+a|0)+4292>>2])*C(-3))/C(z[a+4268>>2]*C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))));c=C(C(ne(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-yo(c>C(1)?C(3.1415927410125732):C(C(f*C(6.2831854820251465))/d))));a:{if(c==C(0)){break a}f=C(c+c);d=C(C(-2)-f);c=C(K(C(C(d*d)+C(C(c*c)*C(-4)))));g=C(C(c-d)/f);if(C(D(g))<=C(1)){break a}g=C(C(-C(c+d))/f)}b=(b<<3)+a|0;z[b+4404>>2]=g;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(C(C(C(d*d)*e)/C(C(1)-C(c*e)))+c)}function Lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-32|0;jb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];g=v[a+4>>2];f=g;b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;jb=e+32|0}function Cha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;Fd(b,0);zP(d,a+1|0);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;Cc(b+8|0,v[b>>2]);Cc(b+4|0,v[b+8>>2]);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function el(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;j=1;i=d&2147483647;m=i;k=c;a:{if(!c&(i|0)==2147418112?a|b:(i|0)==2147418112&(c|0)!=0|i>>>0>2147418112){break a}l=h&2147483647;n=l;i=g;if(!g&(l|0)==2147418112?e|f:(l|0)==2147418112&(g|0)!=0|l>>>0>2147418112){break a}if(!(a|e|(i|k)|(b|f|(m|n)))){return 0}k=d&h;if((k|0)>0?1:(k|0)>=0){j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:(d|0)<(h|0)?1:(d|0)<=(h|0)?c>>>0<g>>>0:0){break a}return(a^e|c^g)!=0|(b^f|d^h)!=0}j=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:(d|0)>(h|0)?1:(d|0)>=(h|0)?c>>>0>g>>>0:0){break a}j=(a^e|c^g)!=0|(b^f|d^h)!=0}return j}function R9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jf(a);if(d>>>0<b>>>0){g=jb-32|0;jb=g;a:{b:{e=b-d|0;c:{if(e>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/52>>>0){nx(a,e,c);break c}f=zb(a);h=oK(a,jf(a)+e|0);j=jf(a);d=0;i=jb-16|0;jb=i;v[i+12>>2]=0;b=g+8|0;Tc(b+12|0,f);if(h){d=iK(v[b+16>>2],h)}v[b>>2]=d;f=B(j,52)+d|0;v[b+8>>2]=f;v[b+4>>2]=f;k=ec(b),l=B(h,52)+d|0,v[k>>2]=l;jb=i+16|0;v[114578]=0;U(1586,b|0,e|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1587,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}fK(b)}jb=g+32|0;break a}a=P()|0;O()|0;fK(b);S(a|0);L()}return}if(b>>>0<d>>>0){pK(a,v[a>>2]+B(b,52)|0)}}function pO(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+820|0]=0;return}t[a+820|0]=1;return}t[a+820|0]=2;return}t[a+820|0]=3;return}t[a+724|0]=w[a+724|0]&254;return}t[a+724|0]=w[a+724|0]|1;return}t[a+736|0]=w[a+736|0]&254;return}t[a+736|0]=w[a+736|0]|1;return}t[a+748|0]=w[a+748|0]&254;return}t[a+748|0]=w[a+748|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+748|0];t[c+748|0]=(b|0)==13?a&238|1:a|17}}function Qaa(a,b){a=a|0;b=b|0;var c=0,d=0;b=78208;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1518,a+8|0,c+12|0,c+8|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{while(1){c:{if(!nd(a)){if(!ji(v[b+8>>2],v[oj(a)>>2])){break c}}v[114578]=0;R(1517,a|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)!=1){break c}break b}b=b+12|0;if((b|0)!=78724){continue}break}b=78736;while(1){d:{if(!nd(a)){if(!ji(v[b+8>>2],v[oj(a)>>2])){break d}}v[114578]=0;R(1517,a|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)!=1){break d}break b}b=b+12|0;if((b|0)!=78784){continue}break}return}b=P()|0;O()|0;Bx(a);S(b|0);L()}function yQ(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0;while(1){k=x[rc(b,g)>>1];l=k+1|0;m=(h&65535)>>>0>k>>>0|k>>>0>127;i=m?i:c>>>0>g>>>0?l:i;j=(j&65535)>>>0>k>>>0?j:l;h=m?h:l;g=g+1|0;if((g|0)!=128){continue}break}eg(b,c);c=v[a+8>>2];a:{b:{if(!f){break b}g=h&65535;if((c+((g<<11)+f|0)|0)!=(Lj(a)&-2)){break b}Pc(a,c+(g<<10)|0);if(kz(a,16,1)){u[e>>1]=8}Pc(a,c);break a}g=i&65535;if((g|0)==(h&65535)){h=i;break a}if(x[e>>1]!=4|f){break a}Pc(a,c+(g<<10)|0);f=kz(a,64,1);Pc(a,c);h=f?h:i}f=j&65535;c:{if(f>>>0>(h&65535)>>>0){if(((c+d|0)+(B(f,x[e>>1])<<8)|0)==(Lj(a)|0)){break c}}if(f>>>0>=255){jz(b,254,65534);jz(b,255,65535)}j=h}return j&65535}function f_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;c=jb-416|0;jb=c;v[c+12>>2]=c+416;d=jb-144|0;jb=d;v[d+28>>2]=d+132;ME(a+8|0,d+32|0,d+28|0,e,f,g);v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=d+32;f=c+16|0;h=WQ(f,v[c+12>>2]);e=jb-16|0;jb=e;v[e+12>>2]=v[a+8>>2];g=Ah(e+8|0,e+12|0);v[114578]=0;a=Pv(f,d+12|0,h,d+16|0);h=v[114578];v[114578]=0;a:{if((h|0)!=1){Ie(g);jb=e+16|0;break a}a=P()|0;O()|0;Ie(g);S(a|0);L()}if((a|0)==-1){ar(65220);L()}v[c+12>>2]=f+(a<<2);jb=d+144|0;d=c+16|0;e=v[c+12>>2];a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if((d|0)!=(e|0)){xF(a+8|0,v[d>>2]);d=d+4|0;continue}break}jb=a+16|0;jb=c+416|0;return v[a+8>>2]}function j9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;v[e+56>>2]=d;d=v[a+28>>2];Dn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];f=v[a+12>>2];g=v[v[b>>2]+4>>2];d=g+v[a+8>>2]|0;f=Og(e+40|0,d,d>>>0<g>>>0?f+1|0:f);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;dj(h,e)}pf(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;YJ(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=mm(e+16|0,xc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114578]=0;aa(1631,a|0,c|0,b|0,e+32|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){Ib(b);jb=e- -64|0;return}a=P()|0;O()|0;Ib(b);S(a|0);L()}function h9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;v[e+56>>2]=d;d=v[a+28>>2];Dn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];f=v[a+12>>2];g=v[v[b>>2]+4>>2];d=g+v[a+8>>2]|0;f=Og(e+40|0,d,d>>>0<g>>>0?f+1|0:f);d=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=d;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d;dj(h,e)}pf(e+16|0,v[a+28>>2]);d=v[e+28>>2];v[e+32>>2]=v[e+24>>2];v[e+36>>2]=d;TJ(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=mm(e+16|0,xc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114578]=0;aa(1631,a|0,c|0,b|0,e+32|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){Ib(b);jb=e- -64|0;return}a=P()|0;O()|0;Ib(b);S(a|0);L()}function Hr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Do(c- -64|0,c+32|0,e);d=me(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;a=c;if(e){while(1){d=0;if(f){while(1){i=v[Of(a,d,g)>>2];fc(b,d);j=Of(h,d,g),k=C(C(i|0)*C(7.450580596923828e-9)),z[j>>2]=k;d=d+1|0;if((f|0)!=(d|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function ep(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;if(e){t[e|0]=0}i=a+484344|0;a:{if(!dg(i,b)){break a}d=Xe(_b(i,b),c,d);g=w[d+5|0];b:{c:{d:{h=w[d+3|0];switch(h-10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}v[f+12>>2]=2;j=0;break b}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4}l=f,m=v[_b(i,b)+12>>2]+(c^-1)|0,v[l+8>>2]=m;a=v[Lb(f+8|0,f+12|0)>>2];if(!a){break a}while(1){k=B(lk(_b(i,b)),6);c=k+d|0;if(w[c+3|0]!=34){break a}h=g<<8;g=j?g>>>0<256?h+-8192|0:h:h;d=w[(d+k|0)+5|0];a=a-1|0;if(e){t[e|0]=1}g=d|g;d=c;if(a){continue}break}}jb=f+16|0;return g|0}function ND(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;c=1;a:{b:{switch(b-a>>2){case 2:b=b-4|0;if(!Jd(b,a)){break a}Zb(a,b);break a;case 3:qm(a,a+4|0,b-4|0);break a;case 4:wv(a,a+4|0,a+8|0,b-4|0);break a;case 5:vv(a,a+4|0,a+8|0,a+12|0,b-4|0);break a;case 0:case 1:break a;default:break b}}e=a+8|0;qm(a,a+4|0,e);d=a+12|0;c:{while(1){g=(b|0)==(d|0);if(g){break c}d:{if(Jd(d,e)){v[f+12>>2]=v[d>>2];h=d;while(1){e:{c=e;v[h>>2]=v[c>>2];if((a|0)==(c|0)){c=a;break e}h=c;e=c-4|0;if(Jd(f+12|0,e)){continue}}break}v[c>>2]=v[f+12>>2];i=i+1|0;if((i|0)==8){break d}}e=d;d=d+4|0;continue}break}c=(d+4|0)==(b|0)}c=c|g}jb=f+16|0;return c&1}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function Kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];h=v[a+28>>2]+h|0;f=h>>12;e=((B(t[k+1|0]-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+16|0}function $G(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb-16|0;jb=e;a:{b:{c:{d=a+8|0;d:{if(!nl(d)){if((b|0)<0|(Qr(d)|0)<=(b|0)){break d}a=vp(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=nl(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ba(8)|0;v[114578]=0;c=Q(85,e|0,40673)|0;b=v[114578];v[114578]=0;e:{if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}jb=e+16|0;return}L()}function oba(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}rK(a+484344|0);Le(a+1304400|0);Le(a+1304412|0);Le(a+1304424|0);iA(a+1304500|0);c=a+900380|0;b=a+484380|0;while(1){on(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Xb(ut(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){kJ(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function Jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];l=v[a+16>>2];f=v[a+4>>2];e=f;i=v[a>>2];v[b+8>>2]=i;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];h=v[a+28>>2]+h|0;f=h>>12;e=e+((B(u[k+2>>1]-e|0,i>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(f,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;i=v[b+8>>2];e=v[b+12>>2];continue}break}i=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;f=h>>12}v[a+40>>2]=g;v[a+20>>2]=f;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=i;v[a+4>>2]=e;jb=b+16|0}function FW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0;l=jb-32|0;jb=l;n=v[c>>2];m=v[c+8>>2];k=l;c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=m;v[114578]=0;v[k+24>>2]=c;v[k+28>>2]=m;v[k+20>>2]=n;v[k+16>>2]=d;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ia(2007,a|0,b|0,k|0)|0;b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;ia(2e3,34684,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();a=-255}jb=l+32|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;Fd(b,0);Qi(d,1,a);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;e=b,f=w[pc(d+16|0,d)|0]<<2,u[e+30>>1]=f;jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function E_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Bc(f+24|0,c);v[114578]=0;a=T(2457,f+24|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){_g(f+24|0,a);break c}Zg(f+24|0,a)}g=f,h=Ed(f+24|0),v[g+16>>2]=h;while(1){g=f,h=Vj(f+24|0),v[g+8>>2]=h;if(!Jb(f+16|0,f+8|0)){c=v[f+40>>2];Lc(f+24|0);break a}a=v[v[f+16>>2]>>2];v[114578]=0;Q(2480,f+40|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){_d(f+16|0);continue}break}c=P()|0;O()|0;Lc(f+24|0);break b}c=P()|0;O()|0;Ob(f+24|0)}S(c|0);L()}jb=f+48|0;return c|0}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(372,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(372,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function Ska(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(380,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function vU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,1,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(372,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function vB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break d}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break d}v[114578]=0;Q(371,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}return a|0}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)==1){break c}v[114578]=0;Z(2041,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[114578]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;X(2080,c+16|0,d|0,c|0,1);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(c+16|0));yb(c+16|0);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1989,37051,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=c+32|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function fT(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(0-c|0,6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}c=i;a=w[(a+h|0)+5|0];if(a?(c|0)!=(a|0):0){break a}if((a|0)!=(c|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}function TV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-48|0;jb=e;f=Tb(b);g=Fb(b);i=Tb(c);j=Fb(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(_n(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=Ed(b),v[k+32>>2]=l;c=Md(e+40|0,e+32|0);k=e,l=Ed(b),v[k+8>>2]=l;k=e,l=cf(e+8|0,h),v[k+16>>2]=l;d=Md(e+24|0,e+16|0);$w(b,v[c>>2],v[d>>2]);break c}if(!Fb(b)){break c}f=Tb(b);h=Fb(b);g=Tb(c);d=-1;i=Fb(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!_n(g,i,c)){continue}break}d=c-f|0}}if((Fb(b)-1|0)!=(d|0)){break c}gd(a);break b}cd(a,b)}jb=e+48|0}function P_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}Bc(f+24|0,c);v[114578]=0;a=T(2423,f+24|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){_g(f+24|0,a);break c}Zg(f+24|0,a)}g=f,h=Ed(f+24|0),v[g+16>>2]=h;while(1){g=f,h=sf(f+24|0),v[g+8>>2]=h;if(!Jb(f+16|0,f+8|0)){c=v[f+40>>2];yb(f+24|0);break a}a=t[v[f+16>>2]];v[114578]=0;Q(2397,f+40|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){qg(f+16|0);continue}break}c=P()|0;O()|0;yb(f+24|0);break b}c=P()|0;O()|0;Ob(f+24|0)}S(c|0);L()}jb=f+48|0;return c|0}function Zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(771,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114578]=0;a=Q(258,b|0,6)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!a){break d}v[114578]=0;U(758,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(759,d|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}hf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;hf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}Dz(d);S(a|0);L()}function Yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+k|0;g=u[f+2>>1];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+B(e,u[f>>1]);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+B(g,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;jb=b+16|0}function DW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[114578]=0;Z(2015,a|0);f=v[114578];v[114578]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114578]=0;Z(2041,b|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}f=v[a+24>>2];b=qc(e+8|0,b);v[114578]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ga(2083,f|0,e|0,c|0,d|0,1);c=v[114578];v[114578]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37133,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();b=0}jb=e+16|0;break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return b|0}function Ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(607,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!a){break d}v[114578]=0;U(599,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(600,d|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}hf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;hf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}$z(d);S(a|0);L()}function jO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;f=jb-16|0;jb=f;g=f+8|0;c=jb-16|0;jb=c;v[114578]=0;e=a;T(1164,a+4|0)|0;a=v[114578];v[114578]=0;a:{b:{c:{if((a|0)!=1){v[114578]=0;v[c+12>>2]=0;W(1165,e+8|0,c+12|0,g|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break c}break b}break b}h=e,i=hc(e),v[h>>2]=i;jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=f+16|0;a=b+236|0;b=ct(a);d:{if((a|0)!=(b|0)){while(1){c=x[a>>1];u[d+14>>1]=c;if(c){v[114578]=0;U(1163,d|0,e|0,d+14|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}jb=d+16|0;return}a=P()|0;O()|0;Ap(e);S(a|0);L()}function gj(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;t[a|0]=0;f=Gf(v[v[b>>2]-12>>2]+b|0);e=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){if(v[e+72>>2]){mr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}Bc(d+24|0,v[v[b>>2]-12>>2]+b|0);v[114578]=0;f=T(21,d+24|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}Ob(d+24|0);c=Cm(d+16|0,b);e=Gk(d+8|0);while(1){d:{if(!to(c,e)){break d}if(!Kg(f,8192,bk(c))){break d}il(c);continue}break}if(!fj(c,e)){break c}Ag(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Gf(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}Ag(e,4)}jb=d+32|0;return a}a=P()|0;O()|0;Ob(d+24|0);S(a|0);L()}function JT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(531,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}if(!a){break d}v[114578]=0;U(513,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(514,d|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break e}hf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;hf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}pA(d);S(a|0);L()}function nM(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)|!(c&255)){break b}d=v[b+700>>2];if(!d){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=eM(a,c&15);b=Fma(a,a>>31,d,d>>31)+32768|0;a=mb;a=yc(Gma(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}}function dF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;jb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[21203]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+60112>>2];if(d<<B(c,6)-6<0?c>>>0<=3:0){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[114552]=25;e=-1}return e|0}function rG(a,b,c,d,e){var f=0,g=0,h=0;f=jb-208|0;jb=f;v[f+204>>2]=c;Rb(f+160|0,0,40);v[f+200>>2]=v[f+204>>2];a:{if((nw(0,b,f+200|0,f+80|0,f+160|0,d,e)|0)<0){b=-1;break a}g=v[a+76>>2]>=0;c=v[a>>2];if(t[a+74|0]<=0){v[a>>2]=c&-33}h=c&32;b:{if(v[a+48>>2]){b=nw(a,b,f+200|0,f+80|0,f+160|0,d,e);break b}v[a+48>>2]=80;v[a+16>>2]=f+80;v[a+28>>2]=f;v[a+20>>2]=f;c=v[a+44>>2];v[a+44>>2]=f;d=nw(a,b,f+200|0,f+80|0,f+160|0,d,e);b=d;if(!c){break b}nb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=c;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;b=b?d:-1}c=a;a=v[a>>2];v[c>>2]=a|h;b=a&32?-1:b;if(!g){break a}}jb=f+208|0;return b}function Xaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}jO(g+16|0,b);i=g,j=cR(g+16|0),v[i+8>>2]=j;i=g,j=yj(g+16|0),v[i>>2]=j;while(1){b:{v[114578]=0;b=Q(786,g+8|0,g|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}if(!b){Ap(g+16|0);break a}v[114578]=0;b=T(787,g+8|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}vt(g+8|0);continue}break}a=P()|0;O()|0;Ap(g+16|0);S(a|0);L()}jb=g+32|0}function nO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b=jb-16|0;jb=b;g=b;d=jb-144|0;jb=d;e=dh(d+8|0);f=v[v[e>>2]-12>>2];v[114578]=0;h=da(122)|0;i=v[114578];v[114578]=0;b:{c:{if((i|0)==1){break c}v[114578]=0;U(123,d|0,f+(d+8|0)|0,h|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}Ob(d);v[114578]=0;R(133,e|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}v[114578]=0;R(125,g|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Yd(e);jb=d+144|0;break b}a=P()|0;O()|0;Yd(e);S(a|0);L()}v[114578]=0;U(13,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;h=v[a+40>>2];i=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){f=(((f&2147483647)<<1|g>>>31)&-2)+k|0;g=t[f+1|0];j=v[a+32>>2];i=v[a+28>>2]+i|0;e=i>>12;v[c>>2]=v[c>>2]+(B(e,t[f|0])<<8);h=h+j|0;j=h>>12;v[c+4>>2]=v[c+4>>2]+(B(g,j)<<8);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];f=v[b+12>>2];continue}break}g=v[b+8>>2];f=v[b+12>>2];break a}j=h>>12;e=i>>12}v[a+40>>2]=h;v[a+20>>2]=e;v[a+36>>2]=i;v[a+24>>2]=j;v[a>>2]=g;v[a+4>>2]=f;jb=b+16|0}function HG(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(Ae(a)){dc(a,31);return 0}f=a,g=Ae(a),t[f+1375|0]=g;e=li(a);b=li(a);li(a);f=a,g=li(a),v[f+1112>>2]=g;li(a);c=Ae(a);v[a+1116>>2]=c;if(!ww(a,a+1120|0,c)){dc(a,10);return 0}v[a+1404>>2]=-2;a:{if((b|0)==-1?(e|0)==-1:0){break a}b=v[a+1116>>2];while(1){if((b|0)<1){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=e;v[a+1404>>2]=b}if(w[a+1377|0]){c=0;d=v[a+1116>>2];b:{if((d|0)>0){b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}b=(c+d|0)+27|0;break b}b=d+27|0}v[a- -64>>2]=e;v[a+60>>2]=b+v[a+56>>2]}v[a+1380>>2]=0;return 1}function rg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb+-64|0;jb=e;a:{b:{if(c-1>>>0>1023){break b}if(dg(a,b)){break b}c:{d:{if(jf(a)>>>0<=b>>>0){d=ox(e+8|0,a);v[114578]=0;U(1583,a|0,b+1|0,d|0);f=v[114578];v[114578]=0;if((f|0)==1){break d}vl(d)}d=Ge(a,b);v[114578]=0;Q(1584,d|0,c|0)|0;c=v[114578];v[114578]=0;e:{if((c|0)!=1){c=Ge(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=Ge(a,b);v[114578]=0;Q(1585,c|0,32324)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break e}}a=V(71204)|0;b=O()|0;break c}g=mh(Ge(a,b));break b}a=V(71204)|0;b=O()|0;vl(d)}if((ga(71204)|0)!=(b|0)){break a}_(a|0)|0;$()}jb=e- -64|0;return g|0}S(a|0);L()}function qU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;v[c+16>>2]=b;v[c+24>>2]=a;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;a:{b:{if(!Jb(d+24|0,d+16|0)){break b}v[d+8>>2]=v[d+24>>2];if(!Jb(_d(d+8|0),d+16|0)){break b}while(1){if(rl(v[d+24>>2],v[d+8>>2])){a=v[d+24>>2];break a}v[d+24>>2]=v[d+8>>2];if(Jb(_d(d+8|0),d+16|0)){continue}break}}a=v[d+16>>2]}jb=d+32|0;v[c+24>>2]=a;if(Jb(c+24|0,c+16|0)){v[c>>2]=v[c+24>>2];_d(c);if(Jb(_d(c),c+16|0)){while(1){if(!rl(v[c+24>>2],v[c>>2])){a=v[v[c>>2]>>2];e=v[_d(c+24|0)>>2],f=a,v[e>>2]=f}if(Jb(_d(c),c+16|0)){continue}break}}_d(c+24|0)}jb=c+32|0;return v[c+24>>2]}function EW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114578]=0;Z(2041,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break d}c=v[a+24>>2];e=qc(d+8|0,b);v[114578]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=vD(c,d,1);e=v[114578];v[114578]=0;c=mb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36983,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();b=0;c=0}jb=d+16|0;a=c;break a}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}qa(a|0);return b|0}function xJ(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;fx(a);ae(d+12|0,C(0));a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];ds(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);ds(a);break a;case 4:b=a;a=Lh(C(z[d+12>>2]*C(32)));v[b+4232>>2]=(a|0)<5?a:5;jb=d+16|0;return;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}b=a;c=z[d+12>>2];if(c==C(0)){ex(a);c=z[d+12>>2]}A[b+4256>>3]=c}jb=d+16|0}function Y4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{c:{if((e|0)==1){break c}v[114578]=0;Z(2041,b|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}e=v[a+24>>2];b=qc(d+8|0,b);v[114578]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;X(2082,e|0,d|0,(c|0)!=0|0,1);c=v[114578];v[114578]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37102,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;aj(a);zb(a);j=b+4|0;h=j;e=v[a+4>>2];k=v[a>>2];if((e|0)!=(k|0)){f=v[h>>2];while(1){e=e-12|0;d=e;i=zb(d);g=jb-16|0;jb=g;c=f-12|0;f=c;v[c>>2]=0;v[c+4>>2]=0;v[g+12>>2]=0;v[114578]=0;W(1026,c+8|0,g+12|0,i|0)|0;i=v[114578];v[114578]=0;a:{if((i|0)!=1){jb=g+16|0;break a}V(0)|0;O()|0;Ab();L()}v[c>>2]=v[d>>2];v[c+4>>2]=v[d+4>>2];c=v[zb(d)>>2];l=zb(f),m=c,v[l>>2]=m;l=zb(d),m=0,v[l>>2]=m;v[d>>2]=0;v[d+4>>2]=0;f=v[h>>2]-12|0;v[h>>2]=f;if((e|0)!=(k|0)){continue}break}}Zb(a,j);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,wc(a))}function WZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=BE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);bi(i,k);Lc(k);Zg(k,a);bi(h,k);Lc(k);l=d,m=fi(a),v[l>>2]=m;l=e,m=ei(a),v[l>>2]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);bi(g,k);Lc(k);a=Qj(a);break a}a=AE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);bi(i,k);Lc(k);Zg(k,a);bi(h,k);Lc(k);l=d,m=fi(a),v[l>>2]=m;l=e,m=ei(a),v[l>>2]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);bi(g,k);Lc(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function Gv(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;Bc(f+8|0,b);v[114578]=0;b=T(2456,f+8|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;aa(2470,b|0,64400,64432,c|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;b=T(2457,f+8|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;c=T(2471,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}v[d>>2]=c;v[114578]=0;c=T(2467,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[e>>2]=c;v[114578]=0;R(2468,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;Ob(f+8|0);S(a|0);L()}function q6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-32|0;jb=d;e=jb-16|0;jb=e;c=a;k=c;g=b;f=Ke(c);h=hc(c);i=jb-16|0;jb=i;if(f){while(1){j=Js(zb(k),f+16|0,g);h=j?h:f;f=v[(j?4:0)+f>>2];if(f){continue}break}}g=v[Qc(i+8|0,h)>>2];jb=i+16|0;v[e+8>>2]=g;l=e,m=yj(c),v[l>>2]=m;a:{b:{if(!Jb(e+8|0,e)){break b}if(Js(zb(c),b,jh(e+8|0))){break b}b=v[e+8>>2];break a}b=yj(c)}jb=e+16|0;v[d+24>>2]=b;l=d,m=yj(a),v[l+16>>2]=m;b=0;if(!rl(d+24|0,d+16|0)){c=v[Qc(d+8|0,v[d+24>>2])>>2];b=jb-16|0;jb=b;v[b+8>>2]=c;c=v[b+8>>2];UJ(a,c);hc(a);jn(jh(b+8|0));my(c);jb=b+16|0;b=1}jb=d+32|0;return b|0}function ln(a){var b=0,c=0,d=0;b=(x[a+24>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+40>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+32>>1]=d;u[a+36>>1]=b?1:1<<c-12;u[a+34>>1]=-1<<d^-1;if(x[a+24>>1]==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+52>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+44>>1]=d;u[a+48>>1]=b?1:1<<c-12;u[a+46>>1]=-1<<d^-1;b=(x[a+30>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+64>>2]=((b&3)<<4)+18720;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+56>>1]=d;u[a+60>>1]=b?1:1<<c-12;u[a+58>>1]=-1<<d^-1}function Wz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;gg(b,Cd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Kb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;while(1){c=a+(d<<2)|0;g=c+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Si(e+14|0,e+12|0)>>1];u[e+14>>1]=g;h=Pb(b,d),i=g,u[h>>1]=i;u[e+14>>1]=x[e+14>>1]+1;c=c+162|0;v[e+8>>2]=(w[c|0]|w[c+1|0]<<8)>>>f;v[e+4>>2]=64;c=v[de(e+8|0,e+4|0)>>2];h=Pb(b,d),i=c,t[h+2|0]=i;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=e+16|0}function b_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=GE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);Gb(i,k);yb(k);Zg(k,a);Gb(h,k);yb(k);l=d,m=fi(a),t[l|0]=m;l=e,m=ei(a),t[l|0]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);Gb(g,k);yb(k);a=Qj(a);break a}a=EE(b);Sj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Rj(k,a);Gb(i,k);yb(k);Zg(k,a);Gb(h,k);yb(k);l=d,m=fi(a),t[l|0]=m;l=e,m=ei(a),t[l|0]=m;ng(k,a);Gb(f,k);yb(k);_g(k,a);Gb(g,k);yb(k);a=Qj(a)}v[j>>2]=a;jb=k+16|0}function Fr(a,b,c){var d=0,e=0;d=a,e=mi(C(C(C(C(C(C(C(C(C(z[c+3328>>2]+z[c+256>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+2816>>2]+z[c+768>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+2304>>2]+z[c+1280>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489)))+C(z[c+1792>>2]*C(75038)))),u[d>>1]=e;d=(b<<5)+a|0,e=mi(C(C(C(C(C(C(C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function qi(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=79680;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;e=rJ(b);f=rJ(b+12|0);g=qJ(b+24|0);d=qJ(b+36|0);v[114578]=0;W(1640,b|0,2,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){a=P()|0;O()|0;as(d);as(g);$r(f);$r(e);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;b=0;u[a+4204>>1]=0;v[c>>2]=a+99&-8;f=v[a+20>>2];e=v[a+16>>2];if((f|0)!=(e+906300|0)){g=a+4200|0;while(1){c=b+1|0;if((f|0)!=((e+B(c,160)|0)+906300|0)){d=b>>>0<248;b=c;if(d){continue}}break}t[g|0]=c}return a}function Jv(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;Bc(f+8|0,b);v[114578]=0;b=T(21,f+8|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;aa(2447,b|0,64400,64432,c|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;b=T(2423,f+8|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;c=T(2448,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}t[d|0]=c;v[114578]=0;c=T(2438,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}t[e|0]=c;v[114578]=0;R(2439,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;Ob(f+8|0);S(a|0);L()}function p_(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-160|0;jb=c;a=Dm(c+16|0,a,8);d=v[v[a>>2]-12>>2];v[114578]=0;b=da(122)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)==1){break b}v[114578]=0;U(123,c+8|0,d+(c+16|0)|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}Ob(c+8|0);v[114578]=0;d=Q(180,a|0,144)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;d=Q(181,d|0,c+4|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}b=v[v[d>>2]-12>>2];v[114578]=0;d=T(174,b+d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}b=v[c+4>>2];If(a);jb=c+160|0;a=d?0:b;break a}c=P()|0;O()|0;If(a);S(c|0);L()}return a|0}function nI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;g=c;d=jb-144|0;jb=d;e=dh(d+8|0);h=v[v[e>>2]-12>>2];v[114578]=0;i=da(122)|0;f=v[114578];v[114578]=0;a:{b:{if((f|0)==1){break b}v[114578]=0;U(123,d|0,(d+8|0)+h|0,i|0);f=v[114578];v[114578]=0;if((f|0)==1){break b}Ob(d);v[114578]=0;R(130,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(125,g|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}Yd(e);jb=d+144|0;break a}a=P()|0;O()|0;Yd(e);S(a|0);L()}v[114578]=0;U(13,a|0,0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function X4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=jb-16|0;jb=e;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)==1){break c}v[114578]=0;Z(2041,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(e+8|0,b);v[114578]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;eb(2084,d|0,e|0,+c,1);d=v[114578];v[114578]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37164,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}jb=e+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Us(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a:{b:{c:{if(b>>>0<=4294967279){f=Kc(a);h=c,i=Fb(a),v[h+8>>2]=i;b=v[bd(c+12|0,c+8|0)>>2];v[c+12>>2]=b;d=Vk(b);v[c+12>>2]=d;if((d|0)==(f|0)){break a}if((d|0)==10){g=1;b=a;e=v[a>>2];break b}b=v[c+12>>2]+1|0;if(d>>>0>f>>>0){b=ai(b);break c}v[114578]=0;b=Q(30,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}Hg();L()}g=Fe(a);e=Tb(a)}xh(b,e,Fb(a)+1|0);if(g){pg(a,e,f+1|0)}d:{if((d|0)!=10){Fg(a,v[c+12>>2]+1|0);we(a,v[c+8>>2]);Ef(a,b);break d}of(a,v[c+8>>2])}}jb=c+16|0}function _G(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{c=a+8|0;d:{if(!nl(c)){if((b|0)<0|(Qr(c)|0)<=(b|0)){break d}c=(w[vp(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=nl(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ba(8)|0;v[114578]=0;c=Q(85,d|0,40673)|0;b=v[114578];v[114578]=0;e:{if((b|0)!=1){mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}jb=d+16|0;return c|0}L()}function kX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a:{b:{c:{if(b>>>0<=1073741807){f=Vq(a);h=c,i=Fb(a),v[h+8>>2]=i;b=v[bd(c+12|0,c+8|0)>>2];v[c+12>>2]=b;d=sm(b);v[c+12>>2]=d;if((d|0)==(f|0)){break a}g=1;if((d|0)==1){b=a;e=v[a>>2];break b}b=v[c+12>>2]+1|0;if(d>>>0>f>>>0){b=rm(b);break c}v[114578]=0;b=Q(2835,a|0,b|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;$();break a}Hg();L()}g=Fe(a);e=Tb(a)}hi(b,e,Fb(a)+1|0);if(g){lo(e,f+1|0)}d:{if((d|0)!=1){Fg(a,v[c+12>>2]+1|0);we(a,v[c+8>>2]);Ef(a,b);break d}of(a,v[c+8>>2])}}jb=c+16|0}function yO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}Le(a);Us(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Lb(f+12|0,f+4|0)>>2];eo(a,Db(b)+g|0,h);Rs(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[om(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=om(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Lb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}jb=f+16|0;return(d|0)!=0|0}function Ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Fd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;e=b;c=a+14|0;d=256;a:{if(!w[c|0]){break a}d=w[c|0]+1|0}u[e+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function Sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=bl(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1021,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=Qy(c+8|0,tm(a,wc(a)+1|0),wc(a),e);f=v[a+8>>2];v[114578]=0;U(1021,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(1015,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}et(a);jb=c+32|0;break b}b=P()|0;O()|0;et(a);S(b|0);L()}}function Yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=$n(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1179,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+32;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=JN(c+8|0,dm(a,xe(a)+1|0),xe(a),e);f=v[a+8>>2];v[114578]=0;U(1179,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+32;v[114578]=0;R(1180,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Ss(a);jb=c+32|0;break b}b=P()|0;O()|0;Ss(a);S(b|0);L()}}function EA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)==1){break c}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Q(371,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}function DA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)==1){break c}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break c}v[114578]=0;Q(380,b|0,d+24|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break b}yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+24|0)}Ec(d+40|0);S(a|0);L()}function $4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;a:{b:{c:{if((d|0)==1){break c}v[114578]=0;Z(2041,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[114578]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(2079,d|0,c|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37014,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}jb=c+16|0;return+e}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function VM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=bl(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1254,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=RM(c+8|0,tm(a,wc(a)+1|0),wc(a),e);f=v[a+8>>2];v[114578]=0;U(1254,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(1255,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Is(a);jb=c+32|0;break b}b=P()|0;O()|0;Is(a);S(b|0);L()}}function t9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1605,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=kx(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(1605,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(1598,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Vm(a);jb=c+32|0;break b}b=P()|0;O()|0;Vm(a);S(b|0);L()}}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=lm(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(608,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+16;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=LS(c+8|0,Mq(a,od(a)+1|0),od(a),e);f=v[a+8>>2];v[114578]=0;U(608,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+16;v[114578]=0;R(609,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}It(a);jb=c+32|0;break b}b=P()|0;O()|0;It(a);S(b|0);L()}}function oka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=bl(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(728,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=xE(c+8|0,tm(a,wc(a)+1|0),wc(a),e);f=v[a+8>>2];v[114578]=0;U(728,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(205,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Yq(a);jb=c+32|0;break b}b=P()|0;O()|0;Yq(a);S(b|0);L()}}function d8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(1762,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=iJ(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(1762,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(1759,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}_r(a);jb=c+32|0;break b}b=P()|0;O()|0;_r(a);S(b|0);L()}}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{c:{if((c|0)==1){break c}v[114578]=0;Z(2041,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}c=v[a+24>>2];b=qc(d+8|0,b);v[114578]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(2077,c|0,d|0,1)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36952,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function lT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=_S(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(557,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+48;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=YS(c+8|0,ZS(a,Ni(a)+1|0),Ni(a),e);f=v[a+8>>2];v[114578]=0;U(557,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+48;v[114578]=0;R(558,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Nt(a);jb=c+32|0;break b}b=P()|0;O()|0;Nt(a);S(b|0);L()}}function zl(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=a+1074308|0;Eb(e+8|0,f,84);a:{if(Cb(e+8|0)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Eb(e+8|0,f,10);if(!Cb(e+8|0)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+796>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Eb(e+8|0,f,10);if(!Cb(e+8|0)){break a}t[b+851|0]=0;u[b+790>>1]=0}jb=e+16|0}function cV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=$n(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(349,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+32;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=JC(c+8|0,dm(a,xe(a)+1|0),xe(a),e);f=v[a+8>>2];v[114578]=0;U(349,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+32;v[114578]=0;R(267,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Cq(a);jb=c+32|0;break b}b=P()|0;O()|0;Cq(a);S(b|0);L()}}function D_(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=bl(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(204,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+12;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=xE(c+8|0,tm(a,wc(a)+1|0),wc(a),e);f=v[a+8>>2];v[114578]=0;U(204,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+12;v[114578]=0;R(205,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Yq(a);jb=c+32|0;break b}b=P()|0;O()|0;Yq(a);S(b|0);L()}}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;Kt(d,2,a+2|0);Ic(d+16|0,d);v[114578]=0;Q(371,b+492|0,d+16|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){yb(d+16|0);f=b+236|0;c=c+1|0;while(1){g=w[(a+e|0)+31|0];h=ed(f,e),i=c+g|0,u[h>>1]=i;e=e+1|0;if(e>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;e=a+2|0;f=a+3|0;g=a+4|0;HK(w[a|0]&15,w[c|0]&15,w[e|0]&15,w[f|0]&15,w[g|0]&15,a+5|0,b+48|0);HK(w[a|0]>>>4|0,w[c|0]>>>4|0,w[e|0]>>>4|0,w[f|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function eV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(348,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=pC(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(348,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(345,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}vq(a);jb=c+32|0;break b}b=P()|0;O()|0;vq(a);S(b|0);L()}}function NA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;d=Xh(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(383,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=fq(c+8|0,Ri(a,oc(a)+1|0),oc(a),e);f=v[a+8>>2];v[114578]=0;U(383,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+2;v[114578]=0;R(382,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}Dj(a);jb=c+32|0;break b}b=P()|0;O()|0;Dj(a);S(b|0);L()}}function PW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(kg(a,v[b+8>>2],f)){ov(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;mv(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;mv(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function ky(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){c=jb-16|0;jb=c;d=qe(c,a,1);a=zb(a);e=v[d+4>>2];v[114578]=0;U(95,a|0,e|0,b|0);a=v[114578];v[114578]=0;a:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+4;Mb(d);jb=c+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}return}c=jb-32|0;jb=c;d=a;e=zb(a);a=ms(c+8|0,Be(a,Kb(a)+1|0),Kb(a),e);f=v[a+8>>2];v[114578]=0;U(95,e|0,f|0,b|0);b=v[114578];v[114578]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114578]=0;R(96,d|0,a|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}nk(a);jb=c+32|0;break b}b=P()|0;O()|0;nk(a);S(b|0);L()}}function ZT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;d=b;f=Ac(d);e=c;a:{if(f>>>0<e>>>0){h=jb-32|0;jb=h;b:{c:{f=e-f|0;d:{if(f>>>0<=v[zb(d)>>2]-v[d+4>>2]>>>0){cC(d,f);break d}e=zb(d);e=nh(h+8|0,Ki(d,Ac(d)+f|0),Ac(d),e);v[114578]=0;R(365,e|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break c}v[114578]=0;R(366,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}Rg(e)}jb=h+32|0;break b}a=P()|0;O()|0;Rg(e);S(a|0);L()}break a}if(e>>>0<f>>>0){Fu(d,e+v[d>>2]|0)}}c=Qb(a,c);if(c){d=jb-16|0;jb=d;gc(g+8|0,v[b>>2],Ac(b));jb=d+16|0;Bd(a,g+8|0)}jb=g+16|0;return c|0}function Yu(a,b,c,d){var e=0,f=0;e=jb-32|0;jb=e;v[e+28>>2]=d;a:{f=v[b>>2];b:{if(!(nb[v[v[f>>2]+40>>2]](f,c,d)|0)){Yh(a);break b}Tk(e+8|0,b);v[114578]=0;b=T(271,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[114578]=0;b=T(d|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;v[e+4>>2]=b-c;b=Q(33,e+28|0,e+4|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}b=v[b>>2];v[114578]=0;X(272,e+16|0,e+8|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}yC(a,e+16|0,0);Bb(e+16|0);Bb(e+8|0)}jb=e+32|0;return}a=P()|0;O()|0;Bb(e+8|0);S(a|0);L()}function R0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;d=ve(b,-1);e=w[a+52|0];a:{if(d){d=b;if(e){break a}d=v[a+48>>2];f=a,g=ve(d,-1)^1,t[f+52|0]=g;break a}if(e){f=c,g=Jm(v[a+48>>2]),t[f+19|0]=g;b:{c:{switch(rr(v[a+36>>2],v[a+40>>2],c+19|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((vr(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}t[a+52|0]=1;v[a+48>>2]=b;d=b}jb=c+32|0;return d|0}function lt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;aQ(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function lC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;d=b+80|0;g=a;c=v[b+84>>2];f=v[d>>2];a:{if(c>>>0<=15){break a}v[e+12>>2]=c-16;f=v[bd(d,e+12|0)>>2]}v[g+8>>2]=f;b:{if(!(w[b+88|0]&2)|!w[b+816|0]){break b}c:{d:{e:{if(!((v[b+88>>2]&2050)==2?(w[v[b+104>>2]+34|0]&8)>>>3|0:0)){c=v[b+104>>2];break e}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break e}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break d}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break b}b=(v[c>>2]-b|0)+48|0;break c}b=(v[c>>2]-d|0)+112|0}h=a,i=v[a>>2]+B(Zn(c),b)|0,v[h+4>>2]=i}jb=e+16|0}function EF(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!Gf(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(ED()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[114578]=0;b=T(2390,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114578]=0;R(2391,a+b|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function eha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;Bi(f+40|0,f+32|0,c);v[114578]=0;c=f+52|0;U(240,c|0,f+24|0,d|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){c:{v[114578]=0;c=f- -64|0;U(224,c|0,f+16|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(241,f+8|0,f+40|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,f+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}im(f+40|0);jb=f+80|0;return}}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;im(f+40|0)}S(a|0);L()}function cla(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;Bi(f+40|0,f+32|0,c);v[114578]=0;c=f+52|0;U(224,c|0,f+24|0,d|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){c:{v[114578]=0;c=f- -64|0;U(224,c|0,f+16|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(241,f+8|0,f+40|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,f+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}im(f+40|0);jb=f+80|0;return}}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;im(f+40|0)}S(a|0);L()}function S9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;v[e+12>>2]=b;a:{if(kj(a)>>>0>=b>>>0){h=e,i=jf(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Lb(e+12|0,e+8|0)>>2];if(f){while(1){vK(d,b);d=d+52|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){nx(a,b-d|0,c);break a}pK(a,v[a>>2]+B(b,52)|0);break a}d=a;if(v[d>>2]){jf(d);rL(d);kK(d);Lx(zb(d),v[d>>2],kj(d));h=zb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=oK(a,b);if(jK(a)>>>0<f>>>0){fd();L()}g=iK(zb(d),f);v[d>>2]=g;v[d+4>>2]=g;h=zb(d),i=B(f,52)+g|0,v[h>>2]=i;hK(d,0);nx(a,b,c)}jb=e+16|0}function zw(a,b,c){var d=0,e=0,f=0,g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=0;d=jb-32|0;jb=d;OG(C(-z[a>>2]),C(z[a+12>>2]+z[a+24>>2]),C(z[a+36>>2]+z[a+48>>2]),d+20|0);OG(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),d+8|0);z[d+12>>2]=-z[d+12>>2];a=0;while(1){e=a<<2;f=e+c|0;h=z[f>>2];n=f;f=e+49008|0;g=z[f>>2];i=z[e+(d+20|0)>>2];j=z[e+(d+8|0)>>2];k=z[f+12>>2];z[n>>2]=C(g*i)-C(j*k);f=b+e|0;l=z[(0-a<<2)+49016>>2];e=5-a<<2;m=z[e+49008>>2];g=C(C(g*j)+C(k*i));z[f>>2]=C(h*l)-C(m*g);z[b+e>>2]=C(m*h)+C(g*l);a=a+1|0;if((a|0)!=3){continue}break}jb=d+32|0}function qp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;g=Kb(a)-1|0;a:{if((Kb(a)|0)==1){break a}while(1){if(x[Dc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Kb(a)-1>>>0){continue}break}}h=x[Dc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Dc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Dc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Dc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}j=f,k=((B(((w[Dc(a,g)+2|0]<<16)/(d|0)|0)-i|0,b-e|0)|0)/(h-e|0)|0)+i|0,v[j+12>>2]=k}ce(f+12|0,0,65536);jb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function _V(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;jm(f+40|0,f+32|0,c);v[114578]=0;c=f+52|0;U(240,c|0,f+24|0,d|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){c:{v[114578]=0;c=f- -64|0;U(240,c|0,f+16|0,e|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;R(241,f+8|0,f+40|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,f+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}im(f+40|0);jb=f+80|0;return}}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}a=P()|0;O()|0;im(f+40|0)}S(a|0);L()}function S2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;f=gh(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[114578]=0;R(2192,c|0,(d+(a<<5)|0)+480289|0);d=v[114578];v[114578]=0;if((d|0)==1){break e}v[114578]=0;U(2185,c+16|0,b|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break d}v[114578]=0;R(1535,f|0,c+16|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}yb(c+16|0);yb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}jb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+16|0)}yb(c)}ld(f);S(a|0);L()}function Kj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=v[a+28>>2];if((c|0)>=(b|0)){e=v[a+24>>2];break a}i=a+32|0;f=v[a+20>>2];d=v[a+16>>2];g=c;while(1){b:{if(d>>>0>=f>>>0){f=$u(a,i,1024);v[a+16>>2]=0;v[a+20>>2]=f;if(!f){break b}d=0;g=v[a+28>>2]}h=d+1|0;v[a+16>>2]=h;d=w[(a+d|0)+32|0];c=g+8|0;v[a+28>>2]=c;e=v[a+24>>2]|d<<g;v[a+24>>2]=e;d=h;g=c;if((c|0)<(b|0)){continue}break a}break}a=ba(8)|0;v[114578]=0;T(264,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);S(b|0);L()}ja(a|0,76880,265);L()}v[a+28>>2]=c-b;v[a+24>>2]=e>>>b;return(-1<<b^-1)&e}function K0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;a:{b:{c:{if(ve(b,-1)){break c}h=c,i=Jm(b),t[h+23|0]=i;if(w[a+44|0]){if((_i(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+23|0;while(1){e=rr(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((_i(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((_i(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Gr(b);break a}a=-1}jb=c+32|0;return a|0}function Vg(a){var b=0,c=0,d=0,e=0;a:{o(+a);b=j(1)|0;j(0)|0;c=b;b=b&2147483647;b:{if(b>>>0>=1083174912){if(!((c|0)<0|b>>>0<1083179008)){return a*8.98846567431158e307}if(b>>>0>=2146435072){return-1/a}if(!(a<=-1075)){break a}d=0;if((c|0)<-1?1:(c|0)<=-1){break b}break a}if(b>>>0>1016070143){break a}d=a+1}return d}e=a+26388279066624;o(+e);j(1)|0;c=(j(0)|0)+128|0;b=c<<4&4080;d=A[b+72128>>3];a=a-(e+-26388279066624)-A[(b|8)+72128>>3];return $h(d+d*a*(a*(a*(a*(a*.0013333559164630223+.009618129842126066)+.0555041086648214)+.2402265069591)+.6931471805599453),(c&-256)/256|0)}function $B(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;g=w[a+8|0];f=v[a>>2];a=v[a+4>>2];d=Tb(b);b=Fb(b);c=jb-16|0;jb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Lb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=f;break b}b=e;a=f;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{d:{e:{switch(g-1|0){case 0:case 1:d=v[c+12>>2];t[c+7|0]=0;Zr(a,((a+d|0)-e|0)+b|0,c+7|0);break d;case 2:case 3:break e;default:break c}}d=v[c+12>>2];t[c+6|0]=32;Zr(a,((a+d|0)-e|0)+b|0,c+6|0)}f:{switch(g-1|0){case 0:case 3:break f;default:break c}}t[(v[c+12>>2]+f|0)-1|0]=0}jb=c+16|0}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;Fd(b,0);zP(d,a+1|0);Ic(d+16|0,d);v[114578]=0;Q(372,b+43|0,d+16|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;Cc(b+8|0,v[b>>2]);Cc(b+4|0,v[b+8>>2]);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function lv(a,b,c){var d=0,e=0,f=0,g=0;g=b;d=v[c+16>>2];a:{if(!d){d=0;e=c;f=w[c+74|0];t[c+74|0]=f-1|f;f=v[c>>2];b:{if(f&8){v[e>>2]=f|32;e=-1;break b}v[e+4>>2]=0;v[e+8>>2]=0;f=v[e+44>>2];v[e+28>>2]=f;v[e+20>>2]=f;v[e+16>>2]=f+v[e+48>>2];e=0}if(e){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<g>>>0){return nb[v[c+36>>2]](c,a,b)|0}c:{if(t[c+75|0]>-1){d=b;while(1){g=d;d=b;if(!g){break c}d=g-1|0;if(w[d+a|0]!=10){continue}break}d=nb[v[c+36>>2]](c,a,g)|0;if(g>>>0>d>>>0){break a}a=a+g|0;f=v[c+20>>2];d=b-g|0;break c}d=b}e=d;lc(f,a,e);v[c+20>>2]=e+v[c+20>>2];d=b}return d}function ev(a){var b=0,c=0,d=0,e=0,f=0;a:{if(y[a+4>>2]<y[zb(a)>>2]){b=jb-16|0;jb=b;c=$n(b,a,1);d=zb(a);e=v[c+4>>2];v[114578]=0;R(266,d|0,e|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Mb(c);jb=b+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}d=jb-32|0;jb=d;c=a;e=zb(a);b=JC(d+8|0,dm(a,xe(a)+1|0),xe(a),e);f=v[b+8>>2];v[114578]=0;R(266,e|0,f|0);e=v[114578];v[114578]=0;b:{c:{if((e|0)==1){break c}v[b+8>>2]=v[b+8>>2]+32;v[114578]=0;R(267,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}Cq(b);jb=d+32|0;break b}a=P()|0;O()|0;Cq(b);S(a|0);L()}}Tg(a)}function aK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;v[e+12>>2]=b;a:{if(yd(a)>>>0>=b>>>0){h=e,i=Kb(a),v[h+8>>2]=i;d=v[a>>2];b=c;f=v[Lb(e+12|0,e+8|0)>>2];if(f){while(1){z[d>>2]=z[b>>2];d=d+4|0;f=f-1|0;if(f){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){ix(a,b-d|0,c);break a}lx(a,v[a>>2]+(b<<2)|0);break a}d=a;if(v[d>>2]){ui(d);Re(zb(d),v[d>>2],yd(d));h=zb(d),i=0,v[h>>2]=i;v[d>>2]=0;v[d+4>>2]=0}f=Be(a,b);if(Ym(a)>>>0<f>>>0){fd();L()}zb(d);g=WJ(f);v[d>>2]=g;v[d+4>>2]=g;h=zb(d),i=(f<<2)+g|0,v[h>>2]=i;mk(d,0);ix(a,b,c)}jb=e+16|0}function Sda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=0;_D(a,c+12|0,1);d=v[c+12>>2];e=d>>>2&3;t[c+11|0]=e;if(e){t[c+4|0]=3;d=w[pc(c+4|0,c+11|0)|0];t[c+4|0]=0;t[c|0]=0;t[c+10|0]=0;a:{if(!d){break a}yh(a,c+4|0);if((d|0)==1){break a}yh(a,c);if(d>>>0<3){break a}yh(a,c+10|0);f=w[c+10|0]<<24}d=w[c+12|0]|w[c+4|0]<<8|w[c|0]<<16|f;v[c+12>>2]=d}v[c+4>>2]=d>>>4;v[c>>2]=1e6;Co(b,v[Lb(c+4|0,c)>>2]);if(Fb(b)){d=0;while(1){ak(a,kc(b,d),1);d=d+1|0;if(Fb(b)>>>0>d>>>0){continue}break}}b=(v[c+12>>2]>>>4|0)-Fb(b)|0;v[c+12>>2]=b;if(b){hl(a,b,-1)}jb=c+16|0}function N0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;d=ve(b,-1);e=w[a+52|0];a:{if(d){d=b;if(e){break a}d=v[a+48>>2];f=a,g=ve(d,-1)^1,t[f+52|0]=g;break a}if(e){v[c+16>>2]=v[a+48>>2];b:{c:{switch(rr(v[a+36>>2],v[a+40>>2],c+16|0,c+20|0,c+12|0,c+24|0,c+32|0,c+20|0)-1|0){case 2:d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d;default:while(1){d=v[c+20>>2];e=1;if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((vr(t[d|0],v[a+32>>2])|0)!=-1){continue}break};break;case 0:case 1:break c}}d=-1;e=0}if(!e){break a}}t[a+52|0]=1;v[a+48>>2]=b;d=b}jb=c+32|0;return d|0}function wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=(e<<1)+j|0;f=(f>>>21&2040)+27888|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Ns(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;e=1;a:{while(1){b:{kN(b,A[Uk(c,0)>>3]);if((e|0)==1e4){f=d,g=bc(c),v[f+8>>2]=g;f=d,g=cc(c),v[f>>2]=g;if(Jb(d+8|0,d)){break b}break a}else{e=e+1|0;continue}}break}while(1){e=v[d+8>>2];f=e,h=kN(b,A[e>>3]),A[f>>3]=h;uy(d+8|0);if(Jb(d+8|0,d)){continue}break}}b=jN(a,zb(c));v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];a=v[zb(c)>>2];f=zb(b),g=a,v[f>>2]=g;f=zb(c),g=0,v[f>>2]=g;v[c>>2]=0;v[c+4>>2]=0;jb=d+16|0}function zr(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;h=v[c>>2];v[g+232>>2]=h;c=v[c+4>>2];v[g>>2]=a;v[g+236>>2]=c;a:{b:{c:{d:{if((h|0)!=1){h=a;i=1;break d}h=a;i=1;if(c){break d}c=a;break c}while(1){c=h-v[(d<<2)+f>>2]|0;if((nb[b|0](c,a)|0)<1){c=h;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=h-4|0;if((nb[b|0](j,c)|0)>-1){break e}if((nb[b|0](j-e|0,c)|0)>-1){break e}}v[(i<<2)+g>>2]=c;e=mG(g+232|0);Ar(g+232|0,e);i=i+1|0;d=d+e|0;e=0;h=c;if(v[g+236>>2]|v[g+232>>2]!=1){continue}break b}break}c=h;break b}if(e){break a}}lG(g,i);lw(c,b,d,f)}jb=g+240|0}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=u[(f<<1)+k>>1];h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;jb=b+16|0}function xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];g=v[a+4>>2];e=g;f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){e=e+j|0;f=(f>>>21&2040)+27888|0;e=(((B(t[e|0],u[f+2>>1])+B(t[e-1|0],u[f>>1])|0)+B(t[e+1|0],u[f+4>>1])|0)+B(t[e+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function $fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=e;j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;e=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=e;a:{if(d){while(1){i=v[a+32>>2];f=t[f+k|0]<<8;h=v[a+28>>2]+h|0;e=h>>12;v[c>>2]=v[c>>2]+B(f,e);g=g+i|0;i=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+12>>2];continue}break}j=v[b+8>>2];f=v[b+12>>2];break a}i=g>>12;e=h>>12}v[a+40>>2]=g;v[a+20>>2]=e;v[a+36>>2]=h;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=f;jb=b+16|0}function hL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{if(w[b+813|0]!=27){a=t[b+851|0];break a}e=a+1074308|0;Eb(c+8|0,e,21);d=Cb(c+8|0);f=a;a=w[b+841|0];a=Hx(f,w[b+848|0],d?a:a+16>>>2|0);Eb(c+8|0,e,45);b:{if(!(!Cb(c+8|0)|w[b+848|0]!=3)){f=b;d=w[b+841|0];c:{if(!(!d|d>>>0>=w[b+849|0])){a=w[b+852|0];d=d+1|0;break c}t[b+852|0]=a;d=1}t[f+841|0]=d;a=a<<24>>24;break b}t[b+841|0]=w[b+841|0]+w[b+849|0]}Eb(c+8|0,e,47);if(!Cb(c+8|0)){break a}t[b+851|0]=a}if(a){g=b,h=Yb(v[b+684>>2]+((B(w[b+850|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}jb=c+16|0}function SX(){var a=0;a:{if(t[462560]&1){break a}if(!wd(462560)){break a}a=462272;while(1){a=Wb(a)+12|0;if((a|0)!=462560){continue}break}vd(462560)}Mc(462272,69644);Mc(462284,69652);Mc(462296,69661);Mc(462308,69667);Mc(462320,69673);Mc(462332,69677);Mc(462344,69682);Mc(462356,69687);Mc(462368,69694);Mc(462380,69704);Mc(462392,69712);Mc(462404,69721);Mc(462416,69730);Mc(462428,69734);Mc(462440,69738);Mc(462452,69742);Mc(462464,69673);Mc(462476,69746);Mc(462488,69750);Mc(462500,69754);Mc(462512,69758);Mc(462524,69762);Mc(462536,69766);Mc(462548,69770)}function PX(){var a=0;a:{if(t[462864]&1){break a}if(!wd(462864)){break a}a=462576;while(1){a=tf(a)+12|0;if((a|0)!=462864){continue}break}vd(462864)}_c(462576,69776);_c(462588,69808);_c(462600,69844);_c(462612,69868);_c(462624,69892);_c(462636,69908);_c(462648,69928);_c(462660,69948);_c(462672,69976);_c(462684,70016);_c(462696,70048);_c(462708,70084);_c(462720,70120);_c(462732,70136);_c(462744,70152);_c(462756,70168);_c(462768,69892);_c(462780,70184);_c(462792,70200);_c(462804,70216);_c(462816,70232);_c(462828,70248);_c(462840,70264);_c(462852,70280)}function gi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;f=jb-16|0;jb=f;o(+b);h=j(1)|0;e=j(0)|0;g=h&2147483647;c=g;d=e;g=c+-1048576|0;a:{if((g|0)==2145386495|g>>>0<2145386495){i=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){i=e<<28;c=h;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e|2147418112;break a}if(!(c|d)){c=0;d=0;break a}g=c;c=c>>>0<1?E(e)+32|0:E(c);qf(f,d,g,0,0,c+49|0);k=v[f>>2];i=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=k;v[a+4>>2]=i;v[a+8>>2]=c;v[a+12>>2]=h&-2147483648|d;jb=f+16|0}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Lb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;h=v[Lb(e+8|0,e+4|0)>>2]>>>1|0;c=Db(b);i=f>>>1|0;if(i){g=v[a+20>>2];f=i;j=d;while(1){j=(Db(w[c|0])+j|0)+(Db(w[c+1|0])<<8)|0;u[g>>1]=j;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(Db(w[c|0])+d|0)+(Db(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}jb=e+16|0;return h+i<<1}function H0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;a:{b:{c:{if(ve(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if((_i(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}v[c+16>>2]=c+24;f=c+32|0;g=c+24|0;d=c+20|0;while(1){e=rr(v[a+36>>2],v[a+40>>2],d,g,c+12|0,c+24|0,f,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((_i(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}d=v[c+16>>2]-(c+24|0)|0;if((_i(c+24|0,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=Gr(b);break a}a=-1}jb=c+32|0;return a|0}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;f=v[Lb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-f;h=v[Lb(e+8|0,e+4|0)>>2]>>>1|0;c=Db(b);i=f>>>1|0;if(i){g=v[a+20>>2];f=i;j=d;while(1){j=(Db(w[c+1|0])+j|0)+(Db(w[c|0])<<8)|0;u[g>>1]=j;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;f=h;while(1){d=(Db(w[c+1|0])+d|0)+(Db(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;f=f-1|0;if(f){continue}break}}jb=e+16|0;return h+i<<1}function wV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;v[e+24>>2]=d;v[e+28>>2]=c;h=e+8|0;f=jb-48|0;jb=f;d=f+40|0;c=EC(d,1);d=Uc(f+16|0,d,1);g=jb-16|0;jb=g;v[g+12>>2]=c;v[114578]=0;c=f+24|0;W(286,c|0,g+12|0,d|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){jb=g+16|0;break a}V(0)|0;O()|0;Ab();L()}d=v[c>>2];v[114578]=0;aa(285,d|0,b|0,e+28|0,e+24|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){co(h,ec(v[c>>2]),Nd(c));xC(c);jb=f+48|0;break b}a=P()|0;O()|0;xC(c);S(a|0);L()}Lu(e+16|0,e+8|0);em(a,e+16|0);Bb(e+16|0);Bb(e+8|0);jb=e+32|0}function Nga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!De(a)){break b}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}on(b);Oy(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Zs(b)){break b}if(v[a>>2]!=(d|0)){Rb(b+68|0,0,36)}f=v[b+20>>2];v[114578]=0;f=T(467,f|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}a=v[a+20>>2];v[114578]=0;a=T(467,a|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}lc(f,a+c|0,d);a=x[b+34>>1];if(e){v[b+8>>2]=d;v[b+4>>2]=0;u[b+34>>1]=a|2;return}v[b+4>>2]=0;v[b+8>>2]=0;u[b+34>>1]=a&65533}return}V(0)|0;O()|0;Ab();L()}function eg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[lf(12e3,d+14|0)>>1];c=oc(a);a:{if(b>>>0>c>>>0){e=jb-32|0;jb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>1>>>0){gq(a,c,f);break d}b=zb(a);b=fq(e+8|0,Ri(a,oc(a)+c|0),oc(a),b);v[114578]=0;U(381,b|0,c|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break c}v[114578]=0;R(382,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}Dj(b)}jb=e+32|0;break b}a=P()|0;O()|0;Dj(b);S(a|0);L()}break a}if(b>>>0<c>>>0){Pn(a,v[a>>2]+(b<<1)|0)}}jb=d+16|0}function Ica(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=(Db(w[c|0])|Db(w[c+1|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=(Db(w[c|0])|Db(w[c+1|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function Fca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=(Db(w[c+1|0])|Db(w[c|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=(Db(w[c+1|0])|Db(w[c|0])<<8)^32768,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;yg(d,2,a+6|0);Ic(d+16|0,d);v[114578]=0;Q(371,b+492|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){f=b+236|0;yb(d+16|0);g=c+1|0;c=0;e=1;while(1){a:{h=w[(a+c|0)+38|0];i=ed(f,c),j=g+h|0,u[i>>1]=j;c=e&255;if(c>>>0>=128){break a}e=e+1|0;continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;vx(a+180|0,b+48|0,0);vx(a+228|0,b+88|0,2);vx(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){Rb(f,0,256)}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function XU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=16384;e=v[Lb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Kj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}oq(d+4|0,Kj(a,4));break b}if((c|0)>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}oq(d+4|0,e-c|0);break b}gC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}gC(a,c,0,b)}c=v[d+4>>2];if((c|0)>17){break a}if(v[a+1068>>2]){continue}break}}jb=d+16|0}function waa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=wx(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(a){v[114578]=0;U(1555,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(1556,f|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}hf(e+8|0);a=Ut(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(e+8|0);break a}a=P()|0;O()|0}tl(f);S(a|0);L()}function aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;f=x[Ej(a,b)>>1];a:{if(!np(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=bc(d),v[j+8>>2]=k;j=c,k=cc(d),v[j>>2]=k;if(!Jb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=Vt(g);if(i){e=0;while(1){if(!(x[rc(g,e)>>1]!=(h|0)|((a|0)==(g|0)?(b|0)==(e|0):0))){d=nK(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}By(c+8|0);if(Jb(c+8|0,c)){continue}break a}break}j=Ej(a,b),k=d,u[j>>1]=k;f=d}jb=c+16|0;return f&65535}function WU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=32768;e=v[Lb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Kj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}oq(d+4|0,Kj(a,3));break b}if((c|0)>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}oq(d+4|0,e-c|0);break b}fC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}fC(a,c,0,b)}c=v[d+4>>2];if((c|0)>9){break a}if(v[a+1068>>2]){continue}break}}jb=d+16|0}function Mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;g=d+8|0;e=b;h=e;if(pR(e,d+24|0)){f=d+26|0;f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)}ud(g,h,f);e=w[d+24|0]|w[d+25|0]<<8|(w[d+26|0]<<16|w[d+27|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;e=w[d+28|0]|w[d+29|0]<<8;t[a+4|0]=e;t[a+5|0]=e>>>8;bm(a+8|0,d+8|0);Bb(d+8|0);a:{if(!c){break a}e=(f>>>0)%(c>>>0)|0;if(!e){break a}v[114578]=0;Q(340,b|0,c-e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;hf(a);S(b|0);L()}jb=d+32|0}function C_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;e=g>>>9&1;g=af(f,e+13|0,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-((e<<3)+107&112)|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2481,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=wm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=C(0),j=0,k=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];g=v[Lb(e+8|0,e+4|0)>>2];i=z[d>>2];b=Db(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);z[e+12>>2]=i*(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;a=d;f=je(f);a:{if(C(D(f))<C(2147483648)){h=~~f;break a}h=-2147483648}j=a,k=Vc(h),u[j>>1]=k;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return g<<2}function Nj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-16|0;jb=d;v[b>>2]=0;v[b+4>>2]=0;t[d+15|0]=0;i=Wg(a,d+15|0);e=w[d+15|0];v[b>>2]=(e&252)>>>2;v[b+4>>2]=0;a:{c=e&3;if(!c){break a}c=-1<<c;k=(c>>>0<4294967294?c:-2)^-1;h=1;c=0;while(1){t[d+15|0]=0;l=Wg(a,d+15|0);m=v[b+4>>2];j=w[d+15|0];g=(h<<3)-2|0;f=g&31;e=b;n=b;if((g&63)>>>0>=32){g=j<<f;f=0}else{g=(1<<f)-1&j>>>32-f;f=j<<f}v[n>>2]=f|v[b>>2];v[e+4>>2]=g|m;i=i&l;if(!c&(h|0)==(k|0)){break a}e=h+1|0;c=e>>>0<1?c+1|0:c;h=e;continue}}jb=d+16|0;return i|0}function nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,26);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function RT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-208|0;jb=d;eu(c,a);LA(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}t[d+12|0]=64;gg(b,w[pc(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Kb(b)){break a}a=0;while(1){if(a){c=x[Pb(b,a-1|0)>>1];v[d+12>>2]=1;e=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[e+1|0]&1)<<8|w[e|0];e=x[zf(d+12|0,d+8|0)>>1];f=Pb(b,a),g=c+e|0,u[f>>1]=g}c=w[((d+16|0)+B(a,3)|0)+2|0];f=Pb(b,a),g=c,t[f+2|0]=g;a=a+1|0;if(Kb(b)>>>0>a>>>0){continue}break}}jb=d+208|0}function Lha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=$y(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;g=v[114578];v[114578]=0;if((g|0)==1){break b}if(a){v[114578]=0;U(972,e+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}v[114578]=0;R(973,f|0,e+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break c}hf(e+8|0);a=Ut(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(e+8|0);break a}a=P()|0;O()|0}Gl(f);S(a|0);L()}function eX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;f=jb-16|0;jb=f;c=jb-16|0;jb=c;h=c,i=Fma(v[a>>2],v[a+4>>2],1e9,0),v[h>>2]=i;v[c+4>>2]=mb;a=pk(c+8|0,c);g=v[a+4>>2];a=v[a>>2];jb=c+16|0;jb=f+16|0;v[d+8>>2]=a;v[d+12>>2]=g;a=v[d+12>>2];c=e+8|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=a;jb=d+16|0;d=v[c>>2];c=v[c+4>>2];a=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];d=d+b|0;v[a+16>>2]=d;v[a+20>>2]=b>>>0>d>>>0?c+1|0:c;a=pk(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];jb=e+32|0;mb=b;return a|0}function e5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[114578]=0;Z(2015,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114578]=0;ia(2073,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(g));yb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1989,36818,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=g+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function d5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[114578]=0;Z(2015,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114578]=0;ia(2074,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(g));yb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1989,36860,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=g+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=Db(w[c|0])|Db(w[c+1|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=Db(w[c|0])|Db(w[c+1|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function Gca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2]<<1;e=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2]<<1;v[d+4>>2]=v[d+12>>2]-e;g=v[Lb(d+8|0,d+4|0)>>2]>>>1|0;c=Db(b);h=e>>>1|0;if(h){f=v[a+20>>2];e=h;while(1){i=f,j=Db(w[c+1|0])|Db(w[c|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}b=Db(b);if(g){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=g;while(1){i=f,j=Db(w[c+1|0])|Db(w[c|0])<<8,u[i>>1]=j;f=f+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=d+16|0;return g+h<<1}function F6(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;a:{b:{if(!a){a=Zd(34181);break b}v[114578]=0;c=Q(85,b|0,a|0)|0;a=v[114578];v[114578]=0;c:{d:{if((a|0)!=1){v[114578]=0;R(1993,b+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}a=Zd(Tb(b+16|0));yb(b+16|0);yb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;yb(c)}_(a|0)|0;a=0;v[114578]=0;X(1989,34182,0,0,0);c=v[114578];v[114578]=0;if((c|0)==1){break a}$()}jb=b+32|0;return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function rha(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-160|0;jb=b;a=Dm(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114578]=0;c=da(122)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)==1){break b}v[114578]=0;U(123,b+8|0,d+(b+16|0)|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}Ob(b+8|0);v[114578]=0;d=Q(177,a|0,b+6|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}c=v[v[d>>2]-12>>2];v[114578]=0;d=T(174,c+d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}c=x[b+6>>1];If(a);jb=b+160|0;a=(d?0:c)&65535;break a}b=P()|0;O()|0;If(a);S(b|0);L()}return a|0}function qv(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Rb(d+24|0,0,39);a=a+f|0;a:{if(kg(e,c,0)){v[d+56>>2]=1;nb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}nb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}jb=d- -64|0;return b}function qM(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?b&240?b&-16:b&15:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(v[a+480180>>2]&59314208?b:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074444|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));ce(d+12|0,0,256);v[c>>2]=v[d+12>>2]}jb=d+16|0}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;qN(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function fX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;d=jb-16|0;jb=d;f=jb-16|0;jb=f;e=jb-16|0;jb=e;h=e,i=Fma(v[a>>2],v[a+4>>2],1e6,0),v[h>>2]=i;v[e+4>>2]=mb;a=pk(e+8|0,e);g=v[a+4>>2];a=v[a>>2];jb=e+16|0;jb=f+16|0;v[d+8>>2]=a;v[d+12>>2]=g;a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;jb=d+16|0;d=v[c+8>>2];e=v[c+12>>2];a=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=a;e=v[c+4>>2]+e|0;b=v[c>>2];d=d+b|0;v[c+16>>2]=d;v[c+20>>2]=b>>>0>d>>>0?e+1|0:e;a=pk(c+24|0,c+16|0);b=v[a+4>>2];a=v[a>>2];jb=c+32|0;mb=b;return a|0}function oM(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)|!(c&255)){break b}d=v[b+700>>2];if(!d){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=dM(a,c&15);b=Fma(a,a>>31,d,d>>31)+32768|0;a=mb;a=yc(Gma(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[e+700>>2]=a-((a|0)==(d|0));return}a=(c&255)+d|0;v[b+700>>2]=(a|0)<65535?a:65535}}function O_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,1,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;g=af(f,(g>>>9&1)+13|0,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-32|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2472,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Xl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Jha(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;t[b+15|0]=128;d=Tt(a,127,b+15|0);v[114578]=0;t[b+14|0]=64;e=W(885,a+12|0,127,b+14|0)|0;c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;t[b+13|0]=0;W(974,a+24|0,127,b+13|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;t[a+44|0]=0;t[a+45|0]=0;t[a+46|0]=0;t[a+47|0]=0;t[a+48|0]=0;t[a+49|0]=0;t[a+50|0]=0;t[a+51|0]=0;t[a+52|0]=0;t[a+53|0]=0;jb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;fe(e)}fe(d);S(a|0);L()}function z_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;g=af(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-96|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2481,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=wm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function L_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;a=jb-32|0;jb=a;u[a+28>>1]=w[64448]|w[64449]<<8;v[a+24>>2]=w[64444]|w[64445]<<8|(w[64446]<<16|w[64447]<<24);Xj(a+24|1,64436,0,v[c+4>>2]);g=v[c+4>>2];f=a-16|0;jb=f;h=le();v[a>>2]=e;g=af(f,g>>>9&1|12,h,a+24|0,a)+f|0;h=mg(f,g,c);e=f-32|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2472,f|0,h|0,g|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Xl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Fy(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(nd(a)){break a}u[v[a>>2]>>1]=0;Ue(v[a>>2]+2|0,b);e=c,f=bc(a),v[e>>2]=f;e=c,f=pp(c,1),v[e+8>>2]=f;e=c,f=cc(a),v[e>>2]=f;if(!Jb(c+8|0,c)){break a}while(1){d=v[c+8>>2];e=c,f=mO(c+8|0,1),v[e>>2]=f;d=x[Si(d,v[c>>2])>>1];u[v[c+8>>2]>>1]=d;Ue(v[c+8>>2]+2|0,b);sB(c+8|0);e=c,f=cc(a),v[e>>2]=f;if(Jb(c+8|0,c)){continue}break}}Ue(a+14|0,Kb(a)-1&255);Ue(a+13|0,w[a+14|0]);Ue(a+16|0,Kb(a)-1&255);Ue(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){Ue(a+17|0,Kb(a)-1&255)}jb=c+16|0}function u3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=Pe(12);f=c;e=zb(b);d=jb-16|0;jb=d;v[c>>2]=0;v[c+4>>2]=0;v[d+12>>2]=0;v[114578]=0;W(2209,c+8|0,d+12|0,e|0)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){jb=d+16|0;break b}break a}v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];d=v[zb(b)>>2];g=zb(f),h=d,v[g>>2]=h;g=zb(b),h=0,v[g>>2]=h;v[b>>2]=0;v[b+4>>2]=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2177,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;c:{if((a|0)!=1){jb=b+16|0;break c}break a}return}V(0)|0;O()|0;Ab();L()}function h5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[114578]=0;Z(2015,a|0);g=v[114578];v[114578]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114578]=0;ma(2071,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(f));yb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1989,36715,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=f+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function g5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[114578]=0;Z(2015,a|0);g=v[114578];v[114578]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114578]=0;ma(2072,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114578];v[114578]=0;if((b|0)==1){break c}b=Zd(Tb(f));yb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114578]=0;X(1989,36765,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}jb=f+16|0;return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Wka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;v[f+28>>2]=c;h=Qb(b,c<<2);a:{if(!h){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);i=f,j=bc(a),v[i+16>>2]=j;i=f,j=cc(a),v[i+8>>2]=j;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];Et(b,f+24|0);c=f+24|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[a>>1]=c;c=c&65535;g=65535;b:{c:{if((c|0)==(d|0)){break c}if((c|0)!=(e|0)){break b}g=65534}u[a>>1]=g}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return h|0}function Sz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c;g=e+12|0;c=a;d=Kb(c);a:{if(d>>>0<b>>>0){f=jb-32|0;jb=f;b:{d=b-d|0;c:{if(d>>>0<=v[zb(c)>>2]-v[c+4>>2]>>2>>>0){qB(c,d,g);break c}b=zb(c);b=ms(f+8|0,Be(c,Kb(c)+d|0),Kb(c),b);v[114578]=0;U(736,b|0,d|0,g|0);d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(96,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}nk(b)}jb=f+32|0;break a}a=P()|0;O()|0;nk(b);S(a|0);L()}if(b>>>0<d>>>0){VR(c,v[c>>2]+(b<<2)|0)}}Nx(a);jb=e+16|0}function RW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(kg(a,v[b+8>>2],e)){nv(b,c,d);return}a:{if(kg(a,v[b>>2],e)){if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];nb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function NU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;vF(b);a:{if(!(w[a|0]|w[a+1|0]<<8)){c=a+2|0;if(!(w[c|0]|w[c+1|0]<<8)){break a}}v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[d+16>>2]=e;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[d+12>>2]=e;c=a+2|0;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>11|0,0,23),v[d+8>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>5&63,0,59),v[d+4>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)<<1&62,0,59),v[d>>2]=e}a=a+4|0;v[b+44>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0;e=jb-16|0;jb=e;j=v[a+4>>2];uH(a,b,c,d);h=z[a+28>>2];b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=jb-16|0;jb=a;b=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=b;b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=a;if(!(!d|h==C(1))){while(1){if(c){k=g+j|0;f=0;while(1){i=qn(b,f,k);z[i>>2]=z[i>>2]*h;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}jb=a+16|0;jb=e+16|0}function u_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-208|0;jb=a;u[a+204>>1]=w[64454]|w[64455]<<8;v[a+200>>2]=w[64450]|w[64451]<<8|(w[64452]<<16|w[64453]<<24);f=le();v[a>>2]=e;h=af(a+176|0,20,f,a+200|0,a);e=h+(a+176|0)|0;f=mg(a+176|0,e,c);Bc(a+8|0,c);v[114578]=0;g=T(2456,a+8|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){Ob(a+8|0);VE(g,a+176|0,e,a+16|0);g=b;b=(a+16|0)+(h<<2)|0;b=wm(g,a+16|0,(e|0)==(f|0)?b:((f-a<<2)+a|0)-688|0,b,c,d);jb=a+208|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Fm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}h=e;i=d;j=64-f|0;g=j&31;if((j&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|h<<g;j=i<<g}i=b;g=f;b=g&31;if((g&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function lM(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}Eb(e+8|0,a+1074308|0,3);if(Cb(e+8|0)){break c}if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,896)+a|0)+1075856|0]&1){Eb(e+8|0,a+1074308|0,3);if(!Cb(e+8|0)){break a}}c=c<<2}if(!c){break a}d=$x(a,b);if(!d){break a}g=d;a=v[(B(b,896)+a|0)+1075640>>2];f=13;d:{if(!a){break d}f=w[a+33|0]}nb[v[v[d>>2]+80>>2]](g,c,f<<24>>24,b)}jb=e+16|0}function bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=Wb(a);a:{b:{c:{if(wc(b)){a=0;while(1){d:{if(!a){break d}v[114578]=0;Q(1250,f|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=sd(b,a);v[114578]=0;R(1251,e|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;Q(1250,f|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}yb(e);a=a+1|0;if(wc(b)>>>0>a>>>0){continue}break}}jb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e)}yb(f);S(a|0);L()}function qS(a,b){a=a|0;b=b|0;var c=0,d=0;c=w[a+3|0];a:{if(c>>>0>18){break a}c=1<<c;b:{if(!(c&126991)){if(c&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{f:{switch(w[a+3|0]){case 9:c=2;break c;case 10:case 17:case 18:c=1;break c;case 11:break e;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:break f;default:break d}}c=w[a|0];if(c&7){break e}c=c>>>3|0;break c}c=w[a+3|0];return B(Vz(a),b+1>>>1|0)+(((c|0)==11)<<4)|0}c=0}d=w[a+3|0];d=B(Vz(a),B(b,c))+(((d|0)==11)<<4)|0}return d|0}function Xga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=jb-16|0;jb=e;c=w[c|0]|w[c+1|0]<<8;u[e+14>>1]=c<<8|c>>>8;c=jb-16|0;jb=c;pI(c,e+14|0);v[114578]=0;U(13,d+16|0,0,c|0);f=v[114578];v[114578]=0;a:{if((f|0)!=1){yb(c);jb=c+16|0;break a}a=P()|0;O()|0;yb(c);S(a|0);L()}jb=e+16|0;v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;b:{if((c|0)==1){break b}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Hx(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;Eb(e+8|0,a+1074308|0,21);a:{if(Cb(e+8|0)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+21616|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=cL(bn(a))+-64|0;break a}d=t[(c>>>1&31)+20720|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+21488|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+21552|0]}a=d;jb=e+16|0;return a}function Ex(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;a:{if((c|0)<2){break a}j=(c-2|0)/2|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=Ro(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(Ro(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=e;u[d>>1]=x[e>>1];if((g|0)>(j|0)){break b}d=g<<1;g=d|1;e=(g<<1)+a|0;d=d+2|0;if((d|0)<(c|0)){i=Ro(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?d:g}d=f;if(!Ro(b,x[e>>1],x[h+14>>1])){continue}}break}u[f>>1]=x[h+14>>1]}jb=h+16|0}function q$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;a=_E(a,e+12|0,d,le());d=mb;f=v[114552];d:{if(f){if(v[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}v[114552]=g;if(v[e+12>>2]==(b|0)){break c}}}v[c>>2]=4;b=0;break a}if(((d|0)<-1?1:(d|0)<=-1?a>>>0<2147483648:0)|((d|0)>0?1:(d|0)>=0?a>>>0>2147483647:0)){break b}b=a;break a}v[c>>2]=4;b=2147483647;if((d|0)>0?1:(d|0)>=0?a>>>0>=1:0){break a}b=-2147483648}jb=e+16|0;return b|0}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>3;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[e+8>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=g;Rf(e+8|0,-1,1);f=A[e+8>>3]*32768;A[e+8>>3]=f;g=a;f=Sd(f);a:{if(D(f)<2147483648){h=~~f;break a}h=-2147483648}i=g,j=Vc(h),u[i>>1]=j;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){c=v[a+20>>2];a=d;while(1){f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[e+12>>2]=f<<24|f<<8&16711680|(f>>>8&65280|f>>>24);ae(e+12|0,C(-1));g=C(z[e+12>>2]*C(32768));z[e+12>>2]=g;f=c;g=je(g);a:{if(C(D(g))<C(2147483648)){h=~~g;break a}h=-2147483648}i=f,j=Vc(h),u[i>>1]=j;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}jb=e+16|0;return d<<2}function Z5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;Z(2026,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[a+24>>2];v[114578]=0;b=Q(2027,d|0,b|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35262,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Vr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;f=a;c=v[b>>2];e=v[b+4>>2]?c&-12289|8192:c;b=v[b+8>>2];c=c&24576?c:(b|0)!=-1?e:c;e=143;a:{b:{if(c&1){break b}if(!(c&2)){break a}e=144}rw(f,e)}c:{if(c&4096){break c}if(c&8192){g=d,h=Ng(4),v[g+24>>2]=h;yG(a,d+24|0);break c}if(!(c&16384)){break c}g=d,h=Ng(256),v[g+16>>2]=h;yG(a,d+16|0)}f=a;d:{if(c&16){c=145}else{if(!(c&32)){break d}c=146}rw(f,c)}if((b|0)!=-1){g=d,h=Ng(b),v[g+8>>2]=h;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[d+8>>2]}jb=d+32|0}function VV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=gd(a);a:{b:{c:{if(wc(b)){a=0;while(1){d:{if(!a){break d}v[114578]=0;Q(192,f|0,c|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=sd(b,a);v[114578]=0;R(252,e|0,d|0);d=v[114578];v[114578]=0;if((d|0)==1){break c}v[114578]=0;Q(192,f|0,e|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}yb(e);a=a+1|0;if(wc(b)>>>0>a>>>0){continue}break}}jb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e)}yb(f);S(a|0);L()}function Yh(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;g=a;d=jb-16|0;jb=d;h=d+8|0;e=jb-48|0;jb=e;b=sc(16,4);f=Uc(e+16|0,e+40|0,1);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=e+24|0;W(280,b|0,c+12|0,f|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;T(279,c|0)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){co(h,ec(v[b>>2]),Nd(b));HC(b);jb=e+48|0;break b}a=P()|0;O()|0;HC(b);S(a|0);L()}em(g,d+8|0);Bb(d+8|0);jb=d+16|0;v[a+8>>2]=0;v[a+12>>2]=0;return a|0}function F_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-96|0;jb=a;u[a+92>>1]=w[64454]|w[64455]<<8;v[a+88>>2]=w[64450]|w[64451]<<8|(w[64452]<<16|w[64453]<<24);f=le();v[a>>2]=e;h=af(a- -64|0,20,f,a+88|0,a);e=h+(a- -64|0)|0;f=mg(a- -64|0,e,c);Bc(a+8|0,c);v[114578]=0;g=T(21,a+8|0)|0;i=v[114578];v[114578]=0;if((i|0)!=1){Ob(a+8|0);WE(g,a- -64|0,e,a+16|0);g=b;b=(a+16|0)+h|0;b=Xl(g,a+16|0,(e|0)==(f|0)?b:((f-a|0)+a|0)-48|0,b,c,d);jb=a+96|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function op(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){b=a;if(d&512){fO(a);d=x[a+34>>1]}u[b+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;Zs(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function bO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<1)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-((c|0)!=0&w[a+17|0]!=0)|0;break a}if(!((e|0)>-1|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function Xu(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;h=wh(f+8|0,b);d=jb-16|0;jb=d;i=d+8|0;e=jb-48|0;jb=e;b=sc(24,4);g=Uc(e+16|0,e+40|0,1);c=jb-16|0;jb=c;v[c+12>>2]=b;v[114578]=0;b=e+24|0;W(274,b|0,c+12|0,g|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=v[b>>2];v[114578]=0;Q(273,c|0,h|0)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){co(i,ec(v[b>>2]),Nd(b));SC(b);jb=e+48|0;break b}a=P()|0;O()|0;SC(b);S(a|0);L()}em(a,d+8|0);Bb(d+8|0);jb=d+16|0;jb=f+16|0}function $F(a){var b=0,c=0,d=0,e=0;b=jb-160|0;jb=b;a=Dm(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114578]=0;c=da(122)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;U(123,b+8|0,d+(b+16|0)|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}Ob(b+8|0);v[114578]=0;d=Q(173,a|0,b+4|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[v[d>>2]-12>>2];v[114578]=0;d=T(174,c+d|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2];If(a);jb=b+160|0;return d?0:c}b=P()|0;O()|0;If(a);S(b|0);L()}function yma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;v[f+28>>2]=c;h=Qb(b,c<<1);a:{if(!h){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);i=f,j=bc(a),v[i+16>>2]=j;i=f,j=cc(a),v[i+8>>2]=j;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];gu(b,f+24|0);c=f+24|0;c=w[c|0]|w[c+1|0]<<8;c=c<<8|c>>>8;u[a>>1]=c;c=c&65535;g=65535;b:{c:{if((c|0)==(d|0)){break c}if((c|0)!=(e|0)){break b}g=65534}u[a>>1]=g}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return h|0}function qf(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;i=f;d=f&31;if((f&63)>>>0>=32){h=g<<d;j=0}else{h=(1<<d)-1&g>>>32-d|e<<d;j=g<<d}d=c;g=b;f=64-f|0;e=f&31;if((f&63)>>>0>=32){f=0;d=d>>>e|0}else{f=d>>>e|0;d=((1<<e)-1&d)<<32-e|g>>>e}d=j|d;e=f|h;f=b;b=i&31;if((i&63)>>>0>=32){h=f<<b;b=0}else{h=(1<<b)-1&f>>>32-b|c<<b;b=f<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);Db(w[b+2|0]);Db(w[b+3|0]);Db(w[b+4|0]);Db(w[b+5|0]);f=a,g=Db(w[b+6|0])|Db(w[b+7|0])<<8,u[f>>1]=g;Db(w[b+8|0]);Db(w[b+9|0]);Db(w[b+10|0]);Db(w[b+11|0]);Db(w[b+12|0]);Db(w[b+13|0]);f=a,g=Db(w[b+14|0])|Db(w[b+15|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+7|0]);Db(w[b+6|0]);Db(w[b+5|0]);Db(w[b+4|0]);Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;Db(w[b+15|0]);Db(w[b+14|0]);Db(w[b+13|0]);Db(w[b+12|0]);Db(w[b+11|0]);Db(w[b+10|0]);f=a,g=Db(w[b+9|0])|Db(w[b+8|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function D9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;g=d;e=u[b>>1];f=e;b=u[a+30>>1];a:{if(!b){break a}if((e|0)>=0){f=(e|0)%(b|0)|0;break a}f=b+((e^-1)%(b|0)^-1)|0}u[g+14>>1]=f;b:{if(!Wc(c)){Wi(bK(a+52|0,d+14|0),c);break b}f=a+52|0;h=d,i=jx(f,d+14|0),v[h+8>>2]=i;h=d,i=Hi(f),v[h>>2]=i;if(!Gi(d+8|0,d)){break b}g=jb-16|0;jb=g;a=v[Qc(g,v[d+8>>2])>>2];e=jb-16|0;jb=e;v[e+8>>2]=a;c=v[e+8>>2];b=UJ(f,c);a=hc(f);At(jh(e+8|0));sh(a,c,1);jb=e+16|0;Qc(g+8|0,b);jb=g+16|0}jb=d+16|0}function v3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-32|0;jb=b;a:{b:{if(ni(a)){Fo(b+24|0);break b}Pm(b+8|0,a);v[114578]=0;R(2175,b+24|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}rf(b+8|0)}c=a+36|0;c:{if(ni(a)){break c}c=v[b+24>>2]}a=v[a+8>>2];d:{if((a|0)==-1){e=b,f=bc(c),v[e+8>>2]=f;e=b,f=cc(c),v[e>>2]=f;if(!Jb(b+8|0,b)){break d}while(1){d=A[v[b+8>>2]>>3]+d;Ik(b+8|0);if(Jb(b+8|0,b)){continue}break}break d}d=A[Rc(c,a)>>3]}gk(b+24|0);jb=b+32|0;return+d}a=P()|0;O()|0;rf(b+8|0);S(a|0);L()}function mw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-32|0;jb=e;v[e+24>>2]=b;m=e,n=Ed(a),v[m+16>>2]=n;j=$l(e+24|0,e+16|0);h=j;i=jb-16|0;jb=i;a:{b=a;g=Fb(b);if(g>>>0>=h>>>0){if(c){f=Kc(b);b:{if(f-g>>>0>=c>>>0){f=Tb(b);k=g-h|0;if(!k){break b}l=f+h|0;_l(l+c|0,l,k);break b}Rl(b,f,(c+g|0)-f|0,g,h,0,c);f=v[b>>2]}wy(f+h|0,c,d);d=b;b=c+g|0;Sg(d,b);t[i+15|0]=0;he(b+f|0,i+15|0)}jb=i+16|0;break a}pm();L()}m=e,n=Ed(a),v[m+8>>2]=n;a=cf(e+8|0,j);jb=e+32|0;return a|0}function Taa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;while(1){e=g&255;c=0;b=1;while(1){c=e&1|c;if((b|0)!=8){e=(e&254)>>>1|0;c=c<<1;b=b+1|0;continue}break}f=0;b=(c&255)<<24;e=1;while(1){d=f;c=b<<1|d>>>31;d=d<<1;b=(b|0)>-1;f=b?d:d^-1798752855;b=b?c:c^-1382821323;if((e|0)!=8){e=e+1|0;continue}break}d=0;c=0;e=1;while(1){d=f&1|d;if((e|0)!=64){f=(b&1)<<31|f>>>1;b=b>>>1|0;c=c<<1|d>>>31;d=d<<1;e=e+1|0;continue}break}b=(g<<3)+85376|0;v[b>>2]=d;v[b+4>>2]=c;g=g+1|0;if((g|0)!=256){continue}break}return a|0}function TZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;d=Fb(a);e=Vq(a);g=rt(b,c);a:{if(!g){break a}if(Zz(b,Tb(a),Tb(a)+(Fb(a)<<2)|0)){d=jb-16|0;jb=d;ZE(f,b,c);jb=d+16|0;b=f;c=Tb(b);d=Fb(b);v[114578]=0;W(2507,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Lc(b);break a}a=P()|0;O()|0;Lc(b);S(a|0);L()}if(e-d>>>0<g>>>0){GD(a,e,(d+g|0)-e|0,d,d)}e=Tb(a)+(d<<2)|0;while(1){if((b|0)!=(c|0)){Te(e,b);b=b+4|0;e=e+4|0;continue}break}v[f>>2]=0;Te(e,f);Sg(a,d+g|0)}jb=f+16|0;return a|0}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=jb-16|0;jb=e;d=c;zb(d);a=b;h=MN(b,e+8|0);b:{f=oc(d);if(!f){break b}v[114578]=0;R(920,a|0,f|0);g=v[114578];v[114578]=0;if((g|0)!=1){g=v[d+4>>2];d=v[d>>2];v[114578]=0;X(1195,a|0,d|0,g|0,f|0);d=v[114578];v[114578]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;bq(h);S(a|0);L()}jb=e+16|0;v[114578]=0;Q(4,b+12|0,c+12|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[b+24>>2]=v[c+24>>2];u[b+28>>1]=x[c+28>>1];break a}b=P()|0;O()|0;kf(a);S(b|0);L()}}function i$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=w[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=v[114552];v[114552]=0;a=Nv(a,e+12|0,d,le());d=mb;g=v[114552];f:{if(g){if(v[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}v[114552]=h;if(v[e+12>>2]==(b|0)){break b}}}}v[c>>2]=4;a=0;b=0;break a}v[c>>2]=4;a=-1;b=-1;break a}b=a;c=(f|0)==45;a=c?0-a|0:a;b=c?0-(d+((b|0)!=0)|0)|0:d}jb=e+16|0;mb=b;return a|0}function x2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{if((h|0)==1){break b}v[114578]=0;U(123,c|0,e+(c+8|0)|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}Ob(c);v[114578]=0;R(135,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Yd(d);jb=c+144|0;break a}a=P()|0;O()|0;Yd(d);S(a|0);L()}jb=f+16|0}function v2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;g=da(122)|0;h=v[114578];v[114578]=0;a:{b:{if((h|0)==1){break b}v[114578]=0;U(123,c|0,e+(c+8|0)|0,g|0);e=v[114578];v[114578]=0;if((e|0)==1){break b}Ob(c);v[114578]=0;R(136,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break b}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Yd(d);jb=c+144|0;break a}a=P()|0;O()|0;Yd(d);S(a|0);L()}jb=f+16|0}function pw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;f=(p(a),j(2));c=f&2147483647;a:{if(c>>>0<=1305022426){g=+a;d=g*.6366197723675814+6755399441055744+-6755399441055744;A[b>>3]=g+d*-1.5707963109016418+d*-1.5893254773528196e-8;if(D(d)<2147483648){c=~~d;break a}c=-2147483648;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}h=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,h-(c<<23)|0),q());c=xG(e+8|0,e,c,1,0);d=A[e>>3];if((f|0)<=-1){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}jb=e+16|0;return c}function yT(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Le(b);Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)==1){break a}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}v[114578]=0;X(416,d+8|0,2,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Gb(b,d+24|0);yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Ec(d+40|0);S(a|0);L()}function wm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>=1){g=g>>2;if((Vl(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>=1){f=UE(i,b,f);h=Tb(f);v[114578]=0;h=W(2484,a|0,h|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}Lc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>=1){b=b>>2;if((Vl(a,c,b)|0)!=(b|0)){break b}}Sy(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;Lc(f);S(a|0);L()}function FA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Le(b);Me(d+40|0,a,c);a=v[d+40>>2];v[114578]=0;e=T(414,d+40|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)==1){break a}v[114578]=0;e=T(415,e|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}v[114578]=0;X(416,d+8|0,3,e|0,a|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}v[114578]=0;R(417,d+24|0,d+8|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Gb(b,d+24|0);yb(d+24|0);Ec(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Ec(d+40|0);S(a|0);L()}function hW(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;c=Ub(b,7035);v[114578]=0;U(226,b+16|0,a|0,c|0);a=v[114578];v[114578]=0;a:{b:{c:{if((a|0)!=1){yb(c);if(wc(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;yb(c);break b}a=0;while(1){d:{c=sd(b+16|0,d);v[114578]=0;c=T(227,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=wc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;cl(b+16|0)}S(d|0);L()}cl(b+16|0);jb=b+32|0;return a|0}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];c=v[Lb(e+8|0,e+4|0)>>2];h=z[d>>2];b=Db(b);if(c){a=v[a+20>>2];d=c;while(1){z[e+12>>2]=h*(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;i=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}j=i,k=Vc(g),u[j>>1]=k;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return c<<2}function y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=af(g,e+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-((e<<3)+187&240)|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2481,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=wm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=e+j|0;e=t[f|0];e=((B(t[f+1|0]-e|0,g>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;jb=b+16|0}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;e=h>>>9&1;f=af(g,e+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-((e<<3)+187&240)|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2481,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=wm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function m4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=jb-16|0;jb=f;d=b+4|0;zb(d);c=jb-16|0;jb=c;b=a;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(2124,a+8|0,c+12|0,f+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{c=od(d);if(!c){break b}v[114578]=0;R(2122,a|0,c|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[d+4>>2];d=v[d>>2];v[114578]=0;X(2123,a|0,d|0,e|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;lI(b);S(a|0);L()}jb=f+16|0}function cO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=b?33:32;e=v[a+8>>2]-1|0;j=e-((e|0)!=0&w[a+17|0]!=0)|0;f=v[a+12>>2];g=v[a>>2]+B(f,62)|0;d=b?1:-1;k=B(f,d)<<1;c=e;while(1){if((f|0)>=1){l=B(c,f);m=v[a+4>>2];b=0;while(1){u[(b<<1)+g>>1]=x[(b+l<<1)+m>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}a:{if(!((c|0)!=(e|0)|(d|0)<=0)){b=w[a+16|0];d=b?-1:1;c=b?j:0;break a}if(!((d|0)>-1|c)){b=w[a+16|0];d=b?1:-1;c=b?0:e;break a}c=d+c|0}g=g+k|0;h=h+1|0;if((i|0)!=(h|0)){continue}break}}function Np(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Qb(b,c);a:{if(!g){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);i=f,j=bc(a),v[i+16>>2]=j;i=f,j=cc(a),v[i+8>>2]=j;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!Wf(b,c)){h=jb-16|0;jb=h;ff(c);jb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return g|0}function Ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];f=v[a+4>>2];e=f;g=v[a>>2];v[b+8>>2]=g;v[b+12>>2]=e;f=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=f;if(d){while(1){f=(e<<1)+j|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,g>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;g=v[b+8>>2];e=v[b+12>>2];continue}break}g=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=g;v[a+4>>2]=e;jb=b+16|0}function m$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114552];v[114552]=0;a=Nv(a,e+12|0,d,le());d=mb;g=v[114552];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114552]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a&65535}function aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=jb-608|0;jb=g;c=jb-16|0;jb=c;d=g+8|0;jQ(c+8|0,d);e=Hb(c+8|0);b=a;f=md(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(b,Hb(c+8|0))}jb=c+16|0;c=(e|0)==(f|0);if(!c){kQ(d)}b=-1;a:{if(!c){break a}b=0;if(!tQ(g+8|0)){break a}b=-1;if(!Df(a,1024)){break a}b=0;d=jb-1024|0;jb=d;c=jb-16|0;jb=c;gz(c+8|0,d);e=Hb(c+8|0);f=md(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;if((e|0)==(f|0)){b=hz(d,0)>>>0<17}jb=d+1024|0}jb=g+608|0;return b|0}function tM(a,b){var c=0,d=0,e=0;a:{b:{if(!w[b+866|0]|v[a+480180>>2]!=1){break b}d=v[b+104>>2];if(!d){break b}if(!De(d)|(x[d+34>>1]&3)!=2){break b}c=w[b+867|0]+w[(w[b+866|0]&15)+21408|0]|0;t[b+867|0]=c;if(c<<24>>24>-1){break b}t[b+867|0]=0;c=v[b+784>>2]+1|0;v[b+784>>2]=c>>>0<v[d+8>>2]-v[d+4>>2]>>>0?c:0;c=v[d+20>>2];v[114578]=0;c=T(467,c|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}b=Db(c)+(v[b+784>>2]+v[d+4>>2]|0)|0;t[b|0]=w[b|0]^-1;Dy(d,a,0)}return}V(0)|0;O()|0;Ab();L()}function T5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114578]=0;Z(2015,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114578]=0;b=ua(2032,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35378,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Q5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114578]=0;Z(2015,a|0);h=v[114578];v[114578]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114578]=0;b=ua(2035,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35467,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Uca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Lb(d+8|0,d+4|0)>>2];c=Db(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=Db(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=Db(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}jb=d+16|0;return g+h|0}function Tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];h=v[Lb(e+8|0,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Lb(e+8|0,e+4|0)>>2];c=Db(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=Db(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=Db(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=Db(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}jb=e+16|0;return h+i|0}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+(B(t[e|0],h)<<8);v[c+4>>2]=v[c+4>>2]+(B(f,g)<<8);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function JE(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;mb=v[e+4>>2];return v[e>>2]}function ZZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;d=Fb(a);e=Kc(a);g=Pi(b,c);a:{if(!g){break a}if(Zz(b,Tb(a),Tb(a)+Fb(a)|0)){b=ri(f+16|0,b,c);c=Tb(b);d=Fb(b);v[114578]=0;W(2499,a|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Rl(a,e,(d+g|0)-e|0,d,d,0,0)}e=Tb(a)+d|0;while(1){if((b|0)!=(c|0)){he(e,b);b=b+1|0;e=e+1|0;continue}break}t[f+15|0]=0;he(e,f+15|0);Sg(a,d+g|0)}jb=f+32|0;return a|0}function Xl(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>=1){if((Vl(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>=1){f=Hj(i,b,f);g=Tb(f);v[114578]=0;g=W(28,a|0,g|0,b|0)|0;h=v[114578];v[114578]=0;if((h|0)==1){break a}yb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>=1){if((Vl(a,c,b)|0)!=(b|0)){break b}}Sy(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;yb(f);S(a|0);L()}function M_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,1,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;f=af(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-48|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2472,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Xl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function M4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[114578]=0;Z(2088,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[114578]=0;b=bb(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,38080,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function K_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;Xj(a+24|1,64438,0,v[c+4>>2]);h=v[c+4>>2];g=a-32|0;jb=g;i=le();v[a>>2]=e;v[a+4>>2]=f;f=af(g,(h>>>9&1)+23|0,i,a+24|0,a)+g|0;h=mg(g,f,c);e=g-48|0;jb=e;Bc(a+8|0,c);v[114578]=0;ia(2472,g|0,h|0,f|0,e|0,a+20|0,a+16|0,a+8|0);f=v[114578];v[114578]=0;if((f|0)!=1){Ob(a+8|0);b=Xl(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function lP(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>32){break a}b=a+32|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+34|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}return(w[a|0]|w[a+1|0]<<8)>>>0<129}return 0}function Oka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if(yt(a)){v[b>>2]=0;a=0;break a}f=xg(a,e,16);d=Db(w[e|0]);c=d&127;v[b>>2]=c;d=d<<24>>24;b:{if(!(f>>>0<2|(d|0)>-1)){d=c?32-E(c)|0:0;c=1;while(1){g=Db(w[c+e|0]);v[b>>2]=g&127|v[b>>2]<<7;d=d+7|0;c=c+1|0;if((f|0)==(c|0)){$b(a,f);f=xg(a,e,16);c=0}g=g<<24>>24;if((g|0)<0?c>>>0<f>>>0:0){continue}break}$b(a,c);a=(g|0)<0;if(d>>>0<33){break b}v[b>>2]=-1;a=0;break a}$b(a,1);a=(d|0)<0}a=!a}jb=e+16|0;return a|0}function dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;a:{if((b-1&65535)>>>0>3998){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!De(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}on(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;op(e,0,c)}jb=c+32|0;return f|0}function al(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;VD(a+32|0);b=jb-16|0;jb=b;c=a+44|0;v[c>>2]=0;v[c+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(208,c+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function Vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];g=v[Lb(d+8|0,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Lb(d+8|0,d+4|0)>>2];c=Db(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=fn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Db(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=fn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}jb=d+16|0;return g+h|0}function Cr(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!c|!(a&3)){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}a=a+1|0;c=c-1|0;d=(c|0)!=0;if(!c){break c}if(a&3){continue}break}}if(!d){break a}}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function EQ(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Je(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Je(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}jb=f+16|0}function P4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114578]=0;Z(2088,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[114578]=0;b=aa(f|0,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37764,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function ck(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[21203]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344?b>>>0>=55296:0)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[114552]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function XE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114552];v[114552]=0;a=Nv(a,e+12|0,d,le());d=mb;g=v[114552];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114552]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a|0}function O4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114578]=0;Z(2088,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[114578]=0;b=aa(f|0,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37721,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function C7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=qi(a,b,c,d);v[a>>2]=80800;d=kk(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=Se(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[114578]=0;W(1640,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1641,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(d);bf(b);S(a|0);L()}function YT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Qb(b,c<<1);a:{if(!g){break a}Cc(f+28|0,65535);eg(a,x[f+28>>1]);h=f,i=bc(a),v[h+16>>2]=i;h=f,i=cc(a),v[h+8>>2]=i;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];gu(b,f+24|0);c=f+24|0;c=w[c|0]|w[c+1|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}te(f+16|0);if(Jb(f+16|0,f+8|0)){continue}break}}jb=f+32|0;return g|0}function vK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=a;d=b;if((c|0)!=(d|0)){e=jb-16|0;jb=e;f=v[d+4>>2];d=v[d>>2];g=(f-d|0)/6|0;a:{if(g>>>0<=Li(c)>>>0){v[e+12>>2]=f;if(bg(c)>>>0<g>>>0){v[e+12>>2]=d;h=bg(c);v[e+12>>2]=v[e+12>>2]+B(h,6);qx(d,v[e+12>>2],v[c>>2]);px(c,v[e+12>>2],f,g-bg(c)|0);break a}Pz(c,qx(d,f,v[c>>2]));break a}tK(c);hS(c,Fz(c,g));px(c,d,f,g)}jb=e+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];uK(a+24|0,b+24|0);Wi(a+36|0,b+36|0)}function K4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114578]=0;Z(2088,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[114578]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,38026,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function I4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114578]=0;Z(2088,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[114578]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37978,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function rj(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;if(!nd(a)){ZN(b+32|0,a);YN(b+24|0,a);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!Xs(c,e)){break a}while(1){d=jb-16|0;jb=d;v[d+8>>2]=v[c+4>>2];f=RN(d+8|0);jb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}RN(c+4|0);if(Xs(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=lA(bc(a),v[b+44>>2])}jb=b+48|0;return c&65535}function nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;yP(a);zb(a);h=b+4|0;f=h;e=v[a+4>>2];i=v[a>>2];if((e|0)!=(i|0)){c=v[f>>2];while(1){c=c-56|0;e=e-56|0;d=e;oP(c,d);oP(c+12|0,d+12|0);Uy(c+24|0,d+24|0);u[c+52>>1]=x[d+52>>1];g=v[d+48>>2];v[c+44>>2]=v[d+44>>2];v[c+48>>2]=g;g=v[d+40>>2];v[c+36>>2]=v[d+36>>2];v[c+40>>2]=g;c=v[f>>2]-56|0;v[f>>2]=c;if((d|0)!=(i|0)){continue}break}}Zb(a,h);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];wk(a);sn(a);sn(a)}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+8>>2]=c>>>2;v[e+4>>2]=v[a>>2];d=v[Lb(e+8|0,e+4|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){v[e+12>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);ae(e+12|0,C(-1));f=C(z[e+12>>2]*C(32768));z[e+12>>2]=f;h=a;f=je(f);a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=h,j=Vc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function W1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=0,j=0,k=0;e=jb-16|0;jb=e;j=v[a+4>>2];qH(a,b,c,d);h=z[a+24>>2];v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=jb-16|0;jb=a;v[a+8>>2]=v[e+8>>2];b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=a;if(!(!d|h==C(1))){while(1){if(c){k=g+j|0;f=0;while(1){i=Of(b,f,k);z[i>>2]=z[i>>2]*h;f=f+1|0;if((f|0)!=(c|0)){continue}break}}g=g+1|0;if((g|0)!=(d|0)){continue}break}}jb=a+16|0;jb=e+16|0}function bv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,20);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function Gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=bg(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/6>>>0){Qz(a,d,c);break c}b=zb(a);b=JR(e+8|0,Fz(a,bg(a)+d|0),bg(a),b);v[114578]=0;U(708,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(709,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}xt(b)}jb=e+32|0;break a}a=P()|0;O()|0;xt(b);S(a|0);L()}return}if(b>>>0<d>>>0){Pz(a,v[a>>2]+B(b,6)|0)}}function vaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=wx(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!a){break c}v[114578]=0;U(1555,d+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(1556,e|0,d+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}hf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(d+8|0);break a}jb=d+32|0;return}a=P()|0;O()|0}tl(e);S(a|0);L()}function hJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=qi(a,b,c,d);v[a>>2]=80160;c=kk(a+4260|0);v[a+4232>>2]=1061997773;d=a+4224|0;v[d>>2]=1061158912;v[d+4>>2]=1059082943;d=a+4216|0;v[d>>2]=1038174126;v[d+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[114578]=0;W(1640,a+44|0,2,2)|0;d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;Z(1641,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(c);bf(b);S(a|0);L()}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0;c=od(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>4>>>0){oB(a,c);break c}b=zb(a);b=LS(d+8|0,Mq(a,od(a)+c|0),od(a),b);v[114578]=0;R(761,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(609,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}It(b)}jb=d+32|0;break a}a=P()|0;O()|0;It(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<4)|0;od(a);WA(a,b);mD(a)}}function Qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=xe(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>5>>>0){Ay(a,d,c);break c}b=zb(a);b=JN(e+8|0,dm(a,xe(a)+d|0),xe(a),b);v[114578]=0;U(1193,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1180,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Ss(b)}jb=e+32|0;break a}a=P()|0;O()|0;Ss(b);S(a|0);L()}return}if(b>>>0<d>>>0){VN(a,v[a>>2]+(b<<5)|0)}}function Hc(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;if(v[a+4>>2]==v[b+4>>2]){c=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=c;v[d+8>>2]=b;v[d+12>>2]=c;e=jb-16|0;jb=e;v[e+12>>2]=v[a+4>>2];b=d;c=v[b+4>>2];v[114578]=0;v[e+8>>2]=c;c=Q(33,e+12|0,e+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){c=Um(v[a>>2],v[b>>2],v[c>>2]);b:{if(c){break b}c=0;if(v[a+4>>2]==v[b+4>>2]){break b}c=y[a+4>>2]<y[b+4>>2]?-1:1}jb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}c=!c}jb=d+16|0;return c}function eK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Kb(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){ix(a,d,c);break c}b=zb(a);b=kx(e+8|0,Be(a,Kb(a)+d|0),Kb(a),b);v[114578]=0;U(1597,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(1598,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Vm(b)}jb=e+32|0;break a}a=P()|0;O()|0;Vm(b);S(a|0);L()}return}if(b>>>0<d>>>0){lx(a,v[a>>2]+(b<<2)|0)}}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=a;e=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(568,a+8|0,c+12|0,c+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(561,d|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(562,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;bT(e);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function R1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-48|0;jb=e;f=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=f;f=v[b+4>>2];v[e+32>>2]=v[b>>2];v[e+36>>2]=f;b=Go(e+24|0,c);v[114578]=0;c=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=c;c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;aa(2013,a+8|0,e+8|0,b|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Yc(b);oH(a);b=nH(a+88|0);v[a>>2]=84152;v[b>>2]=84240;jb=e+48|0;return a|0}a=P()|0;O()|0;Yc(b);S(a|0);L()}function Nw(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Pr(b)){break a}a=a+24|0;if(!dg(v[a>>2]+484344|0,b&65535)){break a}b=_b(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0|(x[v[a>>2]+480188>>1]<=(d|0)|e>>>0>5)){break a}a=Xe(b,c,d&65535);b:{switch(e|0){case 0:f=w[a|0];break a;case 1:f=w[a+1|0];break a;case 2:f=w[a+2|0];break a;case 3:f=w[a+3|0];break a;case 4:f=w[a+4|0];break a;case 5:break b;default:break a}}f=w[a+5|0]}return f|0}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=$y(a);a:{b:{c:{d:{while(1){v[114578]=0;a=Q(258,b|0,8)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}if(!a){break c}v[114578]=0;U(972,d+8|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;R(973,e|0,d+8|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}hf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;hf(d+8|0);break a}jb=d+32|0;return}a=P()|0;O()|0}Gl(e);S(a|0);L()}function HD(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=jb-16|0;jb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Tb(a);a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=sm(v[bd(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=rm(k);if(e){hi(c,j,e)}if(g){hi(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;hi((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){lo(j,b)}Ef(a,c);Fg(a,k);b=a;a=d+(e+g|0)|0;we(b,a);v[i+4>>2]=0;Te(c+(a<<2)|0,i+4|0);jb=i+16|0;return}Hg();L()}function i5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114578]=0;Z(2015,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114578]=0;b=ea(2070,f|0,b|0,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36668,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function U5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114578]=0;Z(2015,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114578]=0;b=ea(2031,f|0,b|0,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35351,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function R5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114578]=0;Z(2015,a|0);f=v[114578];v[114578]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114578]=0;b=ea(2034,f|0,b|0,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35434,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function G4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[114578]=0;Z(2088,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[114578]=0;db(f|0,d|0,b|0,+c);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37940,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function iN(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;e=a;d=3546895/+(b>>>0);c=d*.25;a:{if(D(c)<2147483648){b=~~c;break a}b=-2147483648}v[e+16>>2]=b;c=(d-+(b<<2))*4294967296;b:{if(D(c)<0x8000000000000000){f=~~c>>>0;b=D(c)>=1?c>0?~~F(H(c*2.3283064365386963e-10),4294967295)>>>0:~~I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10)>>>0:0;break b}b=-2147483648}v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=f;v[a+12>>2]=b}function cT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1060>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1068|0,g=Kj(a,7),t[f|0]=g;d=Kj(a,1);e=Kj(a,1);c=v[a+1056>>2];if((c|0)>255){break a}b=v[a+1060>>2]+1|0;v[a+1056>>2]=b;v[a+1060>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1064>>1]=b;cT(a);b=v[a+1060>>2];break b}u[(B(c,6)+a|0)+1064>>1]=65535}v[a+1056>>2]=b;if(e){u[(B(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1066>>1]=65535}}function jc(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){c:{if((b|0)>(c|0)){if((b|0)>=25){break b}if(!c){v[a+1392>>2]=0}while(1){c=-1;e=Er(a);d=0;if((e|0)==-1){break c}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}return jc(a,24)+(jc(a,b-24|0)<<24)|0}ha(50550,50496,1617,50569);L()}function Kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ac(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){Pp(a,d,c);break c}b=zb(a);b=nh(e+8|0,Ki(a,Ac(a)+d|0),Ac(a),b);v[114578]=0;U(702,b|0,d|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(366,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Rg(b)}jb=e+32|0;break a}a=P()|0;O()|0;Rg(b);S(a|0);L()}return}if(b>>>0<d>>>0){Fu(a,v[a>>2]+b|0)}}function pI(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;f=da(122)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;U(123,c|0,e+(c+8|0)|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Ob(c);v[114578]=0;R(132,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Yd(d);jb=c+144|0;return}a=P()|0;O()|0;Yd(d);S(a|0);L()}function Yw(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-144|0;jb=c;d=dh(c+8|0);e=v[v[d>>2]-12>>2];v[114578]=0;f=da(122)|0;g=v[114578];v[114578]=0;a:{if((g|0)==1){break a}v[114578]=0;U(123,c|0,e+(c+8|0)|0,f|0);e=v[114578];v[114578]=0;if((e|0)==1){break a}Ob(c);v[114578]=0;R(124,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;R(125,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Yd(d);jb=c+144|0;return}a=P()|0;O()|0;Yd(d);S(a|0);L()}function D3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=ba(8)|0;v[114578]=0;c=Q(85,h|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=Qw(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function A3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(!(g?!(!f|(!d|!e)):0)){b=ba(8)|0;v[114578]=0;c=Q(85,h|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=Pw(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function yx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=jb-48|0;jb=f;a:{if(!c){c=tc(a,b);a=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=a;a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;break a}e=v[d+12>>2];v[f+24>>2]=v[d+8>>2];v[f+28>>2]=e;g=v[d+4>>2];e=f;v[e+16>>2]=v[d>>2];v[e+20>>2]=g;g=c>>>1|0;yx(a,b,g,e+16|0);Jh(e+32|0,d,tc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;yx(a,b|c,g,e)}jb=f+48|0}function Sia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0),i=0;g=jb-16|0;jb=g;a:{if(!d){break a}a=a+e|0;e=1;while(1){z[g+12>>2]=z[b>>2];ae(g+12|0,C(-1));h=C(z[g+12>>2]*C(128));z[g+12>>2]=h;h=je(h);b:{if(C(D(h))<C(2147483648)){i=~~h;break b}i=-2147483648}f=jb-16|0;jb=f;v[f+12>>2]=i;v[f+8>>2]=-128;v[f+4>>2]=127;i=t[zf(f+8|0,de(f+12|0,f+4|0))|0];jb=f+16|0;t[a|0]=i;if((d|0)==(e|0)){break a}a=a+c|0;b=b+4|0;e=e+1|0;continue}}jb=g+16|0}function sF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;h=-1;f=d&2147483647;i=f;g=c;a:{if(!c&(f|0)==2147418112?a|b:(f|0)==2147418112&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;j=f;if((f|0)==2147418112?0:f>>>0>2147418112){break a}if(!(a|g|(i|j|b))){return 0}g=d&e;if((g|0)>0?1:(g|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c)!=0|(d^e|b)!=0}if(!c&(d|0)==(e|0)?a|b:(d|0)>(e|0)?1:(d|0)>=(e|0)?c:0){break a}h=(a|c)!=0|(d^e|b)!=0}return h}function z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[114578]=0;R(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37818,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[114578]=0;R(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37800,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function vda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;b=Pe(1);v[114578]=0;d=Q(85,c|0,1434)|0;e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){v[114578]=0;e=Q(86,b|0,d|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break b}b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=e;W(90,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;c:{if((a|0)!=1){jb=b+16|0;break c}V(0)|0;O()|0;Ab();L()}yb(d);jb=c+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d)}Xb(b);S(a|0);L()}function RV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;c=jb-16|0;jb=c;e=b+16|0;MC(c+8|0,e);f=Hb(c+8|0);d=a;g=md(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(f|0)==(g|0);if(!c){NC(e)}d=-1;a:{if(!c){break a}d=0;if(!aD(b+16|0)){break a}c=jb-16|0;jb=c;d=b;KC(c+8|0,b);f=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((f|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(e|0);if(!a){LC(d)}d=-1;if(!a){break a}d=$C(b)}jb=b+32|0;return d|0}function N4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[114578]=0;R(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,38090,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function JK(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1095062050?(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=-1346458146:0){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;return((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return 0}function H6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Bc(a,b);v[114578]=0;U(128,d+8|0,b|0,c|0);e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}Ob(d+8|0);v[114578]=0;e=T(27,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}if(e){v[114578]=0;b=T(27,b|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break a}v[114578]=0;U(129,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}Ob(d)}jb=d+16|0;return}b=P()|0;O()|0;Ob(a);S(b|0);L()}function j2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=c;v[d+8>>2]=b;Dq(v[d+8>>2]);b=jb-32|0;jb=b;v[b+24>>2]=v[d>>2];c=v[b+24>>2];e=v[c+12>>2];v[b+16>>2]=v[c+8>>2];v[b+20>>2]=e;e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;Kp(a);v[a>>2]=76312;Oi(a+4|0);t[a+20|0]=0;v[a+16>>2]=0;v[a>>2]=76428;c=v[b+12>>2];v[a+24>>2]=v[b+8>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+32>>2]=v[b+16>>2];v[a+36>>2]=c;t[a+40|0]=0;jb=b+32|0;jb=d+16|0;return a|0}function W5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2030,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35326,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function S5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2033,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35403,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function P5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2036,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35498,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function O5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2037,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35537,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function N5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2038,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35574,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function M5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114578]=0;Z(2015,a|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114578]=0;b=aa(2039,e|0,b|0,c|0,d|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35619,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function E4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[114578]=0;ra(e|0,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114578]=0;X(1989,37904,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function C4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[114578]=0;ra(e|0,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114578]=0;X(1989,37870,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function A4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[114578]=0;ra(e|0,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114578]=0;X(1989,37836,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function xB(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>1>>>0){dB(a,c);break c}b=zb(a);b=fq(d+8|0,Ri(a,oc(a)+c|0),oc(a),b);v[114578]=0;R(412,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(382,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Dj(b)}jb=d+32|0;break a}a=P()|0;O()|0;Dj(b);S(a|0);L()}return}if(b>>>0<c>>>0){Pn(a,v[a>>2]+(b<<1)|0)}}function pka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;j=e+8|0;c=jb-16|0;jb=c;f=a;k=b;d=Ke(a);g=hc(a);h=jb-16|0;jb=h;if(d){while(1){i=yn(zb(f),d+16|0,k);g=i?g:d;d=v[(i?4:0)+d>>2];if(d){continue}break}}f=v[Qc(h+8|0,g)>>2];jb=h+16|0;v[c+8>>2]=f;l=c,m=yj(a),v[l>>2]=m;a:{b:{if(!Jb(c+8|0,c)){break b}if(yn(zb(a),b,jh(c+8|0))){break b}a=v[c+8>>2];break a}a=yj(a)}jb=c+16|0;a=v[Qc(j,a)>>2];jb=e+16|0;return a|0}function H4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[114578]=0;d=+cb(e|0,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37959,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function jx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;j=e+8|0;c=jb-16|0;jb=c;f=a;k=b;d=Ke(a);g=hc(a);h=jb-16|0;jb=h;if(d){while(1){i=hs(zb(f),d+16|0,k);g=i?g:d;d=v[(i?4:0)+d>>2];if(d){continue}break}}f=v[Qc(h+8|0,g)>>2];jb=h+16|0;v[c+8>>2]=f;l=c,m=yj(a),v[l>>2]=m;a:{b:{if(!Jb(c+8|0,c)){break b}if(hs(zb(a),b,jh(c+8|0))){break b}a=v[c+8>>2];break a}a=yj(a)}jb=c+16|0;a=v[Qc(j,a)>>2];jb=e+16|0;return a|0}function aW(a,b){a=a|0;b=b|0;var c=0;a=gd(a);a:{if(w[b+16|0]){v[114578]=0;Q(235,a|0,7065)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[114578]=0;Q(235,a|0,7072)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}}if(Wc(a)){v[114578]=0;Q(235,a|0,7079)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[114578]=0;Q(235,a|0,7085)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;yb(a);S(b|0);L()}function OJ(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(jk(a)>>>0<=mf(a)>>>0){break b}b=zb(a);d=mf(a);e=mf(a);v[114578]=0;b=aa(1644,c+8|0,d|0,e|0,b|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[114578]=0;R(1645,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}fs(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;fs(b)}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function MJ(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(yd(a)>>>0<=Kb(a)>>>0){break b}b=zb(a);d=Kb(a);e=Kb(a);v[114578]=0;b=aa(1646,c+8|0,d|0,e|0,b|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[114578]=0;R(1647,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}es(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;es(b)}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function L4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[114578]=0;b=Q(d|0,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,38053,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function J4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2088,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[114578]=0;b=Q(d|0,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,38002,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function xO(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a=Wb(a);d=Fb(b);v[114578]=0;R(111,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){a:{e=c,f=Ed(b),v[e+8>>2]=f;e=c,f=sf(b),v[e>>2]=f;if(Jb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[114578]=0;R(110,a|0,10);break b}v[114578]=0;R(110,a|0,b<<24>>24)}b=v[114578];v[114578]=0;if((b|0)==1){break a}qg(c+8|0);if(Jb(c+8|0,c)){continue}break}}jb=c+16|0;return}}b=P()|0;O()|0;yb(a);S(b|0);L()}function df(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=_m(a);f=e;i=e;a:{if(b){j=v[b+4>>2];h=v[b>>2];break a}h=_m(a)}v[i+8>>2]=h;v[f+12>>2]=j;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=qu(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}jb=e+16|0;return a}function Ul(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-32|0;jb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=0;f=v[Lb(d+8|0,d+12|0)>>2];h=v[a>>2];if((f|0)!=((j=h,k=Db(d+16|0),l=v[a+8>>2]+g|0,m=f,i=v[v[h>>2]+28>>2],nb[i](j|0,k|0,l|0,m|0)|0)|0)){break a}if(qd(d+16|0,b+g|0,f)){break a}e=v[d+12>>2]-f|0;v[d+12>>2]=e;g=f+g|0;if(e){continue}break}}$b(a,c);e=1}jb=d+32|0;return e}function oY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}g=1;f=jb-16|0;jb=f;v[f+12>>2]=v[a+8>>2];i=Ah(f+8|0,f+12|0);v[114578]=0;j=bF(c,d-c|0,b);l=v[114578];v[114578]=0;b:{if((l|0)!=1){Ie(i);jb=f+16|0;break b}a=P()|0;O()|0;Ie(i);S(a|0);L()}c:{switch(j+2|0){default:g=j;break;case 0:case 1:break a;case 2:break c}}h=h+1|0;k=g+k|0;c=c+g|0;continue}break}return k|0}function Zd(a){var b=0,c=0,d=0;d=ko($e(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function Y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);f=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=f;e=-1;a:{b:{if(!wr(Za(v[a+60>>2],d+16|0,2,d+12|0)|0)){e=v[d+12>>2];if((e|0)>0){break b}}v[a>>2]=v[a>>2]|e&48^16;break a}g=v[d+20>>2];if(g>>>0>=e>>>0){break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}e=c}jb=d+32|0;return e|0}function IT(){var a=0,b=0;a=jb-16|0;jb=a;a:{if(Wa(a+12|0,a+8|0)|0){break a}b=pd((v[a+12>>2]<<2)+4|0);v[115363]=b;if(!b){break a}b=pd(v[a+8>>2]);if(!b){v[115363]=0;break a}v[v[115363]+(v[a+12>>2]<<2)>>2]=0;if(!(Va(v[115363],b|0)|0)){break a}v[115363]=0}jb=a+16|0;b:{if(t[461432]&1){break b}if(!wd(461432)){break b}v[114578]=0;T(2311,461428)|0;a=v[114578];v[114578]=0;if((a|0)!=1){vd(461432);break b}a=P()|0;O()|0;pe(461432);S(a|0);L()}UK()}function eS(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(yf(a)>>>0<=Ac(a)>>>0){break b}b=zb(a);d=Ac(a);e=Ac(a);v[114578]=0;b=aa(39,c+8|0,d|0,e|0,b|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)!=1){v[114578]=0;R(40,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break d}_p(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;_p(b)}_(a|0)|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function a4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Fb(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[kc(b,0)|0]==43){break b}if(w[kc(b,0)|0]==45){break b}}i=d,j=Ed(b),v[i+8>>2]=j;i=d,j=cf(d+8|0,e-c|0),v[i+16>>2]=j;Md(d+24|0,d+16|0);mw(b,v[d+24>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}cd(a,b);jb=d+32|0}function Rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,18);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function HW(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;v[114578]=0;a=wD(2005,a,b,c,d,e,f);b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;ia(2e3,34615,g|0,h|0,i|0,j|0,k|0,l|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function R7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=qi(a,b,c,d);v[a>>2]=80392;c=kk(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[114578]=0;W(1640,a+44|0,2,2)|0;d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;Z(1641,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(c);bf(b);S(a|0);L()}function Ix(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;f=e;a:{if(!tj(b)){c=aM(a,c,v[b+704>>2],d);break a}c=v[b+700>>2]}v[f+12>>2]=c;b=v[b+656>>2];b:{if(!b){break b}f=v[b+40>>2];if(!f){break b}d=(f|0)/2|0;b=v[a+1074420>>2];b=Fma(b,b>>31,c,c>>31);c=d+b|0;d=mb+(d>>31)|0;g=e,h=yc(Gma(c,b>>>0>c>>>0?d+1|0:d,f,f>>31),mb),v[g+12>>2]=h}Cc(e+12|0,2147483647);a=Gma(0,v[e+12>>2],v[a+24620>>2]<<4,0);jb=e+16|0;return a|0}function $w(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;j=d,k=Ed(a),v[j+8>>2]=k;h=$l(d+24|0,d+8|0);f=h;b=$l(d+16|0,d+24|0);e=jb-16|0;jb=e;v[e+12>>2]=b;a:{c=Fb(a);if(f>>>0<=c>>>0){if(b){i=Tb(a);g=c-f|0;v[e+8>>2]=g;b=v[Lb(e+12|0,e+8|0)>>2];v[e+12>>2]=b;g=g-b|0;if(g){f=f+i|0;_l(f,b+f|0,g);b=v[e+12>>2]}f=a;a=c-b|0;Sg(f,a);t[e+7|0]=0;he(a+i|0,e+7|0)}jb=e+16|0;break a}pm();L()}cf(d+8|0,h);jb=d+32|0}function q0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+16>>2];g=v[a+12>>2];if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[de(e+12|0,de(e+8|0,e+4|0))>>2];xh(b,v[a+12>>2],d);v[a+12>>2]=d+v[a+12>>2];f=d+f|0;b=b+d|0;continue}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Jm(d),t[h|0]=i;f=f+1|0;b=b+1|0;continue}break}jb=e+16|0;return f|0}function X5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114578]=0;U(2029,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35294,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=v[b>>2];e=PS(b);c=jb-16|0;jb=c;f=rt(d,e);a:{if(f>>>0<=yd(a)>>>0){v[c+12>>2]=e;if(Kb(a)>>>0<f>>>0){v[c+12>>2]=d;YQ(c+12|0,Kb(a));gf(d,v[c+12>>2],v[a>>2]);Ln(a,v[c+12>>2],e,f-Kb(a)|0);break a}Cu(a,gf(d,e,v[a>>2]));break a}XQ(a);b=a;g=Be(a,f);if(g>>>0>Ym(a)>>>0){fd();L()}zb(b);h=RB(g);v[b>>2]=h;v[b+4>>2]=h;i=zb(b),j=(g<<2)+h|0,v[i>>2]=j;mk(b,0);Ln(a,d,e,f)}jb=c+16|0}function _5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114578]=0;e=+oa(2025,d|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35224,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=bc(b);f=cc(b);c=jb-32|0;jb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Jb(c+24|0,c+16|0)){break a}while(1){e=v[c+24>>2];if(v[v[c+8>>2]>>2]==(w[e|0]|w[e+1|0]<<8)){break a}Ik(c+24|0);if(Jb(c+24|0,c+16|0)){continue}break}}jb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=cc(b),v[g>>2]=h;b:{if(Jb(d+8|0,d)){Ze(a,zb(v[d+8>>2]));break b}Yh(a)}jb=d+16|0}function Fk(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ac(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){kS(a,c);break c}b=zb(a);b=nh(d+8|0,Ki(a,Ac(a)+c|0),Ac(a),b);v[114578]=0;R(41,b|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}v[114578]=0;R(40,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}_p(b)}jb=d+32|0;break a}a=P()|0;O()|0;_p(b);S(a|0);L()}return}if(b>>>0<c>>>0){bS(a,v[a>>2]+b|0)}}function z5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2052,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36059,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function y5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2053,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36103,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function x5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2054,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36151,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=b;d=jb-16|0;jb=d;v[d>>2]=c;v[d+8>>2]=b;b=tt(d,d+8|0);jb=d+16|0;a:{b=Vh(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[114578]=0;U(767,c|0,d|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;_d(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}vc(b);jb=e+32|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function IL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){a=jb-16|0;jb=a;f=a,g=bc(c),v[f+8>>2]=g;f=a,g=cc(c),v[f>>2]=g;if(Jb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[114578]=0;Z(b|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;cx(c);Ab();L()}Ib(b+20|0);Ib(b+8|0);Xb(b);_d(a+8|0);if(Jb(a+8|0,a)){continue}break}}cx(c);jb=a+16|0;Xb(c)}}}function C5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2050,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35973,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function B5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;d=C(pa(2051,c|0,b|0));b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36016,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=C(0)}return C(d)}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function F4(a){a=a|0;var b=0,c=0,d=0;v[114578]=0;Z(2088,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[114578]=0;c=+la(d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37922,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function D4(a){a=a|0;var b=0,c=0,d=0;v[114578]=0;Z(2088,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[114578]=0;c=+la(d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37887,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function B4(a){a=a|0;var b=0,c=0,d=0;v[114578]=0;Z(2088,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[114578]=0;c=+la(d|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37853,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function nt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[fc(a,0)|0]&15)<<8|w[fc(a,1)|0];a:{if((d|0)==4095|!d){break a}e=108;while(1){f=x[(c<<1)+20848>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+20846>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[fc(a,2)|0];g=b,h=w[fc(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[fc(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[fc(a,3)|0],t[g+5|0]=h}function L6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Ai(C(C(Se(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Ai(C(C(b>>>0)*C(1.1892070770263672)));d=Ai(C(C(c>>>0)*C(1.1892070770263672)));g=Ai(C(C(d>>>0)*C(1.1892070770263672)));e=Ai(C(C(b+d>>>0)*C(.11546666920185089)));f=Ai(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;HI(a);FI(a)}function zN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a:{if(qj(a)){d=c+8|0;b=Pe(3848);e=v[c+12>>2];v[114578]=0;e=Q(1199,b|0,e|0)|0;f=v[114578];v[114578]=0;b:{if((f|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=e;W(1200,d|0,b+12|0,b+8|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){jb=b+16|0;break b}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;Xb(b);S(a|0);L()}Hs(a,c+8|0);wf(c+8|0);break a}GN(v[a>>2],b)}yN(a);jb=c+16|0}function l0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+16>>2];g=v[a+12>>2];if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g>>2;v[e+4>>2]=c-f;d=v[de(e+12|0,de(e+8|0,e+4|0))>>2];hi(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+(d<<2);f=d+f|0;b=(d<<2)+b|0;continue}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;f=f+1|0;b=b+4|0;continue}break}jb=e+16|0;return f|0}function c9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=qi(a,b,c,d);v[a>>2]=79272;d=kk(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=Se(c),v[e+4232>>2]=f;v[114578]=0;Z(1639,a+4260|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;W(1640,a+44|0,2,2)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}v[114578]=0;Z(1641,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;Sf(d);bf(b);S(a|0);L()}function Zs(a){a=a|0;var b=0,c=0,d=0,e=0;on(a);b=v[a>>2];c=Zn(a);a:{if(b-1>>>0<=268435455){b=b+208|0;Fma(c,0,b,0);c=mb?0:B(b,c);break a}c=0}b:{if(!c){break b}v[114578]=0;b=T(2826,c|0)|0;d=v[114578];v[114578]=0;c:{d:{if((d|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;Y(20);d=v[114578];v[114578]=0;b=0;if((d|0)==1){break d}}break c}V(0)|0;O()|0;Ab();L()}if(!b){break b}e=Rb(b,0,c)- -64|0}v[a+20>>2]=e;if(!e){return 0}return Aj(a)|0}function au(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-32|0;jb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=0;f=v[Lb(d+8|0,d+12|0)>>2];if((f|0)!=((i=a,j=Db(d+16|0),k=v[a+12>>2]+g|0,l=f,h=v[v[a>>2]+28>>2],nb[h](i|0,j|0,k|0,l|0)|0)|0)){break a}if(qd(d+16|0,b+g|0,f)){break a}e=v[d+12>>2]-f|0;v[d+12>>2]=e;g=f+g|0;if(e){continue}break}}Xc(a,c);e=1}jb=d+32|0;return e}function KA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;e=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(356,a+8|0,d+12|0,d+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(468,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;U(469,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;iC(e);S(a|0);L()}return a|0}function GW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[114578]=0;a=Ja(2006,a|0,b|0,c|0,d|0)|0;b=v[114578];v[114578]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;ia(2e3,34641,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function D6(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;a:{b:{if(!a){break b}a=qc(b+8|0,a);v[114578]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=T(1996,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1989,34236,0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();break b}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}a=0}jb=b+16|0;return a|0}function Aga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=jb-48|0;jb=g;a:{b:{if(c>>>0>d>>>0){break b}if(Ce(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(mh(Ge(b,f))){h=bc(Ge(b,f));i=cc(Ge(b,f));f=OO(g,e);v[114578]=0;X(1031,g+24|0,h|0,i|0,f|0);h=v[114578];v[114578]=0;if((h|0)==1){break a}ke(g+24|0);ke(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}NO(a,e);jb=g+48|0;return}a=P()|0;O()|0;ke(f);S(a|0);L()}function eU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,17);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function WT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{if(!Df(a,7)){break b}c=0;if(!UA(a,12222)){break a}if(!Df(a,1)){break b}c=-1;if(!Xc(a,$p(a))){break a}d=jb-16|0;jb=d;f=e+8|0;$t(d+8|0,f);c=a;g=Hb(d+8|0);h=md(a,ac(d,d+8|0));if((g|0)==(h|0)){Xc(c,Hb(d+8|0))}jb=d+16|0;d=(g|0)==(h|0);if(!d){BA(f)}c=-1;if(!d){break a}c=0;if(!QA(e+8|0)){break a}c=df(a,b,PA(e+8|0),mb);break a}c=-1}jb=e+16|0;return c|0}function i0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;Wi(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Tb(c)+Fb(c)|0,v[d+44>>2]=e;Nm(a,Tb(c),Tb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Fb(c);d=a,e=b+Tb(c)|0,v[d+44>>2]=e;Co(c,Kc(c));Mw(a,Tb(c),Tb(c)+Fb(c)|0);if(!(w[a+48|0]&3)){break a}b:{if((b|0)<=-1){c=b-2147483647|0;while(1){b=c;Mr(a,2147483647);c=1;if((b|0)<0){continue}break}break b}if(!b){break a}}Mr(a,b)}}function g6(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2018,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34986,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function e6(a,b){a=a|0;b=b|0;var c=0,d=0;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;R(2020,c|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35052,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Fd(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;on(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Ub(d,18532);v[114578]=0;Q(372,a+43|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);fO(a);jb=d+16|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function DG(a){var b=C(0),c=0,d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;j=a-24|0;b=z[j>>2];c=a-8|0;d=z[c>>2];e=C(b+d);k=a-16|0;f=z[k>>2];l=z[a>>2];g=C(f+l);z[a>>2]=e+g;z[c>>2]=g-e;c=a-28|0;g=z[c>>2];h=a-12|0;m=z[h>>2];e=C(g+m);p=h;h=a-20|0;i=z[h>>2];a=a-4|0;n=z[a>>2];o=C(i+n);z[p>>2]=o-e;i=C(n-i);b=C(d-b);z[c>>2]=i+b;d=C(m-g);f=C(l-f);z[k>>2]=d+f;z[j>>2]=f-d;z[a>>2]=o+e;z[h>>2]=i-b}function bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;u[e+12>>1]=c;u[e+14>>1]=b;jg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=jb-16|0;jb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Uf(a)>>>0>=d>>>0){g=b,h=oc(a),v[g+8>>2]=h;yz(v[a>>2],v[Lb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){gq(a,d-f|0,c);break a}Pn(a,v[a>>2]+(d<<1)|0);break a}_N(a);dz(a,Ri(a,d));gq(a,d,c)}jb=b+16|0;jb=e+16|0}function F3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114578]=0;c=Q(85,f|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=Qw(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function B3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114578]=0;c=Q(85,f|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=Pw(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function oQ(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function Jo(a,b,c){var d=0,e=0;a=tf(a);d=Fb(b);v[114578]=0;R(113,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){a:{if(Fb(b)){while(1){d=w[kc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[114578]=0;R(112,a|0,d|0);d=v[114578];v[114578]=0;if((d|0)!=1){break b}break a}v[114578]=0;R(112,a|0,65533);d=v[114578];v[114578]=0;if((d|0)==1){break a}}e=e+1|0;if(Fb(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Lc(a);S(b|0);L()}function mC(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);return(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0>27}return 0}function k5(a,b){a=a|0;b=b|0;var c=0;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;b=Q(2068,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36599,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function j5(a,b){a=a|0;b=b|0;var c=0;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;b=Q(2069,c|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36632,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function cS(a,b){var c=0,d=0,e=0,f=0;a:{b:{if(!b){break b}if(!Qb(a,b)){break b}if(b>>>0<=3){c=jb-16|0;jb=c;c:{if(!b){break c}if(!Qb(a,b)){break c}while(1){t[c+11|0]=0;d:{if(b>>>0>d>>>0){Wf(a,c+11|0);e=t[c+11|0];f=e>>>31|0;break d}e=0-f|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24)}jb=c+16|0;a=d;break a}c=Cf(a);$b(a,b-4|0)}a=c}return a}function bX(){var a=0,b=0,c=0,d=0,e=0,f=0;a=jb-48|0;jb=a;a:{b=v[115883];if(b){c=b+48|0;if(CD(c)){d=a;if(v[c>>2]==1126902529&v[c+4>>2]==1129074247){c=v[b+44>>2]}else{c=b+80|0}v[d+44>>2]=c;d=v[b>>2];b=v[d+4>>2];if(nb[v[v[17795]+16>>2]](71180,d,a+44|0)|0){break a}v[a+20>>2]=b;v[a+16>>2]=v[21295];L()}v[a+32>>2]=v[21295];L()}L()}c=v[21295];d=v[a+44>>2];e=a,f=nb[v[v[d>>2]+8>>2]](d)|0,v[e+8>>2]=f;v[a+4>>2]=b;v[a>>2]=c;L()}function Tu(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=jb-16|0;jb=i;if((b^-1)-17>>>0>=c>>>0){j=Tb(a);a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Vk(v[bd(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=ai(k);if(e){xh(c,j,e)}if(g){xh(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){xh((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){pg(a,j,b)}Ef(a,c);Fg(a,k);b=a;a=d+(e+g|0)|0;we(b,a);t[i+7|0]=0;he(a+c|0,i+7|0);jb=i+16|0;return}Hg();L()}function tA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=bc(b);f=cc(b);c=jb-32|0;jb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Jb(c+24|0,c+16|0)){break a}while(1){if((Fj(v[c+24>>2])|0)==v[v[c+8>>2]>>2]){break a}Ik(c+24|0);if(Jb(c+24|0,c+16|0)){continue}break}}jb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=cc(b),v[g>>2]=h;b:{if(Jb(d+8|0,d)){Ze(a,zb(v[d+8>>2]));break b}Yh(a)}jb=d+16|0}function dja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(877,a+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(872,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(873,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;HQ(d);S(a|0);L()}return a|0}function aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(879,a+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(874,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(875,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;GQ(d);S(a|0);L()}return a|0}function Tx(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;v[a+1074368>>2]=b;ZK(a+1074328|0,b);e=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;d=b;if(nb[v[v[b>>2]+132>>2]](b)|0){f=pJ(v[b+16>>2]);b=v[b+16>>2];c=C(C(c*C(y[b+480232>>2]))/C(z[f+8>>2]*z[pJ(b)+20>>2]))}z[d+4196>>2]=c}a=a+160|0;if((e|0)!=(a|0)){continue}break}}function S4(a){a=a|0;var b=0;v[114578]=0;Z(2088,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){nb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37293,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function uK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;if((a|0)!=(b|0)){c=jb-16|0;jb=c;d=v[b>>2];e=v[b+4>>2];f=rt(d,e);a:{if(f>>>0<=yd(a)>>>0){v[c+12>>2]=e;if(Kb(a)>>>0<f>>>0){v[c+12>>2]=d;YQ(c+12|0,Kb(a));gf(d,v[c+12>>2],v[a>>2]);Ln(a,v[c+12>>2],e,f-Kb(a)|0);break a}VR(a,gf(d,e,v[a>>2]));break a}b=a;if(v[a>>2]){Ms(b);Re(zb(b),v[b>>2],yd(b));g=zb(b),h=0,v[g>>2]=h;v[b>>2]=0;v[b+4>>2]=0}rB(a,Be(a,f));Ln(a,d,e,f)}jb=c+16|0}}function tw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!Dr(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}dc(a,32);return 0}ha(50614,50496,1549,50635);L()}function o$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;d=_E(a,e+12|0,d,le());a=mb;f=v[114552];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[114552]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if((a|0)>0?1:(a|0)>=0?d>>>0>=1:0){d=-1;a=2147483647;break a}d=0;a=-2147483648}jb=e+16|0;mb=a;return d|0}function a6(a,b){a=a|0;b=+b;var c=0;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114578]=0;b=+fb(2023,c|0,+b);c=v[114578];v[114578]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[114578]=0;X(1989,35152,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[114578]=0;Y(20);c=v[114578];v[114578]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function IZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;YD(a+16|0,c+12|0,c+8|0);e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(2551,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(2552,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;tE(d);S(a|0);L()}return a|0}function zT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;f=e+8|0;g=b;if(oA(b,e+24|0)){d=e+28|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}ud(f,g,d);a=nA(a,e+24|0,e+8|0);Bb(e+8|0);a:{if(!c){break a}d=(d>>>0)%(c>>>0)|0;if(!d){break a}v[114578]=0;Q(340,b|0,c-d|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;hf(a);S(b|0);L()}jb=e+32|0}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,15);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;jb=c+16|0}return a|0}function uka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;v[e+24>>2]=d;g=Mj(a,c);pf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(xd(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=jb-16|0;jb=f;d=gd(f);v[114578]=0;aa(694,b|0,h|0,d|0,i|0)|0;b=v[114578];v[114578]=0;b:{if((b|0)!=1){yb(d);jb=f+16|0;break b}a=P()|0;O()|0;yb(d);S(a|0);L()}}Zi(a,g,c,e+16|0);jb=e+32|0}function f6(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2019,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35016,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function cH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]*.015625)}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function w5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2055,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36200,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function v5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2056,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36232,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function u5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2057,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36264,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function t5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2058,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36294,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function s5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2059,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36326,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function r5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2060,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,36361,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function c6(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2021,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35084,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function P3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb+-64|0;jb=d;e=v[a>>2];f=v[a+4>>2];g=v[a+12>>2];a=v[a+8>>2];v[d+16>>2]=a;v[d+20>>2]=g;v[d+40>>2]=a;v[d+44>>2]=g;v[d+32>>2]=e;v[d+36>>2]=f;v[d+8>>2]=e;v[d+12>>2]=f;VH(d+48|0,d+8|0,0);a=Go(d+24|0,c);v[114578]=0;b=+xa(2161,d+48|0,+b,a|0);c=v[114578];v[114578]=0;if((c|0)!=1){Yc(a);Bb(d+48|0);jb=d- -64|0;return+b}c=P()|0;O()|0;Yc(a);Bb(d+48|0);S(c|0);L()}function I5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2044,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35764,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function H5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2045,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35797,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function G5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2046,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35830,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function F5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2047,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35863,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function E5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2048,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35898,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function D5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;b=T(2049,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35929,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function O3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ps(a,Kl(b+16|0,Db(c),d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b|0,38633)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}jb=b+32|0;return a|0}L()}function oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=sP(b,c);v[114578]=0;e=Q(989,b+12|0,c+12|0)|0;a=v[114578];v[114578]=0;b:{c:{if((a|0)!=1){v[114578]=0;Q(990,b+24|0,c+24|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}a=v[c+40>>2];v[b+36>>2]=v[c+36>>2];v[b+40>>2]=a;u[b+52>>1]=x[c+52>>1];a=v[c+48>>2];v[b+44>>2]=v[c+44>>2];v[b+48>>2]=a;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;fe(e)}fe(d);S(a|0);L()}}function o0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+28>>2];g=v[a+24>>2];if(d>>>0<=g>>>0){if(((i=a,j=Cg(t[b|0]),h=v[v[a>>2]+52>>2],nb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[de(e+12|0,e+8|0)>>2];xh(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}jb=e+16|0;return f|0}function b6(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;c=+la(2022,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35116,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function aH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((Eo(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}jb=c+16|0;return(w[(v[a+32>>2]+B(b,896)|0)+1075073|0]&4)>>>2|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Kq(a){var b=0,c=0;Cn(a,1,10879);v[114578]=0;b=da(228)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[114578]=0;b=da(229)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[a+16|0]=b;v[114578]=0;b=da(230)|0;c=v[114578];v[114578]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[114578]=0;Z(231,a+20|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;yb(a);S(b|0);L()}function J5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;c=+la(2043,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35723,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function $5(a){a=a|0;var b=0,c=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114578]=0;c=+la(2024,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,35188,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function qba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=jb-896|0;jb=d;b=Rb(a,0,66);v[b+72>>2]=0;v[b+76>>2]=0;v[b+68>>2]=256;u[b+66>>1]=65535;v[b+80>>2]=0;v[b+84>>2]=0;t[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=JL(a)+896|0;if((e|0)!=(a|0)){continue}break}d=Rb(d,0,896);e=JL(d);a=c;c=((a+229376|0)-a|0)/896|0;if((c|0)>=1){while(1){xs(a,e);a=a+896|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}jb=d+896|0;return b|0}function Mv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-160|0;jb=e;Rb(e+16|0,0,144);v[e+92>>2]=-1;v[e+60>>2]=b;v[e+24>>2]=-1;v[e+20>>2]=b;Bh(e+16|0,0,0);oF(e,e+16|0,d,1);d=v[e+8>>2];g=v[e+12>>2];h=v[e>>2];i=v[e+4>>2];if(c){j=c;f=b;b=v[e+20>>2]-v[e+24>>2]|0;k=b;c=b+v[e+136>>2]|0;b=v[e+140>>2]+(b>>31)|0;b=c>>>0<k>>>0?b+1|0:b;v[j>>2]=!(b|c)?f:f+c|0}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=g;jb=e+160|0}function G3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,1);c=Qw(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function C3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,1);c=Pw(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function R3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ps(a,Kl(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b|0,38633)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}jb=b+32|0;return a|0}L()}function nN(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=a;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1229,a+8|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{if(!b){break b}v[114578]=0;R(1223,a|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;R(1224,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;hN(d);S(a|0);L()}return a}function EG(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){dc(a,21);return-1}if(v[a+1396>>2]<=9){dk(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=ll(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!((c|0)>-1|(v[a+1384>>2]?!w[a+1376|0]:0))){dc(a,21)}return c}ha(50824,50496,1778,50846);L()}function hQ(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;if((w[b|0]|w[b+1|0]<<8)>>>0<512|(w[b|0]|w[b+1|0]<<8)>>>0>767){break a}b=a+112|0;if(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function ze(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=wo(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(wG(a,b)&3){case 0:c=wo(A[b>>3],A[b+8>>3]);break a;case 1:c=-xo(A[b>>3],A[b+8>>3],1);break a;case 2:c=-wo(A[b>>3],A[b+8>>3]);break a;default:break b}}c=xo(A[b>>3],A[b+8>>3],1)}a=c;jb=b+16|0;return a}function z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=XH(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=XH(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function x3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=WH(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function w3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114578]=0;c=Q(85,e|0,38690)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(b,c);v[114578]=0;U(2009,b|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=WH(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function fja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Bi(e+24|0,e+16|0,c);v[114578]=0;U(871,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(668,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(518,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Uz(e+24|0,e+16|0,c);v[114578]=0;U(667,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(668,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(518,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function gs(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function fma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;jm(e+24|0,e+16|0,c);v[114578]=0;U(240,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function UL(){var a=0,b=0;a=jb-240|0;jb=a;a:{b:{if(t[85352]&1){break b}if(!wd(85352)){break b}v[114578]=0;da(102)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;R(103,a+120|0,85200);b=v[114578];v[114578]=0;if((b|0)==1){break a}v[114578]=0;Q(104,85232,lc(a,a+120|0,120)|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}vd(85352)}jb=a+240|0;return 85232}a=P()|0;O()|0;pe(85352);S(a|0);L()}function Nka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;jm(e+24|0,e+16|0,c);v[114578]=0;U(224,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function Jy(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-32|0;jb=f;v[f+8>>2]=c;g=f,h=nf(b),v[g+28>>2]=h;Me(f+8|0,b,v[Lb(f+8|0,f+28|0)>>2]);v[114578]=0;b=T(414,f+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[114578]=0;a=ea(442,a|0,b|0,c|0,d|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}Ec(f+8|0);jb=f+32|0;return a|0}a=P()|0;O()|0;Ec(f+8|0);S(a|0);L()}function lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;nO(e+24|0,e+16|0,c);v[114578]=0;U(77,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function jW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Bi(e+24|0,e+16|0,c);v[114578]=0;U(224,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function fU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;ku(e+24|0,e+16|0,c);v[114578]=0;U(446,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function jH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=ba(8)|0;v[114578]=0;c=Q(85,c|0,40593)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(d,c);v[114578]=0;U(2009,d|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=zk(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;To(v[a>>2]);jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function hH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(!(b<=4?!(b<=0):0)){d=ba(8)|0;v[114578]=0;c=Q(85,c|0,40614)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(d,c);v[114578]=0;U(2009,d|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=zk(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;To(v[a>>2]);jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function FP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=Mp(a);f=d,g=bc(b),v[f+8>>2]=g;f=d,g=cc(b),v[f>>2]=g;a:{if(Jb(d+8|0,d)){while(1){a=v[d+8>>2];if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){a=zb(a);v[114578]=0;R(601,e|0,a|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}}Ik(d+8|0);if(Jb(d+8|0,d)){continue}break}}jb=d+16|0;return}a=P()|0;O()|0;hd(e);S(a|0);L()}function fba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=b;a:{if(yf(a)>>>0>=b>>>0){f=e,g=Ac(a),v[f+8>>2]=g;Th(v[a>>2],v[Lb(e+12|0,e+8|0)>>2],c);b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){Pp(a,b-d|0,c);break a}Fu(a,b+v[a>>2]|0);break a}d=a;if(v[d>>2]){Ac(d);eC(d);tp(d);pg(zb(d),v[d>>2],yf(d));f=zb(d),g=0,v[f>>2]=g;v[d>>2]=0;v[d+4>>2]=0}Ip(a,Ki(a,b));Pp(a,b,c)}jb=e+16|0}function Ax(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=F(c,.999);c=d*32768;h=d*3.141592653589793;i=ns(b);while(1){j=a;k=c;e=((f<<12^-1)&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e-16384|0);d=g*.000244140625;g=ns(K(g*-152587890625e-16*d+1)*b);d=h*d;d=g*ii(d)/(d*i)}else{d=1}d=H(k*d+.5);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}u[j>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function ii(a){var b=0,c=0;b=jb-16|0;jb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=xo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(wG(a,b)&3){case 0:a=xo(A[b>>3],A[b+8>>3],1);break a;case 1:a=wo(A[b>>3],A[b+8>>3]);break a;case 2:a=-xo(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-wo(A[b>>3],A[b+8>>3])}jb=b+16|0;return a}function Oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;zb(a);v[c+12>>2]=214748364;v[114578]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){fd();L()}zb(a);c=b;if(c>>>0>214748364){Fc(15551);L()}c=sc(B(c,20),4);v[a>>2]=c;v[a+4>>2]=c;f=zb(a),g=c+B(b,20)|0,v[f>>2]=g;xp(a);xp(a)}function TT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;MA(e+24|0,c);v[114578]=0;U(224,e+36|0,e+8|0,d|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[114578]=0;R(78,e|0,e+24|0);c=v[114578];v[114578]=0;if((c|0)!=1){v[114578]=0;U(72,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}}c=P()|0;O()|0;ef(e+24|0);break b}c=P()|0;O()|0;yb(e+24|0)}S(c|0);L()}ef(e+24|0);jb=e+48|0}function o6(a){a=a|0;var b=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Xb(Sr(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Xb(b);v[a+20>>2]=0}Xb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34780,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=jb-16|0;jb=e;d=-1;a:{if(!Jj(a,e+8|0)){break a}b:{c:{c=e+8|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(Fj(14647)|0)){break c}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>259){break c}c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>255;break b}c=0}d=0;if(!c){break a}d=df(a,b,36,0)}c=d;jb=e+16|0;return c|0}function zz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;mR(a,b);e=b+8|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);Pc(a,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+504|0);lR(a,d);a:{b=b+32|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!Pc(a,b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))){break a}Bn(a,c);return}Rb(c,0,80)}function UF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;c=Ub(d,c);v[114578]=0;U(2358,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){v[114578]=0;Q(2359,a|0,d+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}yb(d+16|0);yb(c);v[a>>2]=58380;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;jb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+16|0)}yb(c);S(a|0);L()}function YG(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40657)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}a=v[a+32>>2]+B(b,896)|0;v[a+1075e3>>2]=0;v[a+1075060>>2]=0;jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function J7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=qi(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=80596;v[114578]=0;W(1640,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1641,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);f=a,g=Db(w[b+2|0])|Db(w[b+3|0])<<8,u[f>>1]=g;Db(w[b+4|0]);Db(w[b+5|0]);f=a,g=Db(w[b+6|0])|Db(w[b+7|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;Db(w[b+7|0]);Db(w[b+6|0]);f=a,g=Db(w[b+5|0])|Db(w[b+4|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function mq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;e=v[a+4>>2];d=v[a>>2];t[c+12|0]=0;Zr(d,d+e|0,c+12|0);d=Tb(b);e=Tb(b);g=c,h=Fb(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;gf(d,e+v[Lb(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];g=c,h=Fb(b),v[g+12>>2]=h;v[c+8>>2]=v[a+4>>2]-1;b=v[Lb(c+12|0,c+8|0)>>2];e=v[a+4>>2];f=v[a>>2];t[c+7|0]=0;Zr(b+d|0,e+f|0,c+7|0);jb=c+16|0;return a|0}function i6(a,b){a=a|0;b=b|0;var c=0;v[114578]=0;Z(2015,a|0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34929,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function bx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(Se(v[a+16>>2])>>>0);c=C(C(nb[v[v[a>>2]+200>>2]](a))*b);d=a,e=C(C(c*C(2.0480000972747803))*C(nb[v[v[a>>2]+192>>2]](a))),z[d+4248>>2]=e;d=a,f=Lh(C(C(c*C(4.0960001945495605))+C(8192))),v[d+4256>>2]=f;c=C(nb[v[v[a>>2]+204>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(nb[v[v[a>>2]+188>>2]](a)|0)){b=zG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function Y8(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[114578]=0;R(508,b+4|0,8);b=v[114578];v[114578]=0;if((b|0)!=1){c=v[v[a+20>>2]+4>>2];b=v[a+4264>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(71204)|0;if((O()|0)==(ga(71204)|0)){_(b|0)|0;Gs(v[a+20>>2]+4|0);$();return}S(b|0);L()}function K9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,52);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[114578]=0;U(1582,f|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d>>2]+52|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}vc(d);jb=e+16|0;return}a=P()|0;O()|0;vc(d);S(a|0);L()}function Jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+(b<<5);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[114578]=0;U(1177,f|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d>>2]+32|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}vc(d);jb=e+16|0;return}a=P()|0;O()|0;vc(d);S(a|0);L()}function HF(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=jb-16|0;jb=c;b=ba(16)|0;a=jb-16|0;jb=a;a:{if(t[461444]&1){break a}if(!wd(461444)){break a}vd(461444)}Uc(a+8|0,1,85172);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;jb=a+16|0;v[114578]=0;W(2399,b|0,59056,c|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ja(b|0,59128,2400);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}}function YX(){var a=0;a:{if(t[462088]&1){break a}if(!wd(462088)){break a}a=461920;while(1){a=Wb(a)+12|0;if((a|0)!=462088){continue}break}vd(462088)}Mc(461920,69216);Mc(461932,69223);Mc(461944,69230);Mc(461956,69238);Mc(461968,69248);Mc(461980,69257);Mc(461992,69264);Mc(462004,69273);Mc(462016,69277);Mc(462028,69281);Mc(462040,69285);Mc(462052,69289);Mc(462064,69293);Mc(462076,69297)}function Vla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;gB(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function VX(){var a=0;a:{if(t[462264]&1){break a}if(!wd(462264)){break a}a=462096;while(1){a=tf(a)+12|0;if((a|0)!=462264){continue}break}vd(462264)}_c(462096,69304);_c(462108,69332);_c(462120,69360);_c(462132,69392);_c(462144,69432);_c(462156,69468);_c(462168,69496);_c(462180,69532);_c(462192,69548);_c(462204,69564);_c(462216,69580);_c(462228,69596);_c(462240,69612);_c(462252,69628)}function g$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0;e=jb-16|0;jb=e;a:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;le();d=jb-16|0;jb=d;Mv(d,a,e+12|0,0);f=mF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[114552];b:{if(a){if(v[e+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}v[c>>2]=4;break a}v[114552]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;f=C(0)}jb=e+16|0;return C(f)}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e;v[d>>2]=v[a+8>>2];f=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=f+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){f=v[a+16>>2];b=v[d>>2];v[114578]=0;U(707,f|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}vc(d);jb=e+16|0;return}a=P()|0;O()|0;vc(d);S(a|0);L()}function Tia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=C(0),h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;a:{if(!d){break a}a=(e<<1)+a|0;e=c<<1;c=1;while(1){z[f+12>>2]=z[b>>2];ae(f+12|0,C(-1));g=C(z[f+12>>2]*C(32768));z[f+12>>2]=g;i=a;g=je(g);b:{if(C(D(g))<C(2147483648)){h=~~g;break b}h=-2147483648}j=i,k=Vc(h),u[j>>1]=k;if((c|0)==(d|0)){break a}b=b+4|0;a=a+e|0;c=c+1|0;continue}}jb=f+16|0}function Ky(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+8>>2]=c;f=e,g=nf(b),v[f+28>>2]=g;Me(e+8|0,b,v[Lb(e+8|0,e+28|0)>>2]);v[114578]=0;b=T(414,e+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[114578]=0;aa(1062,a|0,b|0,c|0,d|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}Ec(e+8|0);jb=e+32|0;return 1}a=P()|0;O()|0;Ec(e+8|0);S(a|0);L()}function j0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;while(1){a:{if((c|0)<=(e|0)){break a}f=v[a+24>>2];g=v[a+28>>2];if(f>>>0>=g>>>0){if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{v[d+12>>2]=g-f>>2;v[d+8>>2]=c-e;f=v[de(d+12|0,d+8|0)>>2];hi(v[a+24>>2],b,f);g=f<<2;v[a+24>>2]=g+v[a+24>>2];e=e+f|0;b=b+g|0}continue}break}jb=d+16|0;return e|0}function nda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[d+12>>2]=0;W(1233,a+8|0,d+12|0,d+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=hn(a+12|0);t[a+30|0]=c;u[a+28>>1]=0;v[a+24>>2]=b;v[114578]=0;R(1232,a|0,1);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;oe(d);gN(a);S(b|0);L()}function eN(a,b,c){var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[a+4>>2]=0;a:{if(b){b:{if(it(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}zb(a);e=bz(d+16|0);v[114578]=0;f=Q(932,a|0,b|0)|0;g=v[114578];v[114578]=0;if((g|0)==1){break a}v[114578]=0;R(933,e|0,f|0);f=v[114578];v[114578]=0;if((f|0)==1){break a}v[e+4>>2]=b;az(a,e);ke(e)}uj(d,a);kq(d,b,w[c|0])}jb=d+32|0;return}a=P()|0;O()|0;ke(e);S(a|0);L()}function haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;e=-1;c=jb-16|0;jb=c;f=d+8|0;EK(c+8|0,f);g=Hb(c+8|0);h=md(a,ac(c,c+8|0));if((g|0)==(h|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(g|0)==(h|0);if(!a){FK(f)}a:{if(!a){break a}e=0;if(!JK(d+8|0)){break a}if(b){a=d+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}e=1}jb=d+32|0;return e|0}function UE(a,b,c){var d=0,e=0,f=0,g=0,h=0;h=jb-16|0;jb=h;e=jb-16|0;jb=e;d=a;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){of(d,b);f=d;break b}g=sm(b)+1|0;f=rm(g);Ef(d,f);Fg(d,g);we(d,b)}g=f;c:{d:{d=b;if(b){v[114578]=0;MD(g,c,d);c=v[114578];v[114578]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Ab();L()}v[e+12>>2]=0;Te((b<<2)+f|0,e+12|0);jb=e+16|0;break a}Hg();L()}jb=h+16|0;return a}function yS(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}b=a+576|0;a=a- -64|0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:d=1;break;case 2:break b;default:break a}}c=d;a=a+16|0;if((b|0)!=(a|0)){continue}break}}return c&1}function t1(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+40816>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+40816>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+40816>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+40816>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+40816>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function Nha(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!cA(a,b+16|0)){break a}c=0;if(!GP(b+16|0)){break a}c=-1;if(!Jj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+8|0;c=(c|0)==((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))&2139062143)}a=c;jb=b+32|0;return a|0}function rx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;a:{while(1){h=g&255;if(tx(b,c,h>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;yK(a,f+15|0,f+14|0);break a}lh(b,d);lh(c,e);g=g+1|0;if(h>>>0<3){continue}break}if(Xm(w[b|0])>>>0>Xm(w[d|0])>>>0){lh(b,d);lh(c,e)}t[f+11|0]=w[b|0];yK(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}jb=f+16|0}function h6(a){a=a|0;var b=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Xb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34959,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function RS(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<14){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;return!(w[a|0]|w[a+1|0]<<8)}return 0}function FE(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=jb-16|0;jb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=_n(d,g+i|0,f+15|0);if(!d){break a}if(!Um(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}jb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function jma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+24>>2]=b;a:{b=Wl(d+8|0,a+8|0,lA(b,c));if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];f=v[d+24>>2];v[114578]=0;U(522,c|0,e|0,f|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+2;te(d+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}vc(b);jb=d+32|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function g9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=Pe(64);v[114578]=0;f=T(1428,d|0)|0;g=v[114578];v[114578]=0;a:{if((g|0)!=1){d=Qx(e+8|0,f);f=v[d>>2];v[114578]=0;b=W(1635,f|0,b|0,c|0)|0;c=v[114578];v[114578]=0;b:{c:{if((c|0)!=1){if((b|0)==1){break c}Px(a);break b}a=P()|0;O()|0;ag(d);break a}Gp(a,d)}ag(d);jb=e+16|0;return}a=P()|0;O()|0;Xb(d)}S(a|0);L()}function fH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(!(b<=1?!(b<0):0)){d=ba(8)|0;v[114578]=0;c=Q(85,c|0,40635)|0;a=v[114578];v[114578]=0;if((a|0)==1){break c}mc(d,c);v[114578]=0;U(2009,d|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=zk(b*256);v[v[a+32>>2]+1074444>>2]=d;jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function L8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+(b<<11);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(1651,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+2048|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function j6(a){a=a|0;var b=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return Zd(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34891,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();return 0}return Zd(34181)|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function di(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=b;a:{if(fj(a,f+8|0)){v[c>>2]=v[c>>2]|6;b=0;break a}b=bk(a);if(!Kg(d,2048,b)){v[c>>2]=v[c>>2]|4;b=0;break a}b=vm(d,b);while(1){b:{il(a);b=b-48|0;if(!to(a,f+8|0)|(e|0)<2){break b}g=bk(a);if(!Kg(d,2048,g)){break a}e=e-1|0;b=vm(d,g)+B(b,10)|0;continue}break}if(!fj(a,f+8|0)){break a}v[c>>2]=v[c>>2]|2}jb=f+16|0;return b}function d$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if((a|0)!=(b|0)){g=v[114552];v[114552]=0;le();d=jb-16|0;jb=d;Mv(d,a,e+12|0,1);f=iw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[114552];b:{if(a){if(v[e+12>>2]!=(b|0)){break b}if((a|0)!=68){break a}v[c>>2]=4;break a}v[114552]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;f=0}jb=e+16|0;return+f}function ci(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=b;a:{if(_j(a,f+8|0)){v[c>>2]=v[c>>2]|6;b=0;break a}b=gl(a);if(!$j(d,2048,b)){v[c>>2]=v[c>>2]|4;b=0;break a}b=um(d,b);while(1){b:{Bm(a);b=b-48|0;if(!lr(a,f+8|0)|(e|0)<2){break b}g=gl(a);if(!$j(d,2048,g)){break a}e=e-1|0;b=um(d,g)+B(b,10)|0;continue}break}if(!_j(a,f+8|0)){break a}v[c>>2]=v[c>>2]|2}jb=f+16|0;return b}function hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,48);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(742,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+48|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function Kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+B(b,33);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(765,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+33|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;AP(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))!=1414807888){d=c+12|0}else{AP(a,c+11|0);t[b|0]=1;d=c+11|0}b=jb-16|0;jb=b;a:{b:{if(d){a=Ub(b,d);v[114578]=0;e=T(976,a|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}yb(a)}jb=b+16|0;break a}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=c+16|0;return e|0}function kp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=jb-16|0;jb=b;e=bc(a);f=cc(a);c=jb-16|0;jb=c;v[c>>2]=f;v[c+8>>2]=e;if(Jb(c+8|0,c)){while(1){d=A[v[c+8>>2]>>3]+d;uy(c+8|0);if(Jb(c+8|0,c)){continue}break}}jb=c+16|0;g=b,h=bc(a),v[g+8>>2]=h;g=b,h=cc(a),v[g>>2]=h;if(Jb(b+8|0,b)){d=-d;while(1){a=v[b+8>>2];d=A[a>>3]+d;A[a>>3]=d;uy(b+8|0);if(Jb(b+8|0,b)){continue}break}}jb=b+16|0}function F8(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function gia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d;v[c>>2]=v[a+8>>2];e=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=e+(b<<3);a:{if(v[c>>2]!=v[c+4>>2]){while(1){e=v[a+16>>2];b=v[c>>2];v[114578]=0;R(926,e|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c>>2]+8|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}vc(c);jb=d+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function cy(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,896)+a|0;v[c+1075680>>2]=0;d=c+1074992|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075072|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,896)+a|0;v[c+1075672>>2]=0;c=v[c+1075072>>2]}d=B(b,896)+a|0;v[d+1075072>>2]=c|2097152;qk(a,b,255,0);if(!(w[d+1075073|0]&2)){break a}a=a+1304392|0;if(!rd(a)){break a}Mh(v[a>>2],b,0)}}function xP(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|(w[a+65|0]!=1?w[a+65|0]!=16:0))){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=jb-16|0;jb=c;d=lB(b,a);jb=c+16|0;a=d?a:b;return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);f=a,g=Db(w[b+1|0])|Db(w[b+2|0])<<8,u[f>>1]=g;Db(w[b+3|0]);f=a,g=Db(w[b+4|0])|Db(w[b+5|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,6)|0}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;Db(w[b+5|0]);f=a,g=Db(w[b+4|0])|Db(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,6)|0}function ek(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=jb-32|0;jb=c;f=qc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Hc(c+8|0,c);jb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}jb=e+16|0;return a}function _J(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=jb-16|0;jb=c;e=0;a:{if(!Gf(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Fi(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}pl(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;Lo(a,c+8|0);f=z[c+8>>2];g=Pb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=Gf(v[v[a>>2]-12>>2]+a|0)}d=e;jb=c+16|0;return d}function ZS(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=89478485;v[114578]=0;v[b+8>>2]=2147483647;e=Q(33,b+12|0,b+8|0)|0;f=v[114578];v[114578]=0;a:{if((f|0)!=1){jb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=Ml(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function ZJ(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=jb-16|0;jb=c;e=0;a:{if(!Gf(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;xf(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}pl(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;Lo(a,c+8|0);f=z[c+8>>2];g=Pb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=Gf(v[v[a>>2]-12>>2]+a|0)}a=e;jb=c+16|0;return a}function ml(a){if((a|0)>=0){if((a|0)<=16383){if((a|0)<=15){return t[a+50656|0]}if((a|0)<=511){return t[(a>>>5|0)+50656|0]+5|0}return t[(a>>>10|0)+50656|0]+10|0}if((a|0)<=16777215){if((a|0)<=524287){return t[(a>>>15|0)+50656|0]+15|0}return t[(a>>>20|0)+50656|0]+20|0}if((a|0)<=536870911){return t[(a>>>25|0)+50656|0]+25|0}a=t[(a>>>30|0)+50656|0]+30|0}else{a=0}return a}function Nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;e=jb-16|0;jb=e;c=e;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+B(b,20);a:{if(v[c+4>>2]!=v[c+8>>2]){while(1){b=zb(a);d=v[c+4>>2];v[114578]=0;R(880,b|0,d|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[c+4>>2]+20|0;v[c+4>>2]=b;if((b|0)!=v[c+8>>2]){continue}break}}Mb(c);jb=e+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;v[c+12>>2]=477218588;v[114578]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){fd();L()}c=b;if(c>>>0>=477218589){Fc(17388);L()}c=sc(B(c,9),1);v[a>>2]=c;v[a+4>>2]=c;f=zb(a),g=c+B(b,9)|0,v[f>>2]=g}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);Db(w[b+2|0]);Db(w[b+3|0]);Db(w[b+4|0]);Db(w[b+5|0]);f=a,g=Db(w[b+6|0])|Db(w[b+7|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+7|0]);Db(w[b+6|0]);Db(w[b+5|0]);Db(w[b+4|0]);Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function kH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-32>>>0>=481){a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40579)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function br(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function HE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=v[hc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Qq((f|0)==2489?0:v[a>>2],d);if(g){if((f|0)!=2489){Nd(a)}v[e+4>>2]=2427;f=Rd(e+8|0,g,e+4|0);DE(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);jb=e+16|0;return}yv();L()}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-32|0;jb=b;a:{a=ps(a,Kl(b+24|0,Db(c),d),0);if(a+1>>>0>=3){a=ba(8)|0;v[114578]=0;b=Q(85,b+8|0,38633)|0;c=v[114578];v[114578]=0;b:{if((c|0)!=1){mc(a,b);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}d=P()|0;O()|0;ca(a|0)}S(d|0);L()}jb=b+32|0;return a|0}L()}function dI(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=$e(e);if((f|0)==(Fb(c)|0)){v[114578]=0;c=ea(346,c|0,0,-1,e|0,f|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Ab();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}jb=d+16|0;return a}function nx(a,b,c){var d=0,e=0,f=0;f=jb-16|0;jb=f;d=f;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{if(v[d+4>>2]!=v[d+8>>2]){while(1){b=zb(a);e=v[d+4>>2];v[114578]=0;U(1582,b|0,e|0,c|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}b=v[d+4>>2]+52|0;v[d+4>>2]=b;if((b|0)!=v[d+8>>2]){continue}break}}Mb(d);jb=f+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function bp(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+830|0]=w[b+830|0]&15|c<<4;break a}c=w[b+830|0]>>>4|0;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function W6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=qi(a,b,c,d);v[a+4272>>2]=1065353216;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[a>>2]=81644;v[114578]=0;W(1640,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1641,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function $Z(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=v[hc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Qq((f|0)==2489?0:v[a>>2],d);if(g){if((f|0)!=2489){Nd(a)}v[e+4>>2]=2427;f=Rd(e+8|0,g,e+4|0);DE(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];jb=e+16|0;return}yv();L()}function lH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-1>>>0>=65535){a=ba(8)|0;v[114578]=0;c=Q(85,c|0,40560)|0;b=v[114578];v[114578]=0;if((b|0)==1){break c}mc(a,c);v[114578]=0;U(2009,a|0,83440,2017);a=v[114578];v[114578]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074416>>2]=b;jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function l6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34831,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function AG(a,b){a:{if((b|0)>=128){a=C(a*C(1.7014118346046923e38));if((b|0)<255){b=b-127|0;break a}a=C(a*C(1.7014118346046923e38));b=((b|0)<381?b:381)-254|0;break a}if((b|0)>-127){break a}a=C(a*C(1.1754943508222875e-38));if((b|0)>-253){b=b+126|0;break a}a=C(a*C(1.1754943508222875e-38));b=((b|0)>-378?b:-378)+252|0}return C(a*(l(2,(b<<23)+1065353216|0),q()))}function xm(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;Bc(d+8|0,b);v[114578]=0;b=T(2457,d+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;e=T(2467,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}v[c>>2]=e;v[114578]=0;R(2468,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(d+8|0);jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);S(a|0);L()}function hN(a){var b=0,c=0,d=0,e=0;a:{if(v[a>>2]){e=v[a>>2];b=a;c=v[a+4>>2];b:{while(1){if((c|0)==(e|0)){break b}d=zb(b);v[114578]=0;c=c-16|0;R(1231,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}break a}v[b+4>>2]=e;zb(a);b=v[a>>2];a=Zh(a);v[114578]=0;U(25,b|0,a<<4,8);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function zm(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;Bc(d+8|0,b);v[114578]=0;b=T(2423,d+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)==1){break a}v[114578]=0;e=T(2438,b|0)|0;f=v[114578];v[114578]=0;if((f|0)==1){break a}t[c|0]=e;v[114578]=0;R(2439,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ob(d+8|0);jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);S(a|0);L()}function ty(a){var b=0,c=0,d=0,e=0;a:{if(v[a>>2]){e=v[a>>2];b=a;c=v[a+4>>2];b:{while(1){if((c|0)==(e|0)){break b}d=zb(b);v[114578]=0;c=c-8|0;R(1228,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}break a}v[b+4>>2]=e;zb(a);b=v[a>>2];a=Ui(a);v[114578]=0;U(25,b|0,a<<3,8);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function jL(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,896)+a|0;d=w[c+1075797|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075799|0];if((c|0)>=0){cM(a,b,(d|0)==32,((w[(B(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0,c&255);return}cM(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function Ks(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=d+8|0;b=jb-16|0;jb=b;v[114578]=0;c=a;T(1252,c+4|0)|0;f=v[114578];v[114578]=0;a:{b:{c:{if((f|0)!=1){v[114578]=0;v[b+12>>2]=0;W(1253,c+8|0,b+12|0,e|0)|0;e=v[114578];v[114578]=0;if((e|0)!=1){break c}break b}break b}g=c,h=hc(c),v[g>>2]=h;jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=d+16|0;return a}function qr(a,b,c,d){var e=0,f=0;e=jb-160|0;jb=e;lc(e+8|0,58064,144);a:{b:{if(b-1>>>0>=2147483647){if(b){break b}b=1;a=e+159|0}v[e+52>>2]=a;v[e+28>>2]=a;f=-2-a|0;b=b>>>0>f>>>0?f:b;v[e+56>>2]=b;a=a+b|0;v[e+36>>2]=a;v[e+24>>2]=a;a=rG(e+8|0,c,d,2303,2304);if(!b){break a}b=v[e+28>>2];t[b-((b|0)==v[e+24>>2])|0]=0;break a}v[114552]=61;a=-1}jb=e+160|0;return a}function vla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=Mp(a);e=d,f=bc(b),v[e+8>>2]=f;e=d,f=cc(b),v[e>>2]=f;a:{if(Jb(d+8|0,d)){while(1){b=v[d+8>>2];if((Fj(b)|0)==(c|0)){b=zb(b);v[114578]=0;R(601,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}}Ik(d+8|0);if(Jb(d+8|0,d)){continue}break}}jb=d+16|0;return}b=P()|0;O()|0;hd(a);S(b|0);L()}function P6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=qi(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=81848;v[114578]=0;W(1640,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1641,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function V0(a){a=a|0;a:{v[114578]=0;T(2317,460568)|0;a=v[114578];v[114578]=0;b:{if((a|0)==1){break b}v[114578]=0;T(2318,460652)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}v[114578]=0;T(2317,460904)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}v[114578]=0;T(2318,460988)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Ab();L()}}function SA(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=Fma(w[a+3|0],0,18,0);d=d+c|0;b=mb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;if(b>>>0<3){a=a+1|0}mb=a;return b}function sx(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=39;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=39;t[b|0]=w[d|0]}t[c|0]=0}}function W3(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;a=gh(a);v[114578]=0;R(2156,b+16|0,0);c=v[114578];v[114578]=0;a:{b:{if((c|0)!=1){c=bc(b+16|0);d=cc(b+16|0);e=v[Qc(b+8|0,a)>>2];v[114578]=0;W(2157,c|0,d|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}Bx(b+16|0);jb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;Bx(b+16|0)}ld(a);S(c|0);L()}function VP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=nb[a|0](b)|0;d=mb;f=d;if((d|0)<0){break b}if((nb[c|0](b,0,0,0)|0)<=-1){break a}if((nb[c|0](b,0,0,2)|0)<=-1){break a}d=nb[a|0](b)|0;a=mb;nb[c|0](b,e,f,0)|0;if((a|0)<0){break b}g=bR(d,a)}return g}nb[c|0](b,e,f,0)|0;return 0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Db(w[b+1|0])+g|0)+(Db(w[b|0])<<8)|0;u[a>>1]=g;d=(Db(w[b+3|0])+d|0)+(Db(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<2}function hU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;c=-1;a:{if(!Df(a,7)){break a}c=0;if(!UA(a,12168)){break a}d=jb-16|0;jb=d;c=e;GA(d+8|0,e);f=a;g=Hb(d+8|0);h=md(a,ac(d,d+8|0));if((g|0)==(h|0)){Xc(f,Hb(d+8|0))}jb=d+16|0;f=(g|0)==(h|0);if(!f){HA(c)}c=-1;if(!f){break a}c=0;if(!TA(e)){break a}c=df(a,b,SA(e),mb)}jb=e+16|0;return c|0}function cea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=b;e=d,f=iz(a,b,c),v[e+24>>2]=f;a:{if(!Jb(d+24|0,d+16|0)){break a}v[d+8>>2]=v[d+24>>2];if(!Jb(te(d+8|0),d+16|0)){break a}while(1){if(x[v[d+8>>2]>>1]!=x[c>>1]){u[v[d+24>>2]>>1]=x[v[d+8>>2]>>1];te(d+24|0)}if(Jb(te(d+8|0),d+16|0)){continue}break}}jb=d+32|0;return v[d+24>>2]}function aP(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if(w[a+30|0]!=2|((b|0)!=2?(b|0)!=26:0)){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if((b|0)!=88?b>>>0>=65:0){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-32|0;if((c&255)>>>0<=94){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0<95}return c}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Db(w[b|0])+g|0)+(Db(w[b+1|0])<<8)|0;u[a>>1]=g;d=(Db(w[b+2|0])+d|0)+(Db(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<2}function yia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=d;oz(a,c,d);d=0;e=v[a+16>>2];if(e>>>0>c>>>0){v[f+8>>2]=e-c;d=v[Lb(f+8|0,f+12|0)>>2];e=jb-32|0;jb=e;a=a+4|0;h=e,i=bc(a),v[h+24>>2]=i;g=cf(e+24|0,c);h=e,i=bc(a),v[h+8>>2]=i;h=e,i=cf(e+8|0,c),v[h+16>>2]=i;wj(g,cf(e+16|0,d),b);jb=e+32|0}jb=f+16|0;return d|0}function m6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114578]=0;Z(2015,a|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1997;return}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34803,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Qd(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;gm(b);d=jb-16|0;jb=d;v[d+12>>2]=b;b=e+8|0;Te(b,d+12|0);jb=d+16|0;a:{a=a+16|0;if(Kb(a)>>>0<=c>>>0){v[114578]=0;R(2556,a|0,c+1|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}}if(v[Pb(a,c)>>2]){fm(v[Pb(a,c)>>2])}d=Nd(b);f=Pb(a,c),g=d,v[f>>2]=g;hE(b);jb=e+16|0;return}a=P()|0;O()|0;hE(b);S(a|0);L()}function lX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Fb(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Lb(f+12|0,f)>>2],v[g+4>>2]=h;b=Um(Tb(a)+b|0,d,v[Lb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}jb=f+16|0;return b|0}pm();L()}function e4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=Ed(b),v[g+8>>2]=h;b:{if(!Fb(b)){break b}if(w[kc(b,0)|0]==43){xr(d+8|0);c=c+1|0;break b}if(w[kc(b,0)|0]!=45){break b}xr(d+8|0);c=c+1|0}if(Fb(b)>>>0>=c>>>0){break a}e=Md(d,d+8|0);f=Fb(b);mw(b,v[e>>2],c-f|0,48)}cd(a,b);jb=d+16|0}function cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{c=Wl(e,a+8|0,py(b,c));if(v[c>>2]!=v[c+4>>2]){while(1){d=v[a+16>>2];f=v[c>>2];v[114578]=0;U(1249,d|0,f|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[c>>2]+2|0;v[c>>2]=d;b=b+2|0;if((d|0)!=v[c+4>>2]){continue}break}}vc(c);jb=e+16|0;return}a=P()|0;O()|0;vc(c);S(a|0);L()}function _O(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>3999){break a}b=a+140|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;return(w[a|0]|w[a+1|0]<<8)==12800}return 0}function Tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Mj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(xd(a,5)){break a}}f=v[a+28>>2];xB(b,v[e+24>>2]);if(v[e+24>>2]){while(1){IN(f,rc(b,g));g=g+1|0;if(g>>>0<y[e+24>>2]){continue}break}}}a=Zi(a,d,c,e+16|0);jb=e+32|0;return a|0}function Cma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=mM(b,c);if((e|0)!=-1){f=d,g=Ed(b),v[f+16>>2]=g;f=d,g=cf(d+16|0,e),v[f+24>>2]=g;f=d,g=cf(d+24|0,1),v[f+32>>2]=g;c=Md(d+40|0,d+32|0);f=d,g=sf(b),v[f>>2]=g;e=Md(d+8|0,d);$w(b,v[c>>2],v[e>>2]);break b}if(!Fb(b)){break b}if(uI(b,c)){break b}gd(a);break a}cd(a,b)}jb=d+48|0}function c7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=mM(b,c);if((e|0)!=-1){f=d,g=Ed(b),v[f+16>>2]=g;f=d,g=cf(d+16|0,e),v[f+24>>2]=g;f=d,g=cf(d+24|0,1),v[f+32>>2]=g;c=Md(d+40|0,d+32|0);f=d,g=sf(b),v[f>>2]=g;e=Md(d+8|0,d);$w(b,v[c>>2],v[e>>2]);break b}if(!Fb(b)){break b}if(uI(b,c)){break b}Wb(a);break a}cd(a,b)}jb=d+48|0}function ap(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+830|0];if(c){t[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function X8(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((Ac(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}lJ(a,b)}gs(a)}function zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b+1|0])|Db(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(Db(w[b+3|0])|Db(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function On(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=b;a:{b:{c:{d:{if(Fe(a)){c=hk(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=10;c=10;b=w[a+11|0];if((b|0)!=10){break c}}Rl(a,c,1,c,c,0,0);b=e;if(Fe(a)){break b}}c=a;of(a,b+1|0);break a}c=v[a>>2];we(a,e+1|0);b=e}a=b+c|0;he(a,d+15|0);t[d+14|0]=0;he(a+1|0,d+14|0);jb=d+16|0}function Cca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b|0])|Db(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(Db(w[b+2|0])|Db(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function iX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(Fe(a)){c=hk(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=1;c=1;b=w[a+11|0];if((b|0)!=1){break c}}GD(a,c,1,c,c);b=e;if(Fe(a)){break b}}c=a;of(a,b+1|0);break a}c=v[a>>2];we(a,e+1|0);b=e}a=(b<<2)+c|0;Te(a,d+12|0);v[d+8>>2]=0;Te(a+4|0,d+8|0);jb=d+16|0}function WP(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=Fma(w[a+30|0],0,37,0);c=mb;d=b;b=a+24|0;b=Fma(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=mb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;e=d;a=w[a+26|0];c=a>>>26|0;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;if(b>>>0<192){a=a+1|0}mb=a;return b}function Ee(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!Fb(a)|(c-b|0)<5){break a}qo(b,c);e=c-4|0;c=Tb(a);f=c+Fb(a)|0;while(1){b:{a=t[c|0];if(b>>>0>=e>>>0){break b}if((a|0)<1|(a|0)>=127|v[b>>2]==t[c|0]){c=(f-c|0)>1?c+1|0:c;b=b+4|0;continue}else{v[d>>2]=4;return}}break}if((a|0)<1|(a|0)>=127|t[c|0]>>>0>v[e>>2]-1>>>0){break a}v[d>>2]=4}}function gR(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=a;f=+(B(a,d)>>>0)*2500;a:{if(!(!c|b)){break a}b:{if(!(!a|!b)){Cc(e+12|0,10);a=w[v[e+12>>2]+15155|0];v[e+12>>2]=a;break b}if(a-1>>>0>9){break b}f=7338401.379310345/+(a>>>0);break a}f=+(a>>>0)*37878.78787878787}g=f;c:{if(f<4294967296&f>=0){a=~~g>>>0;break c}a=0}jb=e+16|0;return a}function WW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb+-64|0;jb=d;e=1;a:{if(kg(a,b,0)){break a}e=0;if(!b){break a}b=qv(b,71736,71784);e=0;if(!b){break a}Rb(d+8|4,0,52);v[d+56>>2]=1;v[d+20>>2]=-1;v[d+16>>2]=a;v[d+8>>2]=b;nb[v[v[b>>2]+28>>2]](b,d+8|0,v[c>>2],1);a=v[d+32>>2];if((a|0)==1){v[c>>2]=v[d+24>>2]}e=(a|0)==1}a=e;jb=d- -64|0;return a|0}function V3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Il(a);e=Il(b);a=jb-32|0;jb=a;v[a+24>>2]=c;a:{b:{if((d|0)!=(e|0)){while(1){b=Ub(a+8|0,v[d>>2]);v[114578]=0;Q(2208,a+24|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)==1){break b}yb(b);d=d+4|0;if((e|0)!=(d|0)){continue}break}c=v[a+24>>2]}jb=a+32|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}return c|0}function $g(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=e;e=0;i=e;f=c;c=0;e=Fma(h,e,f,c);j=mb;g=b;k=Fma(d,0,b,0);b=mb;d=Fma(d,l,f,c);c=b+d|0;b=mb;b=c>>>0<d>>>0?b+1|0:b;f=b;d=b+e|0;b=j;b=d>>>0<f>>>0?b+1|0:b;f=d;e=b;b=Fma(g,m,h,i)+c|0;d=mb;d=b>>>0<c>>>0?d+1|0:d;g=d;d=d+f|0;v[a+8>>2]=d;v[a+12>>2]=d>>>0<g>>>0?e+1|0:e;v[a>>2]=k;v[a+4>>2]=b}function ov(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1|v[a+48>>2]!=1){break a}t[a+54|0]=1;return}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1|(c|0)!=1){break a}t[a+54|0]=1;return}t[a+54|0]=1;v[a+36>>2]=v[a+36>>2]+1}}function Yz(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;Cc(f+12|0,256);Cc(f+12|0,65535);h=x[f+12>>1];eg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Ej(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0;return 1}function $da(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[c+12>>2]=0;W(1176,a+8|0,c+12|0,c+8|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}t[a+16|0]=0;v[a+12>>2]=b;v[114578]=0;Z(1174,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Vs(a);S(b|0);L()}function vV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-48|0;jb=e;bo(a);v[a>>2]=77128;g=uh(e+40|0);f=e+24|0;Qc(f,b);Qc(f+4|0,c);Qc(f+8|0,d);v[114578]=0;v[e+16>>2]=v[e+32>>2];b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;W(287,a+12|0,g|0,e+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=e+48|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function oz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(w[a+20|0]){break a}b=(-1-b>>>0<c>>>0?-1-b|0:c)+b|0;if(b>>>0<=y[a+16>>2]){break a}b=sz(b,4096);PQ(a,b-v[a+16>>2]|0);d=a,e=(g=a,h=xc(a+4|0,v[a+16>>2]),i=b-v[a+16>>2]|0,f=v[v[a>>2]+48>>2],nb[f](g|0,h|0,i|0)|0)+v[a+16>>2]|0,v[d+16>>2]=e;if(!(nb[v[v[a>>2]+44>>2]](a)|0)){break a}t[a+20|0]=1}}function Rl(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-16|0;jb=h;if(-17-b>>>0>=c>>>0){i=Tb(a);a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Vk(v[bd(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=ai(j);if(e){xh(c,i,e)}d=d-(e+f|0)|0;if(d){xh((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){pg(a,i,b)}Ef(a,c);Fg(a,j);jb=h+16|0;return}Hg();L()}function O1(a,b){a=a|0;b=b|0;var c=0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(ve(b,-1)){Nm(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return Gr(b)|0}if(!(w[a+48|0]&16)){if(!ve(Jm(b),t[v[a+12>>2]-1|0])){break a}}Nm(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=Jm(b);t[v[a+12>>2]]=c;return b|0}return-1}function $h(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if((b|0)<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.2250738585072014e-308;if((b|0)>-2045){b=b+1022|0;break a}a=a*2.2250738585072014e-308;b=((b|0)>-3066?b:-3066)+2044|0}l(0,0);l(1,b+1023<<20);return a*+n()}function tN(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function Yha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;a:{if(it(a)>>>0<b>>>0){zb(a);d=bz(c+32|0);v[114578]=0;R(936,d|0,b|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}uj(c+16|0,a);xk(c+8|0,a);v[114578]=0;U(937,d|0,c+16|0,c+8|0);b=v[114578];v[114578]=0;if((b|0)==1){break a}az(a,d);ke(d)}jb=c+48|0;return}a=P()|0;O()|0;ke(d);S(a|0);L()}function uI(a,b){var c=0,d=0,e=0,f=0,g=0;e=Tb(a);c=Fb(a);a=Tb(b);b=Fb(b);if(!b|!c){a=-1}else{f=a+b|0;b=e;g=c+b|0;d=g;a:{if((b|0)==(d|0)){break a}while(1){c=a;if((c|0)!=(f|0)){while(1){if(nb[26](t[b|0],t[c|0])|0){break a}c=c+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}a=(b|0)==(g|0)?-1:b-e|0}return a}function gy(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e|0]=0;v[a>>2]=w[(b&15)+20832|0];t[a+4|0]=w[e|0];break a}t[e+15|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+15|0]=1;f=f<<1}Eb(e,b+1074308|0,66);if(!(!d|!Cb(e))){v[e>>2]=0;Ei(a,e,e+15|0);break a}v[e>>2]=f<<4;Ei(a,e,e+15|0)}jb=e+16|0}function n3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=SM(a);a:{if(!v[b+4>>2]){break a}c=v[b+4>>2];v[114578]=0;R(2180,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[114578]=0;X(2181,a|0,c|0,e+f|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;oC(d);S(a|0);L()}return a|0}function XF(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;e=b+16|0;a:{while(1){c=v[a+36>>2];f=nb[v[v[c>>2]+20>>2]](c,v[a+40>>2],b+8|0,e,b+4|0)|0;c=-1;d=v[b+4>>2]-(b+8|0)|0;if((d|0)!=(_i(b+8|0,1,d,v[a+32>>2])|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}c=Br(v[a+32>>2])?-1:0}jb=b+16|0;return c|0}function GD(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;if(1073741807-b>>>0>=c>>>0){g=Tb(a);a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=sm(v[bd(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=rm(h);if(e){hi(c,g,e)}d=d-e|0;if(d){e=e<<2;hi(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){lo(g,b)}Ef(a,c);Fg(a,h);jb=f+16|0;return}Hg();L()}function r9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Vh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(1605,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function jka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Vh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(413,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=dt(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(571,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function Pha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(w[a+40|0]){break a}e=v[a+28>>2];if(!e){t[a+40|0]=1;return 0}if(!c){break a}d=nb[e|0](v[a+24>>2],b,c)|0;b:{if(d){while(1){e=d+f|0;g=e>>>0<d>>>0?g+1|0:g;f=e;c=c-d|0;if(!c){break b}b=b+d|0;d=nb[v[a+28>>2]](v[a+24>>2],b,c)|0;if(d){continue}break}}t[a+40|0]=1}d=f}return d|0}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=d;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,9);b=v[c+4>>2];if((b|0)!=v[c+8>>2]){while(1){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=v[c+4>>2]+9|0;v[c+4>>2]=b;if(v[c+8>>2]!=(b|0)){continue}break}}Mb(c);jb=d+16|0}function CU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Wl(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114578]=0;U(383,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}vc(b);jb=e+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=jN(a,c+8|0);a:{d=Dg(b);if(!d){break a}v[114578]=0;R(1220,a|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114578]=0;X(1221,a|0,b|0,e|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;ty(f);S(a|0);L()}jb=c+16|0;return a|0}function vI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Pe(12);b=v[b>>2];c=v[c>>2];v[114578]=0;c=W(2001,d|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2003,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return}a=P()|0;O()|0;Xb(d);S(a|0);L()}function qB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=qe(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(413,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+4|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function gq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Xh(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(383,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+2|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function UU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Mi(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(368,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+1|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Qz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Qp(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(707,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+6|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Pp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Mi(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(571,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+1|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Dca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])|Db(w[b+1|0])<<8,u[f>>1]=g;f=a,g=Db(w[b+2|0])|Db(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function Aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;f=a,g=Db(w[b+3|0])|Db(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function uV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+24>>2]=b;Dq(v[d+24>>2]);v[d+16>>2]=v[c+8>>2];b=v[c+4>>2];v[d+8>>2]=v[c>>2];v[d+12>>2]=b;b=jb-16|0;jb=b;c=Tk(b+8|0,v[d+8>>2]);e=v[v[d+12>>2]>>2];f=v[v[d+16>>2]>>2];Kp(a);v[a>>2]=77168;Tk(a+4|0,c);v[a+16>>2]=f;v[a+12>>2]=e;Bb(c);jb=b+16|0;jb=d+32|0;return a|0}function aJ(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=(Se(v[a+16>>2])|0)/5|0;b=yc(b,b>>31);v[a+4272>>2]=b;v[114578]=0;v[c+12>>2]=0;U(1648,a+4256|0,b<<1,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;jb=c+16|0;return}S(b|0);L()}function tB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=mB(a,c+8|0);a:{d=Kb(b);if(!d){break a}v[114578]=0;R(406,a|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114578]=0;X(410,a|0,b|0,e|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;As(f);S(a|0);L()}jb=c+16|0;return a|0}function sP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=qP(a,c+8|0);a:{d=Ac(b);if(!d){break a}v[114578]=0;R(563,a|0,d|0);e=v[114578];v[114578]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114578]=0;X(991,a|0,b|0,e|0,d|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pq(f);S(a|0);L()}jb=c+16|0;return a|0}function mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Le(b);v[d+12>>2]=0;a:{if(!Fi(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!Wg(a,d+11|0)){break b}On(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}jb=d+16|0;return e|0}function VI(a){var b=C(0),c=0,d=C(0),e=0;b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);c=a;d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){e=~~b>>>0;break a}e=0}v[c+4248>>2]=e;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Le(b);t[d+15|0]=0;a:{if(!Wg(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!Wg(a,d+14|0)){break b}On(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}jb=d+16|0;return e|0}function ds(a){var b=0,c=0,d=0,e=0;b=Vg(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){e=a;if(b<=45e-5){b=0}else{b=vo(b)*1.4426950408889634;d=H(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=.5849625007211562;if(b<.792481250360578){break a}c=1}b=Vg(c+d)*.5}A[e+4248>>3]=b}cs(a)}function CS(a){a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>=10){break a}return(w[a|0]|w[a+1|0]<<8)!=0}return 0}function lw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((nb[b|0](a,f)|0)>=0){if((nb[b|0](a,e)|0)>-1){break a}}j=f;f=(nb[b|0](f,e)|0)>-1;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}lG(g,h);jb=g+240|0}function UV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;b=Af(d,b);v[114578]=0;U(253,d+16|0,b|0,c|0);e=v[114578];v[114578]=0;a:{b:{if((e|0)!=1){v[114578]=0;U(5,a|0,d+16|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}yb(d+16|0);yb(b);jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+16|0)}yb(b);S(a|0);L()}function Dm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Tr(a+60|0);v[a>>2]=76784;v[d>>2]=76804;v[114578]=0;e=a+8|0;W(175,a|0,76816,e|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){a:{v[a>>2]=76784;v[d>>2]=76804;v[114578]=0;W(176,e|0,b|0,c|8)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;ah(d);S(a|0);L()}function ws(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;if(b){Eb(f+8|0,a+1074308|0,73);j=Cb(f+8|0)?c- -64|0:c;e=Zo(a);k=e^1;c=120;l=e^-1;g=1;while(1){e=c>>>1|0;i=e+g|0;h=$f(a,i,j,d);a:{if(!((h|0)!=0&k|b>>>0<=h>>>0?!(h>>>0>b>>>0&l):0)){g=i+1|0;c=(e^-1)+c|0;break a}c=e}if(c){continue}break}}jb=f+16|0;return g}function lG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=jb-256|0;jb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;lc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;lc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}jb=e+256|0}function BP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;f=d+8|0;g=b;if(oA(b,d+24|0)){e=_y(d+24|0)}ud(f,g,e);a=nA(a,d+24|0,d+8|0);Bb(d+8|0);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}v[114578]=0;Q(340,b|0,c-e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;hf(a);S(b|0);L()}jb=d+32|0}function jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=SO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1237,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function OS(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function Hga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=SO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1024,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function FK(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function $P(a){var b=0,c=0,d=0,e=0,f=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=nb[a|0](b)|0;d=mb;if((d|0)<0){break b}if((nb[c|0](b,0,0,0)|0)<=-1){break a}if((nb[c|0](b,0,0,2)|0)<=-1){break a}nb[a|0](b)|0;a=mb;nb[c|0](b,e,d,0)|0;f=(a|0)>-1}return f}nb[c|0](b,e,d,0)|0;return 0}function pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=lm(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1230,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+16|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=lD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(420,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=zq(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1227,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+8|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function qW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=lD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(216,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function p9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Vh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1622,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Vh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(821,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function nja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Wl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(828,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=qe(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1056,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Vh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(741,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function Oha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Vh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(948,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function J8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Vh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(1653,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=C(0);c=jb-32|0;jb=c;Nj(a,c+24|0);f=c,g=id(v[c+24>>2],v[c+28>>2]),v[f+16>>2]=g;v[c+12>>2]=256;pl(b,v[Lb(c+16|0,c+12|0)>>2]);if(Kb(b)){while(1){v[c+16>>2]=0;Lo(a,c+16|0);e=z[c+16>>2];f=Pb(b,d),h=e,z[f>>2]=h;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=c+32|0}function oB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=lm(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(420,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+16|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function nU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Wl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(422,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function mW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=dt(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(218,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function jU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Wl(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(427,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function VU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=dt(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(367,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function U9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Qp(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(1580,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+6|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function QW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(kg(a,v[b+8>>2],e)){nv(b,c,d);return}a:{if(!kg(a,v[b>>2],e)){break a}if(!(v[b+20>>2]!=(c|0)?v[b+16>>2]!=(c|0):0)){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=qe(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(878,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Mla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Qp(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(569,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+6|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=dt(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(38,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function LU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Vh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114578]=0;R(373,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}vc(b);jb=d+16|0;return}a=P()|0;O()|0;vc(b);S(a|0);L()}function dB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xh(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(422,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+2|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function cN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;a:{if(oc(hp(a))>>>0<=b>>>0){break a}b:{c:{if(wc(a)>>>0>b>>>0){if(y[sd(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}qy(a,b,c,1);break b}ee(e+8|0,sd(a,b),c);f=Cb(e+8|0);if(f|!d){break a}ee(e+8|0,sd(a,b),c);ge(e+8|0,1);dN(a,b,c)}f=0}jb=e+16|0;return f|0}function cC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Mi(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(367,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+1|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Y7(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=Se(v[a+16>>2]);b=yc(Gma(Fma(b,b>>31,3840,0),mb,1e3,0),mb);v[a+4276>>2]=b;v[114578]=0;v[c+12>>2]=0;U(1648,a+4260|0,b|0,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4276>>2]=0;$()}jb=c+16|0;return}S(b|0);L()}function Ox(a,b){var c=0,d=0,e=0;XQ(a);El(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[zb(b)>>2];d=zb(a),e=c,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function NP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=qe(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(948,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+4|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function MV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=zq(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(270,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+8|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function kS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Mi(d,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){c=zb(a);e=v[b+4>>2];v[114578]=0;R(38,c|0,e|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}c=v[b+4>>2]+1|0;v[b+4>>2]=c;if((c|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=d+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function _c(a,b){var c=0,d=0,e=0,f=0,g=0;d=b;b=gF(b);e=jb-16|0;jb=e;c=Vq(a);a:{if(c>>>0>=b>>>0){f=Tb(a);g=f;c=b;b:{c:{if(b){v[114578]=0;LD(g,d,c);d=v[114578];v[114578]=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Ab();L()}v[e+12>>2]=0;Te((b<<2)+f|0,e+12|0);Sg(a,b);break a}f=a;a=Fb(a);HD(f,c,b-c|0,a,0,a,b,d)}jb=e+16|0}function OB(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){Wf(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=c+16|0;return d}function MB(a){var b=0,c=0,d=0;a:{if(w[a+110|0]>64|((w[a|0]|w[a+1|0]<<8)!=20042?(w[a|0]|w[a+1|0]<<8)!=26217:0)|(t[a+112|0]<0|w[a+111|0]>128)){break a}while(1){b=a+c|0;d=t[b+113|0];if(!(((d&255)>>>0<254?(d|0)<=-1:0)|(w[b+241|0]?0:(d|0)>=0)|w[b+369|0]>=64)){b=1;c=c+1|0;if((c|0)!=128){continue}break a}break}b=0}return b}function k6(a){a=a|0;var b=0;v[114578]=0;Z(2015,a|0);b=v[114578];v[114578]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,34861,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function OK(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+28|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=0}return c}function EI(a){var b=0;v[a+4116>>2]=0;v[a+4132>>2]=0;v[a+4136>>2]=0;u[a+4128>>1]=0;v[a+4104>>2]=0;v[a+4108>>2]=0;b=a+4140|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4148|0;v[b>>2]=0;v[b+4>>2]=0;DI(a+4164|0);DI(a+4156|0);Wo(a+54060|0);Wo(a+62252|0);Wo(a+70444|0);Wo(a+78636|0);Rb(a+4332|0,0,32768);Ly(a+37100|0);Rb(a+37612|0,0,16384)}function R4(a){a=a|0;var b=0;v[114578]=0;Z(2088,a|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114578]=0;X(1989,37320,a|0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Hda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=0;d=a;W(1198,a|0,c+12|0,c+8|0)|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}t[a+530|0]=0;v[114578]=0;R(1197,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;wf(d);S(a|0);L()}function rn(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];f=v[d>>2];if(e|f){if(!b){break a}while(1){v[c>>2]=e-(((-2147483648-e>>>31|0)-1&255)+e>>8);v[d>>2]=v[d>>2]-(((-2147483648-f>>>31|0)-1&255)+f>>8);e=g<<3;v[e+a>>2]=v[c>>2];v[(e|4)+a>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}f=v[d>>2];e=v[c>>2];continue}}vO(a,b<<1)}}function YL(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Kk(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(1384,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+24|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Ay(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=$n(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(1177,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+32|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function ix(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=qe(e,a,b);if(v[b+4>>2]!=v[b+8>>2]){while(1){d=zb(a);f=v[b+4>>2];v[114578]=0;U(1605,d|0,f|0,c|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}d=v[b+4>>2]+4|0;v[b+4>>2]=d;if((d|0)!=v[b+8>>2]){continue}break}}Mb(b);jb=e+16|0;return}a=P()|0;O()|0;Mb(b);S(a|0);L()}function Rga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;bt(a+8|0);jb=c+16|0;c=a;a:{if(!b){break a}v[114578]=0;R(1016,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(1017,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Py(c);S(a|0);L()}return a|0}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);Db(w[b+1|0]);f=a,g=Db(w[b+2|0])|Db(w[b+3|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+3|0]);Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function SN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:IN(a,b);return;default:break a}}d=jb-16|0;jb=d;v[d+12>>2]=c;u[d+10>>1]=0;v[d+4>>2]=2;Xk(a,d+10|0,v[Lb(d+12|0,d+4|0)>>2]);a=mb;if((a|0)>0?1:(a|0)>=0){v[d+4>>2]=2;Lb(d+12|0,d+4|0)}u[d+4>>1]=x[d+10>>1];u[b>>1]=w[d+4|0]|w[d+5|0]<<8;jb=d+16|0}function OU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=a;a=b+18|0;d=b+46|0;b=ad(e,w[a|0]&2?16:8,1,0,(w[d|0]^-1)&1);if(!(!(w[a|0]&4)|c>>>0<532)){UB(b)}if(w[a|0]&8){Gj(b,w[d|0]&4?5:4);return}if(!(w[a|0]&2|w[d|0]!=255)){Gj(b,11);return}if(w[d|0]&2){t[b+2|0]=1}if(w[d|0]&4){Gj(b,2)}if(!(!(w[d|0]&8)|!(w[a|0]&2))){Gj(b,9)}}function t6(){var a=0,b=0;v[114578]=0;a=da(2004)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1989,34568,0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function J6(){var a=0,b=0;v[114578]=0;a=da(1988)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1989,34128,0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function G6(){var a=0,b=0;v[114578]=0;a=da(1992)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;X(1989,34156,0,0,0);a=v[114578];v[114578]=0;if((a|0)==1){break a}$();a=0}return a|0}b=P()|0;O()|0;v[114578]=0;Y(20);a=v[114578];v[114578]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function ema(a,b){a=a|0;b=b|0;var c=0;ot(a,b);vj(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function cia(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Df(a,8)){break a}c=0;if(!au(a,16628,8)){break a}c=-1;if(!Jj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=!((w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))&-2139062144)}a=c;jb=b+16|0;return a|0}function Eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;$Q(c+8|0,f);g=Hb(c+8|0);d=a;h=md(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){aR(f)}d=-1;a:{if(!c){break a}d=0;if(!oR(e+8|0)){break a}d=df(a,b,nR(e+8|0),mb)}jb=e- -64|0;return d|0}function ola(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-112|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;FS(c+8|0,f);g=Hb(c+8|0);d=a;h=md(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){GS(f)}d=-1;a:{if(!c){break a}d=0;if(!JS(e+8|0)){break a}d=df(a,b,IS(e+8|0),mb)}jb=e+112|0;return d|0}function KJ(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[114578]=0;v[c+12>>2]=0;U(1648,a+4208|0,b<<1,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;jb=c+16|0;return}S(b|0);L()}function F9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;c=a;d=jb-96|0;jb=d;qK(b,d,d+96|0);b=0;while(1){e=b<<3;f=e+c|0;g=v[d+e>>2];e=v[(e|4)+d>>2];v[f>>2]=g;v[f+4>>2]=e&65535;b=b+1|0;if((b|0)!=12){continue}break}v[c+104>>2]=0;v[c+96>>2]=!(v[c+88>>2]|v[c+92>>2]);v[c+100>>2]=0;jb=d+96|0;v[a+112>>2]=0;return a|0}function F$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=$E(a,d+8|0);e=Fb(b);f=Fb(c);b=Tb(b);v[114578]=0;X(195,a|0,b|0,e|0,e+f|0);b=v[114578];v[114578]=0;a:{if((b|0)!=1){b=Tb(c);v[114578]=0;W(196,a|0,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+16|0}function b4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Pm(c,a);a=b;if(v[a>>2]){Id(a);zH(a);up(a);Xo(zb(a),v[a>>2],We(a));d=zb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}El(b,c);v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=v[zb(c)>>2];d=zb(b),e=a,v[d>>2]=e;d=zb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0;rf(c);jb=c+16|0}function FU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-512|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;GB(c+8|0,f);g=Hb(c+8|0);d=a;h=md(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){HB(f)}d=-1;a:{if(!c){break a}d=0;if(!MB(e+8|0)){break a}d=df(a,b,LB(e+8|0),mb)}jb=e+512|0;return d|0}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b|0]);f=a,g=Db(w[b+1|0])|Db(w[b+2|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,3)|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(d){a=v[a+20>>2];c=d;while(1){Db(w[b+2|0]);f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,3)|0}function BU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;jB(c+8|0,f);g=Hb(c+8|0);d=a;h=md(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){kB(f)}d=-1;a:{if(!c){break a}d=0;if(!DB(e+8|0)){break a}d=df(a,b,CB(e+8|0),mb)}jb=e+48|0;return d|0}function m_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=v[16163];v[g+24>>2]=v[16162];v[g+28>>2]=h;h=v[16161];v[g+16>>2]=v[16160];v[g+20>>2]=h;h=v[16159];v[g+8>>2]=v[16158];v[g+12>>2]=h;h=v[16157];v[g>>2]=v[16156];v[g+4>>2]=h;a=bj(a,b,c,d,e,f,g,g+32|0);jb=g+32|0;return a|0}function sY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[e>>2]=c;a=Bv(f+12|0,0,b,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}b=a-1|0;c=1;if(b>>>0>d-v[e>>2]>>>0){break a}c=f+12|0;while(1){if(b){a=w[c|0];d=v[e>>2];v[e>>2]=d+1;t[d|0]=a;b=b-1|0;c=c+1|0;continue}break}c=0}jb=f+16|0;return c|0}function og(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;g=a;h=a;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);qf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[h>>2]=b;v[g+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;jb=d+16|0}function oL(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=Pi(b,c);a:{if(e>>>0<=yf(a)>>>0){v[d+12>>2]=c;if(Ac(a)>>>0<e>>>0){v[d+12>>2]=b;f=d,g=Ac(a)+v[d+12>>2]|0,v[f+12>>2]=g;gf(b,v[d+12>>2],v[a>>2]);Vy(a,v[d+12>>2],c,e-Ac(a)|0);break a}bS(a,gf(b,c,v[a>>2]));break a}PM(a);Ip(a,Ki(a,e));Vy(a,b,c,e)}jb=d+16|0}function NT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-1968|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;vA(c+8|0,f);g=Hb(c+8|0);d=a;h=md(d,ac(c,c+8|0));if((g|0)==(h|0)){Xc(d,Hb(c+8|0))}jb=c+16|0;c=(g|0)==(h|0);if(!c){wA(f)}d=-1;a:{if(!c){break a}d=0;if(!AA(e+8|0)){break a}d=df(a,b,1024,0)}jb=e+1968|0;return d|0}function nca(a,b){a=a|0;b=b|0;var c=0,d=0;c=Pe(2500);v[114578]=0;d=W(92,c|0,b|0,0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=d;W(97,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return}a=P()|0;O()|0;Xb(c);S(a|0);L()}function Rca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])^128,t[f|0]=g;f=a,g=Db(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=Db(w[b|0])+g|0;t[a|0]=g;d=Db(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function O9(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;Pk(c+16|0,c+40|0);b=Db(v[c+16>>2]);Pk(c+8|0,c+40|0);b=ri(c+24|0,b,Db(v[c+8>>2]+2|0));v[114578]=0;Q(1192,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function FD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=xw(a,d+8|0);e=$e(b);f=Fb(c);v[114578]=0;X(2836,a|0,b|0,e|0,e+f|0);b=v[114578];v[114578]=0;a:{if((b|0)!=1){b=Tb(c);v[114578]=0;W(2499,a|0,b|0,f|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+16|0}function o7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=qi(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=81236;v[114578]=0;W(1640,a+44|0,2,2)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;Z(1641,b|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;bf(b);S(a|0);L()}function PQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;c=a+4|0;a:{if(Ac(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!Ac(c)){Fk(c,sz(v[a+16>>2]+b|0,65536));break a}f=d,g=Ac(c),v[f+12>>2]=g;e=NQ(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Fk(c,sz(a,65536));break a}f=d,g=Ac(c),v[f+8>>2]=g;Fk(c,NQ(d+8|0))}jb=d+16|0}function kM(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+872|0]=w[b+872|0]|8;g=b;d=a?w[b+833|0]:0;h=(c|0)>-1?0-d|0:d;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[g+876>>2]=h+(d+v[b+876>>2]|0);c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+833|0]=a^a+c}function Kia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;b=-1;a:{if(!Df(a,1084)){break a}yk(a,1080);CQ(a,c+60|0);d=BQ(c+40|0);b=0;if(!AQ(c+60|0,d)){break a}yk(a,20);b=1;while(1){zQ(a,c+8|0);e=nz(c+8|0)+e|0;f=b&65535;b=b+1|0;if(f>>>0<31){continue}break}b=y[d+4>>2]>=e>>>0}jb=c- -64|0;return b|0}function jz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=bc(a);c=cc(a);a=jb-16|0;jb=a;v[a>>2]=c;v[a+8>>2]=b;if(Jb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}te(a+8|0);if(Jb(a+8|0,a)){continue}break}}jb=a+16|0}jb=d+16|0}function fS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:yh(a,b);return;default:break a}}d=jb-32|0;jb=d;v[d+28>>2]=c;t[d+27|0]=0;v[d+20>>2]=1;Xk(a,d+27|0,v[Lb(d+28|0,d+20|0)>>2]);a=mb;if((a|0)>0?1:(a|0)>=0){v[d+16>>2]=1;Lb(d+28|0,d+16|0)}t[d+8|0]=w[d+27|0];t[b|0]=w[d+8|0];jb=d+32|0}function eq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;Cc(f+12|0,256);Cc(f+12|0,65535);h=x[f+12>>1];eg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Ej(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0}function TL(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(1382,b+14|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(1383,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){yp(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function RL(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(1387,b+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(1388,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){mt(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function In(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;Cc(f+12|0,128);Cc(f+12|0,65535);h=x[f+12>>1];eg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Ej(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0}function iI(a){a=a|0;var b=0,c=0,d=0;b=Pe(1304568);v[114578]=0;c=T(2134,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2138,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return}a=P()|0;O()|0;Xb(b);S(a|0);L()}function fK(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-52|0;v[b+8>>2]=d;v[114578]=0;R(1439,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Lx(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/52|0)}}function WI(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=Pi(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){of(a,e);d=a;break a}g=Vk(e)+1|0;d=ai(g);Ef(a,d);Fg(a,g);we(a,e)}if((b|0)!=(c|0)){while(1){he(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;he(d,f+15|0);jb=f+16|0;return}Hg();L()}function W2(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;a:{b:{if(ni(a)){Fo(b+24|0);break b}Pm(b+8|0,a);v[114578]=0;R(2175,b+24|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}rf(b+8|0)}c=a+36|0;c:{if(ni(a)){break c}c=v[b+24>>2]}a=Id(c);gk(b+24|0);jb=b+32|0;return a|0}a=P()|0;O()|0;rf(b+8|0);S(a|0);L()}function zR(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-33|0;v[b+8>>2]=d;v[114578]=0;R(766,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){xR(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/33|0)}}function tP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-56|0;v[b+8>>2]=d;v[114578]=0;R(988,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xy(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/56|0)}}function rY(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[114578]=0;b=aa(2572,0,0,4,b|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}b:{if(b){a=-1}else{a=v[a+8>>2];if(a){break b}a=1}return a|0}v[114578]=0;a=T(2573,a|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}return(a|0)==1|0}V(0)|0;O()|0;Ab();L()}function ZR(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(729,b+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(732,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){sh(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function VJ(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(733,b+16|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(734,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){sh(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function RQ(a){var b=0,c=0,d=0,e=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;d=T(823,b+14|0)|0;e=v[114578];v[114578]=0;if((e|0)==1){break b}v[114578]=0;R(824,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){yp(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function Nt(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-48|0;v[b+8>>2]=d;v[114578]=0;R(573,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){VS(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/48|0)}}function $ca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){g=Db(w[b|0])+d|0;d=g+Db(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function lha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-608|0;jb=e;c=jb-16|0;jb=c;d=e;iP(c+8|0,e);g=Hb(c+8|0);f=a;h=md(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){jP(d)}d=-1;a:{if(!f){break a}d=0;if(!lP(e)){break a}d=df(a,b,kP(e),mb)}jb=e+608|0;return d|0}function ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-576|0;jb=e;c=jb-16|0;jb=c;d=e;tS(c+8|0,e);g=Hb(c+8|0);f=a;h=md(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){uS(d)}d=-1;a:{if(!f){break a}d=0;if(!yS(e)){break a}d=df(a,b,xS(e),mb)}jb=e+576|0;return d|0}function ala(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-192|0;jb=e;c=jb-16|0;jb=c;d=e;Zp(c+8|0,e);g=Hb(c+8|0);f=a;h=md(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){RR(d)}d=-1;a:{if(!f){break a}d=0;if(!sS(e)){break a}d=df(a,b,rS(e),mb)}jb=e+192|0;return d|0}function Zi(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=jb-48|0;jb=c;a:{if(!b){b=1;if(xd(a,5)){break a}b=uD(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;pf(c,v[a+28>>2]);yD(c+16|0,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[c+24>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}jb=c+48|0;return b|0}function xt(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-6|0;v[b+8>>2]=d;v[114578]=0;R(737,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Qt(v[a+16>>2],v[a>>2],(v[ec(a)>>2]-v[a>>2]|0)/6|0)}}function oma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Bi(d+16|0,d+8|0,c);v[114578]=0;R(517,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(518,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function fs(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2048|0;v[b+8>>2]=d;v[114578]=0;R(1652,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){AJ(v[a+16>>2],v[a>>2],v[ec(a)>>2]-v[a>>2]>>11)}}function KD(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;d=Fb(a);f=Kc(a);a:{if(f-d>>>0>=c>>>0){if(!c){break a}e=Tb(a);h=e;f=d;if(d){_l(c+e|0,e,f);b=b>>>0>=e>>>0?d+e>>>0>b>>>0?b+c|0:b:b}_l(h,b,c);b=c+d|0;Sg(a,b);t[g+15|0]=0;he(b+e|0,g+15|0);break a}Tu(a,f,(c+d|0)-f|0,d,0,0,c,b)}jb=g+16|0;return a}function Ika(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Uz(d+16|0,d+8|0,c);v[114578]=0;R(517,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(518,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Bba(a){a=a|0;var b=0,c=0,d=0;b=v[a+2496>>2];c=(b+1>>>0)%624|0;d=v[(c<<2)+a>>2];b=B(d&1,-1727483681)^(v[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|v[(b<<2)+a>>2]&-2147483648)>>>1);v[(v[a+2496>>2]<<2)+a>>2]=b;v[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function ym(a,b){var c=0,d=0;c=jb-16|0;jb=c;Bc(c+8|0,a);v[114578]=0;a=T(2456,c+8|0)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)==1){break b}v[114578]=0;aa(2470,a|0,64400,64426,b|0)|0;a=v[114578];v[114578]=0;if((a|0)==1){break b}Ob(c+8|0);jb=c+16|0;break a}a=P()|0;O()|0;Ob(c+8|0);S(a|0);L()}return b}function yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-80|0;jb=e;c=jb-16|0;jb=c;d=e;MR(c+8|0,e);g=Hb(c+8|0);f=a;h=md(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){NR(d)}d=-1;a:{if(!f){break a}d=0;if(!MO(e)){break a}d=df(a,b,LO(e),mb)}jb=e+80|0;return d|0}function dh(a){var b=0,c=0,d=0;c=Tr(a+56|0);v[a>>2]=76600;v[c>>2]=76620;v[114578]=0;b=a+4|0;W(126,a|0,76632,b|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){a:{v[a>>2]=76600;v[c>>2]=76620;v[114578]=0;Q(127,b|0,16)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}return a}}a=P()|0;O()|0;ah(c);S(a|0);L()}function Sca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=fn(w[b|0]),t[f|0]=g;f=a,g=fn(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function IC(a){a=a|0;var b=0,c=0;b=gd(a);v[114578]=0;T(277,a+12|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(278,a+28|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function xia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-128|0;jb=e;c=jb-16|0;jb=c;d=e;bQ(c+8|0,e);g=Hb(c+8|0);f=a;h=md(f,ac(c,c+8|0));if((g|0)==(h|0)){Xc(f,Hb(c+8|0))}jb=c+16|0;f=(g|0)==(h|0);if(!f){cQ(d)}d=-1;a:{if(!f){break a}d=0;if(!hQ(e)){break a}d=df(a,b,256,0)}jb=e+128|0;return d|0}function Cfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Bi(d+16|0,d+8|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function xl(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{c:{d:{e:{switch(c|0){case 1:break b;case 3:break c;case 0:break d;case 2:break e;default:break a}}e=vM(a,b,d);if(e-251>>>0<5){break d}if(e){break a}}return uM(a,b,d)}e=uM(a,b,d);if(e-251>>>0<5){break b}if(e){break a}}e=vM(a,b,d)}return e}function xU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;ku(d+16|0,d+8|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function je(a){var b=C(0),c=C(0),d=0,e=0;d=(p(a),j(2));e=d>>>23&255;if(e>>>0<=149){if(e>>>0<=125){return C(a*C(0))}a=(d|0)>-1?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){c=C(C(a+b)+C(-1));break a}a=C(a+b);c=a;if(!(b<=C(-.5))){break a}c=C(a+C(1))}a=c;a=(d|0)>-1?a:C(-a)}return a}function ZI(a,b,c){var d=0,e=0,f=0,g=0;if(C(D(a))<C(2147483648)){d=~~a}else{d=-2147483648}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<1)){while(1){d=b-1|0;e=e<<1;if((e|0)<0){break a}g=(b|0)>1;b=d;if(g){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function WV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;jm(d+16|0,d+8|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function AM(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}$s(b,e,a);Eb(f+8|0,a+1074308|0,10);if(!Cb(f+8|0)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}jb=f+16|0}function qy(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=hp(a);a:{if(oc(f)>>>0<=b>>>0){break a}if(ry(a,x[rc(f,b)>>1])>>>0<=c>>>0){break a}b:{if(wc(a)>>>0>b>>>0){if(y[sd(a,b)+4>>2]>c>>>0){break b}}pj(a,0);if(wc(a)>>>0<=b>>>0){break a}}ee(e+8|0,sd(a,b),c);ge(e+8|0,d);if(!d){break a}dN(a,b,c)}jb=e+16|0}function UI(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[114578]=0;v[c+12>>2]=0;U(1648,a+4208|0,b<<2,c+12|0);b=v[114578];v[114578]=0;a:{if((b|0)==1){b=V(71204)|0;if((O()|0)!=(ga(71204)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;jb=c+16|0;return}S(b|0);L()}function NB(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){Wf(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}jb=c+16|0;return d}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;cm(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;KN(h,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Bq(a,xe(a))}function JB(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;Cc(d+12|0,128);Cc(d+12|0,65535);f=x[d+12>>1];eg(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=Ej(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}jb=d+16|0}function Hja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Ph(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-24|0;rR(h,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Wt(a,Id(a))}function wE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;aj(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Ev(h,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,wc(a))}function k7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;f=Pi(b,c);d=Kc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Fb(a);Rl(a,g,h,d,0,d,0)}d=Tb(a);if((b|0)!=(c|0)){while(1){he(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;he(d,e+15|0);Sg(a,f);jb=e+16|0;return a|0}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Wk(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-16|0;BH(h,e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];km(a,od(a))}function YP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-8|0;v[b+8>>2]=d;v[114578]=0;R(923,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ou(v[a+16>>2],v[a>>2],v[ec(a)>>2]-v[a>>2]>>3)}}function Tp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;Ph(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-24|0;Up(h,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Wt(a,Id(a))}function CO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Fb(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=Um(Tb(a),v[c+8>>2],v[Lb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}jb=c+16|0;return a|0}function BV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;cm(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-32|0;DC(h,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Bq(a,xe(a))}function $ja(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=a;if(!w[b+8|0]){if(w[b+24|0]){t[b+24|0]=0;d=b+40|0;while(1){e=Ii(d,c),f=0,t[e+8|0]=f;c=c+1|0;if((c|0)!=16){continue}break}c=b+28|0;Fk(c,0);eS(c)}c=b+12|0;Fk(c,v[b+4>>2]);nb[v[v[b>>2]+44>>2]](b,v[c>>2],0,v[b+4>>2])|0;t[b+8|0]=1}return v[a+12>>2]}function tia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;dQ(d+16|0,c);v[114578]=0;R(517,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(518,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Oca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b|0])|Db(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Lca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Db(w[b+1|0])|Db(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function hT(a,b,c){var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;a:{if(!Jb(d+24|0,d+16|0)){break a}while(1){a=v[d+24>>2];if(v[v[d+8>>2]>>2]==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}Ik(d+24|0);if(Jb(d+24|0,d+16|0)){continue}break}}jb=d+32|0;return v[d+24>>2]}function IQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(!w[a+20|0]){if(!(nb[v[v[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){PQ(a,65536);c=a,d=(f=a,g=xc(b,v[a+16>>2]),h=65536,e=v[v[a>>2]+48>>2],nb[e](f|0,g|0,h|0)|0)+v[a+16>>2]|0,v[c+16>>2]=d;if(!(nb[v[v[a>>2]+44>>2]](a)|0)){continue}break}}t[a+20|0]=1}}function gG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=pr(a);v[a+32>>2]=b;v[a>>2]=55956;sr(d+8|0,e);v[114578]=0;b=T(2315,d+8|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Ob(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Em(b),t[g+44|0]=h;jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);jl(e);S(a|0);L()}function fG(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=OF(a);v[a+32>>2]=b;v[a>>2]=56060;sr(d+8|0,e);v[114578]=0;b=T(2316,d+8|0)|0;f=v[114578];v[114578]=0;if((f|0)!=1){Ob(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Em(b),t[g+44|0]=h;jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);uo(e);S(a|0);L()}function e9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;vf(a);h=zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-4|0;RJ(h,e-4|0,c);e=v[d>>2]-4|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mk(a,Kb(a))}function bf(a){a=a|0;var b=0,c=0;v[a>>2]=79680;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=a+44|0;as(b+36|0);as(b+24|0);$r(b+12|0);$r(b);return a|0}function ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;MA(d+16|0,c);v[114578]=0;R(71,d|0,d+16|0);c=v[114578];v[114578]=0;a:{if((c|0)==1){break a}v[114578]=0;U(72,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Db(w[b|0])+d|0)+(Db(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Db(w[b+1|0])+d|0)+(Db(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function zK(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{c=a-12|0;d:{if(c>>>0>28){break d}a=1;d=1<<c;if(d&270014517){break b}if(d&65792){break c}if((c|0)!=7){break d}b=b&240;if(!b|(b|0)==96|(b|0)==224){break b}}return 0}a=0;b=(b&240)-96|0;if(b>>>0<144){break a}}return a|0}return 297>>>(b>>>4)&1}function mV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=0;if(y[a+16>>2]>c>>>0){d=v[a+4>>2];f=v[a+12>>2];v[e+8>>2]=v[a+16>>2]-c;d=(h=d,i=b,j=c+f|0,k=v[Lb(e+12|0,e+8|0)>>2],g=v[v[d>>2]+28>>2],nb[g](h|0,i|0,j|0,k|0)|0)}jb=e+16|0;return d|0}function TM(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){a=v[a>>2];v[114578]=0;c=T(1256,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break b}v[114578]=0;R(1257,a|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}}if(b){my(b)}break a}V(0)|0;O()|0;Ab();L()}}}function Am(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;g=a;h=a;a:{if(!b){b=0;e=0;break a}d=b;b=E(b);qf(c,d,0,0,0,b+81|0);d=0+v[c+8>>2]|0;b=(v[c+12>>2]^65536)+(16414-b<<16)|0;b=d>>>0<f>>>0?b+1|0:b;f=d;d=b;b=v[c+4>>2];e=v[c>>2]}v[h>>2]=e;v[g+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=d;jb=c+16|0}function pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Wk(a);zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-16|0;bm(e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];km(a,od(a))}function ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;aj(a);zb(a);f=b+4|0;d=f;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){e=v[d>>2];while(1){c=c-12|0;Uy(e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(g|0)){continue}break}}Zb(a,f);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,wc(a))}function bV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=-1;a:{if(!rC(a,c+8|0)){break a}d=0;if(!mC(c+8|0)){break a}if(b){a=c+12|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(!v[b+4>>2]&y[b>>2]<(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))-8>>>0){break a}}d=1}jb=c+48|0;return d|0}function w0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{if(v[b>>2]){if(!Wc(c)){fv(c,58368)}e=v[b+4>>2];nb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[114578]=0;Q(1250,c|0,d|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}yb(d)}cd(a,c);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function j4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-48|0;jb=d;v[d+44>>2]=b;ij(d+8|0,0,c);b=d+24|0;v[b>>2]=v[d+44>>2];cd(b+4|0,d+8|0);v[114578]=0;R(2126,a+4|0,d+24|0);a=v[114578];v[114578]=0;if((a|0)!=1){At(d+24|0);yb(d+8|0);jb=d+48|0;return}a=P()|0;O()|0;At(d+24|0);yb(d+8|0);S(a|0);L()}function g_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=jb-128|0;jb=c;v[c+12>>2]=c+116;ME(a+8|0,c+16|0,c+12|0,e,f,g);d=c+16|0;e=v[c+12>>2];a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if((d|0)!=(e|0)){yF(a+8|0,t[d|0]);d=d+1|0;continue}break}jb=a+16|0;jb=c+128|0;return v[a+8>>2]}function uE(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;b=qe(d,a,b);c=v[b+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}$k(a);c=v[b+4>>2];v[114578]=0;bt(c);c=v[114578];v[114578]=0;if((c|0)!=1){c=v[b+4>>2]+4|0;v[b+4>>2]=c;continue}break}a=P()|0;O()|0;Mb(b);S(a|0);L()}Mb(b);jb=d+16|0}function Pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])|Db(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Mca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b+1|0])|Db(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function ZE(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=rt(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){of(a,e);d=a;break a}g=sm(e)+1|0;d=rm(g);Ef(a,d);Fg(a,g);we(a,e)}while(1){if((b|0)!=(c|0)){Te(d,b);d=d+4|0;b=b+4|0;continue}break}v[f+12>>2]=0;Te(d,f+12|0);jb=f+16|0;return}Hg();L()}function $e(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function rS(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Qb(a,120);a:{if(e){c=jb-16|0;jb=c;gc(d+8|0,b,120);jb=c+16|0;Bd(a,d+8|0);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b+120|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function tU(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+16>>2]=b;v[c+24>>2]=a;a:{if(!Jb(c+24|0,c+16|0)){break a}v[c>>2]=v[c+24>>2];if(!Jb(te(c),c+16|0)){break a}while(1){if(lB(v[c+24>>2],v[c>>2])){v[c+24>>2]=v[c>>2]}if(Jb(te(c),c+16|0)){continue}break}}jb=c+32|0;return v[c+24>>2]}function Ey(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1166,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=255;return a}function Jr(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;v[b+12>>2]=12;v[b+8>>2]=32;a:{if(!v[Lb(b+12|0,b+8|0)>>2]){break a}d=15;while(1){e=_o(a);v[b+8>>2]=32;c=c^e;if(y[Lb(b+12|0,b+8|0)>>2]<=d>>>0){break a}c=c<<15;d=d+15|0;continue}}jb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function e8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[a+4>>2]=b;v[a>>2]=0;b=Ts(a+8|0,e);v[114578]=0;Q(1760,a+20|0,d|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&240|c|8;return a|0}a=P()|0;O()|0;Ib(b);S(a|0);L()}function _ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(!v[a+300>>2]){return 0}if(!(!d|(nb[v[a+304>>2]](v[a+296>>2],c,0,0)|0)<0)){while(1){a:{c=nb[v[a+300>>2]](v[a+296>>2],b,d)|0;e=c+e|0;f=c>>>0>e>>>0?f+1|0:f;if(!c){break a}b=b+c|0;d=d-c|0;if(d){continue}}break}}return e|0}function Ud(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=(a|0)>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function yH(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(2207,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xo(v[a+16>>2],v[a>>2],Nl(a))}}function rD(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;v[b>>2]=0;t[c+15|0]=0;e=Wg(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;a:{f=d&3;if(!f){break a}d=1;while(1){t[c+15|0]=0;g=Wg(a,c+15|0);v[b>>2]=v[b>>2]|w[c+15|0]<<(d<<3)-2;e=e&g;if((d|0)==(f|0)){break a}d=d+1|0;continue}}jb=c+16|0}function kh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;g=Mj(a,c);pf(e+8|0,v[a+28>>2]);f=v[e+20>>2];v[e+24>>2]=v[e+16>>2];v[e+28>>2]=f;a:{b:{if(!g){f=-1;if(!xd(a,5)){break b}break a}f=v[g+8>>2]}nb[d|0](v[a+28>>2],b,f)}a=Zi(a,g,c,e+24|0);jb=e+32|0;return a|0}function et(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(1023,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function XM(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(1236,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function TO(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(1022,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function Ss(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-32|0;v[b+8>>2]=d;v[114578]=0;R(1194,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){sh(v[a+16>>2],v[a>>2],Su(a))}}function GK(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(1561,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xf(v[a+16>>2],v[a>>2],Nl(a))}}function AH(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-16|0;v[b+8>>2]=d;v[114578]=0;R(2206,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xi(v[a+16>>2],v[a>>2],hv(a))}}function vP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(984,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xf(v[a+16>>2],v[a>>2],Nl(a))}}function tT(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(528,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xf(v[a+16>>2],v[a>>2],Nl(a))}}function qR(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(768,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xf(v[a+16>>2],v[a>>2],Nl(a))}}function oD(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-16|0;v[b+8>>2]=d;v[114578]=0;R(217,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xi(v[a+16>>2],v[a>>2],hv(a))}}function nL(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1441,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function es(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1654,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function _r(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1763,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function Yq(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(206,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function WL(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-32|0;v[b+8>>2]=d;v[114578]=0;R(895,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){mt(v[a+16>>2],v[a>>2],Su(a))}}function US(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(572,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xf(v[a+16>>2],v[a>>2],Nl(a))}}function TK(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1525,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function QJ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1440,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function Q1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;d=Go(f+8|0,d);v[114578]=0;ea(2014,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Yc(d);oH(a);b=nH(a+88|0);v[a>>2]=84152;v[b>>2]=84240;jb=f+16|0;return a|0}a=P()|0;O()|0;Yc(d);S(a|0);L()}function NS(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-24|0;v[b+8>>2]=d;v[114578]=0;R(604,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xf(v[a+16>>2],v[a>>2],Nl(a))}}function It(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-16|0;v[b+8>>2]=d;v[114578]=0;R(428,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Xi(v[a+16>>2],v[a>>2],hv(a))}}function Is(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-12|0;v[b+8>>2]=d;v[114578]=0;R(350,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){zh(v[a+16>>2],v[a>>2],no(a))}}function Gm(a,b,c){var d=0,e=0,f=0;a:{if(b>>>0<1){d=a;break a}while(1){d=Ima(a,b,10,0);e=mb;f=e;e=Fma(d,e,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function EO(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(1059,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],sg(a))}}function Cq(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-32|0;v[b+8>>2]=d;v[114578]=0;R(276,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){sh(v[a+16>>2],v[a>>2],Su(a))}}function vq(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(351,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function nm(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-1|0;v[b+8>>2]=d;v[114578]=0;R(215,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){pg(v[a+16>>2],v[a>>2],fA(a))}}function nk(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(107,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function c8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Ed(b);e=sf(b);f=Ed(b);c=jb-32|0;jb=c;v[c+16>>2]=e;v[c+24>>2]=d;v[c+8>>2]=f;if(Jb(c+24|0,c+16|0)){while(1){d=nb[117](t[v[c+24>>2]])|0;t[v[c+8>>2]]=d;qg(c+24|0);qg(c+8|0);if(Jb(c+24|0,c+16|0)){continue}break}}jb=c+32|0;cd(a,b)}function bC(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(364,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Wn(v[a+16>>2],v[a>>2],Vn(a))}}function ZQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(818,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],sg(a))}}function ZA(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(424,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Pl(v[a+16>>2],v[a>>2],Vn(a))}}function Yt(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(532,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Pl(v[a+16>>2],v[a>>2],Vn(a))}}function Wh(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(374,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){vu(v[a+16>>2],v[a>>2],sg(a))}}function Wca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Yb(fn(w[b|0]),-64,63)<<1,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function Vm(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(735,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],sg(a))}}function SQ(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(825,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Pl(v[a+16>>2],v[a>>2],Vn(a))}}function Rg(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-1|0;v[b+8>>2]=d;v[114578]=0;R(363,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){pg(v[a+16>>2],v[a>>2],fA(a))}}function Pda(a,b){a=a|0;b=b|0;var c=0;c=jb-48|0;jb=c;t[c+40|0]=w[b|0];xq(c+16|0,c+40|0);b=Db(v[c+16>>2]);xq(c+8|0,c+40|0);b=ri(c+24|0,b,Db(v[c+8>>2]+1|0));v[114578]=0;Q(1192,a|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function OR(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(738,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],sg(a))}}function HP(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-4|0;v[b+8>>2]=d;v[114578]=0;R(949,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){xj(v[a+16>>2],v[a>>2],sg(a))}}function Dj(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-2|0;v[b+8>>2]=d;v[114578]=0;R(384,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Wn(v[a+16>>2],v[a>>2],Vn(a))}}function qk(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,896)+a|0)+1075640>>2];if(!f){break a}if(!zi(f)){break a}e=w[f+34|0];if(e-251>>>0<5|!e){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}nb[v[v[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,896)+a|0)+1075846>>1]=65535}}function kU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;if(!Qb(b,c)){c=nf(b)}v[a>>2]=c;d=v[b>>2];if(nb[v[v[d>>2]+16>>2]](d)|0){c=a;a=v[b>>2];e=c,f=(nb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;return}d=a+8|0;Fk(d,v[a>>2]);if(!nd(d)){xg(b,xc(d,0),c)}}function gC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;u[(v[a+1064>>2]<<1)+d>>1]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=ue(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function _p(a){var b=0,c=0,d=0,e=0;b=a;e=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(e|0)){break a}c=v[b+16>>2];d=v[b+8>>2]-1|0;v[b+8>>2]=d;v[114578]=0;R(32,c|0,d|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){pg(v[a+16>>2],v[a>>2],fA(a))}}function zJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-16|0;jb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Tb(d);ri(b,a,Fb(d)+a|0);break c}$J(e,c,d);v[114578]=0;U(115,a|0,b|0,e|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Lc(e)}jb=e+16|0;break a}a=P()|0;O()|0;Lc(e);S(a|0);L()}}function u7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=6){ae(d+12|0,C(0));c=z[d+12>>2];a:{if(!((b|0)!=1|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(je(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;bx(a)}jb=d+16|0}function _7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=6){ae(d+12|0,C(0));c=z[d+12>>2];a:{if(!((b|0)!=3|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(je(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;bx(a)}jb=d+16|0}function lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;if(v[c>>2]){wc(c);ZM(c);ft(c);zh(zb(c),v[c>>2],lg(c));d=zb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0}El(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[zb(b)>>2];d=zb(a),e=c,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function Ti(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){c=v[a>>2];while(1){g=a;a:{if(c){d=v[a+4>>2];c=c-1|0;break a}v[a>>2]=8;c=v[a+12>>2];if((c|0)!=v[a+8>>2]){c=c-1|0;v[a+12>>2]=c}d=w[c|0];c=7}v[g>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function pA(a){var b=0,c=0,d=0,e=0;Ph(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(528,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Xf(zb(a),v[a>>2],We(a))}}function ow(a){var b=0,c=0;a:{if(y[a+20>>2]<=y[a+28>>2]){break a}nb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break a}return-1}b=v[a+4>>2];c=v[a+8>>2];if(b>>>0<c>>>0){b=b-c|0;nb[v[a+40>>2]](a,b,b>>31,1)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;return 0}function kT(a){var b=0,c=0,d=0,e=0;Ph(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(572,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Xf(zb(a),v[a>>2],We(a))}}function cx(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(1763,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function cl(a){var b=0,c=0,d=0,e=0;aj(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-12|0;R(206,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;zh(zb(a),v[a>>2],lg(a))}}function TE(a,b){var c=0,d=0;c=jb-16|0;jb=c;Bc(c+8|0,a);v[114578]=0;a=T(21,c+8|0)|0;d=v[114578];v[114578]=0;a:{if((d|0)==1){break a}v[114578]=0;a=Q(22,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}Ob(c+8|0);jb=c+16|0;return a}a=P()|0;O()|0;Ob(c+8|0);S(a|0);L()}function Sd(a){var b=0,c=0,d=0,e=0;o(+a);b=j(1)|0;j(0)|0;e=b;b=b>>>20&2047;if(b>>>0<=1074){if(b>>>0<=1021){return a*0}a=(e|0)>-1?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){d=a+c+-1;break a}a=a+c;d=a;if(!(c<=-.5)){break a}d=a+1}a=d;a=(e|0)>-1?a:-a}return a}function Hl(a){var b=0,c=0,d=0,e=0;cm(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-32|0;R(895,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;mt(zb(a),v[a>>2],th(a))}}function Dz(a){var b=0,c=0,d=0,e=0;Ph(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(768,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Xf(zb(a),v[a>>2],We(a))}}function CP(a){var b=0,c=0,d=0,e=0;yP(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-56|0;R(988,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Xy(zb(a),v[a>>2],sn(a))}}function CL(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(1441,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function Bx(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(1525,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function $z(a){var b=0,c=0,d=0,e=0;Ph(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-24|0;R(604,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Xf(zb(a),v[a>>2],We(a))}}function qX(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a=Vh(c,a+8|0,b);b=v[a>>2];a:{while(1){if(v[a+4>>2]==(b|0)){break a}b=v[a>>2];v[114578]=0;bt(b);b=v[114578];v[114578]=0;if((b|0)!=1){b=v[a>>2]+4|0;v[a>>2]=b;continue}break}b=P()|0;O()|0;vc(a);S(b|0);L()}vc(a);jb=c+16|0}function qC(a){var b=0,c=0,d=0,e=0;vf(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-4|0;R(351,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Re(zb(a),v[a>>2],yd(a))}}function lj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(!(b?0:!(v[a+480180>>2]&1))){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function jC(a){var b=0,c=0,d=0,e=0;Rk(a);if(v[a>>2]){d=a;e=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(e|0)){break a}c=zb(d);v[114578]=0;b=b-2|0;R(364,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[d+4>>2]=e;Wn(zb(a),v[a>>2],Uf(a))}}function uf(a,b){var c=0,d=0,e=0,f=0;c=Fb(a);a:{if((c|0)!=(Fb(b)|0)){break a}d=Tb(a);b=Tb(b);b:{if(!Fe(a)){if(c){break b}return 1}return!Um(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function fC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;t[v[a+1064>>2]+d|0]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=ue(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function xo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-e*f)-b+e*.16666666666666632)}function L0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Cg(t[b|0]),e=v[v[a>>2]+52>>2],nb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=_i(b,1,c,v[a+32>>2])}return c|0}function lI(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-16|0;R(2206,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;Xi(zb(a),v[a>>2],Zh(a))}}function Yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Db(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function Qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[qh(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=((a+b|0)-2|0)/(b-1|0);a=w[qh(d+13|0,d+12|0)|0]}jb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function oC(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-12|0;R(350,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;zh(zb(a),v[a>>2],lg(a))}}function a3(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function NQ(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;b=jb-16|0;jb=b;d=2;e=v[a>>2];if((e|0)!=1){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Lb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Lb(b+12|0,b+8|0)>>2]}jb=b+16|0;jb=c+16|0;return d}function GQ(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-20|0;R(884,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;yp(zb(a),v[a>>2],xp(a))}}function us(a,b){var c=0,d=0;a:{if(b){us(a,v[b>>2]);us(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(1382,b+14|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1383,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}yp(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function sS(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148?(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297:0){break a}b=a+34|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+36|0;return(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return 0}function iC(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-1|0;R(362,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;pg(zb(a),v[a>>2],yf(a))}}function bT(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-6|0;R(570,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;Qt(zb(a),v[a>>2],Li(a))}}function _D(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=0;v[d+4>>2]=4;Xk(a,d+8|0,v[Lb(d+12|0,d+4|0)>>2]);a=mb;if((a|0)>0?1:(a|0)>=0){v[d+4>>2]=4;Lb(d+12|0,d+4|0)}v[d+4>>2]=v[d+8>>2];a=d+4|0;v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);jb=d+16|0}function Yx(a,b){var c=0,d=0;a:{if(b){Yx(a,v[b>>2]);Yx(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(1387,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1388,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}mt(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function VC(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-8|0;R(283,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;Ou(zb(a),v[a>>2],Ui(a))}}function HQ(a){var b=0,c=0,d=0,e=0;if(v[a>>2]){d=v[a>>2];e=a;b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(e);v[114578]=0;b=b-4|0;R(883,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[e+4>>2]=d;xj(zb(a),v[a>>2],yd(a))}}function TF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=ba(16)|0;VF();a=Uc(c+8|0,a,85168);v[114578]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2360,d|0,c|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ja(d|0,58416,2361);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function FJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>2097151){Fc(32651);L()}f=sc(d<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<11)+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function DJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){Fc(32651);L()}f=sc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function yE(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=64776;b=v[a+8>>2];v[114578]=0;c=da(2452)|0;d=v[114578];v[114578]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[114578]=0;Qv(b);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Ab();L()}return a|0}function uz(a,b){var c=0,d=0;a:{if(b){uz(a,v[b>>2]);uz(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(823,b+14|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(824,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}yp(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function lp(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=vk(a,b);if((e|0)==255){break a}if(qj(a)){break a}b=Ii(a+314|0,e);e=xN(e);if(!(f=0,g=!(t[fc(b,10)|0]&1),h=d,h?f:g)){hh(v[a>>2],e- -64&65535,wN(c,w[fc(b,2)|0]))}if(d){break a}hh(v[a>>2],e+67&65535,wN(c,w[fc(b,3)|0]))}}function Zda(a){a=a|0;var b=0,c=0,d=0;c=jb-32|0;jb=c;b=255;a:{if(Nh(a)>>>0<=49){b=Cy(c,v[a+12>>2]);v[114578]=0;R(1178,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)==1){break a}Dl(b);mp(a,Nh(a)-1&255);b=Nh(a)-1|0}jb=c+32|0;return b&255}a=P()|0;O()|0;Dl(b);S(a|0);L()}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Db(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=fn(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function Xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Db(b);if(f){a=v[a+20>>2];c=f;while(1){d=Db(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f|0}function Kz(a,b){var c=0,d=0;a:{if(b){Kz(a,v[b>>2]);Kz(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(733,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(734,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}sh(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function Iz(a,b){var c=0,d=0;a:{if(b){Iz(a,v[b>>2]);Iz(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(729,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(732,a|0,c|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}sh(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function mx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!jf(a)){break a}while(1){if(!mh(Ge(a,e))){break a}d=d+1|0;e=d&65535;if(jf(a)>>>0>e>>>0){continue}break}}if(!(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0?c:0)){return(rg(a,d&65535,b)?d:-1)&65535}return 65535}function dk(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=Er(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function xH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=Lh(C(d*C(65536)));if((e|0)==65536){break a}f=B(b,c);if(!f){break a}c=e;e=e>>31;b=1;while(1){g=v[a>>2];h=a,i=yc(Gma(Fma(g,g>>31,c,e),mb,65536,0),mb),v[h>>2]=i;if((b|0)==(f|0)){break a}a=a+4|0;b=b+1|0;continue}}}function vr(a,b){var c=0,d=0,e=0;c=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{d=v[b+4>>2];c:{if(!d){hG(b);d=v[b+4>>2];if(!d){break c}}if(v[b+44>>2]-8>>>0<d>>>0){break b}}if(!e){break a}return-1}c=d-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;c=a}return c}function ny(a,b){var c=0,d=0;a:{if(b){ny(a,v[b>>2]);ny(a,v[b+4>>2]);a=hc(a);v[114578]=0;c=T(1256,b+16|0)|0;d=v[114578];v[114578]=0;if((d|0)==1){break a}v[114578]=0;R(1257,a|0,c|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}my(b)}return}V(0)|0;O()|0;Ab();L()}function zv(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[114578]=0;c=da(2452)|0;d=v[114578];v[114578]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[114578]=0;Qv(b);b=v[114578];v[114578]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Ab();L()}return a|0}function ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ju(a);a:{if(!b){break a}v[114578]=0;R(920,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(921,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;bq(d);S(a|0);L()}return a|0}function TW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(kg(a,v[b+8>>2],0)){pv(b,c,d);return}e=v[a+12>>2];f=a+16|0;zD(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){zD(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function wU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=iy(a);a:{if(!b){break a}v[114578]=0;R(406,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(407,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;As(d);S(a|0);L()}return a|0}function oS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Rz(a);a:{if(!b){break a}v[114578]=0;R(680,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(681,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Dt(d);S(a|0);L()}return a|0}function k_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(2456,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);PE(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function j_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(2456,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);OE(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function jX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Vq(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Tb(a);hi(d+(e<<2)|0,b,c);b=c+e|0;Sg(a,b);v[f+12>>2]=0;Te(d+(b<<2)|0,f+12|0);break a}HD(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function Tt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Gu(a);a:{if(!b){break a}v[114578]=0;R(563,a|0,b|0);e=v[114578];v[114578]=0;if((e|0)!=1){v[114578]=0;U(564,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pq(d);S(a|0);L()}return a|0}function Gba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-2496|0;jb=c;qK(b,c,c+2496|0);b=lc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<=-1){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}jb=c+2496|0;return a|0}function m0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;e=pr(a);v[a>>2]=76704;f=xw(a+32|0,d+8|0);v[a+48>>2]=c;v[a+44>>2]=0;v[114578]=0;R(182,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){jb=d+16|0;return a|0}a=P()|0;O()|0;yb(f);jl(e);S(a|0);L()}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=bc(a),v[e+8>>2]=f;b=b+(Vp(d+24|0,d+8|0)<<1)|0;if(Jb(d+24|0,d+16|0)){Pn(a,gf(b+(Vp(d+16|0,d+24|0)<<1)|0,v[a+4>>2],b))}a=Ng(b);jb=d+32|0;return a|0}function caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=bc(a),v[e+8>>2]=f;b=b+B(ks(d+24|0,d+8|0),6)|0;if(Jb(d+24|0,d+16|0)){Pz(a,qx(b+B(ks(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}a=Ng(b);jb=d+32|0;return a|0}function w$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function v7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;hJ(a,b,c,d);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=81004;return a|0}function r_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(21,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);SE(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Bc(g,d);v[114578]=0;b=T(21,g|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(g);RE(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function js(a,b,c){var d=0,e=0,f=0;d=jb-32|0;jb=d;a:{if(!(!b|!c)){e=Ub(d,b);v[114578]=0;U(1568,d+16|0,e|0,c|0);f=v[114578];v[114578]=0;if((f|0)==1){break a}Gb(a+36|0,d+16|0);yb(d+16|0);yb(e)}jb=d+32|0;return(b|0)!=0&(c|0)!=0}a=P()|0;O()|0;yb(e);S(a|0);L()}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=jb-16|0;jb=e;mL(d,b,c<<24>>24);jb=e+16|0;b=d;c=Tb(d);e=Fb(d);v[114578]=0;W(196,a|0,c|0,e|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);jb=d+16|0;return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function uM(a,b,c){var d=0,e=0;d=(c|0)==1;c=v[(B(b,896)+a|0)+1075072>>2];a:{if(d&(c&134218752)!=0|c&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function sG(a,b){var c=0,d=0,e=0;o(+a);c=j(1)|0;d=j(0)|0;e=c;c=c>>>20&2047;if((c|0)!=2047){if(!c){c=b;if(a==0){b=0}else{a=sG(a*0x10000000000000000,b);b=v[b>>2]+-64|0}v[c>>2]=b;return a}v[b>>2]=c-1022;l(0,d|0);l(1,e&-2146435073|1071644672);a=+n()}return a}function PA(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;e=c;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;if(b>>>0<47){a=a+1|0}mb=a;return b}function Jaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;d=od(a);e=b,f=bc(a),v[e+8>>2]=f;e=b,f=cc(a),v[e>>2]=f;if(Jb(b+8|0,b)){c=+(d>>>0);while(1){a=v[b+8>>2];A[a>>3]=A[a>>3]/c;A[a+8>>3]=A[a+8>>3]/c;Tf(b+8|0);if(Jb(b+8|0,b)){continue}break}}jb=b+16|0}function zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,64);a:{if(d){kA(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b- -64|0;while(1){iu(b);b=b+2|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function z$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function v9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(!((c|0)!=-1?(c|0)!=4:0)){c=jb-16|0;jb=c;v[c+8>>2]=0;Lo(a,c+8|0);z[b>>2]=z[c+8>>2];jb=c+16|0;return}d=jb-16|0;jb=d;v[d+12>>2]=0;v[d+8>>2]=c;v[d+4>>2]=4;Xk(a,d+12|0,v[Lb(d+8|0,d+4|0)>>2]);v[b>>2]=0;jb=d+16|0}function ij(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=Tb(c);ri(b,a,Fb(c)+a|0);break c}LJ(d,c);v[114578]=0;U(115,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Lc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Lc(d);S(a|0);L()}}function du(a,b,c){var d=0,e=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-4;e=d|a<<1&2;if(a&2){t[b+12|0]=e|4;return}t[b+12|0]=e&251;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function dma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,64);a:{if(d){kA(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b- -64|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;mP(c+8|0,e);f=Hb(c+8|0);g=md(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){nP(e)}if(a){d=xP(b+8|0)}jb=b+160|0;return d|0}function hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-624|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;oT(c+8|0,e);f=Hb(c+8|0);g=md(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){pT(e)}if(a){d=qT(b+8|0)}jb=b+624|0;return d|0}function bs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=Tb(c);ri(b,a,Fb(c)+a|0);break c}$J(d,b,c);v[114578]=0;R(116,a|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}Lc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Lc(d);S(a|0);L()}}function aka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;bu(c+8|0,e);f=Hb(c+8|0);g=md(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){JA(e)}if(a){d=DR(b+8|0)}jb=b+16|0;return d|0}
function Eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,27);a:{if(d){qN(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+27|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function yB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,16);a:{if(d){gB(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+16|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function hG(a){var b=0,c=0;b=w[a+74|0];t[a+74|0]=b-1|b;if(y[a+20>>2]>y[a+28>>2]){nb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function Oz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Oi(a+8|0);v[114578]=0;d=T(332,b|0)|0;e=v[114578];v[114578]=0;b:{if((e|0)==1){break b}v[114578]=0;U(423,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;Pg(c);S(a|0);L()}}function Cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;Jt(c+8|0,e);f=Hb(c+8|0);g=md(a,ac(c,c+8|0));if((f|0)==(g|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(f|0)==(g|0);if(!a){OS(e)}if(a){d=RS(b+8|0)}jb=b+32|0;return d|0}function iia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,6);a:{if(d){_z(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+6|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function eja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,2);a:{if(d){Pk(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+2|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function Sr(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[114578]=0;T(1404,c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){ld(a+68|0);rf(a+36|0);wf(a+32|0);Gh(b);Yc(a+4|0);Yc(a);return a}V(0)|0;O()|0;ld(a+68|0);rf(a+36|0);wf(a+32|0);Gh(b);Yc(a+4|0);Yc(a);Ab();L()}function Gx(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=su(f,c);d=a+1074308|0;Eb(e+8|0,d,31);a=0;if(!Cb(e+8|0)){Eb(e,d,93);a=Cb(e)^1}if(!(t[bL(b,c)|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=nd(f)^1}jb=e+16|0;return d}function Gma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=b^d;h=e>>31;f=b>>31;a=a^f;i=a-f|0;g=b;b=b>>31;g=(g^b)-((a>>>0<f>>>0)+b|0)|0;a=d>>31;b=c^a;c=d>>31;e=e>>31;a=Ima(i,g,b-a|0,(c^d)-((a>>>0>b>>>0)+c|0)|0)^e;b=a-e|0;mb=(h^mb)-((a>>>0<e>>>0)+h|0)|0;return b}function uB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,3);a:{if(d){mu(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+3|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function jia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,1030);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,1030);jb=c+16|0}return a|0}function hz(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[fc(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function CT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Qb(a,8);a:{if(d){Mu(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;e=jb-16|0;jb=e;f=b+8|0;while(1){ff(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=e+16|0;jb=a+16|0}jb=c+16|0;return d|0}function tka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Mj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(xd(a,5)){break a}}gS(v[a+28>>2],b,v[e+24>>2],0)}Zi(a,d,c,e+16|0);jb=e+32|0}function tga(a,b){a=a|0;b=b|0;var c=0,d=0;c=iy(a);a:{if(!b){break a}v[114578]=0;R(406,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(1054,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;As(c);S(a|0);L()}return a|0}function i_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;Bc(a,d);v[114578]=0;b=T(2456,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(a);NE(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Ob(a);S(b|0);L()}function $K(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(!b){break a}g=c;h=c>>31;c=1;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=yc(Gma(Fma(d,d>>31,g,h),mb,256,0),mb);v[a+4>>2]=f-d;v[a>>2]=d+f;if((b|0)==(c|0)){break a}a=a+8|0;c=c+1|0;continue}}}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,274);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,274);jb=c+16|0}return a|0}function raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,225);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,225);jb=c+16|0}return a|0}function pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,106);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,106);jb=c+16|0}return a|0}function naa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,326);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,326);jb=c+16|0}return a|0}function gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,422);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,422);jb=c+16|0}return a|0}function eo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Kc(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Tb(a);xh(d+e|0,b,c);b=c+e|0;Sg(a,b);t[f+15|0]=0;he(b+d|0,f+15|0);break a}Tu(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function cja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,826);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,826);jb=c+16|0}return a|0}function cL(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=7;v[b+8>>2]=32;c=0;a:{if(!v[Lb(b+12|0,b+8|0)>>2]){break a}c=15;while(1){d=_o(a);v[b+12>>2]=7;v[b+8>>2]=32;if(c>>>0<y[Lb(b+12|0,b+8|0)>>2]){c=c+15|0;continue}break}c=d&127}jb=b+16|0;return c}function Xj(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function OM(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=Db(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+85376|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function sU(a,b){a=a|0;b=b|0;var c=0,d=0;c=pB(a);a:{if(!b){break a}v[114578]=0;R(408,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(409,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;nB(c);S(a|0);L()}return a|0}function pS(a,b){a=a|0;b=b|0;var c=0,d=0;c=Gu(a);a:{if(!b){break a}v[114578]=0;R(563,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(669,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;pq(c);S(a|0);L()}return a|0}function o_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;Bc(a,d);v[114578]=0;b=T(21,a|0)|0;d=v[114578];v[114578]=0;if((d|0)!=1){Ob(a);QE(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Ob(a);S(b|0);L()}function lR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,284);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,284);jb=c+16|0}return a|0}function Dba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;if(!(!a|!b)){g=ys(a);f=jb-16|0;jb=f;d=ys(a);a=d;c=ys(b);if(c){while(1){a=c;c=(d>>>0)%(a>>>0)|0;d=a;if(c){continue}break}}jb=f+16|0;c=B(ys(b),(g|0)/(a|0)|0)}jb=e+16|0;return c|0}function wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,34);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,34);jb=c+16|0}return a|0}function uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,73);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,73);jb=c+16|0}return a|0}function tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,42);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,42);jb=c+16|0}return a|0}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,72);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,72);jb=c+16|0}return a|0}function lla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;g=b;zS(c+8|0,b);e=Hb(c+8|0);f=md(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(e|0)==(f|0);if(!a){AS(g)}if(a){d=CS(b)}jb=b+160|0;return d|0}function laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,60);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,60);jb=c+16|0}return a|0}function gga(a){a=a|0;var b=0,c=0,d=0,e=0;c=AO(a);if((c|0)!=(a|0)){while(1){b=0;e=a;dS(a);a:{while(1){d=b+e|0;if(w[d|0]){b=b+1|0;if((b|0)!=32){continue}break a}break}if(b>>>0>31){break a}Rb(d,0,32-b|0)}a=a+32|0;if((c|0)!=(a|0)){continue}break}}}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-208|0;jb=b;d=-1;c=jb-16|0;jb=c;g=b;VO(c+8|0,b);e=Hb(c+8|0);f=md(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(e|0)==(f|0);if(!a){WO(g)}if(a){d=_O(b)}jb=b+208|0;return d|0}function Xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,91);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,91);jb=c+16|0}return a|0}function Sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,71);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,71);jb=c+16|0}return a|0}function Pka(a,b){a=a|0;b=b|0;var c=0,d=0;c=cB(a);a:{if(!b){break a}v[114578]=0;R(36,a|0,b|0);d=v[114578];v[114578]=0;if((d|0)!=1){v[114578]=0;R(37,a|0,b|0);b=v[114578];v[114578]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;IA(c);S(a|0);L()}return a|0}function Me(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Oi(a+8|0);v[114578]=0;U(423,a|0,b|0,c|0);c=v[114578];v[114578]=0;a:{if((c|0)!=1){a=v[a>>2];v[114578]=0;Q(340,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Pg(d);S(a|0);L()}}function KN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=MN(b,zb(c));v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];d=v[zb(c)>>2];e=zb(a),f=d,v[e>>2]=f;e=zb(c),f=0,v[e>>2]=f;v[c>>2]=0;v[c+4>>2]=0;cd(b+12|0,c+12|0);u[b+28>>1]=x[c+28>>1];v[b+24>>2]=v[c+24>>2]}function I_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=Ah(e,e+12|0);v[114578]=0;a=W(2477,a|0,c|0,v[e+8>>2])|0;c=v[114578];v[114578]=0;if((c|0)!=1){Ie(b);jb=e+16|0;return a|0}a=P()|0;O()|0;Ie(b);S(a|0);L()}function A9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Mj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(xd(a,5)){break a}}YJ(v[a+28>>2],b,v[e+24>>2])}Zi(a,d,c,e+16|0);jb=e+32|0}function yN(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(w[a+530|0]){while(1){d=c&65535;Mh(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;Th(a+4|0,18,b+15|0);yz(a+22|0,18,20106);t[b+14|0]=255;Th(a+58|0,256,b+14|0);jb=b+16|0}function le(){var a=0,b=0;a:{b:{if(t[461636]&1){break b}if(!wd(461636)){break b}v[114578]=0;a=W(2454,2147483647,64693,0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}v[115408]=a;vd(461636)}return v[115408]}a=P()|0;O()|0;pe(461636);S(a|0);L()}function HT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,50);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,50);jb=c+16|0}return a|0}function Gla(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!cA(a,b+16|0)){break a}c=0;if(!TS(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!Xc(a,4)){break a}}c=-1;if(!Jj(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}jb=b+32|0;return c|0}function DC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;cd(b,c);bm(b+12|0,c+12|0);a=jb-16|0;jb=a;c=c+28|0;d=a,e=Nd(c),v[d+12>>2]=e;v[114578]=0;W(282,b+28|0,a+12|0,c|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}}function wo(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function zU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-48|0;jb=b;d=-1;c=jb-16|0;jb=c;g=b;hB(c+8|0,b);e=Hb(c+8|0);f=md(a,ac(c,c+8|0));if((e|0)==(f|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(e|0)==(f|0);if(!a){iB(g)}if(a){d=AB(b)}jb=b+48|0;return d|0}function kba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;b=(b-a|0)/160|0;if((b|0)>=1){while(1){f=a;d=c;v[a>>2]=v[d>>2];e=a+4|0;if((e|0)!=(d+4|0)){oL(e,v[d+4>>2],v[d+8>>2])}lc(f+16|0,d+16|0,144);a=a+160|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function zd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){break a}c=c+1|0;if((g|0)!=(c|0)){continue}break}}return}u[a+20>>1]=c-d}function Qy(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>357913941){Fc(17388);L()}f=sc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,12)+f|0,v[g>>2]=h;jb=e+16|0;return a}function MM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[bd(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=BM(c&255),v[e+44>>2]=f}jb=d+16|0}function xE(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>357913941){Fc(6863);L()}f=sc(B(d,12),4)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,12)+f|0,v[g>>2]=h;jb=e+16|0;return a}function YS(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>89478485){Fc(12706);L()}f=sc(B(d,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,48)+f|0,v[g>>2]=h;jb=e+16|0;return a}function YE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){of(a,c);d=a;break a}f=Vk(d)+1|0;d=ai(f);Ef(a,d);Fg(a,f);we(a,c)}xh(d,b,c);t[e+15|0]=0;he(c+d|0,e+15|0);jb=e+16|0;return}Hg();L()}function CE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a:{a=Jb(d+24|0,d+16|0);if(!a){break a}if(!rl(v[d+24>>2],v[d+8>>2])){break a}_d(d+24|0);_d(d+8|0);continue}break}jb=d+32|0;return a^1}function u6(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;b=b+4|0;d=v[b+48>>2];a:{if(d&16){if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}ri(a,v[b+20>>2],v[b+44>>2]);break a}if(d&8){ri(a,v[b+8>>2],v[b+16>>2]);break a}xw(a,c+8|0)}jb=c+32|0}function QD(a){var b=0,c=0,d=0;b=a;c=v[a+4>>2];a:{while(1){if(v[b+8>>2]==(c|0)){break a}v[b+8>>2]=v[b+8>>2]-4;v[114578]=0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){TD(v[a+16>>2],v[a>>2],sg(a))}}function LD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(a-b>>2>>>0<c>>>0){while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break a}}if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function wT(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>2147483647){Fc(12489);L()}f=sc(d<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<1)+f|0,v[g>>2]=h;jb=e+16|0;return a}function pC(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){Fc(11561);L()}f=sc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function jp(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-Sd(A[Uk(a,c)>>3]*131072*f);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Ve(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function iJ(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){d=b;if(b>>>0>1073741823){Fc(33245);L()}f=sc(d<<2,4)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;mu(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;jb=c+16|0}return a|0}function Tga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(lg(a)>>>0<b>>>0){d=zb(a);b=Qy(c+8|0,b,wc(a),d);v[114578]=0;R(1015,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}et(b)}jb=c+32|0;return}a=P()|0;O()|0;et(b);S(a|0);L()}function Gaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(lg(a)>>>0<b>>>0){d=zb(a);b=RM(c+8|0,b,wc(a),d);v[114578]=0;R(1255,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Is(b)}jb=c+32|0;return}a=P()|0;O()|0;Is(b);S(a|0);L()}function sja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(Uf(a)>>>0<b>>>0){d=zb(a);b=fq(c+8|0,b,oc(a),d);v[114578]=0;R(382,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Dj(b)}jb=c+32|0;return}a=P()|0;O()|0;Dj(b);S(a|0);L()}function jja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(yf(a)>>>0<b>>>0){d=zb(a);b=nh(c+8|0,b,Ac(a),d);v[114578]=0;R(366,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}Rg(b)}jb=c+32|0;return}a=P()|0;O()|0;Rg(b);S(a|0);L()}function go(a,b){var c=0;c=b+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a:{b:{b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b>>>0>=Ac(a)>>>0){break b}if(Ac(a)>>>0<c>>>0){break b}a=c>>>0<=Ac(a)-b>>>0;break a}a=0}return a}function g8(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(yd(a)>>>0<b>>>0){d=zb(a);b=iJ(c+8|0,b,Kb(a),d);v[114578]=0;R(1759,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}_r(b)}jb=c+32|0;return}a=P()|0;O()|0;_r(b);S(a|0);L()}function fV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(yd(a)>>>0<b>>>0){d=zb(a);b=pC(c+8|0,b,Kb(a),d);v[114578]=0;R(345,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}vq(b)}jb=c+32|0;return}a=P()|0;O()|0;vq(b);S(a|0);L()}function Jja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;BR(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-33|0,33)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Bk(a);Jl(a);Jl(a)}function Ila(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;WS(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Ni(a);Ml(a);Ml(a)}function o9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=0;a:{if(!Kb(a)){break a}while(1){Af(d,v[Pb(a,e)>>2]+40|0);c=Hp(d,b);yb(d);if(c){c=v[Pb(a,e)>>2];break a}e=e+1|0;if(Kb(a)>>>0>e>>>0){continue}break}c=0}jb=d+16|0;return c|0}function a7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=12){ae(d+12|0,C(0));c=z[d+12>>2];if((b|0)==12){c=C(je(C(c*C(3)))*C(.3333333432674408));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}jb=d+16|0}function Z7(a){a=a|0;var b=0;nb[v[v[a>>2]+124>>2]](a);bx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=nb[v[v[a>>2]+188>>2]](a)|0;v[a+4272>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4292>>2]=b;v[a+4288>>2]=b;v[a+4284>>2]=b;v[a+4280>>2]=b}function X1(a){a=a|0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<y[a+44>>2]){Nm(a,v[a+8>>2],v[a+12>>2],v[a+44>>2])}if(y[a+12>>2]>=y[a+16>>2]){break a}return Cg(t[v[a+12>>2]])|0}return-1}function mg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function iL(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;v[b>>2]=(B(a,v[b>>2])|0)/65536;return}if(v[a+696>>2]){break a}v[b>>2]=0}}function Zka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;a:{if(b){Ub(c,b);break a}Wb(c)}v[114578]=0;R(665,c+16|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){cd(a,c+16|0);yb(c+16|0);yb(c);jb=c+32|0;return a|0}a=P()|0;O()|0;yb(c);S(a|0);L()}function I0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=_i(b,4,c,v[a+32>>2])}return c|0}function hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;b=KQ(d,b);e=jb-16|0;jb=e;b=KQ(e,b);f=jb-16|0;jb=f;Oq(d+8|0,v[b>>2],v[b>>2]+DQ(b)|0);jb=f+16|0;jb=e+16|0;Xu(a,d+8|0);v[a+12>>2]=c;v[a+8>>2]=0;jb=d+16|0;return a|0}function dD(){var a=0,b=0,c=0;b=jb-16|0;jb=b;a=Ub(b,10940);a:{if(!Fb(a)){break a}c=1;if((Yf(a,10946)|0)!=-1){break a}if((Yf(a,10948)|0)!=-1){break a}if((Yf(a,10952)|0)!=-1){break a}c=(Yf(a,10954)|0)!=-1}yb(a);jb=b+16|0;return c|0}function PL(a,b){a=a|0;b=b|0;KL(a);KL(a+368680|0);if(b){WK(a,1);return a|0}UK();gf(219584,285120,a+131112|0);gf(285120,350656,a+196648|0);gf(350656,416192,a+262184|0);gf(88496,219584,a+24|0);lc(a+327720|0,416192,40960);return a|0}function Kf(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[Ve(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function GM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=jb-16|0;jb=a;d=v[b+104>>2];if(d){v[b+88>>2]=v[b+88>>2]&-131|128;d=v[d>>2];v[b+76>>2]=d;v[a+12>>2]=c<<8;v[a+8>>2]=d-1;c=d+(v[Lb(a+12|0,a+8|0)>>2]^-1)|0;v[b>>2]=0;v[b+4>>2]=c}jb=a+16|0}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;aj(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];po(a,wc(a))}function wd(a){var b=0,c=0,d=0;c=jb-16|0;jb=c;a=tv(c,a);d=jb-16|0;jb=d;if(!w[v[Qc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}jb=d+16|0;jb=c+16|0;return b}function pP(a,b){var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=SP(c+8|0,c);jb=c+32|0;return a}function e2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Ph(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-24|0,24)|0;v[c>>2]=f;if((d|0)>=1){lc(f,e,d)}Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Wt(a,Id(a))}function pga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=4896;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Gz(d,b);xg(a,v[d>>2],c);Gz(d,b);Rb(v[d>>2]+c|0,0,4896-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function Z2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function Y2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function TS(a){if(!((w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1179472708?(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179011410:0)){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}return 1}function Rs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;if(b){e=Kc(a);d=Fb(a);g=d+b|0;if(e-d>>>0<b>>>0){Rl(a,e,g-e|0,d,d,0,0)}e=d;d=Tb(a);wy(e+d|0,b,c);Sg(a,g);t[f+15|0]=0;he(d+g|0,f+15|0)}jb=f+16|0;return a|0}function LC(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;jb=b+16|0}function iE(){var a=0;a:{b:{if(t[461648]&1){break b}if(!wd(461648)){break b}v[114578]=0;da(2558)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115411]=461640;vd(461648)}return v[115411]}a=P()|0;O()|0;pe(461648);S(a|0);L()}function hI(a,b){a=a|0;b=b|0;var c=0;a:{c=Pe(8);_H(c);v[c+4>>2]=b;v[c>>2]=83800;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(2140,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}}function SY(){var a=0;a:{b:{if(t[461660]&1){break b}if(!wd(461660)){break b}v[114578]=0;da(2562)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115414]=461652;vd(461660)}return v[115414]}a=P()|0;O()|0;pe(461660);S(a|0);L()}function vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=263;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}GO(d,b);xg(a,v[d>>2],c);GO(d,b);Rb(v[d>>2]+c|0,0,263-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function tR(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=qe(d,a,1);a=zb(a);e=v[c+4>>2];v[114578]=0;U(767,a|0,e|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function qs(a,b){var c=0;c=79244;a:{b:{c:{switch(b-2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=79260;break a;case 2:c=79256;break a;case 1:break b;case 0:break c}}c=79252;break a}c=79248}v[a>>2]=v[c>>2]}function X3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;v[e>>2]=83696;v[e>>2]=83652;v[114578]=0;a=aa(2155,a|0,b|0,c|0,e|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=d+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function D$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=qr(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=pd(c);v[f>>2]=a;if(!a){break a}e=qr(a,c,b,v[d+12>>2])}jb=d+16|0;return e|0}function zg(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;c=Ub(b,11931);v[114578]=0;Q(380,a+9|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=b+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function _aa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a+480180>>2]=b;FL(c,Vo(a));d=v[c+12>>2];b=a+1074316|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074308>>2]=v[c>>2];v[a+1074312>>2]=b;qs(a+8|0,Vo(a));jb=c+16|0}function _2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function Yaa(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function OD(a,b){var c=0,d=0;c=jb-32|0;jb=c;a:{if(yf(a)>>>0<b>>>0){d=zb(a);b=nh(c+8|0,b,Ac(a),d);v[114578]=0;R(209,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}nm(b)}jb=c+32|0;return}a=P()|0;O()|0;nm(b);S(a|0);L()}function ID(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(c>>>0<=1073741807){a:{if(c>>>0<=1){of(a,c);e=a;break a}f=sm(c)+1|0;e=rm(f);Ef(a,e);Fg(a,f);we(a,c)}hi(e,b,c);v[d+12>>2]=0;Te((c<<2)+e|0,d+12|0);jb=d+16|0;return}Hg();L()}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Ce(b);c=OO(d+8|0,c);v[114578]=0;fa(1030,a|0,b|0,0,e-1&65535,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){ke(c);jb=d+32|0;return}a=P()|0;O()|0;ke(c);S(a|0);L()}function $2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=(b|0)){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function zA(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;a:{if(Qb(a,512)){_t(c+8|0,b);Bd(a,c+8|0);break a}a=jb-16|0;jb=a;d=jb-16|0;jb=d;e=b+512|0;while(1){Zt(b);b=b+4|0;if((e|0)!=(b|0)){continue}break}jb=d+16|0;jb=a+16|0}jb=c+16|0}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=22;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Jt(d,b);xg(a,v[d>>2],c);Jt(d,b);Rb(v[d>>2]+c|0,0,22-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function vja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=40;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}wz(d,b);xg(a,v[d>>2],c);wz(d,b);Rb(v[d>>2]+c|0,0,40-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function fN(a,b){var c=0,d=0;c=jb-32|0;jb=c;a:{if(yd(a)>>>0<b>>>0){d=zb(a);b=ms(c+8|0,b,Kb(a),d);v[114578]=0;R(96,a|0,b|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}nk(b)}jb=c+32|0;return}a=P()|0;O()|0;nk(b);S(a|0);L()}function IE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a=Jb(d+24|0,d+16|0);if(!(!a|w[v[d+24>>2]]!=w[v[d+8>>2]])){qg(d+24|0);qg(d+8|0);continue}break}jb=d+32|0;return a^1}function zH(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-24|0;R(2207,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function t8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=33;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Bz(d,b);xg(a,v[d>>2],c);Bz(d,b);Rb(v[d>>2]+c|0,0,33-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function oX(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Ht(b,70468)){FD(c,70481,b);a=Tb(c);v[114578]=0;R(2825,44,a|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);S(a|0);L()}jb=c+16|0;return a|0}L()}function kz(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-1024|0;jb=e;d=jb-16|0;jb=d;gz(d+8|0,e);f=Hb(d+8|0);g=nc(a,ac(d,d+8|0));if((f|0)==(g|0)){$b(a,Hb(d+8|0))}jb=d+16|0;if((f|0)==(g|0)){h=hz(e,c)>>>0<=b>>>0}jb=e+1024|0;return h}function ZX(a){a=a|0;a:{b:{if(t[461736]&1){break b}if(!wd(461736)){break b}v[114578]=0;Y(2577);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115433]=461920;vd(461736)}return v[115433]}a=P()|0;O()|0;pe(461736);S(a|0);L()}function XO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-12|0;R(1023,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function WX(a){a=a|0;a:{b:{if(t[461744]&1){break b}if(!wd(461744)){break b}v[114578]=0;Y(2579);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115435]=462096;vd(461744)}return v[115435]}a=P()|0;O()|0;pe(461744);S(a|0);L()}function TX(a){a=a|0;a:{b:{if(t[461752]&1){break b}if(!wd(461752)){break b}v[114578]=0;Y(2581);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115437]=462272;vd(461752)}return v[115437]}a=P()|0;O()|0;pe(461752);S(a|0);L()}function QX(a){a=a|0;a:{b:{if(t[461760]&1){break b}if(!wd(461760)){break b}v[114578]=0;Y(2583);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115439]=462576;vd(461760)}return v[115439]}a=P()|0;O()|0;pe(461760);S(a|0);L()}function NX(a){a=a|0;a:{b:{if(t[461768]&1){break b}if(!wd(461768)){break b}v[114578]=0;Y(2585);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115441]=462880;vd(461768)}return v[115441]}a=P()|0;O()|0;pe(461768);S(a|0);L()}function KX(a){a=a|0;a:{b:{if(t[461776]&1){break b}if(!wd(461776)){break b}v[114578]=0;Y(2587);a=v[114578];v[114578]=0;if((a|0)==1){break a}v[115443]=462912;vd(461776)}return v[115443]}a=P()|0;O()|0;pe(461776);S(a|0);L()}function IK(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-24|0;R(1561,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function Er(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!tw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Ae(a)}return b}ha(50578,50496,1563,50598);L()}function Co(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=Fb(a);if(c>>>0<b>>>0){Rs(a,b-c|0,0);break a}c=jb-16|0;jb=c;b:{if(Fe(a)){d=v[a>>2];t[c+15|0]=0;he(b+d|0,c+15|0);we(a,b);break b}t[c+14|0]=0;he(a+b|0,c+14|0);of(a,b)}jb=c+16|0}}function yba(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function wP(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-24|0;R(984,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function gO(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){c=v[a>>2];v[114578]=0;R(822,c|0,b+14|0);c=v[114578];v[114578]=0;if((c|0)==1){break b}}if(b){Xi(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function dP(a,b,c){var d=0;d=jb-16|0;jb=d;t[d+15|0]=a;a=0;if(!(c>>>0>108|b>>>0>108|(c>>>0<25|b>>>0<25)|b>>>0>=c>>>0)){t[d+14|0]=(x[(b<<1)+20798>>1]-x[(c<<1)+20798>>1]|0)/5;a=w[pc(d+15|0,d+14|0)|0]}jb=d+16|0;return a&255}function XC(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-32|0;R(276,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function Sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=0;a:{if(!a){break a}e=a|-16;if(!(a>>>0<16&c?0:b>>>0>=2)){break a}t[d+15|0]=1;t[d+14|0]=(a|0)/(b-1|0);e=w[qh(d+15|0,d+14|0)|0]}a=e;jb=d+16|0;return a&255}function QS(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];c=PS(a);d=jb-16|0;jb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=Jd(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}jb=d+16|0;return v[b>>2]}function QQ(a){var b=0;a:{if(qd(a,15547,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}return w[a+3|0]<6}return 0}function LO(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function IO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-4|0;R(1059,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function $x(a,b){var c=0,d=0;c=B(b,896)+a|0;a:{if(v[c+1075072>>2]&134218752){break a}if(!nj(c+1074984|0)){break a}b=w[v[(B(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function xT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114578]=0;b=b-2|0;R(532,c|0,b|0);c=v[114578];v[114578]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function qY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Ah(e+8|0,e+12|0);v[114578]=0;a=dF(a,b,c);b=v[114578];v[114578]=0;if((b|0)!=1){Ie(d);jb=e+16|0;return a|0}a=P()|0;O()|0;Ie(d);S(a|0);L()}function Tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Gz(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,4896);jb=c+16|0}return a|0}function Pba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=(v[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(vo(b)+-4.8737671609324025),A[d+8>>3]=e;Rf(c+8|0,0,127);a=st(A[c+8>>3]);jb=c+16|0;return a|0}function pL(a,b){var c=0,d=0,e=0;d=a;c=jb-16|0;jb=c;Qc(c+8|0,b+116|0);v[114578]=0;b=Na(198,b|0)|0;O()|0;b=b|0;e=v[114578];v[114578]=0;a:{if((e|0)!=1){jb=c+16|0;break a}a=P()|0;O()|0;S(a|0);L()}v[d>>2]=b;_o(a);return a}function mL(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(b>>>0<=4294967279){a:{if(b>>>0<=10){of(a,b);e=a;break a}f=Vk(b)+1|0;e=ai(f);Ef(a,e);Fg(a,f);we(a,b)}wy(e,b,c);t[d+15|0]=0;he(b+e|0,d+15|0);jb=d+16|0;return}Hg();L()}function gp(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){of(a,c);e=a;break a}f=Vk(c)+1|0;e=ai(f);Ef(a,e);Fg(a,f);we(a,c)}xh(e,b,c);t[d+15|0]=0;he(c+e|0,d+15|0);jb=d+16|0;return}Hg();L()}function gP(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function Qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;u[a+34>>1]=0;d=jb-16|0;jb=d;e=jb-16|0;jb=e;c=a+43|0;f=c+22|0;while(1){ff(c);c=c+1|0;if((f|0)!=(c|0)){continue}break}jb=e+16|0;jb=d+16|0;v[a+20>>2]=0;Fd(a,b);return a|0}function Hba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Jb(d+16|0,d+24|0)){while(1){v[d+12>>2]=v[v[d+16>>2]>>2];ky(a,d+12|0);_d(d+16|0);if(Jb(d+16|0,d+24|0)){continue}break}}jb=d+32|0}function Fda(a){a=a|0;var b=0;v[a>>2]=0;a:{if(t[87428]&1){break a}if(!wd(87428)){break a}v[114578]=0;T(1209,87424)|0;b=v[114578];v[114578]=0;if((b|0)!=1){vd(87428);break a}a=P()|0;O()|0;pe(87428);S(a|0);L()}return a|0}function AN(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function sga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;wz(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,40);jb=c+16|0}return a|0}function nn(a){a=a|0;Cc(a+16|0,v[a>>2]);Cc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function l3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=bl(e,a,d);a=zb(a);v[114578]=0;X(2182,a|0,b|0,c|0,d+4|0);a=v[114578];v[114578]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function k4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=lm(e,a,d);a=zb(a);v[114578]=0;X(2125,a|0,b|0,c|0,d+4|0);a=v[114578];v[114578]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Fma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;mb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function BB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;gc(c+8|0,b,37);jb=d+16|0;d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;if((d|0)!=(e|0)){a=jb-16|0;jb=a;Rb(b,0,37);jb=a+16|0}}function $C(a){var b=0;a:{b=a+2|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+4|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<2147483649}return 0}function xX(a){a=a|0;a:{b:{if(t[461872]&1){break b}if(!wd(461872)){break b}v[114578]=0;Q(2590,461860,65076)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461872)}return 461860}a=P()|0;O()|0;pe(461872);S(a|0);L()}function uw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!Dr(a)){break a}if(!(t[a+1375|0]&1)){continue}break}dc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function tX(a){a=a|0;a:{b:{if(t[461904]&1){break b}if(!wd(461904)){break b}v[114578]=0;Q(2590,461892,65172)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461904)}return 461892}a=P()|0;O()|0;pe(461904);S(a|0);L()}function o2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;bo(a);v[a>>2]=83720;d=uh(c+8|0);b=uh(b);v[114578]=0;W(2203,a+12|0,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function n2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;bo(a);v[a>>2]=83760;d=uh(c+8|0);b=uh(b);v[114578]=0;W(2205,a+12|0,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Op(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;kA(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Rb(b,0,64);jb=c+16|0}return a|0}function FX(a){a=a|0;a:{b:{if(t[461808]&1){break b}if(!wd(461808)){break b}v[114578]=0;Q(2590,461796,64968)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461808)}return 461796}a=P()|0;O()|0;pe(461808);S(a|0);L()}function BX(a){a=a|0;a:{b:{if(t[461840]&1){break b}if(!wd(461840)){break b}v[114578]=0;Q(2590,461828,65016)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461840)}return 461828}a=P()|0;O()|0;pe(461840);S(a|0);L()}function kN(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=c*A[a+8>>3]+A[a>>3]*b+e*A[a+16>>3]-(f*A[a+32>>3]+d*A[a+24>>3]);A[a+56>>3]=b;return b}function jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;vf(a);e=v[b+4>>2];d=b+4|0;Oh(zb(a),v[a>>2],c,d);f=c;c=b+8|0;Mk(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mk(a,Kb(a));return e|0}function baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;Pt(a);e=v[b+4>>2];d=b+4|0;HR(zb(a),v[a>>2],c,d);f=c;c=b+8|0;sK(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Rt(a,bg(a));return e|0}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;Ol(a);e=v[b+4>>2];d=b+4|0;Oh(zb(a),v[a>>2],c,d);f=c;c=b+8|0;Mk(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];gA(a,Ac(a));return e|0}function KV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;bo(a);v[a>>2]=76920;d=uh(c+8|0);b=uh(b);v[114578]=0;W(275,a+12|0,d|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Bda(a){a=a|0;var b=0,c=0,d=0,e=0;while(1){c=(b&255)<<24;d=1;while(1){e=c<<1;c=(c|0)>-1?e:e^79764919;if((d|0)!=8){d=d+1|0;continue}break}v[(b<<2)+87440>>2]=c;b=b+1|0;if((b|0)!=256){continue}break}return a|0}function $s(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;Eb(d+8|0,c+1074308|0,102);a:{if(!Cb(d+8|0)){break a}c=x[a+692>>1]+1|0;u[a+796>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+796>>1]=c|32768}v[a+692>>2]=b;jb=d+16|0}function zX(a){a=a|0;a:{b:{if(t[461856]&1){break b}if(!wd(461856)){break b}v[114578]=0;Q(85,461844,65052)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461856)}return 461844}a=P()|0;O()|0;pe(461856);S(a|0);L()}function vX(a){a=a|0;a:{b:{if(t[461888]&1){break b}if(!wd(461888)){break b}v[114578]=0;Q(85,461876,65160)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461888)}return 461876}a=P()|0;O()|0;pe(461888);S(a|0);L()}function vT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;Rk(a);e=v[b+4>>2];d=b+4|0;Oh(zb(a),v[a>>2],c,d);f=c;c=b+8|0;Mk(zb(a),f,v[a+4>>2],c);Zb(a,d);Zb(a+4|0,c);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Eu(a,oc(a));return e|0}function Ig(a){var b=0;v[114578]=0;a=T(1400,a|0)|0;b=v[114578];v[114578]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;Y(20);b=v[114578];v[114578]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Ab();L()}function Hm(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=d*(c*.13339200271297674+.3333313950307914)+a;a=c*c;a=e+d*a*(c*.024528318116654728+.05338123784456704+a*(c*.009465647849436732+.002974357433599673));return C(b?-1/a:a)}function HX(a){a=a|0;a:{b:{if(t[461792]&1){break b}if(!wd(461792)){break b}v[114578]=0;Q(85,461780,64956)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461792)}return 461780}a=P()|0;O()|0;pe(461792);S(a|0);L()}function DX(a){a=a|0;a:{b:{if(t[461824]&1){break b}if(!wd(461824)){break b}v[114578]=0;Q(85,461812,65004)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(461824)}return 461812}a=P()|0;O()|0;pe(461824);S(a|0);L()}function xF(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=nb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!ve(b,-1)){break a}v[a>>2]=0}return a|0}function nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;a=v[a+1304560>>2];a:{if(a){nb[v[v[a>>2]+8>>2]](a,b,c);break a}if(v[19056]<(b|0)){break a}GL(d+8|0,20495,20516,132);YC(d+24|0,d+8|0,b,20486,c)}jb=d+32|0}function KM(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=c&15;if(e){t[b+844|0]=e}c=c&240;if(c){t[b+843|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Eb(d+8|0,a+1074308|0,80);if(!(!e|!Cb(d+8|0))){t[b+844|0]=w[b+844|0]<<2}jb=d+16|0}function Kx(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}lc(a+24604|0,b,40);lL(a,c)}function Cn(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a:{if(c){Ub(d,c);break a}Wb(d)}v[114578]=0;U(13,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function GV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=0;f=v[a+8>>2];if(f>>>0>c>>>0){v[e+8>>2]=f-c;d=Lb(e+8|0,e+12|0);a=v[a+4>>2]+c|0;d=v[d>>2];gf(a,a+d|0,b)}jb=e+16|0;return d|0}function CJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2048|0;R(1652,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function aC(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=2147483647;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function _v(a){a=a|0;var b=0;v[a>>2]=59048;v[114578]=0;R(2374,a|0,0);b=v[114578];v[114578]=0;if((b|0)!=1){Ob(a+28|0);Xb(v[a+32>>2]);Xb(v[a+36>>2]);Xb(v[a+48>>2]);Xb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Ab();L()}function Ym(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=1073741823;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function Nda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e>>2]=c;v[e+8>>2]=b;if(Jb(e+8|0,e)){while(1){Mn(a,v[d>>2],v[e+8>>2]);te(e+8|0);v[d>>2]=v[d>>2]+2;if(Jb(e+8|0,e)){continue}break}}jb=e+16|0}function Jx(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;kL(a+24648|0);yL(a)}function sT(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=178956970;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function qm(a,b,c){var d=0,e=0;d=Jd(b,a);e=Jd(c,b);a:{b:{if(!d){d=0;if(!e){break a}Zb(b,c);d=1;if(!Jd(b,a)){break a}Zb(a,b);break b}if(e){Zb(a,c);return 1}Zb(a,b);d=1;if(!Jd(c,b)){break a}Zb(b,c)}d=2}return d}function qL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-52|0;R(1439,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function qE(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=357913941;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function pv(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function nh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=ai(b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=b+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function jla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;nb[g|0](a,b,e,d);jb=e+16|0}function e_(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=a;b=v[a+112>>2];a:{if((b|0)<=10){c=b+1|0;break a}e=a;b=378;while(1){JE(e);c=f-(b>>>0<1)|0;b=b-1|0;f=c;if(b|c){continue}break}c=1}v[d+112>>2]=c;a=JE(a);return a|0}function dA(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=715827882;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function ZL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-24|0;R(1381,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function YM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-12|0;R(1236,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function UO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-12|0;R(1022,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Qu(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=536870911;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function ON(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-32|0;R(1194,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Lq(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=268435455;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function FC(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=134217727;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function Br(a){var b=0;if(a){if(v[a+76>>2]<=-1){return ow(a)}return ow(a)}if(v[21290]){b=Br(v[21290])}a=v[114557];if(a){while(1){if(y[a+20>>2]>y[a+28>>2]){b=ow(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}function yR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-33|0;R(766,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function yJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(1654,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function xV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;b=Tk(e+8|0,b);v[114578]=0;X(284,a|0,b|0,c|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){Bb(b);jb=e+16|0;return}a=P()|0;O()|0;Bb(b);S(a|0);L()}function nD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-16|0;R(217,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function jK(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=82595524;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function WA(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-16|0;R(428,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Eaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=Ih(a),v[g>>2]=h;Ih(a);if(f>>>0>=60){$b(a,4)}g=e,h=Ih(a),v[g>>2]=h;$b(a,4);b=Ih(a);v[d>>2]=b;if((b|0)>=1){g=c,h=Ih(a),v[g>>2]=h}}function $S(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-48|0;R(573,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function yL(a){var b=0,c=0;b=jb-544|0;jb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){iN(b,Se(a));c=a+1304360|0;a=a+1074984|0;while(1){lc(a+112|0,b,538);a=a+896|0;if((c|0)!=(a|0)){continue}break}}jb=b+544|0}function wx(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1560,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function tL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(107,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function rJ(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1742,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function qJ(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1743,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function kk(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1594,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function jD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-1|0;R(215,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function iz(a,b,c){var d=0;d=jb-16|0;jb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Jb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}te(d+8|0);if(Jb(d+8|0,d)){continue}break}}jb=d+16|0;return v[d+8>>2]}function hA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=d,f=hT(bc(b),cc(b),d+12|0),v[e+8>>2]=f;e=d,f=cc(b),v[e>>2]=f;a:{if(Jb(d+8|0,d)){Ze(a,zb(v[d+8>>2]));break a}Yh(a)}jb=d+16|0}function g7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;b=yc(Gma(Fma(d,d>>31,b,b>>31),mb,1e3,0),mb);v[a+16>>2]=0;v[a+12>>2]=b+c;PI(a,e);b=v[a+12>>2];v[f+12>>2]=0;aK(a,b,f+12|0);jb=f+16|0}function dC(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-1|0;R(363,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function _Q(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(818,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function ZP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-8|0;R(923,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function XB(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;if(!((f-1^e-1)>>>0<32?e:0)){g=v[a>>2];v[(f>>>0<33?g:(f-1>>>3&536870908)+g|0)>>2]=0}Tn(d+8|0,a,e);kq(d+8|0,b,c);jb=d+16|0}function WR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(735,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function UQ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2|0;R(825,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function TR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-6|0;R(737,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function TB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(374,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Sw(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(2131,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function Rla(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Yb(128/(B(v[zf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[qh(c+7|0,c+6|0)|0];jb=c+16|0;return a|b<<4&240}function QK(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=hc(a);if(w[a+4|0]){a=v[a>>2];v[114578]=0;R(1526,a|0,b+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break b}}if(b){SK(b)}break a}V(0)|0;O()|0;Ab();L()}}}function PR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(738,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function IP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-4|0;R(949,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function FB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2|0;R(384,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function $A(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-2|0;R(424,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function uT(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114578]=0;c=c-1|0;R(32,d|0,c|0);d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function cq(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(418,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function XD(a){var b=0,c=0;b=jb-16|0;jb=b;$k(a);v[b+12>>2]=1073741823;v[114578]=0;v[b+8>>2]=2147483647;a=Lb(b+12|0,b+8|0);c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function VD(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(207,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function ME(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){lh(g+13|0,g+14|0)}h=c,i=(Ua(b|0,CA(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;jb=g+16|0}function Jp(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(696,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function Hv(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(203,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function Ez(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(760,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function $y(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(983,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function zy(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){ln(d);BN(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function xs(a,b){a=lc(a,b,88);v[a+88>>2]=v[b+88>>2];lc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];lc(a+672|0,b+672|0,52);dy(a+724|0,b+724|0);dy(a+736|0,b+736|0);dy(a+748|0,b+748|0);lc(a+760|0,b+760|0,135)}function tq(a,b,c){a:{if(y[a+12>>2]<=b>>>0){a=ba(8)|0;v[114578]=0;T(354,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}t[v[a+8>>2]+b|0]=c;return}ja(a|0,77224,265);L()}function g4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a=v[a+24>>2];bs(d,0,c);v[114578]=0;U(646,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function UK(){var a=0;a:{b:{if(t[457176]&1){break b}if(!wd(457176)){break b}v[114578]=0;Q(1524,88472,1)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(457176)}return}a=P()|0;O()|0;pe(457176);S(a|0);L()}function Aba(){var a=0;a:{b:{if(t[85228]&1){break b}if(!wd(85228)){break b}v[114578]=0;T(100,85200)|0;a=v[114578];v[114578]=0;if((a|0)==1){break a}vd(85228)}return 85200}a=P()|0;O()|0;pe(85228);S(a|0);L()}function yc(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=TQ(c+16|0,xz(c+24|0,c+8|0));jb=c+32|0;return v[a>>2]}function aO(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=Kc(a);a:{if(d>>>0>=c>>>0){d=Tb(a);_l(d,b,c);t[e+15|0]=0;he(c+d|0,e+15|0);Sg(a,c);break a}f=d;g=c-d|0;d=Fb(a);Tu(a,f,g,d,0,d,c,b)}jb=e+16|0;return a}function Jf(a,b,c,d,e){var f=0;f=jb-256|0;jb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Rb(f,b&255,d?c:256);if(!d){while(1){Qe(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}Qe(a,f,c)}jb=f+256|0}function JN(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=NN(v[a+16>>2],b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<5)+f|0,v[g>>2]=h;jb=e+16|0;return a}function JC(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=EC(v[a+16>>2],b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<5)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Dda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a;d=bc(b);e=cc(b);b=jb-16|0;jb=b;v[b+8>>2]=e;v[b>>2]=d;if(Jb(b,b+8|0)){while(1){rN(c,w[v[b>>2]]);qg(b);if(Jb(b,b+8|0)){continue}break}}jb=b+16|0;return a|0}function Bh(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;d=v[a+8>>2];g=v[a+4>>2];e=d-g|0;f=e>>31;v[a+120>>2]=e;v[a+124>>2]=f;v[a+104>>2]=b|c?((c|0)<(f|0)?1:(c|0)<=(f|0)?b>>>0<e>>>0:0)?b+g|0:d:d}function $p(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;b=jb-16|0;jb=b;xq(b+8|0,c+15|0);d=Hb(b+8|0);e=md(a,ac(b,b+8|0));if((d|0)==(e|0)){Xc(a,Hb(b+8|0))}jb=b+16|0;jb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function xS(a){var b=0,c=0;b=a+36|0;c=Fma(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+mb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;if(b>>>0<256){a=a+1|0}mb=a;return b}function rK(a){var b=0,c=0,d=0;if(jf(a)){while(1){b=a;d=c&65535;if(jf(b)>>>0>d>>>0){b=Ge(b,d);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;wK(b);Le(b+36|0)}c=c+1|0;if(jf(a)>>>0>(c&65535)>>>0){continue}break}}}function hP(a){var b=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;if((w[a|0]|w[a+1|0]<<8)!=2?(w[a|0]|w[a+1|0]<<8)!=1:0){break a}b=1}return b}function aD(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1129474426&(w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24))==1634291279){a=a+8|0;return(w[a|0]|w[a+1|0]<<8)==14}return 0}function Td(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=pd(b)}return c}function c2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;xH(b,c,d,z[a+28>>2]);wH(a,b,c,d);b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;jb=e+16|0}function XS(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=-1;v[114578]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function Fga(a,b){a=a|0;b=b|0;a:{a=jb-16|0;jb=a;v[b>>2]=0;v[b+4>>2]=0;v[114578]=0;v[a+12>>2]=0;W(1025,b+8|0,a+12|0,a+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}}function Zha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=QB(a);if(d>>>0>=b>>>0){a=it(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[bd(c+12|0,c+8|0)>>2]}jb=c+16|0;return d|0}fd();L()}function WN(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;t[a+16|0]=0;c=Cy(b,v[a+12>>2]);v[114578]=0;U(1175,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){Dl(c);jb=b+32|0;return}a=P()|0;O()|0;Dl(c);S(a|0);L()}function PP(a){var b=0,c=0,d=0,e=0;mb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function zL(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(nb[v[v[b>>2]+112>>2]](b)|0)){break a}nb[v[v[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-16|0;jb=c;xf(a,c+14|0);Sz(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Fi(a,Pb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}Nx(b);jb=c+16|0}function Bd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=v[a>>2];b=(f=d,g=v[a+8>>2],h=ac(c+8|0,b),e=v[v[d>>2]+32>>2],nb[e](f|0,g|0,h|0)|0);v[a+8>>2]=b+v[a+8>>2];jb=c+16|0;return b|0}function pY(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=a;a=Ah(b+8|0,b+12|0);v[114578]=0;c=cF();d=v[114578];v[114578]=0;if((d|0)!=1){Ie(a);jb=b+16|0;return c|0}b=P()|0;O()|0;Ie(a);S(b|0);L()}function Bg(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[114578]=0;T(354,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ja(a|0,77224,265);L()}function lN(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function bE(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=e;e=Ah(f+8|0,f+12|0);v[114578]=0;a=so(a,b,c,d);b=v[114578];v[114578]=0;if((b|0)!=1){Ie(e);jb=f+16|0;return a}a=P()|0;O()|0;Ie(e);S(a|0);L()}function vM(a,b,c){var d=0,e=0;d=v[(B(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,896)+a|0)+1075088>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function ur(a){var b=0;if(v[a+76>>2]<0){b=v[a+4>>2];if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return hw(a)}b=v[a+4>>2];a:{if(b>>>0<y[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=hw(a)}return a}function mi(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function _f(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb+-64|0;jb=c;d=ox(c+8|0,a);v[114578]=0;U(1583,a|0,b|0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){vl(d);jb=c- -64|0;return}a=P()|0;O()|0;vl(d);S(a|0);L()}function SM(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(1259,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function JZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-16|0;jb=b;c=a;a:{if(!Fe(f)){v[c+8>>2]=v[f+8>>2];a=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=a;break a}ID(a,v[f>>2],v[f+4>>2])}jb=b+16|0}function pB(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(419,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function kt(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(931,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function ju(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(411,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function h4(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a=v[a+24>>2];bs(c,0,b);v[114578]=0;U(646,a|0,1,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function bz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[114578]=0;W(935,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Rz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(706,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function RM(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=QM(b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,12)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dA(a)>>>0<b>>>0){fd();L()}zb(a);c=b;if(c>>>0>715827882){Fc(12706);L()}c=sc(B(c,6),1);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+B(b,6)|0,v[d>>2]=e;Rt(a,0)}function Gu(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(357,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Ad(a,b){var c=0;if(x[a+24>>1]!=(b&65535)){u[a+22>>1]=x[a+22>>1]-1&127;if(x[a+20>>1]<128){u[a+20>>1]=x[a+20>>1]+1}c=(x[a+22>>1]<<2)+a|0;u[c+28>>1]=0;u[c+26>>1]=b-x[a+24>>1];u[a+24>>1]=b}}function lq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(QB(a)>>>0<b>>>0){fd();L()}zb(a);b=(b-1>>>5|0)+1|0;c=b;if(b>>>0>1073741823){Fc(11804);L()}c=sc(c<<2,4);v[a+4>>2]=0;v[a>>2]=c;d=zb(a),e=b,v[d>>2]=e}function iy(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(94,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function d3(a){a=a|0;var b=0;a=a+24|0;b=NH(v[a>>2]);if(rj(Vb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074436>>1]}b=x[rc(Vb(v[a>>2]+484360|0),b)>>1];return(Kn(v[a>>2]+484344|0,b)?b:-1)|0}function cB(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114578]=0;v[b+12>>2]=0;W(31,a+8|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Yg(a,b){var c=0,d=0;a=v[a>>2];b=Kd(b);c=b;d=a+16|0;if(Kb(d)>>>0>b>>>0){c=v[Pb(d,c)>>2]!=0}else{c=0}if(!c){a=ba(4)|0;Qm(a);v[a>>2]=71628;ja(a|0,71688,2561);L()}return v[Pb(a+16|0,b)>>2]}function Qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ym(a)>>>0<b>>>0){fd();L()}zb(a);c=b;if(c>>>0>1073741823){Fc(15551);L()}c=sc(c<<2,1);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<2)|0,v[d>>2]=e;mk(a,0)}function LA(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=192;c=v[Lb(d+12|0,d)>>2];if(!Qb(a,c)){c=nf(a)}Zp(d,b);xg(a,v[d>>2],c);Zp(d,b);Rb(v[d>>2]+c|0,0,192-c|0);$b(a,v[d+12>>2]);jb=d+16|0}function uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Qu(a)>>>0<b>>>0){fd();L()}zb(a);c=b;if(c>>>0>536870911){Fc(20113);L()}c=sc(c<<3,8);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<3)|0,v[d>>2]=e;Pu(a,0)}function qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Lq(a)>>>0<b>>>0){fd();L()}zb(a);c=b;if(c>>>0>268435455){Fc(20113);L()}c=sc(c<<4,8);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<4)|0,v[d>>2]=e;km(a,0)}function ms(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=DK(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function kx(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=WJ(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<Ac(a)>>>0){a=mm(d,xc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=kv(c,a);Ib(a);e=b^1}jb=d+16|0;return e|0}function fq(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=EB(b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<1)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Un(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=RB(b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function RG(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;if((b|0)>=1){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=z[c>>2];g=z[e>>2];z[e>>2]=f+g;z[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function Q6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(86224);if(!d){return 0}v[114578]=0;a=aa(1965,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function LS(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=XA(b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=(b<<4)+f|0,v[g>>2]=h;jb=e+16|0;return a}function JR(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Tc(a+12|0,d);if(b){f=KR(b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=ec(a),h=B(b,6)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Bv(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Ah(e+8|0,e+12|0);v[114578]=0;a=ck(a,b,c);b=v[114578];v[114578]=0;if((b|0)!=1){Ie(d);jb=e+16|0;return a}a=P()|0;O()|0;Ie(d);S(a|0);L()}function $N(a,b,c,d){var e=0;e=jb-16|0;jb=e;d=Xh(e,a,d);a=zb(a);v[114578]=0;X(1169,a|0,b|0,c|0,d+4|0);a=v[114578];v[114578]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function z7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=4){ae(d+12|0,C(0));c=z[d+12>>2];if((b|0)==4){c=je(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;VI(a)}jb=d+16|0}function w7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4296);if(!d){return 0}v[114578]=0;a=aa(1879,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function sma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>=1){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function p7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4228);if(!d){return 0}v[114578]=0;a=aa(1892,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function l7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=1){ae(d+12|0,C(0));c=z[d+12>>2];if((b|0)==1){c=je(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;QI(a)}jb=d+16|0}function jN(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(1225,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function gK(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(1592,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function f7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(5048);if(!d){return 0}v[114578]=0;a=aa(1915,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function d9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4268);if(!d){return 0}v[114578]=0;a=aa(1638,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function b8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4296);if(!d){return 0}v[114578]=0;a=aa(1775,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function X6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4276);if(!d){return 0}v[114578]=0;a=aa(1942,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function S7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4280);if(!d){return 0}v[114578]=0;a=aa(1808,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function NV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Qu(a)>>>0<b>>>0){fd();L()}zb(a);c=b;if(c>>>0>536870911){Fc(11120);L()}c=sc(c<<3,1);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=c+(b<<3)|0,v[d>>2]=e;Pu(a,0)}function MN(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(1196,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function K7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4276);if(!d){return 0}v[114578]=0;a=aa(1832,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function I8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4304);if(!d){return 0}v[114578]=0;a=aa(1701,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function D7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Ig(4268);if(!d){return 0}v[114578]=0;a=aa(1855,d|0,a|0,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Xb(d);S(a|0);L()}function uC(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-9&255)>>>0>6|((w[a+5|0]-9&255)>>>0>6|(w[a+6|0]-9&255)>>>0>6))){return(w[a+7|0]-9&255)>>>0<7}return 0}function sba(a){a=a|0;var b=0,c=0,d=0,e=0;v[a>>2]=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;b=a+9|0;e=b+20|0;while(1){ff(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}jb=d+16|0;jb=c+16|0;zg(a);return a|0}function qP(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(992,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function mB(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114578]=0;W(421,a+8|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function LR(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function Fi(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=0;a=Xk(a,c+12|0,4);v[c+8>>2]=v[c+12>>2];d=b;b=c+8|0;v[d>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);jb=c+16|0;return!mb&(a|0)==4}function Af(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=a;a:{if(!Fe(b)){v[c+8>>2]=v[b+8>>2];e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;break a}gp(a,v[b>>2],v[b+4>>2])}jb=d+16|0;return a|0}function ex(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){b=_o(d)^b;if(a>>>0<=16){a=a+15|0;b=b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function SD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}$k(a);v[114578]=0;c=c-4|0;d=v[114578];v[114578]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function DO(a){var b=0,c=0;a:{b:{b=a&240;if((b|0)!=192){if((b|0)==240){break b}c=3;if((b|0)!=208){break a}}c=2;break a}c=1;a=a+15&255;if(a>>>0>2){break a}return 131842>>>(a<<3)&255}return c}function yaa(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Jj(a,b+8|0)){break a}c=0;if(!MK(b+8|0)){break a}c=b;a=cP(a,b);if(!a){QR(c)}c=-1;if(!a){break a}c=LK(b)}jb=b+16|0;return c|0}function yD(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function lF(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function AV(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;bo(a);v[a>>2]=77024;v[114578]=0;W(281,a+12|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Vv(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function Vd(a,b){var c=0;a:{c=$e(b);if((c|0)==(Fb(a)|0)){v[114578]=0;a=ea(346,a|0,0,-1,b|0,c|0)|0;b=v[114578];v[114578]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Ab();L()}function S8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=v[b>>2];a:{if((oh(b)|0)!=8){break a}d=c;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=1869112133){break a}lc(a+4260|0,c,oh(b));gs(a)}}function Q8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=jb-16|0;jb=d;e=d,f=C(C(nb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;ae(d+12|0,C(0));nb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);jb=d+16|0}function MY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}b:{if(y[c>>2]>127){break b}if(!(x[mo()+(v[c>>2]<<1)>>1]&b)){break b}c=c+4|0;continue}break}d=c}return d|0}function Ho(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Nd(b),v[d+12>>2]=e;v[114578]=0;W(2002,a|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function Go(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Nd(b),v[d+12>>2]=e;v[114578]=0;W(2162,a|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function nz(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;b=w[b|0]|w[b+1|0]<<8;a=a+22|0;a=w[a|0]|w[a+1|0]<<8;return c+(((b<<8|b>>>8)&65535)>>>0>((a<<8|a>>>8)&65535)<<1>>>0)|0}function dv(a){var b=0,c=0;a:{c=VD(Pe(12));b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=c;W(268,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}}function OY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;while(1){if((b|0)!=(c|0)){a=d;if(y[b>>2]<=127){e=x[mo()+(v[b>>2]<<1)>>1]}else{e=0}u[a>>1]=e;d=d+2|0;b=b+4|0;continue}break}return c|0}function Lh(a){var b=0;a=je(a);b=2147483647;a:{if(!(a<C(2147483648))){break a}b=-2147483648;if(!(a>C(-2147483648))){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Gp(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=Nd(b),v[d+12>>2]=e;v[114578]=0;W(725,a|0,c+12|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function zB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;hB(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){iB(b)}return a|0}function vz(a,b){var c=0;a:{if(b){vz(a,v[b>>2]);vz(a,v[b+4>>2]);a=hc(a);v[114578]=0;R(822,a|0,b+14|0);c=v[114578];v[114578]=0;if((c|0)==1){break a}Xi(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function ql(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Kb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Kb(c)<<16)-65536>>16<(b|0)){break a}d=z[Pb(c,b-u[a+28>>1]|0)>>2]}return d}function ji(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function hu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;GA(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){HA(b)}return a|0}function ht(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;KP(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){LP(b)}return a|0}function eu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;bu(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){JA(b)}return a|0}function _C(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;MC(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){NC(b)}return a|0}function ZC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;KC(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){LC(b)}return a|0}function OA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;$t(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){BA(b)}return a|0}function Mt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;aA(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){SS(b)}return a|0}function Ju(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;uq(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){nC(b)}return a|0}function G$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Cr(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;lc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function Bn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;MR(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){NR(b)}return a|0}function wja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+8>>2]=b;d=c,e=bc(a),v[d>>2]=e;b=tt(c+8|0,c);b=v[a>>2]+(b<<2)|0;Cu(a,gf(b+4|0,v[a+4>>2],b));a=Ng(b);jb=c+16|0;return a|0}function s6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=sI(f,b,c,d,0,0,0,0,e);jb=f+16|0;return a|0}function fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}ad(a,8,1,0,11);return}d=a;a=b+31|0;ad(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function Ih(a){var b=0,c=0,d=0,e=0;d=Gd(a);b=d&63;a:{if(!(d&64)){break a}c=6;while(1){e=Gd(a);b=(e&127)<<c|b;if(c>>>0>24){break a}c=c+7|0;if(e&128){continue}break}}return d&128?0-b|0:b}function BI(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=ze(31415.926535897932/+b);d=mn((32768-(K((1-c)*+C(a+a)+(c*c-1)*+C(a*a))+c*e)*32768)/(1-e))}return d}function vv(a,b,c,d,e){var f=0;f=wv(a,b,c,d);if(Jd(e,d)){Zb(d,e);if(!Jd(d,c)){return f+1|0}Zb(c,d);if(!Jd(c,b)){return f+2|0}Zb(b,c);if(!Jd(b,a)){return f+3|0}Zb(a,b);f=f+4|0}return f}function jm(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=jb-16|0;jb=b;Yw(b,c);v[114578]=0;U(13,a|0,0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(b);jb=b+16|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function Tv(a,b,c,d,e,f,g,h,i){var j=0;j=jb-16|0;jb=j;Zf(j,b,c,d,e,f,g,h,i^-2147483648);b=v[j+4>>2];v[a>>2]=v[j>>2];v[a+4>>2]=b;b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;jb=j+16|0}function $u(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];b=(f=d,g=Db(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],nb[e](f|0,g|0,h|0,i|0)|0);v[a+8>>2]=b+v[a+8>>2];return b|0}function qI(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114578]=0;T(2016,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ja(a|0,83324,2017);L()}function Xw(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114578]=0;T(2028,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ja(a|0,83336,2017);L()}function Py(a){var b=0;if(v[a>>2]){we(a,v[a>>2]);b=v[a>>2];a=(v[zb(a)>>2]-v[a>>2]|0)/9|0;v[114578]=0;U(25,b|0,B(a,9)|0,1);a=v[114578];v[114578]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function Ab(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;a:{if((a|0)!=1){a=v[115883];if(!a){break a}if(!CD(a+48|0)){break a}BD(v[a+12>>2]);L()}V(0)|0;O()|0;Ab();L()}BD(v[21294]);L()}function xI(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=wI(f,b,c,d,e,0,0,0,0);jb=f+16|0;return+c}function wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=nb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function tm(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=qE(a);if(d>>>0<=b>>>0){a=lg(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function oK(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=jK(a);if(d>>>0<=b>>>0){a=kj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function dm(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=FC(a);if(d>>>0<=b>>>0){a=th(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function Zaa(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function Ri(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=aC(a);if(d>>>0<=b>>>0){a=Uf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function Mq(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=Lq(a);if(d>>>0<=b>>>0){a=Zh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function MX(){var a=0;a:{if(t[462904]&1){break a}if(!wd(462904)){break a}a=462880;while(1){a=Wb(a)+12|0;if((a|0)!=462904){continue}break}vd(462904)}Mc(462880,70296);Mc(462892,70299)}function Ki(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=XS(a);if(d>>>0<=b>>>0){a=yf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function Jk(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sT(a);if(d>>>0<=b>>>0){a=We(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function JX(){var a=0;a:{if(t[462936]&1){break a}if(!wd(462936)){break a}a=462912;while(1){a=tf(a)+12|0;if((a|0)!=462936){continue}break}vd(462936)}_c(462912,70304);_c(462924,70316)}function JV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d>>2]=c;v[d+8>>2]=b;Dq(v[d+8>>2]);b=jb-16|0;jb=b;v[b+8>>2]=v[d>>2];OC(a,wh(b,v[b+8>>2]));jb=b+16|0;jb=d+16|0;return a|0}function Fz(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=dA(a);if(d>>>0<=b>>>0){a=Li(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function Be(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=Ym(a);if(d>>>0<=b>>>0){a=yd(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[bd(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}fd();L()}function zD(a,b,c,d){var e=0,f=0,g=0,h=0;f=v[a+4>>2];a=v[a>>2];g=a;h=b;e=0;a:{if(!c){break a}b=f>>8;e=b;if(!(f&1)){break a}e=v[b+v[c>>2]>>2]}nb[v[v[a>>2]+28>>2]](g,h,e+c|0,f&2?d:2)}function rA(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Aq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}jb=b+16|0;return c|0}function g2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){a=v[d>>2];while(1){v[a>>2]=v[b>>2];Af(a+4|0,b+4|0);a=v[d>>2]+16|0;v[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function cr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Fb(b);if(d>>>0<c>>>0){pm();L()}b=Tb(b);v[e+4>>2]=d-c;gp(a,b+c|0,v[Lb(e+12|0,e+4|0)>>2]);jb=e+16|0}function Yka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Ws(c,b);v[114578]=0;U(646,a|0,4,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function LK(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function Hka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;jS(b,c,32);iS(a,c);jb=c+32|0}function C8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a=jj(a);d=1;a:{if(!a){break a}d=(f=a,g=wh(c+8|0,b),e=v[v[a>>2]+72>>2],nb[e](f|0,g|0)|0)}a=d;jb=c+16|0;return a|0}function wi(a){a=a|0;var b=0,c=0,d=0,e=0;while(1){c=a;e=d&65535;b=e;if(b>>>0<=126){zg(((b<<5)+c|0)+480280|0);pn((B(b,896)+c|0)+1074984|0,c,b)}d=d+1|0;if(e>>>0<126){continue}break}}function e$(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;ij(b,0,a);v[114578]=0;a=T(202,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){yb(b);jb=b+16|0;return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function SS(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;jb=b+16|0}function fz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;d=a,e=(g=a,h=v[a+12>>2],i=ac(c+8|0,b),f=v[v[a>>2]+32>>2],nb[f](g|0,h|0,i|0)|0)+v[a+12>>2]|0,v[d+12>>2]=e;jb=c+16|0}function HA(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;jb=b+16|0}function Dr(a){var b=0;a:{b:{b=a;if((Ae(b)|0)!=79){break b}if((Ae(b)|0)!=103){break b}if((Ae(b)|0)!=103){break b}b=(Ae(b)|0)==83;break a}b=0}if(!b){dc(a,30);return 0}return HG(a)}function t_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;a=cj(a,b,c,d,e,f,g+8|0,g+16|0);jb=g+16|0;return a|0}function rO(a,b){var c=0;c=w[a+822|0];a:{if(c){break a}c=zj(w[a+819|0]-v[a+772>>2]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[fc(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function Yk(a){var b=0,c=0;b=v[21296];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>ob()<<16>>>0){if(!(Qa(a|0)|0)){break a}}v[21296]=a;return b}v[114552]=48;return-1}function QP(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}return w[a+4|0]>95}return 0}function NY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){if(y[c>>2]>127){break a}if(!(x[mo()+(v[c>>2]<<1)>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function M$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=v[c+4>>2];c=v[c>>2];v[d>>2]=c;v[d+4>>2]=e;v[d+8>>2]=c;v[d+12>>2]=e;UF(a,d,b);v[a>>2]=59028;jb=d+16|0;return a|0}function xf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;u[c+14>>1]=0;a=Xk(a,c+14|0,2);u[c+12>>1]=x[c+14>>1];d=b;b=c+12|0;u[d>>1]=w[b|0]|w[b+1|0]<<8;jb=c+16|0;return!mb&(a|0)==2}function mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;oz(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+8|0,d+12|0)>>2]}jb=d+16|0;return c|0}function jv(a,b){var c=0,d=0;c=jb-16|0;jb=c;u[b>>1]=0;t[c+15|0]=0;Wg(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;Wg(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}jb=c+16|0}function fw(a,b){var c=0;c=Tr(a+4|0);v[a>>2]=58852;v[c>>2]=58872;v[114578]=0;R(2313,v[14710]+a|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){return}a=P()|0;O()|0;ah(c);S(a|0);L()}function ew(a,b){var c=0;c=dG(a+4|0);v[a>>2]=58900;v[c>>2]=58920;v[114578]=0;R(2314,v[14722]+a|0,b|0);a=v[114578];v[114578]=0;if((a|0)!=1){return}a=P()|0;O()|0;ah(c);S(a|0);L()}function Gb(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(Fe(a)){pg(a,v[a>>2],hk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;of(b,0);t[c+15|0]=0;he(b,c+15|0);jb=c+16|0}function E0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;nb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=d+8|0;if(ve(v[a+4>>2],v[c+4>>2])){a=v[a>>2]==v[c>>2]}else{a=0}jb=d+16|0;return a|0}function nK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!dg(a,b)){break a}c=mx(a,v[Ge(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=Ge(a,b);vK(Ge(a,c),b);d=c}return d|0}function jw(a,b,c){var d=0;a:{d=jb-16|0;jb=d;Xr(d,b,c);v[114578]=0;U(13,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function ir(a,b,c){var d=0;a:{d=jb-16|0;jb=d;Ww(d,b,c);v[114578]=0;U(13,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function cu(a,b,c){var d=0;a:{d=jb-16|0;jb=d;eI(d,b,c);v[114578]=0;U(13,a|0,0,d|0);a=v[114578];v[114578]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function bi(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(Fe(a)){lo(v[a>>2],hk(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;of(b,0);v[c+12>>2]=0;Te(b,c+12|0);jb=c+16|0}function Z1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;xH(b,c,d,z[a+24>>2]);sH(a,b,c,d);v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;jb=e+16|0}function RK(a,b,c){a=jb-16|0;jb=a;Hh(a+8|0,c);v[114578]=0;b=Q(1529,b|0,a+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}return b>>>31|0}function Js(a,b,c){a=jb-16|0;jb=a;Hh(a+8|0,c);v[114578]=0;b=Q(1060,b|0,a+8|0)|0;c=v[114578];v[114578]=0;a:{if((c|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}return b>>>31|0}function zx(a,b){a:{if(b){zx(a,v[b>>2]);zx(a,v[b+4>>2]);a=hc(a);v[114578]=0;R(1526,a|0,b+16|0);a=v[114578];v[114578]=0;if((a|0)==1){break a}SK(b)}return}V(0)|0;O()|0;Ab();L()}function G9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Kb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=cK(a,b,c,d+8|0);jb=d+16|0;return a|0}function S6(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=gn(C(C(C(Se(v[a+16>>2])>>>0)*C(20938023226335645e-21))+C(-.005025125574320555)),C(0),C(1)),z[b+4272>>2]=c;JI(a);II(a)}function Gy(a,b,c,d,e){var f=0;a:{if(!d){break a}f=1;while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;if((d|0)==(f|0)){break a}c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;continue}}}function sha(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=ad(d,w[a|0]&4?16:8,1,0,0);a:{b:{if(w[a|0]&8){break b}c=2;if(w[a|0]&16){break b}if(w[a|0]&127){break a}}Gj(b,c)}}function gE(a){a=a|0;var b=0,c=0;v[a>>2]=64704;b=a+16|0;while(1){if(Kb(b)>>>0>c>>>0){if(v[Pb(b,c)>>2]){fm(v[Pb(b,c)>>2])}c=c+1|0;continue}break}yb(a+176|0);vE(b);return a|0}function fD(a){var b=0;a:{if(!(y[a>>2]<=18285140|y[a>>2]>=18350592)){b=1;if(v[a>>2]!=18350080){break a}}a=v[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function bR(a,b){var c=0;c=jb-32|0;jb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=TQ(c+16|0,xz(c+24|0,c+8|0));jb=c+32|0;return v[a>>2]}function JS(a){a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(qd(a+44|0,12960,3)){break a}a=a+47|0;return(w[a|0]|w[a+1|0]<<8)>>>0>97}return 0}function zQ(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;nQ(c+8|0,b);d=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){oQ(b)}return a}function wba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];c=v[a+8>>2];c=x[c>>1]|x[c+2>>1]<<16;u[b+4>>1]=0;u[b>>1]=c;u[b+2>>1]=c>>>16;jb=a+16|0}function taa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=c,e=hT(bc(a),cc(a),c+12|0),v[d+8>>2]=e;d=c,e=cc(a),v[d>>2]=e;a=Jb(c+8|0,c);jb=c+16|0;return a|0}function rC(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;uq(c+8|0,b);d=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){nC(b)}return a}function qG(a){var b=0,c=0,d=0;a:{if(!bh(t[v[a>>2]])){break a}while(1){c=v[a>>2];d=t[c|0];v[a>>2]=c+1;b=(b+d|0)-48|0;if(!bh(t[c+1|0])){break a}b=B(b,10);continue}}return b}function nT(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Ot(c+8|0,b);d=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){aT(b)}return a}function mR(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;$Q(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){aR(b)}return a}function lz(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;lQ(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){mQ(b)}return a}function jA(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Ot(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){aT(b)}return a}function cA(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;aA(c+8|0,b);d=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){SS(b)}return a}function bP(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;DS(c+8|0,b);d=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){ES(b)}return a}function Z3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;Uc(a+12|0,0,0);d=a+20|0;c=d;e=c+16|0;while(1){c=Gk(c)+4|0;if((e|0)!=(c|0)){continue}break}pL(d+16|0,b);v[a+40>>2]=1;return a|0}function Xz(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;DS(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){ES(b)}return a}function UH(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2169,a|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function TH(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2170,a|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function SH(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2171,a|0,b+12|0,b+8|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function RP(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;KP(c+8|0,b);d=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){LP(b)}return a}function Jj(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Mu(c+8|0,b);d=Hb(c+8|0);e=md(a,ac(c,c+8|0));if((d|0)==(e|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){zC(b)}return a}function Ep(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){xn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ug(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;xn(a,c)}function Dp(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){xn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(ug(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;xn(a,c)}function zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=nb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ko(a,b){var c=0,d=0,e=0;c=0;a:{if(!a){break a}d=Fma(a,0,b,0);e=mb;c=d;if((a|b)>>>0<65536){break a}c=e?-1:d}b=c;a=pd(b);if(!(!a|!(w[a-4|0]&3))){Rb(a,0,b)}return a}function h0(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Gf(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){mr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function XL(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function U$(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Gf(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){GF(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function K$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=oo(d,a);fE(a,c);v[114578]=0;R(2374,b|0,1);a=v[114578];v[114578]=0;if((a|0)==1){a=P()|0;O()|0;Ob(d);S(a|0);L()}}function nA(a,b,c){var d=0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a>>2]=d;v[a+4>>2]=b;bm(a+8|0,c);return a}function l8(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=0;d=c+12|0;t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;a=mJ(a,c+12|0);jb=c+16|0;return a|0}function Qx(a,b){var c=0;c=jb-16|0;jb=c;v[114578]=0;v[c+12>>2]=b;W(1432,a|0,c+12|0,c+8|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function KY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Xq()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;continue}break}return c|0}function IY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=v[b>>2];if(a>>>0<=127){a=v[Wq()+(v[b>>2]<<2)>>2]}v[d>>2]=a;b=b+4|0;continue}break}return c|0}function yM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];ky(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}jb=d+16|0}function mM(a,b){var c=0,d=0,e=0;c=Tb(a);a=Fb(a);d=Tb(b);e=Fb(b);a=a+c|0;b=-1;a:{while(1){if((a|0)==(c|0)){break a}a=a-1|0;if(_n(d,e,a)){continue}break}b=a-c|0}return b}function Via(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Oi(a+8|0);v[114578]=0;U(423,a|0,b|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Pg(d);S(a|0);L()}}function ye(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[hc(a)>>2];v[114578]=0;Z(a|0,c|0);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function cba(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[114578]=0;a=Q(1426,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function SG(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if(!(b&6)|(b&240)!=240&(b&254)!=226){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function RU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;Zc(a+8|0,d+12|0,d+8|0);if(b){lq(a,b);XB(a,b,w[c|0])}jb=d+16|0;return a|0}function L2(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if((rj(Vb(v[a>>2]+484360|0))|0)<=(b|0)){break a}c=x[rc(Vb(v[a>>2]+484360|0),b)>>1]}return c|0}function vi(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function uma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Wf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=yT(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function qd(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}f=d-e|0}return f}function S1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){e=v[d>>2];while(1){Jz(a,e,b);e=v[d>>2]+12|0;v[d>>2]=e;b=b+12|0;if((c|0)!=(b|0)){continue}break}}}function C9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=pt(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Ls(c+12|0,c+8|0,32408)>>2],v[d+36>>2]=e;Mo(a);jb=c+16|0}function sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;oz(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function kV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function cU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Wf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=FA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function bU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Wf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=EA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function aq(a,b){var c=0;c=jb-16|0;jb=c;jb=c+16|0;return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function aU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(Wf(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=DA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function Px(a){var b=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(1433,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function I6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}zI(a,i,h,g,e,f,b,c,d)}function Fo(a){var b=0;b=jb-16|0;jb=b;v[114578]=0;v[b+12>>2]=0;W(2176,a|0,b+12|0,b+8|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function zO(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if(!(b&6)|(b&224)!=224|(b&24)==8){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function GP(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function EV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function CY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=t[b|0];if((a|0)>=0){a=v[Xq()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;continue}break}return c|0}function AY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((b|0)!=(c|0)){d=b;a=t[b|0];if((a|0)>=0){a=v[Wq()+(t[b|0]<<2)>>2]}t[d|0]=a;b=b+1|0;continue}break}return c|0}function $0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a=wr(Fa(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);jb=e+16|0;mb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function kl(a){a=a>>>1&1431655765|a<<1&-1431655766;a=a>>>2&858993459|a<<2&-858993460;a=a>>>4&252645135|a<<4&-252645136;return Jma(a>>>8&16711935|a<<8&-16711936,16)}function hea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=Rp(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function Zo(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(!(v[a+480208>>2]&16)){break a}Eb(b+8|0,a+1074308|0,7);if(!Cb(b+8|0)){break a}c=v[a+480180>>2]!=4}jb=b+16|0;return c}function VG(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Cg(b),d=v[v[a>>2]+52>>2],nb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Cg(b)}function Pe(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=pd(a);if(b){break a}b=v[115885];if(b){nb[b|0]();continue}break}a=ba(4)|0;Zk(a);ja(a|0,71204,2008);L()}return b|0}function Lr(a,b,c,d){var e=0;a:{if(d==C(1)){break a}c=B(b,c);if(!c){break a}e=+d;b=1;while(1){A[a>>3]=A[a>>3]*e;if((b|0)==(c|0)){break a}a=a+8|0;b=b+1|0;continue}}}function CZ(){var a=0,b=0;a:{Ld(462992);v[115748]=64776;v[114578]=0;a=da(2452)|0;b=v[114578];v[114578]=0;if((b|0)!=1){v[115750]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function yca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=hn(a);v[114578]=0;U(91,a|0,b|0,c|0);b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;oe(d);S(a|0);L()}function oP(a,b){var c=0,d=0,e=0;c=qP(a,zb(b));v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[zb(b)>>2];d=zb(c),e=a,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function nc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=v[a>>2];a=(f=d,g=v[a+8>>2],h=ac(c+8|0,b),e=v[v[d>>2]+32>>2],nb[e](f|0,g|0,h|0)|0);jb=c+16|0;return a}function _u(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c>>2]=v[b>>2];d=c,e=v[b>>2]+vC(b)|0,v[d+4>>2]=e;b=jb-16|0;jb=b;Oq(a,v[c>>2],v[c>>2]+vC(c)|0);jb=b+16|0;jb=c+16|0}function Xba(a){a=C(a);var b=0;a=je(a);b=65535;a:{if(!(a<C(65535))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b|0}function Rr(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Rb(a+32|0,0,40);Dv(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function JL(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;iN(a+112|0,48e3);v[a+668>>2]=0;Mx(a+724|0);Mx(a+736|0);Mx(a+748|0);Rh(a+810|0);return a}function $b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Qb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function rp(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function gX(a,b){a=a|0;b=b|0;Qm(a);v[a>>2]=71244;b=Tb(b);v[114578]=0;Q(2837,a+4|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function MW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=v[c>>2];a=nb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}jb=d+16|0;return a|0}function AB(a){var b=0,c=0;a:{if(qd(a,12061,3)){break a}b=a+3|0;if(w[b|0]<8|w[b|0]>14){break a}a=a+40|0;if(w[b|0]>9?!(w[a|0]<33?w[a|0]:0):0){break a}c=1}return c}function tf(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;W(114,a|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Rm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function eia(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-80|0;jb=d;c=-1;a:{if(!nT(a,d+8|0)){break a}c=0;if(!XP(d+8|0)){break a}c=df(a,b,WP(d+8|0),mb)}jb=d+80|0;return c|0}function ar(a){a=a|0;var b=0;b=ba(8)|0;v[114578]=0;Q(2062,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ja(b|0,71532,265);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function x0(a,b,c){a=a|0;b=b|0;c=c|0;b=c;a:{if((c|0)>=257){VF();c=85168;break a}b:{if(t[461436]&1){break b}if(!wd(461436)){break b}vd(461436)}c=85164}Uc(a,b,c)}function vt(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!ug(a)){while(1){a=v[a+8>>2];if(!ug(a)){continue}break}}a=v[a+8>>2];break a}a=VQ(b)}v[c>>2]=a}function qQ(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878){return(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165}return 0}function oJ(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Lb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])*C(-.007874015718698502))+C(1);jb=c+16|0}function Wb(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;W(14,a|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Rm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Rd(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=b;v[114578]=0;ro(a,d+12|0,c);b=v[114578];v[114578]=0;if((b|0)!=1){jb=d+16|0;return a}V(0)|0;O()|0;Ab();L()}function Qn(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function xw(a,b){var c=0;c=jb-16|0;jb=c;v[114578]=0;W(150,a|0,c+8|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Rm(a);jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function uQ(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;nQ(c+8|0,b);d=Hb(c+8|0);e=nc(a,ac(c,c+8|0));if((d|0)==(e|0)){$b(a,Hb(c+8|0))}jb=c+16|0;if((d|0)!=(e|0)){oQ(b)}}function gd(a){var b=0,c=0;b=jb-16|0;jb=b;v[114578]=0;W(1,a|0,b+8|0,b|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){Rm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Hma(a,b,c){var d=0,e=0;d=b>>31;e=a^d;a=b>>31;Dma(e-d|0,(b^a)-((d>>>0>e>>>0)+a|0)|0,c,0);mb=lb;b=d^kb;c=b-d|0;mb=(a^mb)-((b>>>0<d>>>0)+a|0)|0;return c}function HO(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;v[a>>2]=v[a>>2]+(b>>>3&536870908);break a}b=b+c|0;v[a>>2]=v[a>>2]+((b-31|0)/32<<2)}v[a+4>>2]=b&31}function H2(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=Af(a,b);v[114578]=0;Q(120,a+12|0,c|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function Ft(a){var b=0;b=jb-16|0;jb=b;Uc(b+8|0,a,0);v[114578]=0;U(670,b+8|0,110,0);a=v[114578];v[114578]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function $E(a,b){var c=0;c=jb-16|0;jb=c;v[114578]=0;W(197,a|0,c+8|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){Rm(a);jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function u$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function Lla(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4}function II(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function xg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];return(f=d,g=Db(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],nb[e](f|0,g|0,h|0,i|0)|0)|0}function x$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function l_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return bj(g,b,c,d,e,f,Tb(a),Tb(a)+(Fb(a)<<2)|0)|0}function kd(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}t[c+15|0]=0;Wf(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}jb=c+16|0;return d}function PB(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Qb(a,b)){break a}t[c+15|0]=0;Wf(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}jb=c+16|0;return d}function M8(a,b){a=a|0;b=b|0;var c=0;BJ(a);c=b+4|0;Oh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mf(a);jk(a);jk(a)}function xu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[pc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;jb=d+16|0}function wu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[pc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;jb=d+16|0}function Qka(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Qb(a,12);a:{if(d){aA(c+8|0,b);Bd(a,c+8|0);break a}t[c+7|0]=0;Th(b,12,c+7|0)}jb=c+16|0;return d|0}function NC(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;jb=b+16|0}function uk(a,b){var c=0,d=0;a:{b=vk(a,b);if((b|0)==255){break a}if(qj(a)){break a}c=a+4|0;d=fc(c,b);t[d|0]=w[d|0]&223;hh(v[a>>2],Ps(b)|176,w[fc(c,b)|0])}}function nY(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[114578]=0;a=T(2573,a|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Ab();L()}function lV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function LM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=ep(a,x[b+60>>1],v[b+48>>2],c,0)}return d|0}function K2(a,b){a=a|0;b=b|0;var c=0;a:{if(!Pr(b)){break a}a=a+24|0;if(!dg(v[a>>2]+484344|0,b&65535)){break a}c=v[_b(v[a>>2]+484344|0,b)+12>>2]}return c|0}function Dh(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function Aja(a,b){a=a|0;b=b|0;var c=0;a=pR(a,b);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;jb=c+16|0}return a|0}function Ai(a){var b=0;a=je(a);b=-1;a:{if(!(a<C(4294967296))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function $_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=Ah(e,e+12|0);a=kF(a,c,v[e+8>>2]);Ie(b);jb=e+16|0;return a|0}function yka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=1){c=NB(a,1);break a}c=hg(a);$b(a,b-2|0)}u[d>>1]=c}function wl(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[a+1074400>>2];d=v[a+1074416>>2];v[b+12>>2]=1;a=v[bd(a+1074396|0,b+12|0)>>2];jb=b+16|0;return B(a,c+d|0)}function _i(a,b,c,d){var e=0,f=0;e=B(b,c);f=e;a:{if(v[d+76>>2]<=-1){a=lv(a,e,d);break a}a=lv(a,e,d)}if((f|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function Uo(a,b){var c=0;v[a>>2]=76544;v[a>>2]=76960;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;return a}function T6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=2){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];JI(a)}jb=d+16|0}function O7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=5){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];bJ(a)}jb=d+16|0}function M6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=3){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];HI(a)}jb=d+16|0}function Lf(a,b,c){a:{switch(b-1|0){case 0:if(c){return yi(a,1)}return yi(a,0);case 1:if(c){return yi(a,3)}return yi(a,2);default:break a}}return yi(a,4)}function Kr(a){var b=0,c=0,d=0;b=Jma(v[a>>2],1)^270549120;c=v[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;v[a>>2]=d;b=a;a=B(Jma(d,16),5)+c|0;v[b+4>>2]=a;return a}function G7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=4){ae(d+12|0,C(0));z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];YI(a)}jb=d+16|0}function FV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function DD(a,b){a=a|0;b=b|0;Qm(a);v[a>>2]=71244;v[114578]=0;Q(2837,a+4|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=c;c=0;a:{if(!b){break a}if(!Qb(a,b)){break a}if(b>>>0<=3){c=OB(a,b);break a}c=Cf(a);$b(a,b-4|0)}v[d>>2]=c}function Aw(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(C(z[((c&3)<<2)+43568>>2]*a)*C(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function wp(a,b,c){var d=0;d=b;b=w[a|0]|w[a+1|0]<<8;if((d|0)<=((b<<8|b>>>8)&65535)){a=w[a|0]|w[a+1|0]<<8;a=((a<<8|a>>>8)&65535)<=(c|0)}else{a=0}return a}function Yi(a){var b=0;b=ba(8)|0;v[114578]=0;Q(214,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ja(b|0,71464,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function U0(a,b){a=a|0;b=b|0;var c=0,d=0;b=dw(b);v[a+36>>2]=b;c=a,d=_m(b),v[c+44>>2]=d;c=a,d=Em(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){ar(55808);L()}}function Q0(a,b){a=a|0;b=b|0;var c=0,d=0;b=cw(b);v[a+36>>2]=b;c=a,d=_m(b),v[c+44>>2]=d;c=a,d=Em(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){ar(55808);L()}}function Im(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=pd(b)}return c}function Cm(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114578]=0;b=v[(b+c|0)+24>>2];c=v[114578];v[114578]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Ab();L()}function CG(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];h=g+(c<<2)|0;a:{if(!w[a+23|0]){break a}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;b=c;h=f+g|0}v[h>>2]=b}function Bb(a){var b=0;a=v[a+4>>2];if(a){if(fm(a)){a:{b=a+8|0;if(!v[b>>2]){nb[v[v[a>>2]+16>>2]](a);break a}if((Wu(b)|0)==-1){nb[v[v[a>>2]+16>>2]](a)}}}}}function xba(a,b){a=a|0;b=b|0;var c=0;cm(a);c=b+4|0;Oh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Bq(a,xe(a))}function vN(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function s_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return cj(g,b,c,d,e,f,Tb(a),Tb(a)+Fb(a)|0)|0}function fia(a,b){a=a|0;b=b|0;var c=0;Eq(a);c=b+4|0;Oh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Pu(a,Dg(a))}function cka(a,b){a=a|0;b=b|0;var c=0;Pt(a);c=b+4|0;HR(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Rt(a,bg(a))}function cZ(){var a=0;a:{Ld(463216);v[114578]=0;T(2557,463224)|0;a=v[114578];v[114578]=0;if((a|0)!=1){v[115804]=67580;break a}a=P()|0;O()|0;S(a|0);L()}}function aZ(){var a=0;a:{Ld(463232);v[114578]=0;T(2557,463240)|0;a=v[114578];v[114578]=0;if((a|0)!=1){v[115808]=67736;break a}a=P()|0;O()|0;S(a|0);L()}}function Pc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(nb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function Fc(a){var b=0;b=ba(8)|0;v[114578]=0;Q(23,b|0,a|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){ja(b|0,71412,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function FY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function vd(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;a=tv(b,a);c=jb-16|0;jb=c;d=v[Qc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;jb=c+16|0;jb=b+16|0}function pX(a,b){a=a|0;b=b|0;var c=0;jE(a);c=b+4|0;Oh($k(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(Uq(a),ec(b));v[b>>2]=v[b+4>>2];UD(a,Kb(a))}function pW(a,b){a=a|0;b=b|0;var c=0;Wk(a);c=b+4|0;Oh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];km(a,od(a))}function nu(a,b){a=a|0;b=b|0;var c=0;Rk(a);c=b+4|0;Oh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];Eu(a,oc(a))}function fu(a,b){a=a|0;b=b|0;var c=0;Ol(a);c=b+4|0;Oh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];gA(a,Ac(a))}function fh(a,b){a=a|0;b=b|0;var c=0;vf(a);c=b+4|0;Oh(zb(a),v[a>>2],v[a+4>>2],c);Zb(a,c);Zb(a+4|0,b+8|0);Zb(zb(a),ec(b));v[b>>2]=v[b+4>>2];mk(a,Kb(a))}function Eh(a,b,c){v[b+12>>2]=v[b+12>>2]+c;v[b+8>>2]=v[b+8>>2]-c;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function xY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)>-1?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function qia(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=Cf(b);Cf(b);break a}a=hg(b);hg(b)}if(a){while(1){if(a&1){$b(b,260)}a=a>>>1|0;if(a){continue}break}}}function q2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Rb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function pR(a,b){var c=0,d=0;c=jb-16|0;jb=c;_z(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function p2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Rb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function nq(a,b){var c=0,d=0;c=jb-16|0;jb=c;Pk(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function md(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a=(e=a,f=v[a+12>>2],g=ac(c+8|0,b),d=v[v[a>>2]+32>>2],nb[d](e|0,f|0,g|0)|0);jb=c+16|0;return a}function m3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(qE(a)>>>0<b>>>0){fd();L()}zb(a);c=QM(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=B(b,12)+c|0,v[d>>2]=e;po(a,0)}function hX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=$e(b);d=Pe(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=lc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function cP(a,b){var c=0,d=0;c=jb-16|0;jb=c;vh(c+8|0,b);b=Hb(c+8|0);d=md(a,ac(c,c+8|0));if((b|0)==(d|0)){Xc(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function Wf(a,b){var c=0,d=0;c=jb-16|0;jb=c;xq(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function Sk(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114578]=0;b=T(27,b+c|0)|0;c=v[114578];v[114578]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Ab();L()}function Qha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ym(a)>>>0<b>>>0){fd();L()}zb(a);c=JP(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<2)+c|0,v[d>>2]=e;mk(a,0)}function Nu(a,b){var c=0,d=0;c=jb-16|0;jb=c;Mu(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function BL(a){if(v[a+480224>>2]==2){return+y[a+1074420>>2]*1e-4}return+y[a+24620>>2]*60/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))}function Aq(a,b){var c=0,d=0;c=jb-16|0;jb=c;vh(c+8|0,b);b=Hb(c+8|0);d=nc(a,ac(c,c+8|0));if((b|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;return(b|0)==(d|0)}function rB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Ym(a)>>>0<b>>>0){fd();L()}zb(a);c=DK(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<2)+c|0,v[d>>2]=e;mk(a,0)}function oU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Lq(a)>>>0<b>>>0){fd();L()}zb(a);c=XA(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<4)+c|0,v[d>>2]=e;km(a,0)}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(Lq(a)>>>0<b>>>0){fd();L()}zb(a);c=CH(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<4)+c|0,v[d>>2]=e;km(a,0)}function hS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dA(a)>>>0<b>>>0){fd();L()}zb(a);c=KR(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=B(b,6)+c|0,v[d>>2]=e;Rt(a,0)}function gha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!RP(a,d)){break a}c=0;if(!hP(d)){break a}c=df(a,b,gP(d),mb)}jb=d+96|0;return c|0}function dz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(aC(a)>>>0<b>>>0){fd();L()}zb(a);c=EB(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<1)+c|0,v[d>>2]=e;Eu(a,0)}function bM(a){var b=0;a=je(a);b=255;a:{if(!(a<C(255))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function XY(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(XD(a)>>>0<b>>>0){fd();L()}c=WD($k(a),b);v[a>>2]=c;v[a+4>>2]=c;d=Uq(a),e=(b<<2)+c|0,v[d>>2]=e;UD(a,0)}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!RP(a,d)){break a}c=0;if(!QP(d)){break a}c=df(a,b,PP(d),mb)}jb=d+96|0;return c|0}function Uba(a){a=+a;var b=0;a=Sd(a);b=65535;a:{if(!(a<65535)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function Lm(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<1);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Le(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(Fe(a)){c=v[a>>2];t[b+15|0]=0;he(c,b+15|0);we(a,0);break a}t[b+14|0]=0;he(a,b+14|0);of(a,0)}jb=b+16|0}function Do(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<2);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!bP(a,d)){break a}c=0;if(!RO(d)){break a}c=df(a,b,QO(d),mb)}jb=d+48|0;return c|0}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!bP(a,d)){break a}c=0;if(!aP(d)){break a}c=df(a,b,$O(d),mb)}jb=d+48|0;return c|0}function OW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(kg(a,v[b+8>>2],f)){ov(b,c,d,e);return}a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function Dv(a){var b=0,c=0;v[114578]=0;c=da(2563)|0;b=v[114578];v[114578]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;gm(a);return}V(0)|0;O()|0;Ab();L()}function zaa(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){ad(a,8,1,0,11);return}c=a;a=b+14|0;ad(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function xy(a,b,c){var d=0,e=0,f=0;d=vk(a,b);if((d|0)!=255){e=ed(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=fc(a,b),f=255,t[e|0]=f;e=fc(a,c),f=d,t[e|0]=f}}function u0(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;nb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function s2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;gp(a,v[c+8>>2],v[c+12>>2]);jb=c+32|0;return a|0}function kw(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=d&1?a*c:c;if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function F2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-32|0;jb=h;JH(h+8|0,b,c,d,e,f,g);cd(a,h+20|0);jn(h+8|0);jb=h+32|0}function BG(a,b){a:{b:{if(w[a+23|0]){a=1;if((b|0)!=255){break b}ha(52190,50496,1165,52205);L()}if((b|0)!=255){break a}a=0}return a}return b>>>0>10}function wv(a,b,c,d){var e=0;e=qm(a,b,c);if(Jd(d,c)){Zb(c,d);if(!Jd(c,b)){return e+1|0}Zb(b,c);if(!Jd(b,a)){return e+2|0}Zb(a,b);e=e+3|0}return e}function sD(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+256|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function iQ(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+512|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function QI(a){var b=0;b=(Se(v[a+16>>2])>>>0)/(Ai(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;Cc(a+4224|0,b)}function Maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;vy(a,A[c>>3])}function G2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-32|0;jb=h;JH(h+8|0,b,c,d,e,f,g);cd(a,h+8|0);jn(h+8|0);jb=h+32|0}function FM(a,b){var c=0,d=0;c=lc(a,b,602);a=0;while(1){d=B(a,896);xs((d+c|0)+608|0,(b+d|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}return c}function vba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];f=A[v[a+8>>2]>>3];v[b+8>>2]=0;A[b>>3]=f;jb=a+16|0}function hw(a){var b=0,c=0;b=jb-16|0;jb=b;c=-1;a:{if(hG(a)){break a}if((nb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}jb=b+16|0;return c}function _P(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+32|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function Wg(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;t[c+15|0]=0;a=Xk(a,c+15|0,1);t[c+8|0]=w[c+15|0];t[b|0]=w[c+8|0];jb=c+16|0;return!mb&(a|0)==1}function Bo(a,b){var c=0;a:{if(!SG(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function vC(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(288,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function st(a){a=+a;var b=0;a=Sd(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function r0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;Rr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function mv(a,b,c,d,e,f){var g=0,h=0,i=0;g=v[a+4>>2];h=g>>8;a=v[a>>2];i=a;if(g&1){h=v[v[d>>2]+h>>2]}nb[v[v[a>>2]+20>>2]](i,b,c,d+h|0,g&2?e:2,f)}function hp(a){var b=0,c=0,d=0;c=w[a+30|0];d=Nh(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Vb(b)}return Di(b,w[a+30|0])}function aha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;Au(d+8|0,a);yu(c,d+8|0);jb=d+16|0;a=uf(c,b);yb(c);jb=c+16|0;return a|0}
function _la(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;u[b+14>>1]=1;c=b,d=Vt(a),u[c+12>>1]=d;a=x[Si(b+14|0,b+12|0)>>1];jb=b+16|0;return a-1&65535}function Sm(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function Ip(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(XS(a)>>>0<b>>>0){fd();L()}zb(a);c=ai(b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=b+c|0,v[d>>2]=e;gA(a,0)}function GR(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+4|0;while(1){ff(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function Dla(a,b){a=a|0;b=b|0;var c=0;a=ad(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(w[b|0]&64)){c=0;if(!(w[b|0]&2)){break a}}Gj(a,c)}if(w[b|0]&4){bA(a)}}function DQ(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(882,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function zk(a){var b=0;a=Sd(a);b=-1;a:{if(!(a<4294967295)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function oh(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(29,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function kga(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24}function Hb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114578]=0;a=Q(34,a|0,b|0)|0;b=v[114578];v[114578]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function LI(a){a=a|0;var b=0,c=0;v[a>>2]=81440;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;Sf(b);if((b|0)!=(c|0)){continue}break}bf(a);return a|0}function G0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=v[a+20>>2];d=v[a+16>>2]-e|0;d=c>>>0<d>>>0?c:d;lc(e,b,d);v[a+20>>2]=d+v[a+20>>2];return c|0}function v8(a){a=a|0;var b=0;b=jb-16|0;jb=b;vJ(b+8|0,a,0);if(oh(b+8|0)){a=v[a+20>>2];v[a+148>>2]=-1;oL(a+4|0,v[b+8>>2],v[b+12>>2])}jb=b+16|0}function SL(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function LB(a){var b=0,c=0;c=Fma(w[a+111|0],0,1536,0);b=mb;a=Fma(w[a+110|0],0,25,0);c=c+a|0;b=mb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;mb=b;return a}function EP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=v[c>>2],g=b,h=Hb(c),d=v[v[a>>2]+28>>2],nb[d](e|0,f|0,g|0,h|0)|0)|0}function sj(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function cs(a){var b=0;b=A[a+4248>>3]/+(Se(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*.016666666666666666*A[a+4288>>3]}}function XP(a){a:{if(qd(a,16624,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}return w[a|0]!=0}return 0}function Rq(a,b,c,d,e){var f=0,g=0,h=0;f=v[a+4>>2];g=f>>8;a=v[a>>2];h=a;if(f&1){g=v[v[c>>2]+g>>2]}nb[v[v[a>>2]+24>>2]](h,b,c+g|0,f&2?d:2,e)}function wY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Lb(a+12|0,a+8|0);jb=a+16|0;return v[b>>2]}function m9(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(!xd(a,4)){iv(a)}c=b,d=bc(a+44|0),v[c>>2]=d;a=v[Md(b+8|0,b)>>2];jb=b+16|0;return a|0}function l9(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(!xd(a,4)){iv(a)}c=b,d=cc(a+44|0),v[c>>2]=d;a=v[Md(b+8|0,b)>>2];jb=b+16|0;return a|0}function id(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=-1;v[c+4>>2]=0;a=qu(c+8|0,c);jb=c+16|0;return v[a>>2]}function b1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+15&-16;v[c>>2]=b+16;d=a,e=iw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}
function Lo(a,b){var c=0,d=0;c=jb-16|0;jb=c;vh(c+8|0,b);d=jb-16|0;jb=d;XJ(d+8|0,ac(d,c+8|0));wS(a,d+8|0);jb=d+16|0;vh(c,b);Hb(c);jb=c+16|0}function zj(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[zf(b+8|0,de(b+12|0,b+4|0))|0];jb=b+16|0;return a|0}function uv(a,b){Qm(a);v[a>>2]=71224;v[114578]=0;Q(2837,a+4|0,b|0)|0;a=v[114578];v[114578]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function lu(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(Qb(a,256)){d=jb-16|0;jb=d;gc(c+8|0,b,256);jb=d+16|0;Bd(a,c+8|0);break a}sD(b)}jb=c+16|0}function Vc(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[zf(b+8|0,de(b+12|0,b+4|0))>>1];jb=b+16|0;return a}function Mh(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((vk(a,b)|0)==255){break a}uk(a,b);lp(a,b,0,0);if(!c){break a}a=fc(a+58|0,b);t[a|0]=w[a|0]|128}}function Ch(a){var b=0;a=a*a;b=a*a;return C(a*-.499999997251031+1+b*.04166662332373906+a*b*(a*2439044879627741e-20+-.001388676377460993))}function BM(a){a=50-(B(w[(a>>>4|0)+20368|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return yc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function rU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c>>2]=b;v[c+8>>2]=a;a=jb-16|0;jb=a;xv(v[c+8>>2],v[c>>2],a+8|0);jb=a+16|0;jb=c+16|0}function pma(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Xr(a,b,c);jb=c+32|0}function mja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];c=x[v[a+8>>2]>>1];u[b+2>>1]=0;u[b>>1]=c;jb=a+16|0}function jga(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;JQ(a,b,c);jb=c+32|0}function iha(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;cu(a,b,c);jb=c+32|0}function Wd(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=em(c+8|0,b);TC(d,a);Bb(d);jb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function WF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function Uia(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;jw(a,b,c);jb=c+32|0}
function QY(a){a=a|0;var b=0,c=0,d=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;d=b;if(c&1){a=v[a+v[b>>2]>>2]}nb[a|0](d)}function M1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Nw(a+8|0,b,c,d,2);if(a>>>0<16){a=w[a+32240|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function L1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Nw(a+8|0,b,c,d,3);if(a>>>0<43){a=w[a+32192|0]}else{a=0}if(a>>>0<=4){return a+1|0}return 0}function I2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;KH(g+8|0,b,c,d,e,f);cd(a,g+20|0);jn(g+8|0);jb=g+32|0}function Eka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;ir(a,b,c);jb=c+32|0}function Cba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=250){Yi(20452);L()}Eb(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function CI(a){var b=0,c=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=C(Vg(b-J(b+.5)))}else{c=C(0)}return c}function tz(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;JQ(a,b,c);jb=c+32|0}function qt(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;eI(a,b,c);jb=c+32|0}function kW(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;jw(a,b,c);jb=c+32|0}function cD(a){a=a|0;var b=0;a=gd(a);v[114578]=0;Q(238,a|0,7090)|0;b=v[114578];v[114578]=0;if((b|0)==1){b=P()|0;O()|0;yb(a);S(b|0);L()}}function Xc(a,b){var c=0,d=0,e=0;c=Df(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function UT(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;cu(a,b,c);jb=c+32|0}function Nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=43){Yi(20452);L()}Eb(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=110){Yi(12352);L()}Eb(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function Mba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(b>>>0>=16){Yi(20452);L()}Pj(d+8|0,a,b);ge(d+8|0,c);jb=d+16|0;return a|0}function J2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;KH(g+8|0,b,c,d,e,f);cd(a,g+8|0);jn(g+8|0);jb=g+32|0}function Ij(a){var b=0;b=a+28|0;a=b;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[b|0]^-128}else{a=255}return a&255}function I$(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;ir(a,b,c);jb=c+32|0}function H$(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;ir(a,b,c);jb=c+32|0}function E9(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;ir(a,b,c);jb=c+32|0}function Bma(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;cu(a,b,c);jb=c+32|0}function $d(a,b){a=a|0;b=b|0;return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|0}function ula(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,6)){_z(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Th(a,6,c+7|0)}jb=c+16|0}function lW(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;jw(a,b,c);jb=c+32|0}function gQ(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Qb(a,32);a:{if(d){aQ(c+8|0,b);Bd(a,c+8|0);break a}_P(b)}jb=c+16|0;return d|0}function Rha(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,5)){bu(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Th(a,5,c+7|0)}jb=c+16|0}function Ar(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function y8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!be(c&255))){xJ(a,8,C(0))}a=jj(a);if(a){nb[v[v[a>>2]+88>>2]](a,b,c,d,e)}}function hq(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,3)){mu(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Th(a,3,c+7|0)}jb=c+16|0}function eD(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=Ub(a,10940);c=0;a:{if(!Fb(b)){break a}c=(Yf(b,10950)|0)!=-1}yb(b);jb=a+16|0;return c|0}function Sl(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,4)){vh(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;Th(a,4,c+7|0)}jb=c+16|0}function JD(a){var b=0,c=0,d=0;c=Tb(a);b=Fb(a);a=jb-16|0;jb=a;t[a+15|0]=0;d=-1;if(b){b=_n(c,b,a+15|0);d=b?b-c|0:-1}jb=a+16|0;return d}function Cf(a){var b=0,c=0;b=jb-16|0;jb=b;if(Aq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=b+16|0;return c}function CV(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;IC(b)}function BA(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;jb=b+16|0}function An(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Qb(a,4);a:{if(d){vh(c+8|0,b);Bd(a,c+8|0);break a}GR(b)}jb=c+16|0;return d|0}function ce(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)<(b|0)){v[a>>2]=b;return}if((c|0)>=(d|0)){break a}v[a>>2]=c}}function af(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=Ah(f,f+12|0);a=qr(a,b,d,v[f+8>>2]);Ie(c);jb=f+16|0;return a}function Yn(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0<b>>>0){v[a>>2]=b;return}if(c>>>0>=d>>>0){break a}v[a>>2]=c}}function yr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function dq(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Qb(b,2)){Pk(c+8|0,a);Bd(b,c+8|0);break a}t[c+7|0]=0;fB(a,c+7|0)}jb=c+16|0}function Yv(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Cg(t[b|0])|0}function U3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];Rr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function $V(){var a=0,b=0;a=jb-16|0;jb=a;v[a+8>>2]=19466496;a:{if(fD(a+8|0)){break a}if(eD()){break a}b=dD()^1}jb=a+16|0;return b|0}function mT(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179468868){return(w[a+4|0]-1&255)>>>0<10}return 0}function ho(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;b=wh(c,b);d=jb-16|0;jb=d;Oq(a,v[b>>2],v[b>>2]+oh(b)|0);jb=d+16|0;jb=c+16|0}function R8(a){a=a|0;a=jb-16|0;jb=a;v[a+12>>2]=1869112133;jb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function _R(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];u[b>>1]=x[v[a+8>>2]>>1];gd(b+4|0);jb=a+16|0}function MU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=Jma(0-Jma(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function yu(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=Sm(d,d+e|0,c+15|0);ri(a,v[b>>2],d);jb=c+16|0}function Uy(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=zb(b),d=0,v[c>>2]=d}function ww(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}lc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function wg(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;if(b>>>0>=110){Yi(12596);L()}Eb(c+8|0,a,b);ge(c+8|0,0);jb=c+16|0;return a|0}function uO(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=Fma(b,b>>31,a,a>>31)+5e5|0;a=mb;return yc(Gma(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function tO(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=Fma(b,b>>31,a,a>>31)+5e5|0;a=mb;return yc(Gma(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function sN(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){rN(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function pQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=Tk(c+8|0,b);TC(d,a);Bb(d);jb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function jj(a){var b=0,c=0;b=Ij(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function RE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=hr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function OE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=fr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function HY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function zY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function Ie(a){a:{a=v[a>>2];if(a){v[114578]=0;Ov(a);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function HN(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){we(b,a)}if(c){we(c,a)}if(d){we(d,a)}if(e){we(e,a)}}function BD(a){v[114578]=0;Y(a|0);a=v[114578];v[114578]=0;if((a|0)!=1){v[114578]=0;L()}a=V(0)|0;O()|0;_(a|0)|0;v[114578]=0;L()}function yk(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(nb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function sk(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];Uc(a,c,v[Lb(d+12|0,d+8|0)>>2]);jb=d+16|0}function qo(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}Zb(a,b);a=a+4|0;continue}}}function p0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Cg(t[a|0])|0}function Wj(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}lh(a,b);a=a+1|0;continue}}}function UW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(kg(a,v[b+8>>2],0)){pv(b,c,d);return}a=v[a+8>>2];nb[v[v[a>>2]+28>>2]](a,b,c,d)}function pr(a){v[a>>2]=58624;Dv(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function p1(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}nb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function hi(a,b,c){a:{if(c){v[114578]=0;WF(a,b,c);a=v[114578];v[114578]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function Wp(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(nq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8;c=a<<8|a>>>8}jb=b+16|0;return c&65535}function Vf(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Bg(d,a);return((Bg(d,a+1|0)<<8|e<<16|Bg(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function Sb(a,b){var c=0,d=0,e=0;c=a;d=v[b>>2];e=d+v[a>>2]|0;a=v[a+4>>2]+v[b+4>>2]|0;v[c>>2]=e;v[c+4>>2]=e>>>0<d>>>0?a+1|0:a}function SE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=hr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function PE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=fr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function OL(a){a=a|0;v[a>>2]=0;Oi(a+4|0);v[a+152>>2]=0;v[a+156>>2]=0;v[a+144>>2]=0;v[a+148>>2]=0;Rb(a+16|0,0,128);return a|0}function OF(a){v[a>>2]=58688;Dv(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function $O(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;mb=c;return a}function zh(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,12)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function yp(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,20)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function xR(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,33)|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function pt(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Lb(b+12|0,b+8|0)>>2];jb=b+16|0;return a|0}function ns(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function lK(a){a=a|0;var b=0,c=0;b=Ce(a);while(1){c=b;if(c&65535){b=c-1|0;if(!dg(a,b&65535)){continue}}break}return c&65535}function Xo(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,24)|0,8);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function VS(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,48)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Lx(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,52)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function t4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];cd(b,v[a+8>>2]);Wb(b+12|0);jb=a+16|0}function sO(a){a=a|0;v[a+700>>2]=0;u[a+862>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function mK(a,b,c){var d=0;b=b-a>>2;if((b|0)>=1){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function ez(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function VK(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function Qt(a,b,c){a:{v[114578]=0;U(25,b|0,B(c,6)|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function MD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function z2(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=jb-16|0;jb=c;v[c+12>>2]=w[b|0];Yw(a,c+12|0);jb=c+16|0;jb=d+16|0}function eM(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074308|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?25184:25248)>>2]}function dM(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074308|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?25248:25184)>>2]}function _x(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074308|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?25312:26336)>>2]}function Zx(a,b){var c=0;c=jb-16|0;jb=c;Eb(c+8|0,a+1074308|0,7);a=Cb(c+8|0);jb=c+16|0;return v[(b<<2)+(a?26336:25312)>>2]}function Fv(a,b,c){c=v[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=v[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function ok(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;xx(a,c)}function k0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function eO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){cO(a,1);cO(a,0)}}function dO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){bO(a,1);bO(a,0)}}function YU(a){a=a|0;var b=0;a:{if(!ve(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=TE(a,32);v[b+76>>2]=a}return a<<24>>24}function MO(a){var b=0;b=a+68|0;if(!(!(w[b|0]|w[b+1|0]<<8)|(w[b|0]|w[b+1|0]<<8)>>>0>127)){return!qd(a,17965,17)}return 0}function MK(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1179011410){return _y(a)>>>0>80}return 0}function BF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function qT(a){var b=0;a:{if(qd(a,12667,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}return t[a+47|0]>-1}return 0}function hba(a,b){a=a|0;b=b|0;if(b>>>0>255){return 20525}a=v[((b<<2)+a|0)+900380>>2];if(!a){return 20525}return a+492|0}function ae(a,b){var c=C(0);a:{if(b>C(1)){break a}c=z[a>>2];if(!(c>=b)){z[a>>2]=b;return}if(c<=C(1)){break a}z[a>>2]=1}}function Zr(a,b,c){var d=0;b=b-a|0;if((b|0)>=1){while(1){t[a|0]=w[c|0];a=a+1|0;d=(b|0)>1;b=b-1|0;if(d){continue}break}}}function Dd(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=83472;v[b+8>>2]=83576;v[a>>2]=v[b+12>>2];v[a+4>>2]=v[b+8>>2];jb=b+16|0}function DR(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1279544644){return w[a+4|0]<32}return 0}function AJ(a,b,c){a:{v[114578]=0;U(25,b|0,c<<11,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function xj(a,b,c){a:{v[114578]=0;U(25,b|0,c<<2,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function vu(a,b,c){a:{v[114578]=0;U(25,b|0,c<<2,2);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function mt(a,b,c){a:{v[114578]=0;U(25,b|0,c<<5,8);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function eA(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Lb(b+12|0,b+8|0)>>1];jb=b+16|0;return a|0}function _ia(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(nq(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}jb=b+16|0;return c|0}function XJ(a,b){var c=0,d=0;c=jb-16|0;jb=c;b=ac(c,b);d=jb-16|0;jb=d;Oq(a,v[b>>2],v[b>>2]+Hb(b)|0);jb=d+16|0;jb=c+16|0}function Wn(a,b,c){a:{v[114578]=0;U(25,b|0,c<<1,2);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Re(a,b,c){a:{v[114578]=0;U(25,b|0,c<<2,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Pl(a,b,c){a:{v[114578]=0;U(25,b|0,c<<1,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ou(a,b,c){a:{v[114578]=0;U(25,b|0,c<<3,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ae(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function uA(a){var b=0;b=a;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==810369604){return w[a+4|0]<4}return 0}function pg(a,b,c){a:{v[114578]=0;U(25,b|0,c|0,1);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function mc(a,b){var c=0;Qm(a);v[a+4>>2]=0;v[a>>2]=83428;c=a;a=pd(Fb(b)+1|0);v[c+4>>2]=a;if(a){lc(a,Tb(b),Fb(b)+1|0)}}function eR(a){a=a|0;var b=0;b=jb-16|0;jb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[lf(b+14|0,b+12|0)|0];jb=b+16|0;return a|0}function aB(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){gc(a,c,v[b>>2]);return}b=b+8|0;if(!nd(b)){Vi(a,b);return}Qf(a)}function EH(a,b){v[114578]=0;U(25,a|0,B(b,324)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function vk(a,b){a=a+58|0;if(t[fc(a,b)|0]<0){return 255}if(w[fc(a,b)|0]!=255){a=w[fc(a,b)|0]&127}else{a=255}return a}function uP(a,b){v[114578]=0;U(25,a|0,B(b,56)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function tda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=zq(e,a,d);Mk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function QC(a,b){v[114578]=0;U(25,a|0,B(b,24)|0,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function rF(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function px(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Qp(e,a,d);sK(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function fo(a,b,c){var d=0;d=jb-16|0;jb=d;ho(d+8|0,wh(d,b));Xu(a,d+8|0);v[a+12>>2]=c;v[a+8>>2]=0;jb=d+16|0;return a}function Vy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Mi(e,a,d);Mk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function Ln(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=qe(e,a,d);Mk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function LN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Xh(e,a,d);Mk(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function q8(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function AT(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function yF(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!ve(VG(c,b),-1)){break a}v[a>>2]=0}return a|0}function tK(a){var b=0,c=0;if(v[a>>2]){wK(a);Qt(zb(a),v[a>>2],Li(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function rk(a,b){var c=0;c=b&15;if(c){t[a+844|0]=c<<2}b=b&240;if(b){t[a+843|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function f9(a,b){a=a|0;b=b|0;var c=0;a:{if(Kb(a)>>>0>511){break a}if(!rd(b)){break a}c=v[b>>2];SJ(a,b)}return c|0}function _N(a){var b=0,c=0;if(v[a>>2]){Xp(a);Wn(zb(a),v[a>>2],Uf(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function XQ(a){var b=0,c=0;if(v[a>>2]){vR(a);vu(zb(a),v[a>>2],yd(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function XI(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function V8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=bM(C(c*C(255))),t[d|0]=e;gs(a)}}function PM(a){var b=0,c=0;if(v[a>>2]){Gs(a);pg(zb(a),v[a>>2],yf(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function Oj(a,b,c){var d=0;d=a+24|0;a=jb-16|0;jb=a;if(b>>>0>=12){Yi(6934);L()}Pj(a+8|0,d,b);ge(a+8|0,c);jb=a+16|0}function JM(a,b){var c=0;c=b&15;if(c){t[a+847|0]=c<<2}b=b&240;if(b){t[a+846|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function Caa(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function vG(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+(c*c-e+(c+c)*d)}function lo(a,b){a:{v[114578]=0;gv(a,b<<2,4);a=v[114578];v[114578]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Rf(a,b,c){var d=0;a:{if(b>c){break a}d=A[a>>3];if(!(d>=b)){A[a>>3]=b;return}if(c>=d){break a}A[a>>3]=c}}function qA(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;b=a;a=Ub(c,v[c+12>>2]);Hy(b,a);yb(a);jb=c+16|0}function pp(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+(b<<2);jb=c+16|0;return v[c+8>>2]}function kD(a,b){v[114578]=0;U(25,a|0,b<<4,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function ZH(a){var b=0;a:{while(1){if(!v[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function Xg(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function M0(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=dw(b);v[a+36>>2]=b;c=a,d=Em(b),t[c+44|0]=d}function J0(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=cw(b);v[a+36>>2]=b;c=a,d=Em(b),t[c+44|0]=d}function Fs(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function Fj(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function CC(a,b){v[114578]=0;U(25,a|0,b<<5,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function n6(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=Ub(b,38128);mc(a,c);yb(c);v[a>>2]=83388;jb=b+16|0;return a|0}function kg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!ji(v[a+4>>2],v[b+4>>2])}function ge(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function dK(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Lb(b+12|0,b+8|0)>>1];jb=b+16|0;return a}function Y5(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=Ub(b,38147);mc(a,c);yb(c);v[a>>2]=83408;jb=b+16|0;return a|0}function Xs(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Jb(c+8|0,c);jb=c+16|0;return a}function St(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=(B(a,b)>>>0)/255;ce(c+12|0,0,15);jb=c+16|0;return w[c+12|0]}function w4(a,b){a=a|0;b=b|0;if(a){b=nb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=Zd(b);break a}b=Zd(34181)}v[a>>2]=b}}function vQ(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(!(b<0)){A[a+8>>3]=b;v[a+16>>2]=3}return a}function bL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function Yd(a){a=a|0;var b=0;b=v[19157];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19160];Or(a+4|0);ah(a+56|0);return a|0}function Xm(a){var b=0;while(1){if(w[b+32256|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function If(a){a=a|0;var b=0;b=v[19203];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[19206];Or(a+8|0);ah(a+60|0);return a|0}function np(a,b){a=a|0;b=b|0;if(oc(a)>>>0>b>>>0){a=dg(v[a+24>>2]+484344|0,x[Ej(a,b)>>1])}else{a=0}return a|0}function mo(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;if((a|0)!=1){return v[15131]}V(0)|0;O()|0;Ab();L()}function iR(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;if((Vt(a)|0)!=65535){NA(a,c+14|0)}jb=c+16|0}function Xq(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;if((a|0)!=1){return v[15324]}V(0)|0;O()|0;Ab();L()}function Wq(){var a=0;v[114578]=0;a=v[114578];v[114578]=0;if((a|0)!=1){return v[15712]}V(0)|0;O()|0;Ab();L()}function QE(a,b,c,d,e){b=di(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function NE(a,b,c,d,e){b=ci(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function IF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return Cg(t[b|0])}function un(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Lb(b+12|0,b+8|0)|0];jb=b+16|0;return a}function my(a){v[114578]=0;U(25,a|0,40,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function eh(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Dc(c,(b>>31&a)+b|0)>>2]}function aS(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){YR(c+52|0);yb(c+40|0);Sf(c+16|0);Sf(c+4|0);Xb(c)}}}function SK(a){v[114578]=0;U(25,a|0,28,4);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function OG(a,b,c,d){z[d+4>>2]=c+a;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=a+b}function Ls(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(!Yp(a,b)){b=Yp(c,a)?c:a}jb=d+16|0;return b|0}function su(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function nX(a){a=a|0;a=jb-16|0;jb=a;if(Ta(a+12|0,4)|0){TF(v[114552],70510);L()}jb=a+16|0;return v[a+12>>2]}function lja(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Jj(a,b+8|0)){c=QQ(b+8|0)}jb=b+16|0;return c|0}function cma(a,b){a=a|0;b=b|0;var c=0;b=jb-80|0;jb=b;c=-1;if(nT(a,b+8|0)){c=mT(b+8|0)}jb=b+80|0;return c|0}function cf(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+b;jb=c+16|0;return v[c+8>>2]}function _o(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=Db(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function WG(a){var b=0;b=v[(w[a+2|0]&12)+42468>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function TD(a,b,c){v[114578]=0;RD(a,b,c);a=v[114578];v[114578]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function Dw(a,b){var c=0;c=(B(B(Bw(a),Cw(a)),125)>>>0)/(WG(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function ox(a,b){Rz(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Xx(a+24|0);Wb(a+36|0);v[a+48>>2]=b;return a}function ot(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Sl(c+8|0,a);v[c+4>>2]=v[c+8>>2];nt(c+4|0,b);jb=c+16|0}function jV(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Jj(a,b+8|0)){c=uC(b+8|0)}jb=b+16|0;return c|0}function hg(a){var b=0,c=0;b=jb-16|0;jb=b;if(nq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}jb=b+16|0;return c}function dE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function LT(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Jj(a,b+8|0)){c=uA(b+8|0)}jb=b+16|0;return c|0}function CF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function ig(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];mb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function Jh(a,b,c){var d=0,e=0,f=0,g=0;d=A[c>>3];e=A[b>>3];f=A[c+8>>3];g=A[b+8>>3];Bl(a,d*e-f*g,e*f+d*g)}function BN(a){u[a+70>>1]=w[((x[v[a+4>>2]+22>>1]<<4|x[v[a+4>>2]+20>>1]>>>6)&65535)+19968|0]>>>x[a+68>>1]}function e0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function co(a,b,c){var d=0;d=jb-16|0;jb=d;a=Qf(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;jb=d+16|0}function c0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function _K(a,b){var c=0;c=jb-16|0;jb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];jb=c+16|0}function _$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function Zb(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];jb=c+16|0}function X$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function Ru(a,b){a=a|0;b=b|0;var c=0;b=b-1|0;c=1085;a:{if(b>>>0>4){break a}c=v[(b<<2)+76228>>2]}Ub(a,c)}function Q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function KO(a,b){var c=0;c=y[b>>2]>y[a>>2];a=v[a+4>>2];b=v[b+4>>2];return(a|0)<(b|0)?1:(a|0)<=(b|0)?c:0}function fO(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;v[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function Ov(a){a=a|0;var b=0;b=v[21203];if(a){v[21203]=(a|0)==-1?458288:a}return((b|0)==458288?-1:b)|0}function CQ(a,b){var c=0;c=jb-16|0;jb=c;a:{if(Df(a,4)){vh(c+8|0,b);fz(a,c+8|0);break a}GR(b)}jb=c+16|0}function ry(a,b){if(dg(v[a+24>>2]+484344|0,b)){a=v[_b(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function J3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;ho(d+8|0,wh(d,b));fo(a,d+8|0,c);jb=d+16|0}function Cw(a){var b=0;b=w[a+1|0];return w[(B(b>>>1&3,15)+B(b>>>3&1,45)+(w[a+2|0]>>>4)|0)+42465|0]<<1}function am(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function JA(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;jb=b+16|0}function ou(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function cd(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];Rm(b);return a}function W8(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])*C(.003921568859368563)):C(0))}function CB(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;if(b>>>0<2624){a=a+1|0}mb=a;return b}function zja(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;yz(a+236|0,128,c+14|0);jb=c+16|0}function vg(a){var b=0;b=a+44|0;Wk(b);if(v[b>>2]){nD(b,v[b>>2]);Xi(zb(b),v[b>>2],Zh(b))}BC(a+32|0)}function uW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return nb[a|0](b,c,d,e,f,g)|0}function u4(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Tb(b);if(c){nb[c|0](b,v[a+8>>2]);return}Yr(b,a)}function tu(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Wf(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function T9(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;Rh(b)}function PY(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[mo()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function Dia(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(cA(a,b)){c=qQ(b)}jb=b+16|0;return c|0}function wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=A[b+8>>3];d=qw(A[b>>3]);e=ii(c);Bl(a,d*ze(c),d*e)}function w8(a,b,c){a=a|0;b=b|0;c=c|0;a=jj(a);if(!a){return 0}return nb[v[v[a>>2]+96>>2]](a,b,c)|0}function lh(a,b){var c=0;c=jb-16|0;jb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];jb=c+16|0}function lf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Xn(c+8|0,b,a);jb=c+16|0;return(d?b:a)|0}function kJ(a){a=a|0;var b=0;b=v[a>>2];if(b){nb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Gs(a);eS(a)}function Si(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Xn(c+8|0,a,b);jb=c+16|0;return(d?b:a)|0}function Fka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;WB(c,a);a=uf(c,b);yb(c);jb=c+16|0;return a|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;v[b+8>>2]=v[c+8>>2]}function Eg(a,b,c){a=a|0;b=b|0;c=c|0;Te(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function E3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;nb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;oo(d,a);fE(a,c)}function xK(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];nS(c+8|0,b);jb=c+16|0;return v[c+8>>2]}function fQ(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>=1){b=120;if((c|0)<121){break a}}v[a>>2]=b}}function TU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Au(c+8|0,a);mq(c+8|0,b);jb=c+16|0;return a|0}function QO(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;if(b>>>0<259){a=a+1|0}mb=a;return b}function PU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;VB(c+8|0,a);mq(c+8|0,b);jb=c+16|0;return a|0}function L3(a,b){a=a|0;b=b|0;pr(a);v[a>>2]=76704;Wb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function DU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;IB(c+8|0,a);mq(c+8|0,b);jb=c+16|0;return a|0}function nka(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Aq(a,b+8|0);jb=b+16|0;return C(a?z[b+8>>2]:C(0))}function mla(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function gu(a,b){a=a|0;b=b|0;var c=0;a=nq(a,b);if(!a){c=jb-16|0;jb=c;iu(b);jb=c+16|0}return a|0}function a2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function Ro(a,b,c){a=v[a>>2]+1074984|0;return v[(a+B(b,896)|0)+680>>2]>v[(a+B(c,896)|0)+680>>2]}function NW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(kg(a,v[b+8>>2],f)){ov(b,c,d,e)}}function Lka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;mS(c,b);cd(a,c);yb(c);jb=c+16|0;return a|0}function KG(a){var b=0;b=+((a&2097151)>>>0);return C($h(+C((a|0)>-1?b:-b),(a>>>21&1023)-788|0))}function IU(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Wf(a,b+8|0)){c=w[b+8|0]}jb=b+16|0;return c|0}function Faa(a,b){a=a|0;b=b|0;Ih(a);Ih(a);a:{if(b>>>0>=60){$b(a,4);break a}Ih(a)}return Ih(a)|0}function y7(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Se(v[a+16>>2]),v[b+4256>>2]=c;VI(a);UI(a)}function u8(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;Vi(b,v[a+20>>2]+4|0);uJ(a,Od(b+8|0,b),0);jb=b+16|0}function lA(a,b){var c=0;c=jb-16|0;jb=c;v[c>>2]=b;v[c+8>>2]=a;a=Vp(c,c+8|0);jb=c+16|0;return a}function gT(a,b){return(Yb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((B(a&15,b)>>>0)/15|0,1,15))&255}function Ys(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=zk(Vg(b)*+(c>>>0)),v[d+24>>2]=e}function Yr(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;v[b>>2]=a;a=v[13922];oG(a,34267,b);Br(a);jb=b+16|0}function U8(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Se(v[a+16>>2]),v[b+4232>>2]=c;gs(a);KJ(a)}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=a;a=cd(c,b);Hy(d,a);yb(a);jb=c+16|0}function zW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=nb[a|0](b,c,d,e)|0;qa(mb|0);return a|0}function Vj(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,Tb(a)+(Fb(a)<<2)|0)>>2];jb=b+16|0;return a}function SO(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function S$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[v[v[a>>2]+16>>2]](a,b,c,d,e)|0}function R$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0}function C0(a,b,c){a=a|0;b=b|0;c=c|0;if(ve(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function mG(a){var b=0;b=Ema(v[a>>2]-1|0);if(!b){a=Ema(v[a+4>>2]);return a?a+32|0:0}return b}function lD(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function gF(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function eE(a){a=a|0;var b=0;v[a>>2]=64724;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Xb(b)}return a|0}function Yo(a,b,c){a=wl(a)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function Xk(a,b,c){var d=0;d=jb-16|0;jb=d;gc(d+8|0,Db(b),c);a=wS(a,d+8|0);jb=d+16|0;return a}function Wl(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function Vh(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function Up(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;bm(b+8|0,c+8|0)}function P$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return nb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function Lia(a,b){a=a|0;b=b|0;var c=0;a=jb-16|0;jb=a;c=b;b=Yh(a);OQ(c,b,0,0);Bb(b);jb=a+16|0}function Hp(a,b){var c=0;c=Fb(a);if((c|0)==(Fb(b)|0)){a=!Um(Tb(a),Tb(b),c)}else{a=0}return a}function zf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Yp(a,b);jb=c+16|0;return(d?b:a)|0}function v6(a,b,c){a=a|0;b=b|0;c=c|0;Uw(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=83356;return a|0}function tC(a){a=a|0;var b=0;b=v[a>>2];return Db((nb[v[v[b>>2]+20>>2]](b)|0)+v[a+8>>2]|0)|0}function sK(a,b,c,d){a=c-b|0;if((a|0)>=1){lc(v[d>>2],b,a);v[d>>2]=v[d>>2]+B((a>>>0)/6|0,6)}}function rma(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;yg(c,1,a);$B(c,b);jb=c+16|0;return a|0}function qu(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=ou(b,a);jb=c+16|0;return(d?b:a)|0}function qma(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Xt(c,1,a);$B(c,b);jb=c+16|0;return a|0}function qh(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=qD(a,b);jb=c+16|0;return(d?b:a)|0}function pc(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=qD(b,a);jb=c+16|0;return(d?b:a)|0}function oga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;gp(a,b,c);jb=d+16|0;return a|0}function ku(a,b,c){a=a|0;b=b|0;c=c|0;b=jb-16|0;jb=b;t[b+15|0]=w[c|0];nI(a,b+15|0);jb=b+16|0}function kia(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Nu(a,b+8|0);jb=b+16|0;return+(a?A[b+8>>3]:0)}function fy(a){var b=0;v[a+72>>2]=0;v[a+76>>2]=0;b=v[a+68>>2];v[a+80>>2]=b;v[a+84>>2]=b<<12}function de(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Yp(b,a);jb=c+16|0;return(d?b:a)|0}function bd(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Jd(a,b);jb=c+16|0;return(d?b:a)|0}function Qb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return nb[v[v[c>>2]+36>>2]](c,v[a+8>>2],b)|0}function PI(a,b){var c=0;c=v[a+12>>2];if((c|0)>=1){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function Lb(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Jd(b,a);jb=c+16|0;return(d?b:a)|0}function KL(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function BC(a){var b=0;Ol(a);b=a;if(v[b>>2]){jD(b,v[b>>2]);pg(zb(b),v[b>>2],yf(b))}return a}function w6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;zI(a,b,c,d,e,0,0,f,g)}function uF(a){var b=0;b=v[a>>2];if(b){if(!ve(IF(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function tF(a){var b=0;b=v[a>>2];if(b){if(!ve(CF(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function ri(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;WI(a,b,c);jb=d+16|0;return a|0}function oaa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;ad(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function jaa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;ad(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function Vk(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Vi(a,b){a=a|0;b=b|0;var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+Ac(b)|0,v[c+4>>2]=d}function OC(a,b){var c=0,d=0;Kp(a);v[a>>2]=76960;v[a+4>>2]=v[b>>2];c=a,d=oh(b),v[c+8>>2]=d}function Hj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;mL(a,b,c);jb=d+16|0;return a|0}function HR(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>=1){lc(c,b,a)}}function z8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=jj(a);if(a){nb[v[v[a>>2]+84>>2]](a,b,c,d)}}function xd(a,b){var c=0;c=jb-16|0;jb=c;Pj(c+8|0,a+24|0,b);a=Cb(c+8|0);jb=c+16|0;return a}function wJ(a){a=a|0;var b=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];A[a+4256>>3]=b-J(b)}function kG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function bw(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;a=qr(a,b,c,d);jb=e+16|0;return a}function WD(a,b){a:{if(!(w[a+112|0]|b>>>0>28)){t[a+112|0]=1;break a}a=sc(b<<2,4)}return a}function Vw(a){a=a|0;var b=0;v[a>>2]=83428;b=v[a+4>>2];if(b){Xb(b);v[a+4>>2]=0}return a|0}function V9(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=-1?(c|0)!=4:0)){Fi(a,b);return}_D(a,b,c)}function N$(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){aw(a,c);return}Ub(a,58945)}function Jma(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function CW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;nb[a|0](b,c,d,e,f,g)}function B8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=jj(a);if(a){nb[v[v[a>>2]+76>>2]](a,b,c,d)}}function A8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=jj(a);if(a){nb[v[v[a>>2]+80>>2]](a,b,c,d)}}function yz(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function sf(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,Tb(a)+Fb(a)|0)>>2];jb=b+16|0;return a}function rR(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];u[b+4>>1]=x[c+4>>1];bm(b+8|0,c+8|0)}function Gd(a){var b=0;b=jb-16|0;jb=b;a=Wf(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)&255}function wh(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+oh(b)|0,v[c+4>>2]=d;return a}function sR(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function rN(a,b){var c=0;b=Db(b);c=a;a=v[a>>2];v[c>>2]=a<<8^v[((b^a>>>24)<<2)+87440>>2]}function os(a,b){if(!(v[a+480180>>2]==8?t[b+872|0]&1:0)){Fx(a,b,0);Fx(a,b,1);Fx(a,b,2)}}function nV(a){a=a|0;var b=0;b=v[a+4>>2];return(nb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function m8(a,b,c){a=a|0;b=b|0;c=c|0;Od(a,b);b=v[c+4>>2];v[a+8>>2]=v[c>>2];v[a+12>>2]=b}function jM(a,b){var c=0;c=w[a+872|0];if(c&1){t[a+872|0]=c|8;v[a+876>>2]=v[a+876>>2]+b}}function hF(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a=kF(a,64656,b);jb=c+16|0;return a}function fm(a){var b=0;b=Wu(a+4|0);if((b|0)==-1){nb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function dt(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function ac(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+Hb(b)|0,v[c+4>>2]=d;return a}function Ze(a,b){var c=0;Tk(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function Rh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function KQ(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+DQ(b)|0,v[c+4>>2]=d;return a}function D8(a,b){a=a|0;b=b|0;a=jj(a);if(!a){return 1}return nb[v[v[a>>2]+68>>2]](a,b)|0}function xA(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+12336|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function wN(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function pe(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[tv(b,a)+8>>2],d=0,t[c|0]=d;jb=b+16|0}function im(a){var b=0;b=a+36|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function gD(a){var b=0;b=a+48|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function ef(a){var b=0;b=a+24|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function ZO(a){var b=0;b=44325e5/+(a>>>0);if(b<4294967296&b>=0){return~~b>>>0}return 0}function Ub(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;gp(a,b,$e(b));jb=c+16|0;return a|0}function Th(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function RD(a,b,c){a=a|0;b=b|0;c=c|0;if((a|0)==(b|0)){t[a+112|0]=0;return}gv(b,c<<2,4)}function NL(a){gd(a);gd(a+12|0);gd(a+24|0);gd(a+36|0);gd(a+48|0);v[a+60>>2]=0;return a}function Av(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;ID(a,b,gF(b));jb=c+16|0;return a|0}function sm(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function rba(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=v[pL(b+8|0,a)>>2];jb=b+16|0;return a|0}function i1(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function gt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function g1(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function a_(a,b,c){a=a|0;b=b|0;c=c|0;c=Yv(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function XX(a){a=a|0;a=462088;while(1){a=yb(a-12|0);if((a|0)!=461920){continue}break}}function UX(a){a=a|0;a=462264;while(1){a=Lc(a-12|0);if((a|0)!=462096){continue}break}}function RX(a){a=a|0;a=462560;while(1){a=yb(a-12|0);if((a|0)!=462272){continue}break}}function Q2(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;IB(c+8|0,b);yu(a,c+8|0);jb=c+16|0}function OX(a){a=a|0;a=462864;while(1){a=Lc(a-12|0);if((a|0)!=462576){continue}break}}function LX(a){a=a|0;a=462904;while(1){a=yb(a-12|0);if((a|0)!=462880){continue}break}}function IX(a){a=a|0;a=462936;while(1){a=Lc(a-12|0);if((a|0)!=462912){continue}break}}function nf(a){a=a|0;var b=0;b=v[a>>2];return(nb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Qh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Rh(a)}function DY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Xq()+((b&255)<<2)>>2]}return b<<24>>24}function BY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Wq()+((b&255)<<2)>>2]}return b<<24>>24}function wW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nb[a|0](b,c,d)|0;qa(mb|0);return a|0}function rf(a){var b=0;Ph(a);b=a;if(v[b>>2]){zH(b);Xo(zb(b),v[b>>2],We(b))}return a}function p6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return rI(a,b,c,d,0,0,0,0,e)|0}function faa(a,b){a=a|0;b=b|0;if(b>>>0<=42){return w[v[a+84>>2]+b|0]!=63|0}return 0}function em(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function WE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function VE(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function uh(a){var b=0,c=0;b=jb-16|0;jb=b;c=b+8|0;PC(c,a);jb=b+16|0;return v[c>>2]}function lU(a){a=a|0;var b=0;b=jb-16|0;jb=b;bB(b+8|0,a);jb=b+16|0;return v[b+8>>2]}function dy(a,b){var c=0;t[a|0]=w[b|0];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c}function cR(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,v[a>>2])>>2];jb=b+16|0;return a}function LG(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function IM(a,b){var c=0;c=b&15;if(c){t[a+850|0]=c}b=b&240;if(b){t[a+849|0]=b>>>4}}function Ej(a,b){a=a|0;b=b|0;if(oc(a)>>>0<=b>>>0){iG();L()}return v[a>>2]+(b<<1)|0}function CK(a,b){a=a|0;b=b|0;if(b>>>0<=15){return w[v[a+88>>2]+b|0]!=63|0}return 0}function xC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);sh(v[a>>2],b,v[a+4>>2])}}function tI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){nb[v[v[c>>2]+4>>2]](c)}}}function mA(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8;t[b|0]=a;t[b+1|0]=a>>>8}function bl(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function _S(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function SC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);Xf(v[a>>2],b,v[a+4>>2])}}function Oy(a,b){a=lc(a,b,34);u[a+34>>1]=x[b+34>>1];lc(a+36|0,b+36|0,68);return a}function Lu(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){gm(a)}}function Kk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,24);return a}function HC(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);Xi(v[a>>2],b,v[a+4>>2])}}function GH(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=hc(a);Xy(v[a>>2],b,v[a+4>>2])}}function zq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function yj(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,hc(a))>>2];jb=b+16|0;return a}function vn(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,cR(a))>>2];jb=b+16|0;return a}function qe(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function lm(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function Xh(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function Qp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function Hi(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,yj(a))>>2];jb=b+16|0;return a}function Ed(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,Tb(a))>>2];jb=b+16|0;return a}function $n(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function vW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[a|0](b,c,d,e,f)}function v$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-16|0;jb=b;ZE(a,c,d);jb=b+16|0}function MS(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function yW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[a|0](b,c,d,e)|0}function y0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,58295);return}aw(a,c)}function v1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return ZG(a-88|0,b,c,d,e)|0}function oG(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;rG(a,b,c,0,0);jb=d+16|0}function jt(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function bm(a,b){var c=0;em(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function _s(a,b){return zk(Vg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function Iga(a,b){a=a|0;b=b|0;aj(b);if(v[b>>2]){XO(b);zh(zb(b),v[b>>2],lg(b))}}function A0(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,58216);return}aw(a,c)}function ki(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Xb(b)}function iba(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946300|0:20525)|0}function b7(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function b2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Lr(b,c,d,z[a+28>>2]);vH(a,b,c,d)}function _1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Lr(b,c,d,z[a+28>>2]);tH(a,b,c,d)}function Y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Lr(b,c,d,z[a+24>>2]);rH(a,b,c,d)}function VW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(kg(a,v[b+8>>2],0)){pv(b,c,d)}}function V1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Lr(b,c,d,z[a+24>>2]);pH(a,b,c,d)}function Tk(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){gm(b)}return a}function xz(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=KO(b,a);jb=c+16|0;return d?b:a}function ud(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];$b(b,c);Yu(a,b,d,c)}function ol(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=jJ(b,a);jb=c+16|0;return d?b:a}function m7(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function dx(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=jJ(a,b);jb=c+16|0;return d?b:a}function _y(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function YH(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function Wi(a,b){a=a|0;b=b|0;if((a|0)!=(b|0)){a=aO(a,Tb(b),Fb(b))}return a|0}function VF(){a:{if(t[461440]&1){break a}if(!wd(461440)){break a}vd(461440)}}function UM(a){var b=0;b=jb-16|0;jb=b;PC(b+8|0,a);jb=b+16|0;return v[b+8>>2]}function U6(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function TQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=KO(a,b);jb=c+16|0;return d?b:a}function P7(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function Oh(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>=1){lc(c,b,a)}}function Ng(a){var b=0;b=jb-16|0;jb=b;a=v[Qc(b+8|0,a)>>2];jb=b+16|0;return a}function N6(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function Mk(a,b,c,d){a=c-b|0;if((a|0)>=1){lc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function Il(a){var b=0;b=jb-16|0;jb=b;v[b+8>>2]=a;jb=b+16|0;return v[b+8>>2]}function H7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function DE(a,b){var c=0,d=0;ye(a,Nd(b));b=v[hc(b)>>2];c=hc(a),d=b,v[c>>2]=d}function A7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function $7(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function yA(a,b){a=a|0;b=b|0;a=v[a>>2];return nb[v[v[a>>2]+36>>2]](a,0,b)|0}function rr(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function bW(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;jm(a,c+8|0,b);jb=c+16|0}function bD(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Bi(a,c+8|0,b);jb=c+16|0}function _F(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function VQ(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function RO(a){if((w[a+14|0]-49&255)>>>0<=3){return!qd(a,17504,14)}return 0}function OO(a,b){rP(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function Mi(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function BK(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function AK(a,b){a=a|0;b=b|0;return(b>>>0<=42?t[v[a+84>>2]+b|0]:63)<<24>>24}function tv(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function fg(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function dg(a,b){a=a|0;b=b|0;if(Kn(a,b)){a=mh(Ge(a,b))}else{a=0}return a|0}function WM(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;HO(a,c)}function Tm(a,b){a=v[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function Og(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function LY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Xq()+(b<<2)>>2]}return b|0}function JY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Wq()+(b<<2)>>2]}return b|0}function wQ(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function tW(a,b,c){a=a|0;b=b|0;c=c|0;a=nb[a|0](b,c)|0;qa(mb|0);return a|0}function pk(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function ad(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function WB(a,b){var c=0;c=jb-16|0;jb=c;VB(c+8|0,b);yu(a,c+8|0);jb=c+16|0}function W$(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+32>>2]](a,b,c)|0}function Vl(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+48>>2]](a,b,c)|0}function $j(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+12>>2]](a,b,c)|0}function zka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=cS(a,b),t[d|0]=e}function p8(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function lS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=cS(a,b),v[d>>2]=e}function lB(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function _A(a,b){var c=0;c=jb-16|0;jb=c;gc(a,v[b>>2],oc(b)<<1);jb=c+16|0}function _9(a,b,c){a=a|0;b=b|0;c=c|0;if(Fb(b)>>>0>c>>>0){Co(b,c)}cd(a,b)}function RF(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Og(a,-1,-1)}function Hz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,v[b>>2],Kb(b)<<2);jb=c+16|0}function xN(a){if(a>>>0<=8){return w[a+20096|0]}return w[a+20087|0]|256}function wn(a){BR(a);if(v[a>>2]){yR(a,v[a>>2]);xR(zb(a),v[a>>2],Jl(a))}}function uD(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function sw(a){return((Lg(a)+(Lg(a)<<8)|0)+(Lg(a)<<16)|0)+(Lg(a)<<24)|0}function rw(a,b){a=a|0;b=b|0;nb[b|0](v[v[a>>2]-12>>2]+a|0)|0;return a|0}function qc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=$e(b),v[c+4>>2]=d;return a}function hR(a){Rk(a);if(v[a>>2]){UQ(a,v[a>>2]);Pl(zb(a),v[a>>2],Uf(a))}}function gH(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function eQ(a){Eq(a);if(v[a>>2]){ZP(a,v[a>>2]);Ou(zb(a),v[a>>2],Ui(a))}}function dR(a){vf(a);if(v[a>>2]){_Q(a,v[a>>2]);xj(zb(a),v[a>>2],yd(a))}}function YO(a){aj(a);if(v[a>>2]){UO(a,v[a>>2]);zh(zb(a),v[a>>2],lg(a))}}function Sc(a){if((a|0)>=-32768){return(a|0)>32767?32767:a}return-32768}function Kg(a,b,c){return(c|0)>=0?(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0:0}function Ji(a){vf(a);if(v[a>>2]){PR(a,v[a>>2]);xj(zb(a),v[a>>2],yd(a))}}function GN(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Cv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Bj(a){Rk(a);if(v[a>>2]){$A(a,v[a>>2]);Pl(zb(a),v[a>>2],Uf(a))}}function BQ(a){v[a+8>>2]=0;v[a>>2]=0;v[a+4>>2]=40;u[a+12>>1]=0;return a}function xx(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function wS(a,b){ak(a,Db(v[b>>2]),Hb(b));a=v[a+4>>2];mb=a>>31;return a}function sC(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function nv(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function jy(a,b,c){a:{if(a<b){break a}b=c;if(b<a){break a}b=a}return b}function iK(a,b){if(b>>>0>82595524){Fc(32335);L()}return sc(B(b,52),4)}function gn(a,b,c){a:{if(a<b){break a}b=c;if(b<a){break a}b=a}return b}function g0(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){Ba();L()}}function Tj(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function HL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){wf(c);Xb(c)}}}function Dc(a,b){if(Kb(a)>>>0<=b>>>0){iG();L()}return v[a>>2]+(b<<2)|0}function YV(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;hD(a,b);jb=c+16|0}function Wr(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;dQ(a,b);jb=c+16|0}function QM(a){if(a>>>0>357913941){Fc(20272);L()}return sc(B(a,12),4)}function LW(a){a=a|0;if(!a){return 0}return(qv(a,71736,71880)|0)!=0|0}function HH(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){EH(b,v[hc(a)+4>>2])}}function Ci(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function CD(a){return(v[a>>2]&-256)==1126902528&v[a+4>>2]==1129074247}function xW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[a|0](b,c,d)|0}function qx(a,b,c){b=b-a|0;if(b){$i(c,a,b)}return B((b|0)/6|0,6)+c|0}function jo(a,b,c,d,e){b=La(a|0,b|0,c|0,d|0,e|0)|0;mb=O()|0;return b}function dl(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function az(a,b){Zb(a,b);Zb(a+4|0,b+4|0);Zb(zb(a),zb(b));zb(a);zb(b)}function Z0(a,b){a=a|0;b=b|0;if(!v[114578]){v[114579]=b;v[114578]=a}}function WC(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(BC(c))}}}function RY(a){a=a|0;var b=0;b=v[115416]+1|0;v[115416]=b;v[a+4>>2]=b}function NN(a,b){if(b>>>0>134217727){Fc(18648);L()}return sc(b<<5,4)}function KZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Af(a,f)}function KR(a){if(a>>>0>715827882){Fc(14480);L()}return sc(B(a,6),1)}function EC(a,b){if(b>>>0>134217727){Fc(11120);L()}return sc(b<<5,4)}function EB(a){if(a>>>0>2147483647){Fc(11932);L()}return sc(a<<1,2)}
function Cy(a,b){Ql(a);gd(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function BH(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];cd(b+4|0,c+4|0)}function zV(a,b,c){a=a|0;b=b|0;c=c|0;Kp(a);v[a>>2]=77064;return a|0}function wD(a,b,c,d,e,f,g){return Ka(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function ro(a,b,c){a=a|0;b=b|0;c=c|0;Te(a,b);Te(a+4|0,c);return a|0}function rm(a){if(a>>>0>1073741823){Fc(70328);L()}return sc(a<<2,4)}function m1(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function Yy(a){a=a|0;v[a>>2]=76256;Pg(a+28|0);Pg(a+12|0);return a|0}function WJ(a){if(a>>>0>1073741823){Fc(32462);L()}return sc(a<<2,4)}function RB(a){if(a>>>0>1073741823){Fc(11804);L()}return sc(a<<2,2)}function JP(a){if(a>>>0>1073741823){Fc(16711);L()}return sc(a<<2,1)}function GL(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function Cd(a,b,c){if(a>>>0>=b>>>0){return a>>>0>c>>>0?c:a}return b}function qn(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<2)|0}function on(a){var b=0;b=v[a+20>>2];if(b){Xb(b+-64|0)}v[a+20>>2]=0}function iM(a,b){v[a+876>>2]=v[a+876>>2]+b;t[a+872|0]=w[a+872|0]|8}function gk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(b){Xb(rf(b))}}}function bF(a,b,c){a=a|0;b=b|0;c=c|0;return so(0,a,b,c?c:461468)|0}function Yb(a,b,c){if((a|0)>=(b|0)){return(a|0)>(c|0)?c:a}return b}function YD(a,b,c){a=a|0;b=b|0;c=c|0;bt(a);t[a+128|0]=0;return a|0}function Xe(a,b,c){a=a|0;b=b|0;c=c|0;return Nc(a,B(lk(a),b)+c|0)|0}function XA(a){if(a>>>0>268435455){Fc(12065);L()}return sc(a<<4,4)}function VL(a){if(a>>>0>134217727){Fc(20384);L()}return sc(a<<5,8)}function Ola(a){a=a|0;return v[a+16>>2]+(v[a+8>>2]-v[a+20>>2]|0)|0}function NO(a,b){Uy(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function Mm(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function GY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function DK(a){if(a>>>0>1073741823){Fc(1447);L()}return sc(a<<2,4)}function CH(a){if(a>>>0>268435455){Fc(39501);L()}return sc(a<<4,4)}function tj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function pV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+12>>2]](a)|0}function oV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+16>>2]](a)|0}function nB(a){if(v[a>>2]){WA(a,v[a>>2]);Xi(zb(a),v[a>>2],Zh(a))}}function kP(a){a=a+34|0;a=Fma(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function eH(a){a=a|0;return+(+v[v[a+32>>2]+1074444>>2]*.00390625)}function MP(a){if(v[a>>2]){IP(a,v[a>>2]);xj(zb(a),v[a>>2],yd(a))}}function IS(a){mb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function Bw(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function Ah(a,b){var c=0,d=0;c=a,d=Ov(v[b>>2]),v[c>>2]=d;return a}function ts(a){yb(a+48|0);yb(a+36|0);yb(a+24|0);yb(a+12|0);yb(a)}function tJ(a){a=a|0;v[a>>2]=79476;Pg(a+4208|0);bf(a);return a|0}function rX(a){a=a|0;var b=0,c=0;b=a,c=le(),v[b>>2]=c;return a|0}function qV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function oy(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){if(c){Xb(c)}}}function fn(a){var b=0;b=jb-16|0;jb=b;jb=b+16|0;return a<<24>>24}function ax(a){a=a|0;v[a>>2]=80160;Sf(a+4260|0);bf(a);return a|0}function TI(a){a=a|0;v[a>>2]=80800;Sf(a+4208|0);bf(a);return a|0}function JJ(a){a=a|0;v[a>>2]=79272;Sf(a+4208|0);bf(a);return a|0}function Db(a){a=a|0;var b=0;b=jb-16|0;jb=b;jb=b+16|0;return a|0}function Cda(a,b){a=a|0;b=b|0;sN(a,v[b>>2],v[b+4>>2]);return a|0}function $I(a){a=a|0;v[a>>2]=80392;Sf(a+4256|0);bf(a);return a|0}function x6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function wj(a,b,c){a=a|0;b=b|0;c=c|0;return Az(Il(a),Il(b),c)|0}function tn(a){vf(a);if(v[a>>2]){uR(a);vu(zb(a),v[a>>2],yd(a))}}function tl(a){Ph(a);if(v[a>>2]){IK(a);Xf(zb(a),v[a>>2],We(a))}}function oN(a,b){b=1/(564505.8718779281/b+1);lN(a,b,0,0,b+-1,0)}function me(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function jr(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+44>>2]](a,b)|0}function gN(a){aj(a);if(v[a>>2]){ZM(a);zh(zb(a),v[a>>2],lg(a))}}function eJ(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function as(a){vf(a);if(v[a>>2]){EJ(a);Re(zb(a),v[a>>2],yd(a))}}function Vx(a){WS(a);if(v[a>>2]){jT(a);VS(zb(a),v[a>>2],Ml(a))}}function Vs(a){cm(a);if(v[a>>2]){PN(a);sh(zb(a),v[a>>2],th(a))}}function Ux(a){sL(a);if(v[a>>2]){rL(a);Lx(zb(a),v[a>>2],kj(a))}}function Sf(a){vf(a);if(v[a>>2]){XR(a);Re(zb(a),v[a>>2],yd(a))}}function Rx(a){cm(a);if(v[a>>2]){XC(a);sh(zb(a),v[a>>2],th(a))}}function Rv(a,b){a=a|0;b=b|0;return(bh(a)|0)!=0|(a|32)-97>>>0<6}function OQ(a,b,c,d){Ze(a,b);u[a+18>>1]=d;u[a+16>>1]=c;return a}function Nk(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+28>>2]](a,b)|0}function Lj(a){a=a|0;a=v[a>>2];return nb[v[v[a>>2]+24>>2]](a)|0}function Kv(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+12>>2]](a,b)|0}function JO(a){vf(a);if(v[a>>2]){IO(a);xj(zb(a),v[a>>2],yd(a))}}function Io(a){a=a|0;return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Gl(a){Ph(a);if(v[a>>2]){wP(a);Xf(zb(a),v[a>>2],We(a))}}function DT(a){Rk(a);if(v[a>>2]){xT(a);Pl(zb(a),v[a>>2],Uf(a))}}function DM(a){Ph(a);if(v[a>>2]){_L(a);Xo(zb(a),v[a>>2],We(a))}}function DB(a){if(!qd(a,12035,25)){return w[a+34|0]<65}return 0}function BW(a,b){a=a|0;b=b|0;a=nb[a|0](b)|0;qa(mb|0);return a|0}function $r(a){BJ(a);if(v[a>>2]){HJ(a);AJ(zb(a),v[a>>2],jk(a))}}function wq(a){a=a|0;a=v[a>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function vA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,1954);jb=c+16|0}function oq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function mba(a,b){a=a|0;b=b|0;uv(a,b);v[a>>2]=71324;return a|0}function jI(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function gz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,1024);jb=c+16|0}function VZ(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,BF(v[b>>2]),v[b>>2])}function Or(a){a=a|0;v[a>>2]=76704;yb(a+32|0);jl(a);return a|0}function Gz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,4896);jb=c+16|0}function Ff(a,b){a=a|0;b=b|0;a=Nu(a,b);if(!a){zC(b)}return a|0}function Et(a,b){a=a|0;b=b|0;a=Aq(a,b);if(!a){QR(b)}return a|0}function Df(a,b){return nb[v[v[a>>2]+36>>2]](a,v[a+12>>2],b)|0}function BS(a){a=a|0;a=w[a|0];return be(a)^1|(a-49&255)>>>0<36}function zS(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,157);jb=c+16|0}function yV(a){a=a|0;var b=0;b=jb-16|0;jb=b;kD(a,1);jb=b+16|0}function vD(a,b,c){b=Ha(2078,a|0,b|0,c|0)|0;mb=O()|0;return b}function tS(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,576);jb=c+16|0}function sz(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function sV(a){a=a|0;var b=0;b=jb-16|0;jb=b;CC(a,1);jb=b+16|0}function rW(a,b){a=a|0;b=b|0;uv(a,b);v[a>>2]=71432;return a|0}function qja(a,b,c){a=a|0;b=b|0;c=c|0;cd(a,KD(c,Tb(b),Fb(b)))}function om(a,b){if(Fb(a)>>>0<=b>>>0){pm();L()}return kc(a,b)}function oT(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,610);jb=c+16|0}function nW(a,b){a=a|0;b=b|0;uv(a,b);v[a>>2]=71380;return a|0}function mp(a,b){a=a|0;b=b|0;if(xe(a)>>>0>b>>>0){t[a+16|0]=b}}function mP(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,146);jb=c+16|0}function lQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,130);jb=c+16|0}function k2(a){a=a|0;var b=0;b=jb-16|0;jb=b;EH(a,1);jb=b+16|0}function jQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,600);jb=c+16|0}function iP(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,608);jb=c+16|0}function h2(a){a=a|0;var b=0;b=jb-16|0;jb=b;uP(a,1);jb=b+16|0}function f4(a,b,c){a=a|0;b=b|0;c=c|0;zJ(a,0,Nz(v[b+24>>2]),c)}function bQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,126);jb=c+16|0}function aN(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function _t(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,512);jb=c+16|0}function Zp(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,192);jb=c+16|0}function Vda(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1185)|0}function VO(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,204);jb=c+16|0}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1186)|0}function Tq(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function SR(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,674);jb=c+16|0}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1191)|0}function Od(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function MR(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,80);jb=c+16|0}
function IV(a){a=a|0;var b=0;b=jb-16|0;jb=b;QC(a,1);jb=b+16|0}function GO(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,263);jb=c+16|0}function GB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,497);jb=c+16|0}function FR(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,128);jb=c+16|0}function yv(){var a=0;a=ba(4)|0;Zk(a);ja(a|0,71204,2008);L()}function x9(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1615)|0}function wz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,40);jb=c+16|0}function wka(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,710)|0}function wA(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,1954);jb=b+16|0}function w9(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1616)|0}function uq(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,36);jb=c+16|0}function qN(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,27);jb=c+16|0}function nQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,30);jb=c+16|0}function kA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,64);jb=c+16|0}function jB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,38);jb=c+16|0}function iH(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function hB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,41);jb=c+16|0}function gB(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,16);jb=c+16|0}function fx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function aQ(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,32);jb=c+16|0}function aA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,12);jb=c+16|0}function _n(a,b,c){if(!b){return 0}return Cr(a,Cg(t[c|0]),b)}function X9(a,b,c){a=a|0;b=b|0;c=c|0;return kh(a,b,c,1579)|0}function Ot(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,66);jb=c+16|0}function MC(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,10);jb=c+16|0}function KP(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,96);jb=c+16|0}function KC(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,14);jb=c+16|0}function Jt(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,22);jb=c+16|0}function GA(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,11);jb=c+16|0}function FS(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,98);jb=c+16|0}function EK(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,24);jb=c+16|0}function DS(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,48);jb=c+16|0}function Bz(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,33);jb=c+16|0}function $Q(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,52);jb=c+16|0}function yY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>-1?b:c)|0}function xq(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,1);jb=c+16|0}function x8(a){a=a|0;a=jj(a);if(a){nb[v[v[a>>2]+92>>2]](a)}}function vh(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,4);jb=c+16|0}function uS(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,576);jb=b+16|0}function pT(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,610);jb=b+16|0}function nP(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,146);jb=b+16|0}function mu(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,3);jb=c+16|0}function mQ(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,130);jb=b+16|0}function kQ(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,600);jb=b+16|0}function jP(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,608);jb=b+16|0}function cQ(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,126);jb=b+16|0}function bu(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,5);jb=c+16|0}function _z(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,6);jb=c+16|0}function Wu(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function WO(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,204);jb=b+16|0}function RR(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,192);jb=b+16|0}function Pk(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,2);jb=c+16|0}function Mu(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,8);jb=c+16|0}function HB(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,497);jb=b+16|0}function Dq(a){var b=0;b=jb-16|0;jb=b;v[b+8>>2]=a;jb=b+16|0}function AS(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,157);jb=b+16|0}function $t(a,b){var c=0;c=jb-16|0;jb=c;gc(a,b,7);jb=c+16|0}function nC(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,36);jb=b+16|0}function kB(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,38);jb=b+16|0}function iB(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,41);jb=b+16|0}function f3(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function d4(a){a=a|0;kI(a,2,100);mp(v[a+24>>2]+484360|0,0)}function aT(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,66);jb=b+16|0}function aR(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,52);jb=b+16|0}function X0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb=0;return 0}function Rp(a){if((a|0)>=1){return(a|0)<120?a:120}return 1}function Pf(a,b){a=Gma(v[a>>2],v[a+4>>2],b,b>>31);return a}function Nm(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function NR(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,80);jb=b+16|0}function LP(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,96);jb=b+16|0}function GS(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,98);jb=b+16|0}function Fb(a){if(Fe(a)){return v[a+4>>2]}return w[a+11|0]}function ES(a){var b=0;b=jb-16|0;jb=b;Rb(a,0,48);jb=b+16|0}function AW(a,b,c){a=a|0;b=b|0;c=c|0;return nb[a|0](b,c)|0}function AD(a){a=v[a>>2]-12|0;if((Wu(a+8|0)|0)<=-1){Xb(a)}}function yw(a,b){return v[((a>>>24^b)<<2)+457184>>2]^a<<8}function tE(a){if(v[a>>2]){sE(a);TD($k(a),v[a>>2],_k(a))}}function pq(a){if(v[a>>2]){eC(a);pg(zb(a),v[a>>2],yf(a))}}function nj(a){a=v[a+656>>2];if(!a){return 0}return zi(a)}function ke(a){if(v[a>>2]){Re(zb(a),v[a>>2],v[zb(a)>>2])}}function ee(a,b,c){Uc(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function ch(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function bq(a){if(v[a>>2]){eB(a);Wn(zb(a),v[a>>2],Uf(a))}}function _U(a){a=a|0;UC(a,11650);v[a>>2]=77244;return a|0}function Wla(a,b,c){a=a|0;b=b|0;c=c|0;return EA(a,b,c)|0}
function V2(a){a=a|0;return rj(Vb(v[a+24>>2]+484360|0))|0}function Tn(a,b,c){Uc(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function Of(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function Mw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function LV(a){a=a|0;UC(a,11072);v[a>>2]=76900;return a|0}function Km(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function JG(a){while(1){if((Er(a)|0)!=-1){continue}break}}function IA(a){if(v[a>>2]){BT(a);pg(zb(a),v[a>>2],yf(a))}}function Dt(a){if(v[a>>2]){UR(a);Qt(zb(a),v[a>>2],Li(a))}}function De(a){if(!v[a+20>>2]){return 0}return v[a>>2]!=0}function As(a){if(v[a>>2]){DL(a);Re(zb(a),v[a>>2],yd(a))}}function xka(a,b){a=a|0;b=b|0;Ub(a,b?b:14548);return a|0}function wC(a){a=a|0;v[a>>2]=77128;Ku(a+12|0);return a|0}function vy(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function vS(a){a=a|0;if(!w[a|0]){return 1}return cg(a)|0}function ut(a){tn(a+88|0);tn(a+68|0);tn(a+48|0);return a}function tD(a,b,c){b=Da(a|0,b|0,c|0)|0;mb=O()|0;return b}function s1(a,b,c){a=a|0;b=b|0;c=c|0;return pd(B(b,c))|0}function n4(a,b,c){a=a|0;b=b|0;c=c|0;cd(a,KD(c,b,$e(b)))}function mha(a,b){a=a|0;b=b|0;return LF(a,Tb(b),Fb(b))|0}function li(a){return Ae(a)|Ae(a)<<8|Ae(a)<<16|Ae(a)<<24}function fE(a,b){gm(v[b>>2]);fm(v[a>>2]);v[a>>2]=v[b>>2]}function dV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Yu(a,b,c,d)}function aE(a){a=a|0;v[a>>2]=64824;yb(a+12|0);return a|0}function Zt(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function Zl(a,b,c){a=Gma(v[a>>2],v[a+4>>2],b,c);return a}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;return Cr(a,b,c)|0}function Wja(a,b,c){a=a|0;b=b|0;c=c|0;return DA(a,b,c)|0}function QF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Og(a,-1,-1)}function OV(a,b,c){a=a|0;b=b|0;c=c|0;Yu(a,b,v[b+8>>2],c)}function KB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ye(a,c,d,b)}function FH(a){a=a|0;v[a>>2]=83720;Yy(a+12|0);return a|0}function DH(a){a=a|0;v[a>>2]=83760;Wy(a+12|0);return a|0}function $D(a){a=a|0;v[a>>2]=64864;yb(a+16|0);return a|0}function uo(a){a=a|0;v[a>>2]=58688;Ob(a+4|0);return a|0}function sv(a){a=a|0;v[a>>2]=71224;AD(a+4|0);return a|0}function sA(a,b,c){a=a|0;b=b|0;c=c|0;return yT(a,b,c)|0}function jl(a){a=a|0;v[a>>2]=58624;Ob(a+4|0);return a|0}function j7(a){a=a|0;QI(a);t[a+4202|0]=1;v[a+4224>>2]=0}function iF(a){return(a|0)!=0&(a|0)!=60368&(a|0)!=60392}function hE(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){fm(b)}}function dr(a,b,c){return FE(Tb(a),Fb(a),Tb(b),c,Fb(b))}function _E(a,b,c,d){a=aF(a,b,c,0,-2147483648);return a}function Zc(a,b,c){a=a|0;b=b|0;c=c|0;Te(a,b);return a|0}function Wy(a){a=a|0;v[a>>2]=76312;Pg(a+4|0);return a|0}function Ur(a){a=a|0;v[a>>2]=83592;Rw(a+4|0);return a|0}function UG(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function Tz(a,b,c){a=a|0;b=b|0;c=c|0;return FA(a,b,c)|0}function Sq(a){a=a|0;v[a>>2]=71244;AD(a+4|0);return a|0}function QN(a,b,c){a=a|0;b=b|0;c=c|0;return Rs(a,b,c)|0}function QA(a){if(w[a+1|0]==2){return w[a|0]<3}return 0}function NI(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function MI(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function Lba(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function Ku(a){a=a|0;v[a>>2]=77168;Bb(a+4|0);return a|0}function Kc(a){if(Fe(a)){a=hk(a)-1|0}else{a=10}return a}function Hla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nA(b,c,d)}function Az(a,b,c){b=b-a|0;if(b){$i(c,a,b)}return b+c|0}function y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ri(a,c,d)}function s3(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function ng(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+20>>2]](a,b)}function ej(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function cJ(a){a=a|0;return Ai(C(z[a+4224>>2]*C(4)))|0}function a0(a){a=a|0;return If(v[v[a>>2]-12>>2]+a|0)|0}function _g(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+24>>2]](a,b)}function Zg(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+28>>2]](a,b)}function X2(a){a=a|0;return Yd(v[v[a>>2]-12>>2]+a|0)|0}function Vq(a){if(Fe(a)){a=hk(a)-1|0}else{a=1}return a}function Raa(a){a=a|0;z[a+12>>2]=1;ZK(a,4);return a|0}
function NF(a){a=a|0;return nr(v[v[a>>2]-12>>2]+a|0)|0}function Lg(a){var b=0;b=Er(a);v[a+1396>>2]=0;return b}function Iu(a,b){a=Fma(v[a>>2],v[a+4>>2],b,0);return a}function CN(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;yy(a)}function Ao(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function AF(a){a=a|0;return kr(v[v[a>>2]-12>>2]+a|0)|0}function zC(a){var b=0;b=jb-16|0;jb=b;am(a);jb=b+16|0}function yb(a){if(Fe(a)){pg(a,v[a>>2],hk(a))}return a}function wma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function wO(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function vm(a,b){return nb[v[v[a>>2]+36>>2]](a,b,0)|0}function um(a,b){return nb[v[v[a>>2]+52>>2]](a,b,0)|0}function uc(a,b,c){a=a|0;b=b|0;c=c|0;bt(a);return a|0}function hO(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function gW(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+48}function fi(a){a=a|0;return nb[v[v[a>>2]+12>>2]](a)|0}function ei(a){a=a|0;return nb[v[v[a>>2]+16>>2]](a)|0}function _m(a){a=a|0;return nb[v[v[a>>2]+24>>2]](a)|0}function ZV(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function Ye(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function U2(a){a=a|0;return lK(v[a+24>>2]+484344|0)|0}function T8(a,b,c){a=a|0;b=b|0;c=c|0;Kl(a,b+4260|0,8)}function T1(a,b){a=a|0;b=b|0;VM(v[a>>2],b);return a|0}function QR(a){var b=0;b=jb-16|0;jb=b;Zt(a);jb=b+16|0}function Kn(a,b){a=a|0;b=b|0;return Ce(a)>>>0>b>>>0|0}function GC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function r4(a){a=a|0;a=v[a+4>>2];return(a?a:38169)|0}function q9(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function hia(a,b){a=a|0;b=b|0;return LF(a,b,$e(b))|0}function g3(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function fla(a){a=a|0;return zK(w[a+3|0],w[a+5|0])|0}function dJ(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function c3(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function ao(a){a=a|0;a=a+12|0;nb[v[v[a>>2]>>2]](a)|0}function Zm(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function T7(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function Mn(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function Ema(a){if(a){return 31-E(a-1^a)|0}return 32}function E8(a){a=a|0;t[a+4202|0]=1;cs(a);ex(a);wJ(a)}function zba(a){a=a|0;wf(85224);wf(85216);yb(85204)}function yC(a,b,c){Tk(a,b);v[a+12>>2]=c;v[a+8>>2]=0}function y1(a,b,c){a=a|0;b=b|0;c=c|0;$G(a-88|0,b,c)}function wr(a){if(!a){return 0}v[114552]=a;return-1}function rda(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0}function r3(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function q7(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function oo(a,b){b=v[b>>2];v[a>>2]=b;gm(b);return a}function nl(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function mN(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function hy(a){a=a|0;return Bs(w[a+2|0],w[a+4|0])|0}function hm(a,b){Ze(a,b);Rb(a+16|0,0,1040);return a}function b3(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function W9(a,b){a=a|0;b=b|0;a=a+24|0;uK(a,b);Nx(a)}function Um(a,b,c){if(!c){return 0}return qd(a,b,c)}function Qr(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function Nd(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function Mc(a,b){a=a|0;b=b|0;return aO(a,b,$e(b))|0}function Lc(a){if(Fe(a)){lo(v[a>>2],hk(a))}return a}function Kl(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function Iy(a,b){a=a|0;b=b|0;return eo(a,b,$e(b))|0}function Eo(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function Eb(a,b,c){Uc(a,(c>>>3&536870908)+b|0,1<<c)}function Ds(a){a=a|0;return Bs(w[a+3|0],w[a+5|0])|0}function A1(a,b,c){a=a|0;b=b|0;c=c|0;bH(a-88|0,b,c)}function z1(a,b){a=a|0;b=b|0;return aH(a-88|0,b)|0}function yl(a){xi(a+724|0);xi(a+736|0);xi(a+748|0)}function w1(a,b){a=a|0;b=b|0;return _G(a-88|0,b)|0}function tha(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,24,b)}function pba(a,b){a=a|0;b=b|0;return lc(a,b,116)|0}function jG(a,b){cG(a,74);v[a+4>>2]=v[a+4>>2]|b&74}function iq(a,b,c){a=a|0;b=b|0;c=c|0;cd(a,UN(b,c))}function Zz(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function Qja(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,16,b)}function Ny(a,b,c){a=a|0;b=b|0;c=c|0;HO(Od(a,b),c)}function Nq(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function Lz(a,b,c){Kl(a,v[b+28>>2]+(c<<12)|0,4096)}function Lp(a){return(v[a+480180>>2]&740327453)!=0}function HM(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function FO(a,b,c){a=a|0;b=b|0;c=c|0;cd(a,Iy(b,c))}function Ei(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function C1(a,b,c){a=a|0;b=b|0;c=+c;dH(a-88|0,b,c)}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,33,b)}function $9(a,b){a=a|0;b=b|0;Wi(a+36|0,b);return 1}function yg(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,32,b)}function yG(a,b){gw(v[v[a>>2]-12>>2]+a|0,v[b>>2])}function xp(a){return(v[zb(a)>>2]-v[a>>2]|0)/20|0}function ve(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function tG(a,b){if(!a){return 0}return ck(a,b,0)}function sn(a){return(v[zb(a)>>2]-v[a>>2]|0)/56|0}function no(a){return(v[ec(a)>>2]-v[a>>2]|0)/12|0}function lga(a,b){a=a|0;b=b|0;return nb[b|0](a)|0}function lg(a){return(v[zb(a)>>2]-v[a>>2]|0)/12|0}function kj(a){return(v[zb(a)>>2]-v[a>>2]|0)/52|0}function Yf(a,b){return FE(Tb(a),Fb(a),b,0,$e(b))}function Xt(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,64,b)}function We(a){return(v[zb(a)>>2]-v[a>>2]|0)/24|0}function Uc(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function Tl(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,22,b)}function Sg(a,b){if(Fe(a)){we(a,b);return}of(a,b)}function Nl(a){return(v[ec(a)>>2]-v[a>>2]|0)/24|0}function Nja(a,b){a=a|0;b=b|0;return js(a,b,17)|0}function Ml(a){return(v[zb(a)>>2]-v[a>>2]|0)/48|0}function Kt(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,28,b)}function Jl(a){return(v[zb(a)>>2]-v[a>>2]|0)/33|0}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,9,b)}function Hn(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,20,b)}function Hk(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,12,b)}function HS(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,40,b)}function GT(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,30,b)}function FF(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function Bu(a,b,c){a=a|0;b=b|0;c=c|0;Ye(a,c,26,b)}function Bl(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function yy(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function yK(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function rh(a){return(mf(a)|0)!=(0-mf(a+12|0)|0)}function rT(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function iS(a,b){a=a|0;b=b|0;return js(a,b,32)|0}function iO(a,b){Qc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function gv(a,b,c){a=a|0;b=b|0;c=c|0;iD(c);Xb(a)}function _ka(a,b){a=a|0;b=b|0;return Ul(a,b,3)|0}function _T(a,b){a=a|0;b=b|0;return js(a,b,11)|0}function Tb(a){if(Fe(a)){return v[a>>2]}return a}function Rm(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Mx(a){v[a+4>>2]=0;v[a+8>>2]=-1;t[a|0]=0}function Li(a){return(v[zb(a)>>2]-v[a>>2]|0)/6|0}function Kh(a){return v[a+8>>2]!=0|v[a+12>>2]!=0}function Jla(a,b,c){a=a|0;b=b|0;c=c|0;lc(b,c,48)}function Cp(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function B1(a,b){a=a|0;b=b|0;return+cH(a-88|0,b)}function Aia(a,b){a=a|0;b=b|0;return Ul(a,b,2)|0}function zZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461708))}function yZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461716))}function xr(a){var b=0;b=v[a>>2];qg(a);return b}function xZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461724))}function wk(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function wc(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function wZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461488))}function vZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461496))}function uZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461504))}function tZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461512))}function s7(a){a=a|0;return z[a+4212>>2]<C(1)|0}function rZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461552))}function qZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461560))}function ph(a,b){a=a|0;b=b|0;return Ul(a,b,4)|0}function pZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461568))}function oZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461576))}function mZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461584))}function jf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function jZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461592))}function hZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461600))}function fZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461608))}function eZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461520))}function dZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461528))}function bk(a){a=a|0;return IF(v[a>>2])<<24>>24}function bZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461536))}function ZY(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461616))}function YY(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461624))}function V7(a){a=a|0;return z[a+4220>>2]<C(1)|0}function UP(a,b){a=a|0;b=b|0;return Ul(a,b,8)|0}function Ts(a,b){a=a|0;b=b|0;Af(a,b);return a|0}function Rn(a,b){a=a|0;b=b|0;return Xe(a,b,0)|0}function Qs(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Qj(a){return nb[v[v[a>>2]+36>>2]](a)|0}function Q9(a,b){a=a|0;b=b|0;return js(a,b,1)|0}function Nv(a,b,c,d){a=aF(a,b,c,-1,-1);return a}function Ni(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function L9(a,b){a=a|0;b=b|0;tB(a,b);return a|0}function Id(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function IW(a){a=a|0;a=jb-a&-16;jb=a;return a|0}function HZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461472))}function HU(a,b){a=a|0;b=b|0;On(a,b);return a|0}function GZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461480))}function Fp(a,b,c){b=b-a|0;if(b){$i(c-b|0,a,b)}}function FZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461676))}function Em(a){return nb[v[v[a>>2]+28>>2]](a)|0}function EZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461668))}function DZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461684))}function Cl(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Bk(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function BZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461692))}function Ag(a,b){a=a|0;b=b|0;HF(a,v[a+16>>2]|b)}function AZ(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461700))}function $Y(a,b){a=a|0;b=b|0;Qd(a,b,Kd(461544))}function vp(a,b){return(B(b,104)+a|0)+484380|0}function uN(a){tN(a);Rb(a+27|0,0,255);return a}function ks(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function gc(a,b,c){a=a|0;b=b|0;c=c|0;Kl(a,b,c)}function fk(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function bo(a){RC(a);v[a+8>>2]=0;v[a>>2]=70608}function bg(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function Vz(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function Qe(a,b,c){if(!(w[a|0]&32)){lv(b,c,a)}}function Ps(a){return(a>>>0<9?a:a-9|256)&65535}function PS(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function N7(a){a=a|0;t[a+4202|0]=1;aJ(a);bJ(a)}function FN(a,b){AN(v[a>>2],b);AN(v[a+4>>2],b)}function F7(a){a=a|0;t[a+4202|0]=1;YI(a);XI(a)}function F0(a,b,c){a=a|0;b=b|0;c=c|0;Uc(a,c,b)}function Ck(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function $6(a){a=a|0;OI(a);Zw(a);t[a+4202|0]=1}function zi(a){return(w[a+31|0]-1&255)>>>0<17}function zF(a){a=a|0;Wv(v[v[a>>2]-12>>2]+a|0)}function zE(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function uu(a,b){a=a|0;b=b|0;return su(a,b)|0}function to(a,b){a=a|0;b=b|0;return JF(a,b)^1}function qla(a,b,c){a=a|0;b=b|0;c=c|0;Ze(b,c)}function oA(a,b){a=a|0;b=b|0;return Nu(a,b)|0}function lr(a,b){a=a|0;b=b|0;return DF(a,b)^1}function jk(a){return v[zb(a)>>2]-v[a>>2]>>11}function jg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function hga(a){a=a|0;Ly(a+288|0);sp(a+800|0)}function fv(a,b){a=a|0;b=b|0;return Iy(a,b)|0}function fj(a,b){a=a|0;b=b|0;return JF(a,b)|0}function eT(a){t[a+12|0]=w[a+12|0]|2;return a}function at(a,b){a=a|0;b=b|0;return UN(a,b)|0}function _j(a,b){a=a|0;b=b|0;return DF(a,b)|0}function V$(a){a=a|0;KF(v[v[a>>2]-12>>2]+a|0)}function Uw(a){a=a|0;v[a>>2]=83460;return a|0}function TN(a,b){a=a|0;b=b|0;return sd(a,b)|0}function R2(a){a=a|0;OH(v[v[a>>2]-12>>2]+a|0)}function Qf(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Pi(a,b){a=a|0;b=b|0;return CA(a,b)|0}function NM(a,b){if(!(z[a>>2]<=b)){z[a>>2]=b}}function MF(a){a=a|0;Zv(v[v[a>>2]-12>>2]+a|0)}function Jb(a,b){a=a|0;b=b|0;return rl(a,b)^1}function Ima(a,b,c,d){a=Dma(a,b,c,d);return a}function Gi(a,b){a=a|0;b=b|0;return Jb(a,b)|0}function ER(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function EM(a){DM(a+20|0);$L(a+8|0);wf(a+4|0)}function Cc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function Bia(a){a=a|0;IQ(a);return v[a+16>>2]}function Ak(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function yd(a){return v[zb(a)>>2]-v[a>>2]>>2}function ug(a){return v[v[a+8>>2]>>2]==(a|0)}function th(a){return v[zb(a)>>2]-v[a>>2]>>5}function sg(a){return v[ec(a)>>2]-v[a>>2]>>2}function hv(a){return v[ec(a)>>2]-v[a>>2]>>4}function gx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function gka(a,b){a=a|0;b=b|0;Sp(Rb(b,0,48))}function e3(a){a=a|0;return NH(v[a+24>>2])|0}function a1(a){a=a|0;return _a(v[a+60>>2])|0}function _w(a){return C(C(a*C(7900))+C(100))}function _k(a){return v[Uq(a)>>2]-v[a>>2]>>2}function Zh(a){return v[zb(a)>>2]-v[a>>2]>>4}function Vn(a){return v[ec(a)>>2]-v[a>>2]>>1}function Uz(a,b,c){a=a|0;b=b|0;c=c|0;pI(a,c)}function Ui(a){return v[zb(a)>>2]-v[a>>2]>>3}function Uf(a){return v[zb(a)>>2]-v[a>>2]>>1}function Su(a){return v[ec(a)>>2]-v[a>>2]>>5}function RJ(a,b,c){a=a|0;b=b|0;c=c|0;Gp(b,c)}function Jz(a,b,c){a=a|0;b=b|0;c=c|0;Af(b,c)}function Gia(a){a=a|0;IQ(a);return v[a+4>>2]}function Ev(a,b,c){a=a|0;b=b|0;c=c|0;cd(b,c)}function Bi(a,b,c){a=a|0;b=b|0;c=c|0;Ws(a,c)}function yf(a){return v[zb(a)>>2]-v[a>>2]|0}function xL(a){return a>>>0<=255&a>>>0>=251}function ti(a,b){a=a|0;b=b|0;return C(C(0))}function r7(a){a=a|0;return C(z[a+4220>>2])}function mf(a){return v[a+4>>2]-v[a>>2]>>11}function kZ(a,b){a=a|0;b=b|0;return ai(b)|0}function il(a){a=a|0;Yv(v[a>>2]);return a|0}function gJ(a){a=a|0;nb[v[v[a>>2]+4>>2]](a)}function fJ(a){a=a|0;return C(z[a+4208>>2])}function fA(a){return v[ec(a)>>2]-v[a>>2]|0}function f1(a){a=a|0;cG(a,16384);return a|0}function e1(a,b){a=a|0;b=b|0;return bh(a)|0}function dG(a){RH(a);v[a>>2]=59220;return a}function d1(a){a=a|0;gw(a,16384);return a|0}function cG(a,b){v[a+4>>2]=v[a+4>>2]&(b^-1)}function Ue(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function U7(a){a=a|0;return C(z[a+4212>>2])}function Tr(a){RH(a);v[a>>2]=59148;return a}function TY(){oo(461652,iE());return 461652}function PD(a,b){a=a|0;b=b|0;return rm(b)|0}function Gg(a,b,c){return Ma(a|0,b|0,c|0)|0}function EN(a,b){u[a+22>>1]=b&7;yy(a);zy(a)}function Bm(a){a=a|0;BF(v[a>>2]);return a|0}function AI(a){return Lh(C(CI(a)*C(32768)))}function zma(a,b){a=a|0;b=b|0;Wi(a+12|0,b)}function xe(a){return v[a+4>>2]-v[a>>2]>>5}function vl(a){yb(a+36|0);oe(a+24|0);Ll(a)}function tt(a,b){return v[a>>2]-v[b>>2]>>2}function ru(a){a=a|0;return Yg(a,461676)|0}function od(a){return v[a+4>>2]-v[a>>2]>>4}function oc(a){return v[a+4>>2]-v[a>>2]>>1}function oI(a,b){a=a|0;b=b|0;Uv(a,v[b>>2])}function k8(a,b,c){a=a|0;b=b|0;c=c|0;Qf(a)}function hk(a){return v[a+8>>2]&2147483647}function h3(a){a=a|0;return+BL(v[a+24>>2])}function f0(a){a=a|0;return Yg(a,461488)|0}function dw(a){a=a|0;return Yg(a,461684)|0}function cw(a){a=a|0;return Yg(a,461692)|0}function cF(){return(v[v[21203]>>2]?4:1)|0}function aba(a,b){a=a|0;b=b|0;Wi(a+40|0,b)}function Zy(a){ke(a+24|0);fe(a+12|0);fe(a)}function Zq(a,b){nb[v[v[b>>2]+40>>2]](a,b)}function Xv(a){a=a|0;return Yg(a,461668)|0}function Vp(a,b){return v[a>>2]-v[b>>2]>>1}function Uu(a){Fq(a+28|0);Bb(a+12|0);yb(a)}function T$(a){a=a|0;return Yg(a,461504)|0}function Sj(a,b){nb[v[v[b>>2]+44>>2]](a,b)}function Rj(a,b){nb[v[v[b>>2]+32>>2]](a,b)}function Pr(a){return(a|0)<=65535&(a|0)>=0}function P8(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function Lv(a){a=a|0;return Yg(a,461716)|0}function Kb(a){return v[a+4>>2]-v[a>>2]>>2}function Iv(a){a=a|0;return Yg(a,461724)|0}function HV(a){a=a|0;return v[a+4>>2]!=0|0}function GI(a){return C(C(a*C(96))+C(-96))}function Dg(a){return v[a+4>>2]-v[a>>2]>>3}function DN(a,b){t[a+21|0]=b&3;yy(a);zy(a)}function D2(a,b){a=a|0;b=b|0;return b-a>>3}function A5(a,b){a=a|0;b=b|0;Uv(a,x[b>>1])}function u1(a,b){a=a|0;b=b|0;YG(a-88|0,b)}function te(a){v[a>>2]=v[a>>2]+2;return a}function sd(a,b){return v[a>>2]+B(b,12)|0}function rz(a,b){return v[a>>2]+B(b,20)|0}function nr(a){a=a|0;ah(a+8|0);return a|0}function n1(a){a=a|0;if(a){NG(a);Xd(a,a)}}function mm(a,b,c){ri(a,b,b+c|0);return a}function kr(a){a=a|0;ah(a+4|0);return a|0}function kC(a){return(w[a+24|0]&16)>>>4|0}function hs(a,b,c){return u[b>>1]<u[c>>1]}function gl(a){a=a|0;return CF(v[a>>2])|0}function d6(a,b){a=a|0;b=b|0;Uv(a,w[b|0])}function cY(a,b){a=a|0;b=b|0;Af(a,b+16|0)}function _d(a){v[a>>2]=v[a>>2]+4;return a}function _M(a){v[a>>2]=v[a>>2]-4;return a}function Yl(a,b){return v[a>>2]+(b<<11)|0}function Xn(a,b,c){return x[b>>1]<x[c>>1]}function Wm(a){return v[v[a+48>>2]+12>>2]}function UN(a,b){return eo(a,Tb(b),Fb(b))}function Rc(a,b){return v[a>>2]+B(b,24)|0}function RN(a){v[a>>2]=v[a>>2]-2;return a}function PK(a,b){Bl(a,A[b>>3],-A[b+8>>3])}function P9(a,b){a=a|0;b=b|0;Af(a,b+36|0)}function Md(a,b){v[a>>2]=v[b>>2];return a}function MH(a,b){a=a|0;b=b|0;Af(a,b+12|0)}function K8(a,b){a=a|0;b=b|0;Rb(b,0,2048)}function K1(a,b){a=a|0;b=b|0;lH(a-88|0,b)}function J1(a,b){a=a|0;b=b|0;kH(a-88|0,b)}function Ge(a,b){return v[a>>2]+B(b,52)|0}function Fw(a){a=a|0;Sr(a+8|0);return a|0}function Fl(a,b){return v[a>>2]+B(b,56)|0}function FI(a){a=a|0;Rb(a+4296|0,0,81928)}function En(a){return x[a+480190>>1]<3999}function CR(a,b){return v[a>>2]+B(b,33)|0}function Bc(a,b){a=a|0;b=b|0;oo(a,b+28|0)}function Ac(a){return v[a+4>>2]-v[a>>2]|0}function $l(a,b){return v[a>>2]-v[b>>2]|0}function wt(a){a=a|0;return v[a>>2]+14|0}function tc(a,b){return v[a>>2]+(b<<4)|0}function rl(a,b){return v[a>>2]==v[b>>2]}function rc(a,b){return v[a>>2]+(b<<1)|0}function pu(a,b){return v[a>>2]+(b<<5)|0}function pE(){Ld(463120);v[115780]=67864}function oE(){Ld(463152);v[115788]=68360}function nd(a){return v[a>>2]==v[a+4>>2]}function nJ(a){return(w[a+24|0]&8)>>>3|0}function nE(){Ld(463160);v[115790]=68524}function mE(){Ld(463168);v[115792]=68688}function lk(a){return x[Wm(a)+480188>>1]}function lE(){Ld(463176);v[115794]=68852}function kma(a,b){a=a|0;b=b|0;Uc(a,b,44)}function kE(){Ld(463248);v[115812]=69016}function fl(a){return(a|0)==32|a-9>>>0<5}function fI(a){return(Tb(a)+Fb(a)|0)-1|0}function en(a){a=a|0;return CM(w[a|0])|0}function cg(a){a=a|0;return be(w[a|0])|0}function bY(a,b){a=a|0;b=b|0;Ub(a,64896)}function b9(a){a=a|0;AT(a,80,150,80,255)}function aY(a,b){a=a|0;b=b|0;Av(a,64904)}function _X(a,b){a=a|0;b=b|0;Av(a,64932)}function Zn(a){return B(sq(a),ue(a))&255}function Z6(a){a=a|0;return v[a+4260>>2]}function Uk(a,b){return v[a>>2]+(b<<3)|0}function TC(a,b){Zb(a,b);Zb(a+4|0,b+4|0)}function RC(a){v[a+4>>2]=0;v[a>>2]=70552}function Pb(a,b){return v[a>>2]+(b<<2)|0}function P1(a){a=a|0;return Fw(a-88|0)|0}function Nc(a,b){return v[a>>2]+B(b,6)|0}function Mr(a,b){v[a+24>>2]=v[a+24>>2]+b}function Mb(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function I1(a,b){a=a|0;b=+b;jH(a-88|0,b)}function Hha(a,b){a=a|0;b=b|0;Uc(a,b,10)}function Gf(a){a=a|0;return!v[a+16>>2]|0}function G1(a,b){a=a|0;b=+b;hH(a-88|0,b)}function Fja(a,b){a=a|0;b=b|0;Uc(a,b,17)}function Fg(a,b){v[a+8>>2]=b|-2147483648}function E1(a,b){a=a|0;b=+b;fH(a-88|0,b)}function $X(a,b){a=a|0;b=b|0;Ub(a,64924)}function xi(a){v[a+4>>2]=0;v[a+8>>2]=-1}function xM(a,b){return(vk(a,b)|0)!=255}function wy(a,b,c){if(b){Rb(a,Cg(c),b)}}function wB(a,b){a=a|0;b=b|0;return b|0}function qha(a,b){a=a|0;b=b|0;Uc(a,b,5)}function oda(a,b){a=a|0;b=b|0;Bl(b,0,0)}function nS(a,b){v[a>>2]=v[a>>2]+B(b,6)}function jJ(a,b){return z[a>>2]<z[b>>2]}function j1(a){a=a|0;jG(a,2);return a|0}function h1(a){a=a|0;jG(a,8);return a|0}function Yp(a,b){return v[a>>2]<v[b>>2]}function YQ(a,b){v[a>>2]=v[a>>2]+(b<<2)}function Xd(a,b){if(!v[a+80>>2]){Xb(b)}}function Vt(a){a=a|0;return eA(oc(a))|0}function QL(a,b){return A[a>>3]<A[b>>3]}function OT(a,b){a=a|0;b=b|0;Uc(a,b,11)}function O8(a){a=a|0;return w[a+4201|0]}function N8(a){a=a|0;return w[a+4202|0]}function LE(a,b){a=a|0;b=b|0;Hj(a,1,45)}function KE(a,b){a=a|0;b=b|0;UE(a,1,45)}function Jd(a,b){return y[a>>2]<y[b>>2]}function Fh(a,b,c){cd(a,b);cd(a+12|0,c)}function C6(a){a=a|0;return(a|0)==277|0}function Au(a,b){a=a|0;b=b|0;Uc(a,b,32)}function ys(a){return(a|0)<=-1?0-a|0:a}function vs(a){a=a|0;return 2147483647}function vc(a){v[v[a+8>>2]>>2]=v[a>>2]}function ue(a){return w[a+34|0]&64?2:1}function t0(a){a=a|0;return v[a+20>>2]}function q3(a){a=a|0;return+A[a+16>>3]}function mU(a,b){a=a|0;b=b|0;u[b>>1]=0}function mS(a,b){a=a|0;b=b|0;bs(a,0,b)}function iga(a){a=a|0;BO(a);return a|0}function hj(a,b){return Tb(a)+(b<<2)|0}function gw(a,b){v[a+4>>2]=v[a+4>>2]|b}function be(a){return(a-1&255)>>>0<120}function XN(a,b){v[a+4>>2]=b;v[a>>2]=b}function Vha(a){a=a|0;return w[a+40|0]}function UC(a,b){DD(a,b);v[a>>2]=71484}function U1(a){a=a|0;return v[a+16>>2]}function SU(a){a=a|0;return v[a+12>>2]}function QB(a){zb(a);return 2147483647}function K6(a){a=a|0;return-2013527448}function JU(a){a=a|0;return v[a+24>>2]}function IH(a){return a?(a|0)==2?3:2:1}function H1(a){a=a|0;return+iH(a-88|0)}function F1(a){a=a|0;return+gH(a-88|0)}function D1(a){a=a|0;return+eH(a-88|0)}function Aj(a){return B(v[a>>2],Zn(a))}function zu(a){return w[a+21|0]>>>7|0}function yt(a){a=a|0;return Qb(a,1)^1}function yI(a,b){a=a|0;b=b|0;return 0}function y6(a,b){a=a|0;b=b|0;return 2}function x7(a){a=a|0;return-281111764}function wF(a){a=a|0;$v(a);return a|0}function t7(a){a=a|0;return-271958638}function sq(a){return t[a+34|0]&1?2:1}function s8(a){a=a|0;return 542066252}function qD(a,b){return w[a|0]<w[b|0]}function or(a,b){a=a|0;b=b|0;return-1}function nH(a){v[a>>2]=84408;return a}function kO(a){a=a|0;_P(a);return a|0}function ima(a,b){a=a|0;b=b|0;Us(a,b)}function i7(a){a=a|0;return-620920304}function hx(a,b){a=a|0;b=b|0;return 1}function dka(a){a=a|0;return w[a+8|0]}function ah(a){a=a|0;_v(a);return a|0}function _6(a){a=a|0;return-275227023}function YB(a){return w[a+22|0]>>>7|0}function W7(a){a=a|0;return-270114148}function Vb(a){return pu(a,w[a+16|0])}function T0(a){a=a|0;return aG(a,0)|0}function S0(a){a=a|0;return aG(a,1)|0}function R6(a){a=a|0;return 302837129}function Qv(a){a=a|0;if(iF(a)){Xb(a)}}function P0(a){a=a|0;return YF(a,0)|0}function O0(a){a=a|0;return YF(a,1)|0}function Nz(a){return v[a+1304496>>2]}function Ne(a,b){v[a+4>>2]=b;return a}function NH(a){return x[a+1074438>>1]}function M7(a){a=a|0;return-285139079}function Lt(a){return(w[a+16|0]&5)!=0}function JF(a,b){return uF(a)^uF(b)^1}function Fn(a,b){u[a+8>>1]=b;return a}function Fe(a){return w[a+11|0]>>>7|0}function Ek(a){a=a|0;Gt(a);return a|0}function E7(a){a=a|0;return-284078960}function DF(a,b){return tF(a)^tF(b)^1}function Cz(a){a=a|0;return v[a+8>>2]}function Bt(a){a=a|0;return v[a+4>>2]}function Bp(a){a=a|0;vt(a);return a|0}function A6(a,b){a=a|0;b=b|0;return 3}function $v(a){a=a|0;Sq(a);return a|0}function xma(a){a=a|0;return wq(a)|0}function vka(a){a=a|0;return Nz(a)|0}function pK(a,b){jf(a);qL(a,b);kK(a)}function lx(a,b){Kb(a);WR(a,b);Qg(a)}function jd(a,b){return Yl(a+12|0,b)}function j8(a,b,c){a=a|0;b=b|0;c=c|0}function it(a){return v[zb(a)>>2]<<5}function gm(a){v[a+4>>2]=v[a+4>>2]+1}function f8(a,b){a=a|0;b=b|0;Ts(a,b)}function eY(a){a=a|0;return t[a+8|0]}function dY(a){a=a|0;return t[a+9|0]}function bS(a,b){Ac(a);uT(a,b);tp(a)}function bB(a,b){a=a|0;b=b|0;aB(a,b)}function _ca(a){a=a|0;return Lj(a)|0}function Ws(a,b){a=a|0;b=b|0;Af(a,b)}function VR(a,b){Kb(a);tL(a,b);Qg(a)}function VN(a,b){xe(a);ON(a,b);Zu(a)}function Ut(a){return v[a+4>>2]-24|0}function Tg(a){return v[a+4>>2]-32|0}function Pz(a,b){bg(a);TR(a,b);IR(a)}function Pn(a,b){oc(a);FB(a,b);Nn(a)}function PV(a){a=a|0;return Cf(a)|0}
function PH(a){return v[a+4>>2]-48|0}function LH(a){return v[a+4>>2]-12|0}function Iaa(a){a=a|0;return Ih(a)|0}function Fu(a,b){Ac(a);dC(a,b);tp(a)}function DP(a){return v[a+4>>2]-56|0}function DI(a){v[a>>2]=0;v[a+4>>2]=0}function Cu(a,b){Kb(a);TB(a,b);Qg(a)}function CM(a){return(a+5&255)>>>0<2}function zs(a){return _o(a)<<24>>24}function yq(a){a=a|0;return Gd(a)|0}function yn(a,b,c){return Xn(a,b,c)}function xh(a,b,c){if(c){lc(a,b,c)}}function xc(a,b){return v[a>>2]+b|0}function vw(a){return!qd(a,84484,6)}function qz(a,b){return cf(a,0-b|0)}function pha(a,b){a=a|0;b=b|0;Zy(b)}function pD(a){a=a|0;return v[a>>2]}function oj(a){return v[a+4>>2]-4|0}function mX(a){a=a|0;return Pe(a)|0}function mO(a,b){return pp(a,0-b|0)}function kda(a,b){a=a|0;b=b|0;ke(b)}function hda(a,b){a=a|0;b=b|0;kt(b)}function hC(a){a=a|0;return hg(a)|0}function h7(a){a=a|0;v[a+4224>>2]=0}function gf(a,b,c){return Az(a,b,c)}function fR(a){a=a|0;return wt(a)|0}function dW(a){a=a|0;return $F(a)|0}function cc(a){return Ng(v[a+4>>2])}function ada(a,b){a=a|0;b=b|0;jn(b)}function _l(a,b,c){if(c){$i(a,b,c)}}function _B(a){return w[a+21|0]&127}function ZB(a){return w[a+22|0]&127}function Vaa(a,b){a=a|0;b=b|0;vl(b)}function Uaa(a,b){a=a|0;b=b|0;ag(b)}function Se(a){return v[a+24620>>2]}function SB(a){t[a+2|0]=0;u[a>>1]=0}function Qc(a,b){v[a>>2]=b;return a}function Mda(a,b){a=a|0;b=b|0;Dl(b)}function Ija(a,b){a=a|0;b=b|0;wR(b)}function Ii(a,b){return B(b,12)+a|0}function D0(a){a=a|0;return Lt(a)|0}function Ct(a){a=a|0;return jh(a)|0}function zt(a,b){a=a|0;b=b|0;Zt(b)}function yi(a,b){return(b<<13)+a|0}function xk(a,b){Tn(a,b,v[b+4>>2])}function si(a){a=a|0;t[a+4202|0]=0}function r1(a,b){a=a|0;b=b|0;Xb(b)}function oW(a,b){a=a|0;b=b|0;uD(b)}function ni(a){return nd(a+36|0)^1}function jh(a){return v[a>>2]+16|0}function iu(a){t[a|0]=0;t[a+1|0]=0}function iU(a,b){a=a|0;b=b|0;Yh(b)}function eW(a){a=a|0;Cn(a,1,10956)}function cE(a,b){a=a|0;b=b|0;Ib(b)}function _q(a,b){a=a|0;b=b|0;tf(a)}function Zk(a){Qm(a);v[a>>2]=71116}function YA(a,b){a=a|0;b=b|0;iu(b)}function VA(a,b){a=a|0;b=b|0;Bb(b)}function Uj(a,b){a=a|0;b=b|0;Wb(a)}function Tc(a,b){bt(a);Qc(a+4|0,b)}function Ry(a,b){a=a|0;b=b|0;ff(b)}function Om(a,b){v[a+1304560>>2]=b}function Mz(a,b){a=a|0;b=b|0;At(b)}function My(a,b){a=a|0;b=b|0;bt(b)}function Ld(a){RC(a);v[a>>2]=65252}function KU(a,b){a=a|0;b=b|0;SB(b)}function Jn(a,b){a=a|0;b=b|0;hf(b)}function Jg(a,b){v[a>>2]=v[a>>2]|b}function Hh(a,b){Uc(a,Tb(b),Fb(b))}function Gr(a){return ve(a,-1)?0:a}function GE(a){return Yg(a,461560)}function Ew(a){a=a|0;t[a+6152|0]=0}function EE(a){return Yg(a,461552)}function DV(a,b){a=a|0;b=b|0;Uu(b)}function BE(a){return Yg(a,461576)}function AE(a){return Yg(a,461568)}function AC(a,b){a=a|0;b=b|0;am(b)}function zn(a){v[a>>2]=v[a>>2]+12}function z0(a){a=a|0;return 58288}function xQ(a,b){return Ul(a,b,5)}function sy(a){v[a>>2]=v[a>>2]+52}function rQ(a,b){return(b<<4)+a|0}function pJ(a){return a+1074328|0}function kc(a,b){return Tb(a)+b|0}function jha(a){a=a|0;Yy(a);Xb(a)}function fP(a,b){return au(a,b,4)}function ed(a,b){return(b<<1)+a|0}function dha(a){a=a|0;Wy(a);Xb(a)}function bn(a){return a+1074324|0}function bh(a){return a-48>>>0<10}function bc(a){return Ng(v[a>>2])}function _W(a){a=a|0;return 71128}function XW(a){a=a|0;return 71640}function Ve(a,b){return(b<<2)+a|0}function Uh(a){v[a>>2]=1;return a}function UA(a,b){return au(a,b,7)}function Tw(a,b){return VK(a,b)^1}function Tf(a){v[a>>2]=v[a>>2]+16}function TA(a){return w[a+1|0]==1}function RA(a,b){return Ul(a,b,7)}function Ow(a){return a+1304500|0}function O$(a){a=a|0;return 58936}function Lk(a,b){Ze(a,b);return a}function Ke(a){return v[hc(a)>>2]}function Ik(a){v[a>>2]=v[a>>2]+24}function Hy(a,b){cd(a,b);return a}function Hu(a){return t[a+24|0]&1}function Ht(a,b){return Vd(a,b)^1}function Gn(a){v[a>>2]=2;return a}function Gk(a){v[a>>2]=0;return a}function Eha(a){a=a|0;iR(a,65535)}function Ce(a){return jf(a)&65535}function By(a){v[a>>2]=v[a>>2]+32}function B0(a){a=a|0;return 58208}function Al(a){u[a>>1]=0;return a}function $m(a){Pg(a+4|0);return a}function $W(a){a=a|0;return 71091}function yP(a){sn(a);wk(a);sn(a)}function wK(a){bg(a);UR(a);IR(a)}function vf(a){yd(a);Kb(a);yd(a)}function vR(a){Kb(a);uR(a);Qg(a)}function v4(a){a=a|0;Uw(a);Xb(a)}function uy(a){v[a>>2]=v[a>>2]+8}function ui(a){Kb(a);XR(a);Qg(a)}function sL(a){kj(a);jf(a);kj(a)}function rv(a){a=a|0;sv(a);Xb(a)}function rd(a){return v[a>>2]!=0}function qg(a){v[a>>2]=v[a>>2]+1}function mI(a){a=a|0;Vw(a);Xb(a)}function ly(a){t[a|0]=0;return a}function ls(a){return xL(w[a|0])}function jR(a,b){lc(a,b+4|0,256)}function jE(a){_k(a);Kb(a);_k(a)}function ik(a){a=a|0;bf(a);Xb(a)}function iA(a){Ni(a);jT(a);iT(a)}function eP(a){return w[a|0]<129}function dX(a,b){a=a|0;b=b|0;L()}function cm(a){th(a);xe(a);th(a)}function bG(a){a=a|0;jl(a);Xb(a)}function aj(a){lg(a);wc(a);lg(a)}function ZF(a){a=a|0;uo(a);Xb(a)}function Xp(a){oc(a);eB(a);Nn(a)}function Wk(a){Zh(a);od(a);Zh(a)}function WS(a){Ml(a);Ni(a);Ml(a)}function Vu(a){a=a|0;Sq(a);Xb(a)}function Te(a,b){v[a>>2]=v[b>>2]}function Sp(a){return Rb(a,0,48)}function Rk(a){Uf(a);oc(a);Uf(a)}function RI(a){a=a|0;ax(a);Xb(a)}function Pt(a){Li(a);bg(a);Li(a)}function Ph(a){We(a);Id(a);We(a)}function PJ(a){mf(a);HJ(a);GJ(a)}function Ol(a){yf(a);Ac(a);yf(a)}function NJ(a){Kb(a);EJ(a);Qg(a)}function Ms(a){Kb(a);DL(a);Qg(a)}function MQ(a){xp(a);xp(a);GQ(a)}function Gs(a){Ac(a);BT(a);tp(a)}function Gq(a){xe(a);XC(a);Zu(a)}function FT(a){oc(a);xT(a);Nn(a)}function Eq(a){Ui(a);Dg(a);Ui(a)}function Cj(a){v[a>>2]=v[a>>2]+6}function BR(a){Jl(a);Bk(a);Jl(a)}function BJ(a){jk(a);mf(a);jk(a)}function yX(a){a=a|0;yb(461844)}function wX(a){a=a|0;Lc(461860)}function uX(a){a=a|0;yb(461876)}function sX(a){a=a|0;Lc(461892)}function rt(a,b){return WQ(a,b)}function mn(a){return sj(Sd(a))}function mj(a){return!v[a+4>>2]}function kv(a,b){return uf(a,b)}function jq(a,b){return NB(a,b)}function jn(a){yb(a+12|0);yb(a)}function ie(a){a=a|0;return a|0}function eL(a,b){return bL(a,b)}function _h(a,b){return a>>>b&1}function _e(a){yb(a+20|0);yb(a)}function _b(a,b){return Ge(a,b)}function So(a){u[a+480214>>1]=0}function SP(a,b){return Ci(b,a)}function Qi(a,b,c){Ye(a,c,13,b)}function Pj(a,b,c){Uc(a,b,1<<c)}function Pd(a,b){return Yl(a,b)}function Ok(a,b){return OB(a,b)}function Nh(a){return xe(a)&255}function N1(a){a=a|0;mH(a-88|0)}function Jm(a){return a<<24>>24}function Je(a,b){return Wf(a,b)}function GX(a){a=a|0;yb(461780)}function EX(a){a=a|0;Lc(461796)}function Dl(a){yb(a+12|0);kf(a)}function Di(a,b){return pu(a,b)}function CX(a){a=a|0;yb(461812)}function AX(a){a=a|0;Lc(461828)}function $q(a){a=a|0;return 127}function $o(a){oe(a+12|0);gN(a)}function vY(a){a=a|0;Xb(yE(a))}function v0(a){a=a|0;Xb($v(a))}function tV(a){a=a|0;Xb(wC(a))}function sJ(a){a=a|0;Xb(tJ(a))}function s4(a){a=a|0;Xb(Vw(a))}function s0(a){a=a|0;Xb(jl(a))}function rV(a){a=a|0;Xb(Ku(a))}function r2(a){a=a|0;Xb(Ur(a))}function py(a,b){return b-a>>1}function n0(a){a=a|0;Xb(uo(a))}function mH(a){a=a|0;Xb(Fw(a))}function l2(a){a=a|0;Xb(FH(a))}function is(a){return a>>>27^a}function iD(a){return a>>>0>16}function i2(a){a=a|0;Xb(DH(a))}function he(a,b){t[a|0]=w[b|0]}function gY(a){a=a|0;Xb(aE(a))}function fY(a){a=a|0;Xb($D(a))}function dc(a,b){v[a+100>>2]=b}function dL(a,b,c){qy(a,b,c,1)}function _I(a){a=a|0;Xb($I(a))}function Zv(a){a=a|0;Xb(nr(a))}function ZW(a){a=a|0;Xb(sv(a))}function ZD(a){a=a|0;Xb(zv(a))}function YW(a){a=a|0;Xb(Sq(a))}function Y6(a){a=a|0;return 13}function X7(a){a=a|0;Xb(ax(a))}function Wv(a){a=a|0;Xb(kr(a))}function WQ(a,b){return b-a>>2}function UY(a){a=a|0;Xb(gE(a))}function SI(a){a=a|0;Xb(TI(a))}function SF(a){a=a|0;Xb(ah(a))}function Pga(a){a=a|0;return 9}function OH(a){a=a|0;Xb(Yd(a))}function L$(a){a=a|0;Xb(wF(a))}function KI(a){a=a|0;Xb(LI(a))}function KF(a){a=a|0;Xb(If(a))}function J$(a){a=a|0;Xb(_v(a))}function IJ(a){a=a|0;Xb(JJ(a))}function EY(a){a=a|0;Xb(eE(a))}function ED(){return(Sa()|0)>0}function Bs(a,b){return a<<8|b}function B2(a){a=a|0;Xb(Or(a))}function AO(a){return a+4896|0}function vO(a,b){Rb(a,0,b<<2)}function ul(a,b){v[a+32>>2]=b}function tr(a,b){v[a+72>>2]=b}function se(a){a=a|0;return 1}function rq(a){Gu(a);return a}function re(a){a=a|0;return 2}function qj(a){return rd(a)^1}function p4(){return 19466496}function mh(a){return nd(a)^1}function kn(a,b){v[a+36>>2]=b}function kR(a){a=a|0;return 7}function ic(a){a=a|0;return 0}function hn(a){iy(a);return a}function gh(a){SM(a);return a}function fc(a,b){return a+b|0}function ct(a){return a+256|0}function ai(a){return sc(a,1)}function Xx(a){hn(a);return a}function Wx(a){sC(a);return a}function Sn(a){return a>>>0<5}function SV(a){a=a|0;return 3}function Ql(a){ju(a);return a}function Qk(a){return!v[a>>2]}function PF(a){a=a|0;return-1}function Oq(a,b,c){Uc(a,b,c)}
function Oi(a){cB(a);return a}function Oe(a,b){u[a+28>>1]=b}function Mp(a){pB(a);return a}function L7(a){a=a|0;return 6}function KK(a){a=a|0;return 5}function Hq(a){a=a|0;return 4}function Gt(a){Gk(a);return a}function CA(a,b){return b-a|0}function zc(a,b){a=a|0;b=b|0}function zP(a,b){Ye(a,b,8,2)}function xn(a,b){v[a+8>>2]=b}function we(a,b){v[a+4>>2]=b}function uR(a){TB(a,v[a>>2])}function sr(a,b){oo(a,b+4|0)}function sE(a){SD(a,v[a>>2])}function rL(a){qL(a,v[a>>2])}function po(a,b){lg(a);lg(a)}function of(a,b){t[a+11|0]=b}function oH(a){v[a>>2]=84384}function mk(a,b){yd(a);yd(a)}function km(a,b){Zh(a);Zh(a)}function jT(a){$S(a,v[a>>2])}function hK(a,b){kj(a);kj(a)}function gA(a,b){yf(a);yf(a)}function ec(a){return a+12|0}function eC(a){dC(a,v[a>>2])}function eB(a){FB(a,v[a>>2])}function cv(a,b){WC(a,Nd(b))}function _L(a){ZL(a,v[a>>2])}function _H(a){v[a>>2]=83632}function ZN(a,b){XN(a,cc(b))}function ZM(a){YM(a,v[a>>2])}function YN(a,b){XN(a,bc(b))}function XR(a){WR(a,v[a>>2])}function Wt(a,b){We(a);We(a)}function Uq(a){return a+16|0}function Ug(a){return a+20|0}function UR(a){TR(a,v[a>>2])}function UD(a,b){_k(a);_k(a)}function Rt(a,b){Li(a);Li(a)}function RH(a){v[a>>2]=59048}function Qo(a,b){z[a+8>>2]=b}function Qm(a){v[a>>2]=71152}function Pu(a,b){Ui(a);Ui(a)}function PN(a){ON(a,v[a>>2])}function Oo(a,b){z[a+4>>2]=b}function Nr(a){v[a>>2]=83912}function No(a,b){t[a+36|0]=b}function Kp(a){v[a>>2]=76544}function JQ(a,b,c){Ww(a,b,c)}function Hs(a,b){oy(a,Nd(b))}function HJ(a){CJ(a,v[a>>2])}function Eu(a,b){Uf(a);Uf(a)}function El(a,b){zb(b);zb(a)}function EL(a){return a+80|0}function EJ(a){yJ(a,v[a>>2])}function Dx(a,b){t[a+37|0]=b}function DL(a){tL(a,v[a>>2])}function Cx(a,b){t[a+38|0]=b}function Bq(a,b){th(a);th(a)}function BT(a){uT(a,v[a>>2])}function $k(a){return a+32|0}function zb(a){return a+8|0}function uG(){return 458208}function sp(a){Rb(a,0,4096)}function q4(){return 327688}function pm(){Yi(70684);L()}function iG(){Yi(55692);L()}function hc(a){return a+4|0}function fd(){Fc(55692);L()}function dd(a){return a+1|0}function cX(){return 463532}function Wo(a){Rb(a,0,8192)}function Wc(a){return!Fb(a)}function VB(a,b){Uc(a,b,22)}function Sy(a){v[a+12>>2]=0}function Sh(a){return a+3|0}function ML(a){Rb(a,0,1024)}function Kla(){return 65535}function IB(a,b){Uc(a,b,20)}function Hg(){Fc(70684);L()}function Gj(a,b){t[a+3|0]=b}function Fha(){return 65534}function Cg(a){return a&255}function Bf(a){return a+2|0}function zp(a){uz(a,Ke(a))}function zM(a){Yx(a,Ke(a))}function vE(a){jE(a);tE(a)}function up(a){We(a);Id(a)}function uj(a,b){Tn(a,b,0)}function tp(a){yf(a);Ac(a)}function tk(a){ny(a,Ke(a))}function sh(a,b,c){CC(b,c)}function rE(a){_k(a);Kb(a)}function qq(a){Ol(a);iC(a)}function oe(a){vf(a);As(a)}function mD(a){Zh(a);od(a)}function ld(a){aj(a);oC(a)}function kf(a){Rk(a);bq(a)}function kK(a){kj(a);jf(a)}function ip(a){Wk(a);hN(a)}function iT(a){Ml(a);Ni(a)}function hd(a){Wk(a);nB(a)}function ft(a){lg(a);wc(a)}function fe(a){Ol(a);pq(a)}function fB(a,b){Th(a,2,b)}function dT(a){Pt(a);bT(a)}function dS(a){t[a+31|0]=0}function av(a){Eq(a);VC(a)}function Zu(a){th(a);xe(a)}function YR(a){Kz(a,Ke(a))}function Xy(a,b,c){uP(b,c)}function Xi(a,b,c){kD(b,c)}function Xf(a,b,c){QC(b,c)}function XK(a){zx(a,Ke(a))}function Rw(a){Wk(a);lI(a)}function Qg(a){yd(a);Kb(a)}function Po(a,b){z[a>>2]=b}function Pg(a){Ol(a);IA(a)}function Oc(a){a=a|0;Xb(a)}function Ob(a){fm(v[a>>2])}function OP(a){vf(a);MP(a)}function Nn(a){Uf(a);oc(a)}function Mf(a){Eq(a);ty(a)}function Ly(a){Rb(a,0,512)}function Ll(a){Pt(a);Dt(a)}function LQ(a){vf(a);HQ(a)}function Jq(a){a=a|0;Kq(a)}function Jc(a){v[a+8>>2]=0}function IR(a){Li(a);bg(a)}function GJ(a){jk(a);mf(a)}function Ef(a,b){v[a>>2]=b}function C$(){return 60524}function B$(){return 61296}function Ap(a){vz(a,Ke(a))}function A$(){return 62848}function $R(a){Iz(a,Ke(a))}function $L(a){us(a,Ke(a))}function wR(a){Rb(a,0,33)}function vF(a){Rb(a,0,44)}function eG(a){gw(a,8192)}function UB(a){t[a+1|0]=3}function Q3(){return 2048}function KW(){return jb|0}function JW(a){a=a|0;jb=a}function yh(a,b){Wg(a,b)}function ih(a){a=a|0;L()}function hf(a){Bb(a+8|0)}function dQ(a,b){Yw(a,b)}function bt(a){v[a>>2]=0}function bA(a){t[a|0]=16}function PC(a,b){Qc(a,b)}function MA(a,b){nI(a,b)}function IN(a,b){xf(a,b)}function Ec(a){Pg(a+8|0)}function Dn(a,b){HF(a,b)}function At(a){yb(a+4|0)}function $M(a,b){YN(a,b)}function ff(a){t[a|0]=0}function wf(a){oy(a,0)}function ss(a){IL(a,0)}function rs(a){HL(a,0)}function kL(a){WK(a,0)}function ag(a){aS(a,0)}function Yc(a){tI(a,0)}function Gh(a){gI(a,0)}function Gc(a){ye(a,0)}function Fq(a){WC(a,0)}function sB(a){_d(a)}function Ib(a){yb(a)}function He(a){a=a|0}function sZ(){pE()}function nZ(){oE()}function lZ(){nE()}function iZ(){mE()}function gZ(){lE()}function _Y(){kE()}function aX(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var nb=c([null,Cl,Ub,iq,Af,Cma,Cn,Uia,hia,ij,mha,lga,Fea,bs,Cl,h0,YU,Xl,Ag,g0,$,ru,Nk,nW,sv,gv,ve,JU,Vl,Pi,kZ,uc,zc,Lb,Pi,Pka,Ip,kS,Ry,nh,fu,Mga,Yy,ih,se,se,dka,$ja,Bt,Sja,EP,zha,wha,aX,Wy,ih,se,ic,se,Gia,Bia,yia,sia,mia,jha,_ha,dha,Vha,Pha,ie,ih,wO,wea,Us,TN,at,QN,nO,hO,Qs,vda,Ba,mda,Zc,Zc,Ub,oX,ky,yca,nca,Zc,Hba,Gba,yM,uc,Zm,fh,Zc,nX,Bba,yda,zba,Aba,tba,pba,He,F9,zc,Taa,yM,On,Us,iX,kX,Cl,s9,r8,Io,On,k7,Af,c7,iE,H6,z6,u6,U3,L3,K$,E3,d6,V5,A5,oI,oI,f5,W4,Xr,iq,Vr,e4,a4,Vr,j1,h1,f1,d1,Vr,Vr,Co,Cl,Yd,OH,X2,R2,kr,Wv,AF,zF,Or,B2,zc,Cl,t2,a2,ic,ic,q0,X1,p0,O1,o0,x1,b0,D0,r0,m0,d0,Z$,Y$,rw,$$,i0,If,KF,a0,V$,nr,Zv,NF,MF,I$,at,H$,F$,YE,eo,Cl,e_,cr,Ws,D_,p_,uc,Ev,wE,cE,uc,uc,fu,Nq,qW,pW,mW,rW,zc,oW,zc,Ry,Nfa,lW,kW,jW,iW,Bi,gW,s$,e$,fW,eD,dD,eW,cr,dW,bW,fv,Jq,Wi,Mc,_V,jm,ZV,YV,$V,XV,WV,cW,Cfa,aW,cD,VV,UV,bD,TV,Ff,Lj,Pc,$u,Qb,OV,Kj,$u,NV,MV,LV,Sq,CV,BV,Zc,uc,AC,pD,xV,KV,Eg,JV,DV,Yh,Zc,AV,Eg,zV,Zc,zc,wV,vV,Eg,uV,Pi,Vu,Bt,ie,Oc,ao,yI,IV,Oc,HV,se,se,Bt,Cz,GV,EP,FV,EV,ie,Oc,ao,yV,Oc,ic,se,se,ic,ic,GC,wC,tV,ao,sV,Ku,rV,qV,pV,oV,nV,U1,mV,lV,kV,io,nf,Lb,fV,Faa,eV,Eaa,dV,wq,$b,Iaa,IC,ud,cV,fh,lX,uc,Zm,DC,cE,zc,tC,$U,_U,Vu,uc,uc,uc,hC,XU,WU,zc,zc,zc,VU,fu,Ry,Nq,LU,fh,TU,PU,KU,zc,hC,uu,IU,tu,HU,DU,CU,nu,Mn,zc,xU,xB,wU,Fd,yq,vB,vU,PV,pc,bd,uU,tU,sU,uB,tB,rU,qU,tg,_f,rg,pU,rB,qB,oU,oB,Ln,uc,nU,Zm,lU,Db,KB,Ic,uc,uc,iU,uc,mU,kU,zc,jU,nu,YA,VA,fU,eU,dU,cU,bU,zg,aU,$T,_T,ZT,mw,zJ,Db,yO,YT,dg,XT,ku,OA,id,Hd,Wi,lj,UT,TT,Si,qh,uL,ST,RT,eu,yc,bv,QT,NA,de,hu,Zs,Db,Ip,UU,OT,mq,Xe,dq,JT,tA,_C,wi,lf,Nb,wg,Bma,sA,Ama,Mc,Wp,Zda,zma,yma,mp,xma,HT,GT,vma,rA,uma,$9,Rn,Qn,sl,rx,zK,tma,CT,kJ,sma,rma,qma,Fk,qA,pma,oma,Au,zT,nma,mma,vT,wO,lma,kma,uc,mA,mA,jma,ima,TN,at,QN,Jn,Up,Tp,uc,zc,Qs,fma,ema,dma,ama,oA,$la,hA,_la,Zla,Yla,Vt,Xla,np,Jy,Wla,Vla,Ula,Tla,zf,cg,Sla,Rla,Qla,Jla,Ila,Hla,Tp,Nla,Mla,Ip,Pp,cT,Ola,uc,uc,Lla,zc,Nq,Jn,zc,vj,Op,Ela,Kt,Dla,Ala,tA,Np,zla,Mt,Ky,HT,yla,Tl,xla,wla,QS,gg,vla,ula,kG,Sl,nt,tla,lea,zT,sla,rla,xg,KS,Jn,Up,Tp,uc,qla,pla,KS,BS,CK,faa,ux,vS,gla,fla,ph,cla,bla,_aa,_ka,Zka,Yka,Xka,Bu,Wka,Vka,Uka,Ff,NU,Tka,gga,hga,Ska,Rka,ela,Bn,QU,Qka,op,OU,qS,Oka,Nka,nba,bd,Mka,Lka,pS,Kka,GU,Jka,Ika,Hka,oS,Gka,Ty,Fka,Eka,MU,lT,dla,Dka,mS,Cka,Uz,hO,cC,kq,Bka,Aka,Dm,Waa,zka,yka,lS,lS,Tz,hS,Qz,al,xka,sW,wka,vka,uka,tka,kh,Xda,kh,N9,ska,n9,gS,uc,hka,Vi,Bd,An,nka,fka,bB,ho,ri,uc,LR,eka,cka,fS,rka,qka,xf,pka,Gi,Ct,o9,bba,f9,oka,iq,mka,lka,kka,Zc,Ek,Zc,Jz,ie,_R,Eg,Mz,ie,Mz,zc,jka,zc,zc,ika,fh,zt,gka,Zja,Yja,Xja,yg,Hn,Wja,Vja,ZC,Uja,Tja,Rja,Qja,Pja,Oja,Nja,Mja,Lja,uc,Gja,Fja,Kja,Jja,Ija,zc,sR,Jn,rR,Hja,uc,lR,Bn,Cja,Bja,Aja,zja,hea,Ff,yja,xja,wja,vja,HS,jO,Jb,wt,zz,Yz,id,tu,uja,tja,iR,sja,Et,eA,rja,Hj,qja,iq,Ff,gu,Ff,Ju,hq,pja,Gi,fR,aea,mx,eR,Bp,uc,Ek,Zc,uc,zc,oja,fh,zt,zc,ie,zc,zc,nja,nu,YA,mja,Eg,jja,ija,Vi,hja,gja,tz,qt,fja,eja,dja,cja,bja,aja,zB,$ia,_ia,Db,Zia,Yia,Xia,Wia,fga,eda,GC,Via,Db,pt,k1,Oz,l1,pt,Tia,Sia,m1,n1,Xaa,Ria,jS,iS,oO,Bi,Qia,Pia,Oia,Nia,Mia,uc,zt,uc,Lia,Nq,Pi,zc,VA,Tt,ot,zj,ri,Ff,Op,Aia,zia,Jia,yt,zc,via,OA,KA,uia,Yaa,tia,ria,nK,An,qia,gQ,pia,oia,xu,wu,lt,Pba,nia,lia,Ys,kia,Kn,jia,iia,dz,gq,uc,zc,gia,fia,AC,Ff,aia,eg,$ha,Zc,Zha,Yha,TP,Zc,lq,Xha,Tha,Sha,Hk,nn,lt,Rha,eaa,Qha,NP,uc,zt,zc,Oha,fh,Lha,Kha,hA,UP,FP,hu,Jha,Iha,Hha,Gha,Kla,Fha,Eha,Dha,ht,Cha,Bha,ht,Aha,yA,BP,yha,RU,uc,rha,oha,nha,Op,uha,tha,sha,uc,Jn,qha,Up,Tp,pha,sP,rP,Vy,uc,iha,Bn,hha,eha,BO,gQ,Bn,gda,fda,aha,Xga,Wga,bv,Vga,Uga,Tga,Sga,Rga,st,Qga,Oga,Nga,Lga,Kga,Jga,uc,Hga,Gga,Ega,Iga,zc,Fga,uc,uc,FO,Bga,cz,Aga,zga,bea,wga,vga,Baa,uga,tga,sga,zaa,rga,Aaa,Caa,qga,pga,oga,hW,hD,eea,jz,gba,eba,Ny,nga,mga,uc,My,kga,fh,zc,CO,jga,ega,dga,cga,bga,aga,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Qfa,Pfa,Ofa,Mfa,Lfa,Kfa,Jfa,Ifa,Hfa,Gfa,Ffa,Efa,Dfa,Bfa,Afa,zfa,yfa,xfa,wfa,vfa,ufa,tfa,sfa,rfa,qfa,pfa,ofa,nfa,mfa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,efa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Vea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Lea,Kea,Jea,Iea,Hea,Gea,Eea,Dea,Cea,Bea,Aea,zea,yea,xea,vea,uea,tea,sea,rea,qea,pea,oea,nea,mea,kea,jea,gea,kO,iea,Ek,Zc,uc,Mn,Eg,Nda,Ej,cea,dea,dB,WN,_da,uc,Lda,Yda,KN,Kda,Wda,Vda,Uda,Tda,Sda,SN,Rda,Qda,Pda,Oda,fS,Ts,Jda,Mda,LN,uc,zN,Zc,Ida,Zc,Gda,Fda,Eda,sN,Dda,aB,Cda,pD,Bda,pN,Naa,Ada,zda,ns,Laa,xda,Kaa,Jaa,wda,uda,tda,sda,qda,pda,uc,uc,rda,zc,uc,oda,zc,pj,uc,jda,ida,kda,hda,Ew,o1,Ls,dda,cba,wj,fea,Dy,cda,vT,Mn,Mn,at,bD,Ek,Zc,Ev,wE,ie,ada,Eg,uc,Vz,$d,yB,ZU,Me,PT,$ca,_ca,Db,Pla,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Oba,nda,Nba,Mba,Lba,cN,bN,Kba,Jba,en,Ds,hy,Iba,MM,$s,ep,LM,hL,vL,Ix,dp,Cs,cp,Fba,GM,pO,sO,Eba,Dba,Gi,Ct,Bp,yN,Os,Mh,Gi,fR,Cba,Bp,lda,uc,yba,xba,Ek,Zc,Zc,Ek,Zc,uc,zc,ie,zc,XL,wba,Eg,ie,zc,vba,Eg,sba,$da,iga,OL,UL,rba,Raa,qba,LL,Pe,Zc,Zc,uc,oba,mba,RV,jV,hV,bV,kba,aV,iV,QV,gV,i8,jba,Tx,Daa,uc,Hda,uc,Zm,fh,Zc,fba,dba,D9,I9,aba,G9,C9,Zc,Zc,Iy,$aa,lO,uc,uc,Vaa,Uaa,zc,yga,xga,ala,$ka,gha,fha,$ga,_ga,Eja,Dja,eia,dia,aka,_ja,LT,KT,ola,nla,hU,gU,WT,VT,cia,bia,lha,kha,Dga,Cga,cma,bma,Gla,Fla,BU,AU,zU,yU,Nha,Mha,xha,vha,xia,wia,bka,ER,lla,kla,ila,hla,hma,gma,Cla,Bla,Wha,Uha,yaa,xaa,haa,gaa,Dia,Cia,cha,bha,Zga,Yga,Kia,Fia,Eia,FU,EU,NT,MT,lja,kja,Iia,Hia,Paa,uc,Zm,fh,Oaa,Ek,Zc,PL,zc,cE,Jz,Eg,CO,Maa,yx,Rs,Gaa,Haa,VM,waa,vaa,hA,uaa,Xt,taa,FP,saa,raa,qaa,Op,paa,oaa,Ff,naa,maa,laa,kaa,jaa,BP,iaa,t1,q1,p1,uc,Jn,Up,Tp,daa,caa,baa,LR,_9,U9,kh,Y9,X9,kh,Sz,W9,Gf,Wg,hl,V9,T9,S9,M9,R9,aaa,Q9,K9,J9,O9,Z9,L9,px,uc,eK,uc,Ek,Zc,r9,fh,p9,jx,Gi,Ct,E9,c8,q9,A9,z9,kh,y9,x9,w9,cK,H9,Mo,SN,v9,xf,bK,t9,Nj,Wg,My,_R,Eg,m9,l9,k9,j9,i9,h9,Zi,g9,SJ,u9,B9,RJ,e9,c9,b9,a9,q8,$8,_8,FJ,M8,DJ,fh,aK,L8,J8,K8,zc,My,zc,JJ,IJ,IJ,R8,ic,He,ic,ic,ic,zc,Hq,V8,W8,Y8,X8,Z8,ti,hx,hx,gx,gx,gx,wma,He,ER,Q8,P8,O8,N8,U8,si,KJ,p8,ic,ic,se,fx,re,re,se,T8,S8,zc,He,zc,He,H8,t8,tJ,sJ,sJ,s8,ic,He,ic,ic,ic,zc,Pga,xJ,F8,v8,u8,G8,ti,D8,C8,B8,A8,z8,y8,x8,w8,E8,si,wJ,ic,ic,se,re,re,se,vJ,uJ,m8,l8,mJ,uc,uc,bf,ih,n8,lJ,o8,ic,k8,j8,h8,Ws,g8,f8,e8,d8,Zc,fh,Ts,uc,Zm,zc,b8,S7,K7,D7,w7,p7,f7,X6,Q6,d9,I8,hJ,ax,X7,gJ,W7,ic,He,ic,ic,ic,zc,kR,_7,$7,a8,ti,Z7,si,Y7,ic,ic,se,re,re,zc,He,fJ,V7,U7,eJ,T7,dJ,cJ,R7,$I,_I,_I,M7,ic,He,ic,ic,ic,zc,L7,O7,P7,Q7,ti,N7,si,aJ,ic,ic,se,re,re,J7,ik,ik,E7,ic,He,ic,ic,ic,zc,KK,G7,H7,I7,ti,F7,si,XI,ic,ic,se,re,re,C7,TI,SI,SI,x7,ic,He,ic,ic,ic,zc,KK,z7,A7,B7,ti,y7,si,UI,ic,ic,se,re,re,v7,RI,RI,t7,kR,u7,fJ,s7,r7,eJ,q7,dJ,cJ,o7,ik,ik,i7,ic,He,ic,ic,ic,zc,re,l7,m7,n7,ti,j7,si,h7,ic,ic,se,re,re,e7,g7,LI,KI,KI,_6,ic,He,ic,ic,Z6,zc,Y6,a7,b7,d7,ti,$6,si,Zw,ic,ic,se,re,re,zc,He,W6,ik,ik,R6,ic,He,ic,ic,ic,zc,SV,T6,U6,V6,ti,S6,si,II,ic,ic,se,re,re,P6,ik,ik,K6,ic,He,ic,ic,ic,zc,Hq,M6,N6,O6,ti,L6,si,FI,ic,ic,se,re,re,q4,I6,x4,h4,p4,o4,W3,fv,T3,Yr,vI,P3,w6,v6,Zc,Zc,Q3,O3,N3,M3,ie,ja,r6,q6,vI,K3,I3,qI,n6,Vw,QH,Cz,s3,r3,v3,p3,q3,t3,Xw,H3,Y5,kI,G3,F3,D3,C3,B3,A3,z3,y3,x3,w3,o3,Xw,i3,h3,g3,f3,e3,d3,c3,b3,a3,$2,_2,Z2,Y2,W2,Eo,V2,U2,nl,Qr,T2,DD,S2,P2,O2,N2,M2,L2,K2,Nw,J2,I2,G2,F2,E2,C2,A2,y2,w2,u2,_3,cI,bI,aI,$H,R1,Q1,qI,Xw,P4,O4,N4,M4,L4,K4,J4,I4,H4,G4,F4,E4,D4,C4,B4,A4,z4,y4,w4,t4,Uw,v4,u4,mI,r4,mI,s4,YC,Wr,n4,bda,Iq,l4,k4,uc,g2,i4,BH,f2,Es,c4,uc,XL,e2,uba,Z3,FD,FO,Zc,Zc,Zc,z2,s2,x2,v2,lba,b4,m4,g4,Ru,Gi,Ct,Bp,qu,X3,Saa,Qaa,V3,iI,hI,R3,S3,Zc,o2,n2,$3,VH,Y3,d4,Zc,Zc,Zc,Db,gc,J3,u3,Zc,Zc,AL,n3,m3,l3,S1,hba,iba,f4,Zaa,k3,j3,Pm,MH,P9,Q2,rj,lK,H2,Xe,wL,BK,AK,D2,uc,Eg,m2,Eg,j2,Mz,zc,T1,uc,ih,Ur,r2,j4,ie,ih,ie,Oc,q2,p2,ih,FH,l2,ao,k2,DH,i2,ao,h2,Oc,d2,ie,Oc,c2,b2,Oc,wH,vH,ih,Oc,$1,_1,Oc,uH,tH,Oc,Z1,Y1,Oc,sH,rH,Oc,W1,V1,Oc,qH,pH,Fw,mH,M1,L1,lH,kH,jH,iH,hH,gH,fH,eH,dH,cH,bH,aH,$G,_G,ZG,YG,P1,N1,K1,J1,I1,H1,G1,F1,E1,D1,C1,B1,A1,z1,y1,w1,v1,u1,ie,ih,ie,ih,s1,r1,i1,g1,c1,b1,a1,_0,$0,Y0,ic,X0,W0,V0,Rr,Rr,dw,cw,mr,GF,jl,bG,U0,RF,QF,T0,S0,R0,or,uo,ZF,Q0,Cl,RF,QF,ic,ic,l0,P0,O0,N0,j0,or,bG,M0,XF,PF,or,L0,K0,ZF,J0,XF,PF,k0,or,I0,H0,G0,w0,gX,UF,$v,ie,Oc,B0,F0,E0,C0,A0,Oc,z0,x0,y0,v0,u0,WF,_m,f0,c0,t0,e0,_$,Q$,X$,Yv,W$,mla,jla,MS,U$,_m,Ag,T$,S$,R$,Q$,P$,yF,He,M$,wF,s0,n0,zc,nr,Zv,NF,MF,kr,Wv,AF,zF,Oc,O$,N$,L$,_v,J$,ah,SF,ah,SF,G$,Lv,_g,Zg,hr,Xb,yv,to,fj,bk,Kv,il,ro,Zj,q$,Ee,ei,ng,o$,m$,XE,XE,i$,gr,g$,WE,fi,d$,b$,Bc,le,$_,E$,Ov,Xv,Iv,_g,Zg,fr,lr,_j,gl,Nk,Bm,Yj,ei,ng,er,VE,fi,N_,Wj,I_,H_,ro,D$,Rv,e1,xF,B_,jr,qo,Vl,w_,wm,ro,Pv,He,c_,ar,b_,a_,IE,$Z,HE,ro,ZZ,eo,XZ,WZ,$j,VZ,CE,HE,TZ,jX,RZ,QZ,NZ,MZ,Qv,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,oZ,nZ,mZ,lZ,jZ,iZ,hZ,gZ,fZ,eZ,dZ,cZ,bZ,aZ,$Y,_Y,ZY,YY,XY,uE,YD,My,RY,VY,rX,WY,qX,pX,ie,TY,SY,QY,C$,B$,A$,fF,ck,eF,so,qY,pY,dF,cF,bF,YX,XX,VX,UX,SX,RX,PX,OX,MX,LX,JX,IX,GX,Av,EX,CX,AX,yX,wX,uX,sX,RD,zc,gE,UY,gJ,eE,EY,DY,CY,BY,AY,wB,zY,yY,xY,yE,vY,uY,tY,sY,rY,ic,oY,nY,aE,gY,eY,dY,MH,bY,$X,$D,fY,Cz,SU,cY,aY,_X,ie,Oc,Oc,PY,OY,NY,MY,LY,KY,JY,IY,wB,HY,GY,FY,Oc,dE,dE,Cv,se,se,wY,se,Oc,mY,lY,Cv,ic,ic,kY,Hq,Oc,jY,iY,Cv,ic,ic,hY,Hq,ie,Oc,z$,y$,x$,ie,Oc,w$,v$,u$,Oc,t$,r$,p$,n$,l$,k$,j$,h$,f$,c$,a$,Oc,__,Z_,Y_,X_,W_,V_,U_,T_,S_,R_,Q_,Oc,P_,O_,M_,L_,K_,J_,G_,F_,Oc,E_,C_,A_,z_,y_,x_,v_,u_,ie,Oc,re,t_,s_,r_,q_,o_,n_,ZX,TX,NX,zX,vX,HX,DX,ie,Oc,re,m_,l_,k_,j_,i_,h_,WX,QX,KX,xX,tX,FX,BX,zv,ZD,g_,zv,ZD,f_,Oc,$q,$q,Uj,Uj,Uj,LE,ic,Tj,Tj,Oc,$q,$q,Uj,Uj,Uj,LE,ic,Tj,Tj,Oc,vs,vs,Uj,_q,_q,KE,ic,Tj,Tj,Oc,vs,vs,Uj,_q,_q,KE,ic,Tj,Tj,Oc,d_,_Z,Oc,YZ,UZ,Oc,SZ,PZ,Oc,OZ,LZ,Oc,zE,KZ,zc,Oc,zE,JZ,zc,TF,mX,ie,ih,ih,ic,ic,ic,LD,MD,PD,YE,hX,Ra,uG,fX,eX,bX,cX,dX,Oc,_W,Oc,$W,ZW,Bt,YW,rv,rv,rv,Vu,Oc,XW,ie,Oc,He,He,WW,NW,QW,VW,Oc,OW,RW,UW,Oc,PW,SW,TW]);function ob(){return s.byteLength/65536|0}function tb(ub){ub=ub|0;var pb=ob()|0;var qb=pb+ub|0;if(pb<qb&&qb<65536){var rb=new ArrayBuffer(B(qb,65536));var sb=new Int8Array(rb);sb.set(t);t=new Int8Array(rb);u=new Int16Array(rb);v=new Int32Array(rb);w=new Uint8Array(rb);x=new Uint16Array(rb);y=new Uint32Array(rb);z=new Float32Array(rb);A=new Float64Array(rb);s=rb;r.buffer=s;e=w}return pb}return{"ya":IT,"za":nb,"Aa":J6,"Ba":G6,"Ca":Oc,"Da":Xb,"Ea":F6,"Fa":E6,"Ga":D6,"Ha":Yr,"Ia":zc,"Ja":C6,"Ka":B6,"La":A6,"Ma":hx,"Na":y6,"Oa":yI,"Pa":x6,"Qa":ie,"Ra":xI,"Sa":wI,"Ta":xI,"Ua":t6,"Va":HW,"Wa":GW,"Xa":FW,"Ya":s6,"Za":sI,"_a":p6,"$a":rI,"ab":o6,"bb":m6,"cb":l6,"db":k6,"eb":j6,"fb":i6,"gb":h6,"hb":g6,"ib":f6,"jb":e6,"kb":c6,"lb":b6,"mb":a6,"nb":$5,"ob":_5,"pb":Z5,"qb":X5,"rb":W5,"sb":U5,"tb":T5,"ub":S5,"vb":R5,"wb":Q5,"xb":P5,"yb":O5,"zb":N5,"Ab":M5,"Bb":L5,"Cb":K5,"Db":J5,"Eb":I5,"Fb":H5,"Gb":G5,"Hb":F5,"Ib":E5,"Jb":D5,"Kb":C5,"Lb":B5,"Mb":z5,"Nb":y5,"Ob":x5,"Pb":w5,"Qb":v5,"Rb":u5,"Sb":t5,"Tb":s5,"Ub":r5,"Vb":q5,"Wb":p5,"Xb":o5,"Yb":n5,"Zb":m5,"_b":l5,"$b":k5,"ac":j5,"bc":i5,"cc":h5,"dc":g5,"ec":e5,"fc":d5,"gc":c5,"hc":b5,"ic":a5,"jc":EW,"kc":$4,"lc":_4,"mc":Z4,"nc":Y4,"oc":DW,"pc":X4,"qc":V4,"rc":U4,"sc":T4,"tc":S4,"uc":R4,"vc":Q4,"wc":pd,"xc":uG,"yc":KW,"zc":JW,"Ac":IW,"Bc":Z0,"Cc":MW,"Dc":LW,"Ec":CW,"Fc":BW,"Gc":AW,"Hc":zW,"Ic":uW,"Jc":yW,"Kc":xW,"Lc":wW,"Mc":vW,"Nc":uW,"Oc":tW}}return vb(xb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


